(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     52306,       1338]
NotebookOptionsPosition[     49561,       1248]
NotebookOutlinePosition[     50332,       1274]
CellTagsIndexPosition[     50289,       1271]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Load packages", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<CUDALink`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Calendar`\>\"", "]"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Code", "Section",
 CellChangeTimes->{{3.520786469854125*^9, 3.52078648436975*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dividends", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<DividendYield\>\"", ",", "\"\<DividendPerShare\>\"", ",", 
     "\"\<Dividend\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"LongTermTrends", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Average200Day\>\"", ",", "\"\<Average50Day\>\"", ",", 
     "\"\<AverageVolume3Month\>\"", ",", "\"\<Change200Day\>\"", ",", 
     "\"\<Change50Day\>\"", ",", "\"\<ChangeHigh52Week\>\"", ",", 
     "\"\<ChangeLow52Week\>\"", ",", "\"\<CumulativeFractionalChange\>\"", 
     ",", "\"\<CumulativeReturn\>\"", ",", "\"\<FractionalChange\>\"", ",", 
     "\"\<FractionalChange200Day\>\"", ",", "\"\<FractionalChange50Day\>\"", 
     ",", "\"\<FractionalChangeHigh52Week\>\"", ",", 
     "\"\<FractionalChangeLow52Week\>\"", ",", "\"\<Volatility20Day\>\"", 
     ",", "\"\<Volatility50Day\>\"", ",", "\"\<High52Week\>\"", ",", 
     "\"\<Low52Week\>\"", ",", "\"\<Range52Week\>\""}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"DailyPriceProperties", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Change\>\"", ",", "\"\<Close\>\"", ",", "\"\<FractionalChange\>\"", 
     ",", "\"\<High\>\"", ",", "\"\<Low\>\"", ",", "\"\<Open\>\"", ",", 
     "\"\<OHLC\>\"", ",", "\"\<OHLCV\>\"", ",", "\"\<Range\>\"", ",", 
     "\"\<Return\>\"", ",", "\"\<Volume\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RecentPriceProperties", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Bid\>\"", ",", "\"\<Ask\>\"", ",", "\"\<LatestTrade\>\"", ",", 
     "\"\<Price\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RawDailyPriceProperties", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<RawClose\>\"", ",", "\"\<RawHigh\>\"", ",", "\"\<RawLow\>\"", ",", 
     "\"\<RawOHLC\>\"", ",", "\"\<RawOpen\>\"", ",", "\"\<RawRange\>\""}], 
    "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Fundamentals", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<BookValuePerShare\>\"", ",", "\"\<FloatShares\>\"", ",", 
     "\"\<ForwardPERatio\>\"", ",", "\"\<MarketCap\>\"", ",", 
     "\"\<PEGRatio\>\"", ",", "\"\<PriceTarget\>\"", ",", 
     "\"\<PriceToBookRatio\>\"", ",", "\"\<PriceToSalesRatio\>\"", ",", 
     "\"\<ShortRatio\>\"", ",", "\"\<YearPERatioEstimate\>\""}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Earnings", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<EarningsPerShare\>\"", ",", "\"\<EBITDA\>\"", ",", 
     "\"\<ForwardEarnings\>\"", ",", "\"\<QuarterForwardEarnings\>\"", ",", 
     "\"\<YearEarningsEstimate\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "financialDataProperties", "]"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "financialDataProperties", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Properties\>\"", "\[Rule]", "All"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "\"\<Dividends\>\"", ",", "\"\<LongTermTrends\>\"", ",", 
      "\"\<DailyPriceProperties\>\"", ",", "\"\<RecentPriceProperties\>\"", 
      ",", "\"\<RawDailyPriceProperties\>\"", ",", "\"\<Fundamentals\>\"", 
      ",", "\"\<Earnings\>\""}], " ", "*)"}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"financialDataProperties", "[", 
   RowBox[{"name_String", ",", 
    RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"optVal", "=", 
       RowBox[{"OptionValue", "[", "\"\<Properties\>\"", "]"}]}], ",", 
      "props", ",", "heading", ",", "cases"}], "}"}], ",", 
    RowBox[{
     RowBox[{"props", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{"optVal", ",", "All", ",", 
        RowBox[{"FinancialData", "[", 
         RowBox[{"name", ",", "\"\<Properties\>\""}], "]"}], ",", 
        "\"\<Dividends\>\"", ",", "Dividends", ",", "\"\<LongTermTrends\>\"", 
        ",", "LongTermTrends", ",", "\"\<DailyPriceProperties\>\"", ",", 
        "DailyPriceProperties", ",", "\"\<RecentPriceProperties\>\"", ",", 
        "RecentPriceProperties", ",", "\"\<RawDailyPriceProperties\>\"", ",", 
        "RawDailyPriceProperties", ",", "\"\<Fundamentals\>\"", ",", 
        "Fundamentals", ",", "\"\<Earnings\>\"", ",", "Earnings", ",", "_", 
        ",", 
        RowBox[{"FinancialData", "[", 
         RowBox[{"name", ",", "\"\<Properties\>\""}], "]"}]}], "]"}]}], ";", 
     RowBox[{"heading", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{
       "optVal", ",", "All", ",", "\"\<All Properties\>\"", ",", 
        "\"\<Dividends\>\"", ",", "\"\<Dividend Properties\>\"", ",", 
        "\"\<LongTermTrends\>\"", ",", "\"\<Long Term Trend Properties\>\"", 
        ",", "\"\<DailyPriceProperties\>\"", ",", 
        "\"\<Daily Price Properties\>\"", ",", 
        "\"\<RecentPriceProperties\>\"", ",", 
        "\"\<Recent Price Properties\>\"", ",", 
        "\"\<RawDailyPriceProperties\>\"", ",", 
        "\"\<Raw Daily Price Properties\>\"", ",", "\"\<Fundamentals\>\"", 
        ",", "\"\<Fundamental Properties\>\"", ",", "\"\<Earnings\>\"", ",", 
        "\"\<Earning Properties\>\"", ",", "_", ",", 
        "\"\<All Properties\>\""}], "]"}]}], ";", 
     RowBox[{"cases", "=", 
      RowBox[{"Cases", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"props", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"FinancialData", "[", 
              RowBox[{"name", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
            "props"}]}], "}"}], "]"}], ",", 
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"_", ",", 
            RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "}"}], 
          "|", 
          RowBox[{"{", 
           RowBox[{"_", ",", "_FinancialData"}], "}"}], "|", 
          RowBox[{"{", 
           RowBox[{"_", ",", 
            RowBox[{"{", 
             RowBox[{"_List", ",", "_"}], "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
     ";", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Grid", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Transpose", " ", "/@", " ", 
            RowBox[{"Switch", "[", 
             RowBox[{"optVal", ",", "\"\<LongTermTrends\>\"", ",", 
              RowBox[{"Partition", "[", 
               RowBox[{"cases", ",", "3", ",", "3", ",", "1", ",", 
                RowBox[{"{", "}"}]}], "]"}], ",", "_", ",", 
              RowBox[{"Partition", "[", 
               RowBox[{"cases", ",", "4", ",", "4", ",", "1", ",", 
                RowBox[{"{", "}"}]}], "]"}]}], "]"}]}], ",", "1"}], "]"}], 
         ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Alignment", "\[Rule]", 
          RowBox[{"{", "Left", "}"}]}], ",", 
         RowBox[{"Background", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"None", ",", 
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Lighter", "[", 
                RowBox[{
                 RowBox[{"Blend", "[", 
                  RowBox[{"{", 
                   RowBox[{"Blue", ",", "Green"}], "}"}], "]"}], ",", ".8"}], 
                "]"}], ",", 
               RowBox[{"Lighter", "[", 
                RowBox[{"Yellow", ",", ".9"}], "]"}]}], "}"}], "}"}]}], 
           "}"}]}]}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"heading", "<>", "\"\< of \>\"", "<>", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"MatchQ", "[", 
             RowBox[{
              RowBox[{"FinancialData", "[", 
               RowBox[{"name", ",", "\"\<Name\>\""}], "]"}], ",", 
              RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "]"}], 
            ",", "name", ",", 
            RowBox[{"FinancialData", "[", 
             RowBox[{"name", ",", "\"\<Name\>\""}], "]"}]}], "]"}]}], ",", 
         RowBox[{"FontColor", "\[Rule]", "Blue"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",",
        "Top"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5838509689830904`*^9, 3.583850993063468*^9}, 
   3.5838512554654765`*^9, {3.5838520716441593`*^9, 3.583852072916232*^9}, {
   3.5838521624123507`*^9, 3.5838521967323136`*^9}, {3.583852299133171*^9, 
   3.5838523065885973`*^9}, {3.5838523373253555`*^9, 
   3.5838523495980573`*^9}, {3.583852383981024*^9, 3.583852401149006*^9}, {
   3.5838524827976756`*^9, 3.583852494798362*^9}, {3.5838526947848005`*^9, 
   3.5838526963358893`*^9}, {3.5838528147526627`*^9, 
   3.5838528517447786`*^9}, {3.5838550212408667`*^9, 3.583855026153147*^9}, {
   3.5838550602170954`*^9, 3.583855109002886*^9}, {3.583868635378916*^9, 
   3.5838686644189568`*^9}, {3.5838687659490986`*^9, 3.5838687747491107`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SimpleMovingAverage", "[", 
     RowBox[{"list_", ",", "n_Integer"}], "]"}], "/;", 
    RowBox[{"(", 
     RowBox[{"n", "<=", " ", 
      RowBox[{"Length", "[", "list", "]"}]}], ")"}]}], ":=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Mean", " ", "/@", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Take", "[", 
         RowBox[{"list", ",", "k"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"MovingAverage", "[", 
      RowBox[{"list", ",", "n"}], "]"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TrendLinesDateListPlot", "[", 
   RowBox[{
   "tickSymbol_String", ",", "proportions_List", ",", "dateRange_List"}], 
   "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"data", "=", 
       RowBox[{"FinancialData", "[", 
        RowBox[{"tickSymbol", ",", "\"\<Close\>\"", ",", "dateRange"}], 
        "]"}]}], ",", 
      RowBox[{"props", "=", "proportions"}], ",", "trdata", ",", "datarange", 
      ",", "x", ",", "lmfns", ",", "lmdata", ",", "titles"}], "}"}], ",", 
    RowBox[{
     RowBox[{"trdata", "=", 
      RowBox[{"Transpose", "[", "data", "]"}]}], ";", 
     RowBox[{"datarange", "=", 
      RowBox[{"Outer", "[", 
       RowBox[{"Times", ",", 
        RowBox[{"Sort", "[", "props", "]"}], ",", 
        RowBox[{"trdata", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";", 
     RowBox[{"lmfns", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"LinearModelFit", "[", 
         RowBox[{"#", ",", "x", ",", "x"}], "]"}], "&"}], " ", "/@", " ", 
       "datarange"}]}], ";", 
     RowBox[{"lmdata", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"Length", "[", "data", "]"}], ",", "1"}], "]"}], 
              "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"lmfns", "[", 
               RowBox[{"[", "k", "]"}], "]"}], "[", 
              RowBox[{"Length", "[", "data", "]"}], "]"}]}], "}"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "[", "lmfns", "]"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"titles", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ToString", "[", "#", "]"}], "<>", "\"\< %\>\""}], "&"}], 
       " ", "/@", " ", 
       RowBox[{"Round", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"props", "-", "1"}], "]"}], " ", "100"}], "]"}]}]}], ";", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Framed", "[", 
        RowBox[{"DateListPlot", "[", 
         RowBox[{
          RowBox[{"Prepend", "[", 
           RowBox[{"lmdata", ",", "data"}], "]"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"Frame", "\[Rule]", "False"}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<dates\>\"", ",", "\"\<Prices\>\""}], "}"}]}], ",", 
          RowBox[{"Epilog", "\[RuleDelayed]", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{
               RowBox[{"titles", "[", 
                RowBox[{"[", "k", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"data", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"-", "2"}], ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"lmfns", "[", 
                   RowBox[{"[", "k", "]"}], "]"}], "[", 
                  RowBox[{"Length", "[", "data", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1", ",", 
               RowBox[{"Length", "[", "lmfns", "]"}]}], "}"}]}], "]"}]}]}], 
         "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MatchQ", "[", 
           RowBox[{
            RowBox[{"FinancialData", "[", 
             RowBox[{"tickSymbol", ",", "\"\<Name\>\""}], "]"}], ",", 
            RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "]"}], 
          ",", "tickSymbol", ",", 
          RowBox[{"FinancialData", "[", 
           RowBox[{"tickSymbol", ",", "\"\<Name\>\""}], "]"}]}], "]"}], "<>", 
        "\"\< with \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"Length", "[", "props", "]"}], "]"}], "<>", 
        "\"\< Trend Lines\>\""}], ",", "Top"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5402394418035975`*^9, 3.5402394524032035`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DailyRangeData", "[", 
   RowBox[{"dataName_String", ",", "numbDaysOfData_Integer"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "data", ",", "rangeData", ",", "dailyGroups", ",", "rangeLists", ",", 
      "days", ",", "name"}], "}"}], ",", 
    RowBox[{
     RowBox[{"data", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"dataName", ",", " ", "\"\<Range\>\"", ",", 
        RowBox[{"DatePlus", "[", 
         RowBox[{"-", "numbDaysOfData"}], "]"}]}], "]"}]}], ";", "\n", 
     RowBox[{"rangeData", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"Subtract", " ", "@@", " ", 
           RowBox[{"Reverse", "[", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "}"}], "&"}], " ", "/@",
        " ", "data"}]}], ";", "\n", 
     RowBox[{"dailyGroups", "=", 
      RowBox[{"GatherBy", "[", 
       RowBox[{"rangeData", ",", 
        RowBox[{
         RowBox[{"DayOfWeek", "[", 
          RowBox[{"First", "[", "#", "]"}], "]"}], "&"}]}], "]"}]}], ";", 
     "\n", 
     RowBox[{"rangeLists", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "&"}], ",", " ", "dailyGroups", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"days", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"DayOfWeek", "[", 
         RowBox[{"First", "[", "#", "]"}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"dailyGroups", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], ";", 
     RowBox[{"name", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"dataName", ",", "\"\<Name\>\""}], "]"}]}], ";", "\n", 
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"BoxWhiskerChart", "[", 
         RowBox[{"rangeLists", ",", 
          RowBox[{"ChartLabels", "\[Rule]", "days"}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{
           "\"\<Box-Whisker plots for \>\"", "<>", "name", "<>", 
            "\"\< daily Ranges\>\""}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"350", ",", "200"}], "}"}]}]}], "]"}], ",", " ", 
        RowBox[{"TableForm", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Through", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
               "Length", ",", "Mean", ",", " ", "Median", ",", 
                "StandardDeviation"}], "}"}], "[", "#", "]"}], "]"}], "&"}], 
           " ", "/@", " ", "rangeLists"}], ",", " ", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"days", ",", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Number\>\"", ",", "Mean", ",", " ", "Median", ",", 
               "StandardDeviation"}], "}"}]}], "}"}]}]}], "]"}]}], "}"}], 
      "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"financialDataComparisons", "[", 
   RowBox[{
    RowBox[{"dataNames", ":", 
     RowBox[{"{", "__String", "}"}]}], ",", "numbDays_Integer"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dataArray1", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"#", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "numbDays"}], "]"}], ",", "\"\<Value\>\""}], "]"}], 
         "&"}], " ", "/@", " ", "dataNames"}]}], ",", 
      RowBox[{"returnArray1", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"#", ",", "\"\<Return\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "numbDays"}], "]"}], ",", "\"\<Value\>\""}], "]"}], 
         "&"}], " ", "/@", " ", "dataNames"}]}], ",", "dataPosns", ",", 
      "returnPosns", ",", "dataArray", ",", "returnArray", ",", "datanames", 
      ",", "stats", ",", "returnStats", ",", "trRetStats", ",", " ", 
      "histograms", ",", "rankedMeans", ",", "rankedSDs", ",", "tableStats", 
      ",", "ranktable", ",", "partNumb"}], "}"}], ",", 
    RowBox[{
     RowBox[{"dataPosns", "=", 
      RowBox[{"Position", "[", 
       RowBox[{"dataArray1", ",", 
        StyleBox[
         RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True]}], 
       StyleBox["]",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}], 
     StyleBox[";",
      ShowSpecialCharacters->False,
      ShowStringCharacters->True,
      NumberMarks->True], 
     RowBox[{"returnPosns", "=", 
      RowBox[{"Position", "[", 
       RowBox[{"returnArray1", ",", 
        StyleBox[
         RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True]}], 
       StyleBox["]",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}], 
     StyleBox[";",
      ShowSpecialCharacters->False,
      ShowStringCharacters->True,
      NumberMarks->True], 
     RowBox[{"dataArray", "=", 
      RowBox[{"Delete", "[", 
       RowBox[{"dataArray1", ",", "dataPosns"}], "]"}]}], ";", 
     RowBox[{"returnArray", "=", 
      RowBox[{"Delete", "[", 
       RowBox[{"returnArray1", ",", "returnPosns"}], "]"}]}], ";", 
     RowBox[{"datanames", "=", 
      RowBox[{"Delete", "[", 
       RowBox[{"dataNames", ",", "returnPosns"}], "]"}]}], ";", 
     RowBox[{"returnStats", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Mean", ",", " ", "StandardDeviation"}], "}"}], "[", "#", 
          "]"}], "]"}], "&"}], " ", "/@", " ", "returnArray"}]}], ";", 
     RowBox[{"stats", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Mean", ",", " ", "Median", ",", "StandardDeviation"}], 
           "}"}], "[", "#", "]"}], "]"}], "&"}], " ", "/@", " ", 
       "dataArray"}]}], ";", 
     RowBox[{"trRetStats", "=", 
      RowBox[{"Transpose", "[", "returnStats", "]"}]}], ";", 
     RowBox[{"partNumb", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "datanames", "]"}], "\[GreaterEqual]", "3"}], 
        ",", "3", ",", "2"}], "]"}]}], ";", 
     RowBox[{"tableStats", "=", 
      RowBox[{"TableForm", "[", 
       RowBox[{"stats", ",", 
        RowBox[{"TableHeadings", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"datanames", ",", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Mean\>\"", ",", " ", "\"\<Median\>\"", ",", 
             "\"\<StandardDeviation\>\""}], "}"}]}], "}"}]}]}], "]"}]}], ";", 
     RowBox[{"rankedMeans", "=", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Sort", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"trRetStats", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "datanames"}], "}"}], 
           "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#1", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ">", 
            RowBox[{"#2", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", 
     RowBox[{"rankedSDs", "=", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Sort", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"trRetStats", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "datanames"}], "}"}], 
           "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#1", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "<", 
            RowBox[{"#2", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", 
     RowBox[{"ranktable", "=", 
      RowBox[{"TableForm", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"rankedMeans", ",", "rankedSDs"}], "}"}], "]"}], ",", 
        RowBox[{"TableHeadings", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"None", ",", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Decr. Ranked \\nReturn Means\>\"", ",", " ", 
             "\"\<Incr. Ranked \\nReturn SDs\>\""}], "}"}]}], "}"}]}]}], 
       "]"}]}], ";", 
     RowBox[{"histograms", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"MapThread", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Histogram", "[", 
              RowBox[{
              "#1", ",", "Automatic", ",", "\"\<ProbabilityDensity\>\"", ",", 
               RowBox[{"PlotLabel", "\[Rule]", 
                RowBox[{"\"\<Prob Density of \>\"", "<>", "#2"}]}]}], "]"}], 
             "&"}], ",", 
            RowBox[{"{", 
             RowBox[{"dataArray", ",", "datanames"}], "}"}]}], "]"}], ",", 
          "partNumb", ",", "partNumb", ",", "1", ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"800", ",", "570"}], "}"}]}]}], "]"}]}], ";", 
     RowBox[{"Column", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Row", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"tableStats", ",", "ranktable"}], "}"}], ",", 
           "\"\<        \>\""}], "]"}], ",", "histograms"}], "}"}], ",", 
       "\"\<      \>\""}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Signer", "[", "x_", "]"}], ":=", 
   RowBox[{"Which", "[", 
    RowBox[{
     RowBox[{"x", ">", "0"}], ",", "\"\<+\>\"", ",", 
     RowBox[{"x", "\[Equal]", "0"}], ",", "\"\< \>\"", ",", "True", ",", 
     "\"\<\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "FromFractionalChangeToPercentString", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<Sign\>\"", "\[Rule]", "True"}], ",", 
      RowBox[{"\"\<DecimalDigits\>\"", "\[Rule]", "2"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FromFractionalChangeToPercentString", "[", 
     RowBox[{"xx_", ",", 
      RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", "=", 
        RowBox[{"Chop", "@", "xx"}]}], "}"}], ",", 
      RowBox[{"StringJoin", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"OptionValue", "[", "\"\<Sign\>\"", "]"}], ",", 
          RowBox[{"Signer", "@", "x"}], ",", "\"\<\>\""}], "]"}], ",", 
        RowBox[{"ToString", "@", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{"100", " ", "x"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", 
             RowBox[{"OptionValue", "@", "\"\<DecimalDigits\>\""}]}], "}"}]}],
           "]"}]}], ",", "\"\<%\>\""}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DeltaGammaHedge", "[", 
    RowBox[{"type_", ",", "a_", ",", " ", "b_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tab", ",", "lower", ",", "upper", ",", 
       RowBox[{"price", "=", 
        RowBox[{"FinancialDerivative", "[", 
         RowBox[{"type", ",", " ", "a", ",", " ", "b", ",", "\"\<Value\>\""}],
          "]"}]}], ",", 
       RowBox[{"delta", "=", 
        RowBox[{"FinancialDerivative", "[", 
         RowBox[{"type", ",", " ", "a", ",", " ", "b", ",", "\"\<Delta\>\""}],
          "]"}]}], ",", 
       RowBox[{"gamma", "=", 
        RowBox[{"FinancialDerivative", "[", 
         RowBox[{"type", ",", " ", "a", ",", " ", "b", ",", "\"\<Gamma\>\""}],
          "]"}]}], ",", "myLinearApproximation", ",", 
       "myParabolicApproximation", ",", 
       RowBox[{"underlyingprice", "=", 
        RowBox[{"\"\<CurrentPrice\>\"", "/.", "b"}]}], ",", 
       RowBox[{"strikeprice", "=", 
        RowBox[{"\"\<StrikePrice\>\"", "/.", "a"}]}], ",", 
       RowBox[{"volatility", "=", 
        RowBox[{"\"\<Volatility\>\"", "/.", "b"}]}], ",", 
       RowBox[{"timetoexpiry", "=", 
        RowBox[{"\"\<Expiration\>\"", "/.", "a"}]}], ",", "underlyingrange"}],
       "}"}], ",", " ", "\n", 
     RowBox[{
      RowBox[{
       RowBox[{"myLinearApproximation", "[", "x_", "]"}], ":=", 
       RowBox[{"price", "+", 
        RowBox[{"delta", "*", 
         RowBox[{"(", 
          RowBox[{"x", "-", "underlyingprice"}], ")"}]}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"myParabolicApproximation", "[", "x_", "]"}], ":=", 
       RowBox[{"price", "+", 
        RowBox[{"delta", "*", 
         RowBox[{"(", 
          RowBox[{"x", "-", "underlyingprice"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"gamma", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "underlyingprice"}], ")"}], "^", "2"}]}], 
          ")"}], "/", "2"}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"underlyingrange", "[", "number_", "]"}], ":=", 
       RowBox[{"underlyingprice", "+", 
        RowBox[{"number", "*", "underlyingprice", "*", "volatility", "*", 
         RowBox[{"Sqrt", "[", "timetoexpiry", "]"}]}]}]}], ";", "\n", 
      RowBox[{"lower", "=", 
       RowBox[{"underlyingprice", "-", 
        RowBox[{"1.5", "*", "strikeprice", "*", "volatility", "*", 
         RowBox[{"Sqrt", "[", "timetoexpiry", "]"}]}]}]}], ";", "\n", 
      RowBox[{"upper", "=", 
       RowBox[{"underlyingprice", "+", 
        RowBox[{"1.5", "*", "strikeprice", "*", "volatility", "*", 
         RowBox[{"Sqrt", "[", "timetoexpiry", "]"}]}]}]}], ";", "\n", 
      RowBox[{"tab", "=", 
       RowBox[{"Transpose", "@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"val", ",", 
              RowBox[{"FinancialDerivative", "[", 
               RowBox[{"type", ",", " ", "a", ",", " ", 
                RowBox[{"b", "/.", 
                 RowBox[{
                  RowBox[{"_", "[", 
                   RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "_"}], "]"}], ":>", 
                  RowBox[{"Rule", "[", 
                   RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "val"}], 
                   "]"}]}]}], ",", "\"\<Value\>\""}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"val", ",", 
              RowBox[{"myLinearApproximation", "[", "val", "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"val", ",", 
              RowBox[{"myParabolicApproximation", "[", "val", "]"}]}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"val", ",", "lower", ",", "upper", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"upper", "-", "lower"}], ")"}], "/", "81"}]}], "}"}]}], 
         "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Column", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{"tab", ",", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<underlying price\>\"", ",", "\"\<value\>\"", ",", "None", 
              ",", "None"}], "}"}]}], ",", 
           RowBox[{"AxesOrigin", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"lower", ",", "0"}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"530", ",", "370"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"FontFamily", "\[Rule]", "\"\<Verdana\>\""}], ",", 
              RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"StringJoin", " ", "@", " ", "type"}], ")"}], "<>", 
             "\"\< \[Delta]-\[Gamma] Hedge\>\""}]}], " ", ",", " ", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Value\>\"", ",", " ", "\"\<Delta\>\"", ",", 
              "\"\<Delta-Gamma\>\""}], "}"}]}]}], "]"}], ",", " ", 
         RowBox[{"Spacer", "[", "20", "]"}], ",", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"t", "=", 
             RowBox[{"Module", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"pricemovements", "=", 
                  RowBox[{"(*", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "0.5"}], ",", "0.5", ",", "1"}], "}"}], 
                   "*)"}], 
                  RowBox[{"Select", "[", 
                   RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{
                    RowBox[{"-", "1.2"}], ",", "1.2", ",", ".2"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Chop", "[", "#", "]"}], "=!=", "1000"}], "&"}]}],
                    "]"}]}], ",", "ranges", ",", "truevalues"}], "}"}], ",", 
               RowBox[{
                RowBox[{"ranges", "=", 
                 RowBox[{"N", "[", 
                  RowBox[{"underlyingrange", "/@", "pricemovements"}], 
                  "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"truevalues", "=", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"FinancialDerivative", "[", 
                    RowBox[{"type", ",", " ", "a", ",", " ", 
                    RowBox[{"b", "/.", 
                    RowBox[{
                    RowBox[{"_", "[", 
                    RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "_"}], "]"}], ":>", 
                    RowBox[{"Rule", "[", 
                    RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "#"}], 
                    "]"}]}]}], ",", "\"\<Value\>\""}], "]"}], "&"}], "/@", 
                  "ranges"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"Grid", "[", 
                 RowBox[{
                  RowBox[{"Join", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Thread", "[", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<price\>\"", ",", 
                    "\"\<shares short for \[Delta]-neutral\>\"", ",", 
                    "\"\<\[Delta]-neutral tracking error\>\"", ",", 
                    "\"\<\[Delta]-\[Gamma] shares short\>\"", ",", 
                    "\"\<\[Delta]-\[Gamma] tracking error\>\""}], "}"}], ",", 
                    " ", "Bold"}], "]"}], "]"}], "}"}], ",", 
                    RowBox[{"Transpose", "@", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"NumberForm", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"10", ",", "2"}], "}"}]}], "]"}], "&"}], ",", 
                    "ranges"}], "]"}], ",", 
                    RowBox[{"Array", "[", 
                    RowBox[{
                    RowBox[{"delta", "&"}], ",", 
                    RowBox[{"Length", "@", "ranges"}]}], "]"}], ",", 
                    RowBox[{"Map", "[", 
                    RowBox[{"FromFractionalChangeToPercentString", ",", 
                    RowBox[{
                    RowBox[{"1", "/", "price"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"delta", " ", 
                    RowBox[{"(", 
                    RowBox[{"ranges", "-", "underlyingprice"}], ")"}]}], "-", 
                    RowBox[{"(", 
                    RowBox[{"truevalues", "-", "price"}], ")"}]}], ")"}]}]}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"delta", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}], " ", "gamma", " ", 
                    RowBox[{"(", 
                    RowBox[{"#", "-", "underlyingprice"}], ")"}]}]}], ")"}], 
                    "&"}], ",", "ranges"}], "]"}], ",", 
                    RowBox[{"Map", "[", 
                    RowBox[{"FromFractionalChangeToPercentString", ",", 
                    RowBox[{
                    RowBox[{"1", "/", "price"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"delta", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}], " ", "gamma", " ", 
                    RowBox[{"(", 
                    RowBox[{"#", "-", "underlyingprice"}], ")"}]}]}], ")"}], 
                    "&"}], ",", "ranges"}], "]"}], 
                    RowBox[{"(*", 
                    RowBox[{
                    RowBox[{
                    "the", " ", "preceding", " ", "is", " ", "the", " ", 
                    "quantity", " ", "of", " ", "shares", " ", "per", " ", 
                    "option", " ", "contract", " ", "to", " ", "obtain", " ", 
                    "a", " ", "delta"}], "-", 
                    RowBox[{"gamma", " ", "hedged", " ", "portfolio"}]}], 
                    "*)"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"ranges", "-", "underlyingprice"}], ")"}]}], "-", 
                    RowBox[{"(", 
                    RowBox[{"truevalues", "-", "price"}], ")"}]}], ")"}]}]}], 
                    "]"}]}], "}"}]}]}], "]"}], ",", " ", 
                  RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]}]}], "]"}]}], 
            "}"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"FreeQ", "[", 
              RowBox[{"t", ",", "Indeterminate", ",", "Infinity"}], "]"}], 
             ",", "t", ",", "$Failed"}], "]"}]}], "]"}]}], "}"}], "]"}]}]}], 
    "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.5837831496415677`*^9, {3.591408245606044*^9, 3.591408246417245*^9}, {
   3.591408405663325*^9, 3.5914084130421376`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PFEBackTest", "[", 
    RowBox[{"OHLCVData_List", ",", "a_", ",", "b_"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "OHLCVData", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ")"}]}], ":=", 
  RowBox[{
   RowBox[{"Charting`BackTesting", "[", 
    RowBox[{"OHLCVData", ",", " ", "\"\<PFE\>\"", ",", 
     RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b"}], "}"}]}], ",", " ", 
     RowBox[{"\"\<Threshold\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"15", ",", "0.8", ",", "25", ",", 
        RowBox[{"-", "15"}]}], "}"}]}], ",", 
     RowBox[{"\"\<StopLoss\>\"", "\[Rule]", "0.1"}], ",", 
     RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", " ", 
     RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
     RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "50000"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "9", ",", "1", ",", "1", ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.499626226271566*^9, 3.499626299845377*^9}, {
   3.49962705281682*^9, 3.499627067597726*^9}, 3.5354823483060827`*^9, {
   3.5355552977200193`*^9, 3.5355553027910194`*^9}, {3.5355722056660194`*^9, 
   3.5355722059700193`*^9}, {3.5379954165271034`*^9, 3.537995421345585*^9}, {
   3.5379955401244617`*^9, 3.53799555510896*^9}, {3.5379956793482137`*^9, 
   3.5379957071882133`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MACDBackTest", "[", 
    RowBox[{"OHLCVData_List", ",", "s_", ",", "l_"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "OHLCVData", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ")"}]}], ":=", " ", 
  RowBox[{
   RowBox[{"Charting`BackTesting", "[", 
    RowBox[{"OHLCVData", ",", " ", "\"\<MACD\>\"", ",", 
     RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"s", ",", "l"}], "}"}]}], ",", " ", 
     RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", " ", 
     RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
     RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "50000"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "9", ",", "1", ",", "1", ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.499627088795846*^9, 3.499627120689699*^9}, 
   3.499627165482944*^9, {3.4996286297210293`*^9, 3.499628632824604*^9}, {
   3.49962874635847*^9, 3.499628776738965*^9}, 3.53548233387464*^9, {
   3.5355554366390195`*^9, 3.5355554405430193`*^9}, {3.5355723275310197`*^9, 
   3.5355723279300194`*^9}, {3.5379954278062305`*^9, 3.537995433015752*^9}, {
   3.5379955605305023`*^9, 3.537995563757825*^9}, 3.5379957356952133`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"LRSBackTest", "[", 
    RowBox[{"OHLCVData_List", ",", "a_", ",", "b_"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "OHLCVData", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ")"}]}], ":=", " ", 
  RowBox[{
   RowBox[{"Charting`BackTesting", "[", 
    RowBox[{"OHLCVData", ",", " ", "\"\<LRS\>\"", ",", 
     RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", "a"}], ",", " ", 
     RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
     RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
     RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "b"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "9", ",", "1", ",", "1", ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.499627088795846*^9, 3.499627120689699*^9}, 
   3.499627165482944*^9, {3.4996286297210293`*^9, 3.499628632824604*^9}, {
   3.49962874635847*^9, 3.499628776738965*^9}, 3.53548233387464*^9, {
   3.5355554366390195`*^9, 3.5355554405430193`*^9}, {3.53555571990302*^9, 
   3.5355557207350197`*^9}, {3.53555579562702*^9, 3.5355558062980194`*^9}, {
   3.5355559032370195`*^9, 3.5355559228520193`*^9}, {3.5379954416226125`*^9, 
   3.537995445036954*^9}, {3.5379955673241816`*^9, 3.537995570242473*^9}, 
   3.5379957422292137`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Data", "Section",
 CellChangeTimes->{{3.520786469854125*^9, 3.52078648436975*^9}, {
  3.52121936621875*^9, 3.521219370578125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"stocksUS", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<AAPL\>\"", ",", "\"\<GOOG\>\"", ",", "\"\<CTSH\>\"", ",", 
     "\"\<GRMN\>\"", ",", "\"\<AMZN\>\"", ",", "\"\<DLB\>\"", ",", 
     "\"\<COH\>\"", ",", "\"\<INFY\>\"", ",", "\"\<DECK\>\"", ",", 
     "\"\<BIDU\>\"", ",", "\"\<SYK\>\"", ",", "\"\<NVDA\>\"", ",", 
     "\"\<EBIX\>\"", ",", "\"\<DV\>\"", ",", "\"\<FCX\>\"", ",", 
     "\"\<AFAM\>\"", ",", "\"\<GILD\>\"", ",", "\"\<FSLR\>\"", ",", 
     "\"\<MIDD\>\"", ",", "\"\<ORCL\>\"", ",", "\"\<QSII\>\"", ",", 
     "\"\<MSFT\>\"", ",", "\"\<NFLX\>\"", ",", "\"\<WDC\>\"", ",", 
     "\"\<LULU\>\"", ",", "\"\<PG\>\"", ",", "\"\<ARO\>\"", ",", 
     "\"\<GE\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.539714494578482*^9, {3.5796246127315426`*^9, 3.57962462265316*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"stocksForeign", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<F:UTDI\>\"", ",", "\"\<F:S92\>\"", ",", "\"\<TSX:RIM\>\"", ",", 
     "\"\<F:SWV\>\"", ",", "\"\<F:NDA\>\"", ",", "\"\<F:SZG\>\"", ",", 
     "\"\<F:SDF\>\"", ",", "\"\<F:MAN\>\"", ",", "\"\<F:DBK\>\"", ",", 
     "\"\<F:DAI\>\"", ",", "\"\<ASX:WOW\>\"", ",", "\"\<F:VIA\>\"", ",", 
     "\"\<F:APC\>\"", ",", "\"\<F:BMW\>\"", ",", "\"\<F:ALV\>\"", ",", 
     "\"\<F:SAP\>\"", ",", "\"\<F:SIE\>\"", ",", "\"\<F:WDI\>\"", ",", 
     "\"\<F:CBK\>\"", ",", "\"\<F:IFX\>\"", ",", "\"\<ASX:BHP\>\"", ",", 
     "\"\<F:DB1\>\"", ",", "\"\<F:BAS\>\"", ",", "\"\<F:LHA\>\"", ",", 
     "\"\<F:ADS\>\"", ",", "\"\<F:EOAN\>\"", ",", "\"\<F:MUV2\>\"", ",", 
     "\"\<TSX:POT\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.539618721102978*^9, 3.579624647036003*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"indices", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<^AORD\>\"", ",", "\"\<^ATX\>\"", ",", "\"\<^SSEC\>\"", ",", 
     "\"\<^HSI\>\"", ",", "\"\<^N225\>\"", ",", "\"\<^BFX\>\"", ",", 
     "\"\<^BSESN\>\"", ",", "\"\<^FCHI\>\"", ",", "\"\<^BXD\>\"", ",", 
     "\"\<^BXM\>\"", ",", "\"\<^VIX\>\"", ",", "\"\<^VXN\>\"", ",", 
     "\"\<FTSE100\>\"", ",", "\"\<FTSE250\>\"", ",", "\"\<FTSE350\>\"", ",", 
     "\"\<^DJI\>\"", ",", "\"\<SP100\>\"", ",", "\"\<SP400\>\"", ",", 
     "\"\<SP500\>\"", ",", "\"\<SP600\>\"", ",", "\"\<^SSMI\>\"", ",", 
     "\"\<^OSEAX\>\"", ",", "\"\<^GDAXI\>\"", ",", "\"\<^OMXSPI\>\"", ",", 
     "\"\<^KLSE\>\"", ",", "\"\<^NZ50\>\"", ",", "\"\<^KS11\>\"", ",", 
     "\"\<^JKSE\>\"", ",", "\"\<^MXX\>\"", ",", "\"\<^MERV\>\"", ",", 
     "\"\<^BVSP\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.546793950903283*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating a Report  ", "Title",
 CellChangeTimes->{{3.5673550442140083`*^9, 3.567355047985757*^9}, 
   3.567357011226471*^9, {3.568981889211762*^9, 3.56898189071437*^9}}],

Cell[TextData[{
 "You can use or modify the code below to generate your own reports. ",
 StyleBox[ButtonBox["Learn more \[RightGuillemet]",
  BaseStyle->"Link",
  ButtonData->"paclet:ReportGeneration/tutorial/RunningReport#509267359"],
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.56736548144623*^9, 3.567365494363881*^9}, {
  3.567365534532933*^9, 3.5673655434044323`*^9}, {3.567365599240382*^9, 
  3.56736563220608*^9}, {3.567365708289185*^9, 3.567365752578026*^9}, {
  3.567428158695491*^9, 3.5674281591717987`*^9}, {3.568462092226097*^9, 
  3.568462094745254*^9}, {3.568462180931364*^9, 3.568462220156323*^9}, {
  3.568638785568681*^9, 3.568638785571105*^9}, {3.568639090535976*^9, 
  3.568639094551483*^9}, {3.568981934130793*^9, 3.5689819435775957`*^9}, {
  3.5692437531834373`*^9, 3.569243754285715*^9}, {3.570297704156425*^9, 
  3.570297769563719*^9}, {3.570900279712476*^9, 3.570900290081263*^9}, {
  3.570900367905416*^9, 3.5709003934887753`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Load", " ", "the", " ", "ReportGeneration", " ", 
    RowBox[{"package", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Needs", "[", "\"\<ReportGeneration`\>\"", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5673577373980293`*^9, 3.567357741294982*^9}, 
   3.568638737978706*^9, {3.5689819670920563`*^9, 3.568981981195059*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5841815038613825`*^9, 3.5841815185879717`*^9}, 
   3.5912108520793514`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Evaluate", " ", "the", " ", "code", " ", "below", " ", "to", " ", 
    "generate", " ", "the", " ", 
    RowBox[{"report", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"ReportGenerate", "[", 
   RowBox[{"\"\<Example-4 Template.nb\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<days\>\"", "\[Rule]", "365"}], ",", 
      RowBox[{"\"\<company\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<ticker\>\"", "\[Rule]", "\"\<GE\>\""}], ",", 
           RowBox[{"\"\<name\>\"", "\[Rule]", "\"\<General Electric\>\""}]}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<ticker\>\"", "\[Rule]", "\"\<AAPL\>\""}], ",", 
           RowBox[{"\"\<name\>\"", "\[Rule]", "\"\<Apple Inc.\>\""}]}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<ticker\>\"", "\[Rule]", "\"\<GOOG\>\""}], ",", 
           RowBox[{"\"\<name\>\"", "\[Rule]", "\"\<Google Inc.\>\""}]}], 
          "}"}]}], "}"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5673580776668587`*^9, 3.567358104154232*^9}, {
  3.56898199674889*^9, 3.568982006667996*^9}, {3.5912933786739388`*^9, 
  3.591293415724004*^9}, {3.5914044300778756`*^9, 3.5914044337078805`*^9}}],

Cell[BoxData[
 TemplateBox[{FrontEndObject[
    LinkObject["a8z6k_shm", 3, 1]],59,
   "FrontEndObject[LinkObject[\"a8z6k_shm\", 3, 1]]","59","\"Untitled-2\""},
  "NotebookObjectUnsaved"]], "Output",
 CellChangeTimes->{3.591403670695812*^9, 3.591403914216153*^9, 
  3.591404449887903*^9}]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{740, 867},
WindowMargins->{{Automatic, 493}, {Automatic, 28}},
TaggingRules->{
 "Highlight" -> True, "ReportTemplateVersion" -> 1., 
  "TemplateVariablesValue" -> {"ExampleCode" -> RawBoxes[
      RowBox[{"ReportGenerate", "[", 
        RowBox[{"template", ",", "data"}], "]"}]]}, 
  "TemplateVariables" -> {"ExampleCode" -> RawBoxes[
      RowBox[{"ReportGenerate", "[", 
        RowBox[{"template", ",", "data"}], "]"}]]}},
ShowCellTags->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (May 20, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 32, 0, 98, "Section"],
Cell[614, 24, 119, 3, 36, "Input",
 InitializationCell->True],
Cell[736, 29, 101, 2, 36, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[874, 36, 88, 1, 60, "Section"],
Cell[965, 39, 230, 7, 36, "Input",
 InitializationCell->True],
Cell[1198, 48, 831, 16, 106, "Input",
 InitializationCell->True],
Cell[2032, 66, 416, 9, 60, "Input",
 InitializationCell->True],
Cell[2451, 77, 244, 7, 36, "Input",
 InitializationCell->True],
Cell[2698, 86, 306, 8, 36, "Input",
 InitializationCell->True],
Cell[3007, 96, 468, 11, 60, "Input",
 InitializationCell->True],
Cell[3478, 109, 311, 8, 36, "Input",
 InitializationCell->True],
Cell[3792, 119, 110, 2, 36, "Input",
 InitializationCell->True],
Cell[3905, 123, 531, 12, 60, "Input",
 InitializationCell->True],
Cell[4439, 137, 5660, 126, 418, "Input",
 InitializationCell->True],
Cell[10102, 265, 707, 21, 60, "Input",
 InitializationCell->True],
Cell[10812, 288, 4651, 121, 244, "Input",
 InitializationCell->True],
Cell[15466, 411, 3173, 85, 244, "Input",
 InitializationCell->True],
Cell[18642, 498, 6955, 188, 451, "Input",
 InitializationCell->True],
Cell[25600, 688, 13309, 311, 888, "Input",
 InitializationCell->True],
Cell[38912, 1001, 1509, 33, 83, "Input",
 InitializationCell->True],
Cell[40424, 1036, 1337, 28, 83, "Input",
 InitializationCell->True],
Cell[41764, 1066, 1373, 28, 83, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[43174, 1099, 136, 2, 60, "Section"],
Cell[43313, 1103, 857, 17, 60, "Input",
 InitializationCell->True],
Cell[44173, 1122, 885, 16, 83, "Input",
 InitializationCell->True],
Cell[45061, 1140, 920, 17, 83, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[46018, 1162, 177, 2, 79, "Title"],
Cell[46198, 1166, 978, 16, 63, "Text"],
Cell[47179, 1184, 417, 8, 60, "Input",
 InitializationCell->True],
Cell[47599, 1194, 248, 6, 36, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[47872, 1204, 1371, 32, 152, "Input"],
Cell[49246, 1238, 287, 6, 59, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
