(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     31921,        680]
NotebookOptionsPosition[      7777,        178]
NotebookOutlinePosition[     31712,        672]
CellTagsIndexPosition[     31601,        666]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\"\<interestRate\>\"", ",", "\"\<expirationYears\>\"", ",", 
   RowBox[{"\"\<company\>\"", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"\"\<ticker\>\"", ",", "\"\<name\>\""}], "}"}], "}"}]}]}], 
  "}"}]], "TemplateHeaderCell"],

Cell[CellGroupData[{

Cell["\<\
\[Delta] - \[Gamma] Hedges for a list of securities\
\>", "Title",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
   3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
   3.5838045314475374`*^9}, {3.5838049388248377`*^9, 
   3.5838049392088594`*^9}, {3.583805225786251*^9, 3.583805237241906*^9}, {
   3.583805545995566*^9, 3.583805546363587*^9}, {3.5838068151691585`*^9, 
   3.583806822049552*^9}, {3.5838069601934533`*^9, 3.583806960626478*^9}, {
   3.58380760213317*^9, 3.583807631092827*^9}, {3.5838116233511705`*^9, 
   3.583811629062497*^9}, 3.5912939374513197`*^9}],

Cell["\<\
Various \[Delta] - \[Gamma] Hedges designed to replicate underlying securities\
\>", "Subtitle",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9, 
   3.5838068609627776`*^9, {3.583811423989768*^9, 3.5838114473181024`*^9}, {
   3.5838116356548743`*^9, 3.5838116388550577`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Comany:  \[Delta] - \[Gamma] Hedges for ",
 Cell[BoxData[
  FormBox[
   TemplateBox[{"name"},
    "TemplateVariable"], TextForm]]]
}], "Section",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}, {
   3.591294319589591*^9, 3.591294343972434*^9}},
 CellTags->"/company:"],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"price", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{
        TemplateBox[{"ticker"},
         "TemplateVariable"], ",", "\"\<Close\>\""}], "]"}]}], ",", "\n", 
     RowBox[{"div", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{
        TemplateBox[{"ticker"},
         "TemplateVariable"], ",", "\"\<DividendYield\>\""}], "]"}]}], ",", 
     "\n", 
     RowBox[{"vol", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{
        TemplateBox[{"ticker"},
         "TemplateVariable"], ",", "\"\<Volatility50Day\>\""}], "]"}]}]}], 
    "}"}], ",", 
   RowBox[{"Column", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Global`DeltaGammaHedge", "[", 
       RowBox[{"#", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", 
           RowBox[{"Switch", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"-", "1"}], "]"}], "]"}], ",", "\"\<Put\>\"", ",", 
             RowBox[{"1.1", "*", "price"}], ",", "\"\<Call\>\"", ",", 
             RowBox[{"0.9", "*", "price"}]}], "]"}]}], ",", " ", 
          RowBox[{"\"\<Expiration\>\"", "\[Rule]", 
           TemplateBox[{"expirationYears"},
            "TemplateVariable"]}]}], "}"}], ",", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<InterestRate\>\"", "\[Rule]", " ", 
           TemplateBox[{"interestRate"},
            "TemplateVariable"]}], ",", 
          RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", " ", "price"}], ",", " ", 
          RowBox[{"\"\<Dividend\>\"", "\[Rule]", "div"}], ",", " ", 
          RowBox[{"\"\<Volatility\>\"", "\[Rule]", "vol"}]}], "}"}]}], "]"}], 
      "&"}], " ", "/@", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Call\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Put\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Put\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Put\>\""}], 
        "}"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4952132473995705`*^9, 3.4952132521652565`*^9}, {
   3.495213350994646*^9, 3.4952133583228655`*^9}, {3.495213543793989*^9, 
   3.4952136202637177`*^9}, {3.495213665498672*^9, 3.495213671217495*^9}, {
   3.4952138342352066`*^9, 3.49521388523586*^9}, {3.495214258316529*^9, 
   3.495214258785261*^9}, {3.4952142910183983`*^9, 3.4952142992055836`*^9}, {
   3.4952144392314568`*^9, 3.4952144771206264`*^9}, {3.495214566712267*^9, 
   3.495214641117564*^9}, {3.4952147925062513`*^9, 3.495214857458545*^9}, 
   3.4952157716963673`*^9, 3.495217663645976*^9, {3.495217869427843*^9, 
   3.4952178964276705`*^9}, {3.495217986192721*^9, 3.4952179896926985`*^9}, {
   3.4952180212862463`*^9, 3.495218065551588*^9}, {3.495218096770138*^9, 
   3.495218188113773*^9}, 3.495218579474202*^9, 3.4952187111469197`*^9, {
   3.495218744162756*^9, 3.4952187494596653`*^9}, {3.4952188203038683`*^9, 
   3.4952188234288883`*^9}, {3.4952188554603434`*^9, 3.495218855882221*^9}, 
   3.4952193374946785`*^9, {3.495219376463678*^9, 3.4952193790886946`*^9}, {
   3.4952200570149083`*^9, 3.4952200623743176`*^9}, {3.495284465908083*^9, 
   3.4952844775800323`*^9}, 3.4952845197053022`*^9, 3.4952845616586957`*^9, {
   3.4952849458174047`*^9, 3.495285022739772*^9}, 3.4952862327631407`*^9, {
   3.495286510280542*^9, 3.4952865144524436`*^9}, {3.4952868488452086`*^9, 
   3.4952868826422997`*^9}, {3.4952869897992353`*^9, 3.49528709048738*^9}, 
   3.495289290188958*^9, {3.5074663423934727`*^9, 3.5074663636966915`*^9}, {
   3.5074664743380194`*^9, 3.5074664747750444`*^9}, {3.507466817002334*^9, 
   3.507466827797553*^9}, {3.5074673499480743`*^9, 3.507467356656086*^9}, {
   3.5206175359046288`*^9, 3.5206175365956974`*^9}, {3.5206177430003357`*^9, 
   3.520617743762412*^9}, {3.520618657824809*^9, 3.52061867133616*^9}, {
   3.520620080156826*^9, 3.520620080416696*^9}, {3.5206205246678495`*^9, 
   3.5206205380078497`*^9}, {3.521404919171875*^9, 3.521404928890625*^9}, 
   3.5214224365625*^9, {3.583807556758575*^9, 3.5838075621658845`*^9}, {
   3.5838078753357964`*^9, 3.583807875783822*^9}, {3.583810013153073*^9, 
   3.5838100155212083`*^9}, {3.583810051865287*^9, 3.583810120946238*^9}, {
   3.583810170594078*^9, 3.5838102168347225`*^9}, {3.583810322754781*^9, 
   3.583810342531912*^9}, {3.583810413027944*^9, 3.5838104695401764`*^9}, {
   3.5838105125326357`*^9, 3.5838105444364605`*^9}, 3.5838106047409096`*^9, {
   3.583810677430067*^9, 3.583810679156166*^9}, {3.583810755253518*^9, 
   3.583810820584255*^9}, 3.583810851176005*^9, {3.58381092189705*^9, 
   3.583811064615213*^9}, {3.5838115190182033`*^9, 3.5838115191772127`*^9}, {
   3.5912940469947124`*^9, 3.5912940500211177`*^9}, {3.5912941952261724`*^9, 
   3.591294241932655*^9}, {3.5912944925002947`*^9, 3.5912945248235517`*^9}, 
   3.5912945646816216`*^9},
 CellTags->{"/company:", "EvaluateDeleteInput:"}]
}, Open  ]]
}, Open  ]]
},
Editable->True,
WindowSize->{1019, 946},
WindowMargins->{{Automatic, 360}, {Automatic, 13}},
DockedCells->Cell[
  BoxData[
   PanelBox[
    PaneBox[
     TagBox[
      GridBox[{{
         ItemBox[
          TagBox[
           GridBox[{{"\"  \"", "\" \"", 
              StyleBox["\"Report Template\"", 17, Bold, 
               RGBColor[0.4196, 0.4196, 0.4196], FontFamily -> "Sans Serif", 
               StripOnInput -> False]}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"], 
          Alignment -> {Left, Center}, StripOnInput -> False], 
         ItemBox[
          TagBox[
           GridBox[{{
              TagBox[
               TooltipBox[
                ButtonBox[
                 PaneSelectorBox[{False -> TagBox[
                    GridBox[{{
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJyt1U1rwkAQBuCB9tJTL6X3/qXeggQ0qBgS6F08iEe/QlAsqAlJ/Eiif07a
Wxd3OitZWQpFXbPwwOzlZfYlkDfr4916AIBX8kIeCSKWrcxz2G636LpuKdI0
Pe52O+44DuhS37rf71me56Xl0W6MduS2bYMgS1DnK88pL8syRv2d89brNQrq
fA2ZR7sxuvNWqwUFLKjzRTJvs9mwJEl4s9kEXWp/q9WKRVHEG40GCLIMdb6l
P9rtlFev10EIggAFdb6GzIvjmNGdW5YFBSyo80UyLwxDtlgseK1WA11qf8vl
ks3n89LyaDex343V/3/ovcfJZIJlmc1m3Pd9FEzTPJF3HdPplA+HQ/Q8DyuV
CghivsOx2+3+jMfjcwdi1tXr9b7o+0k7nQ4OBgMcjUZa+v0+ttttrFarn4Zh
PJOMfBPUdCAJeSJwD/zzP/oFlRw+QA==
                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, 
                    PlotRange -> {{0, 20}, {0, 22}}}]}, {
                    InterpretationBox[
                    Cell[
                    BoxData[
                    FormBox[
                    StyleBox["\"Author\"", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif", StripOnInput -> False], TextForm]], 
                    "InlineText"], 
                    Text[
                    Style["Author", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]]}}, 
                    GridBoxAlignment -> {"Columns" -> {{Center}}}, 
                    DefaultBaseStyle -> "Column", 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{0}}}], "Column"], 
                   True -> TagBox[
                    GridBox[{{
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJyt1UtLAlEYBuADtYkWJlZIUVFGN4oKWiQh3cMM0yxzExUS4abaiFR0v6BJ
rdsk1hjU/xH8Ey2aRkfTg+frnHLiEIR28oMH3lnMC/NuptW74/JWIITqqVqq
kgKAcivnyblLK8Q8/WWhhhz5XNhJYst9SBT/reqNB2ev5onk7kWi+L7UtRtn
g3NEWupBjDYCn0u8r77wIn6/mCWSqwsx+ZNRYPhcCq0vGXLizPkMeVjoQAVQ
wOeitD4laMeZ0wny4GhHovj9lEsbTh+Nknt7G2K0Mfj8l/2UMytOH4yQ+7kW
xOQCg8DwuRRa39vxFFb3hknU1oQKoIDPRWl98uE4VgNDJGptQKL4/eR9C075
B0h0xohE8X2vu2ac8ff/cfrfL7lnzmd8zVAuye1ukt5sBCYyrv+kPYtQtjqJ
7DWCumGEyJgOMSyLevGZ8omVxpzqrfvegGVR8TWT8jhd95RY0oO8aoDUuphX
+m58sQakScPtnaVaRz1TSQoEyZREVVHoP+DH/+gD+vUHrA==
                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, 
                    PlotRange -> {{0, 20}, {0, 22}}}]}, {
                    InterpretationBox[
                    Cell[
                    BoxData[
                    FormBox[
                    StyleBox["\"Author\"", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif", StripOnInput -> False], TextForm]], 
                    "InlineText"], 
                    Text[
                    Style["Author", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]]}}, 
                    GridBoxAlignment -> {"Columns" -> {{Center}}}, 
                    DefaultBaseStyle -> "Column", 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{0}}}], "Column"]}, 
                  Dynamic[
                   FrontEnd`CurrentValue["MouseOver"]]], 
                 ButtonFunction :> (
                  ReportGeneration`Authoring`Private`dir$10349 = FileNameDrop[
                    FindFile["ReportGeneration`"], -2]; NotebookOpen[
                    
                    FileNameJoin[{
                    ReportGeneration`Authoring`Private`dir$10349, "FrontEnd", 
                    "Palettes", "Report Generation.nb"}]]), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                InterpretationBox[
                 Cell[
                  BoxData[
                   FormBox[
                    StyleBox[
                    "\"Show the Report Generation palette.\"", {
                    FontFamily -> "Sans Serif"}, StripOnInput -> False], 
                    TextForm]], "InlineText"], 
                 Text[
                  Style[
                  "Show the Report Generation palette.", {
                   FontFamily -> "Sans Serif"}]]], TooltipDelay -> 0.6], 
               Annotation[#, 
                Text[
                 Style[
                 "Show the Report Generation palette.", {
                  FontFamily -> "Sans Serif"}]], "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                ButtonBox[
                 DynamicBox[
                  ToBoxes[
                   If[
                    TrueQ[
                    CurrentValue[
                    ButtonNotebook[], {TaggingRules, "Highlight"}]], 
                    PaneSelector[{False -> Column[{
                    Graphics[
                    Raster[CompressedData["
1:eJy9lD1rwlAUhgPt2LGUQqdOXTt17dq5m6KoUaKiUJzcdXJQ/P6MX0gQdfEf
ZCv4FwpdXLKkkKWgS07PCd6g8TYaCr3wwD3mva/nvfcm9+Lbq3ghCMINco1c
IgDwn3gdhpufoiiQSqXOZj6fm+l0WiB4frPZzPSSZ6d/QTRO78J0OmV+5wxL
v16v9cFgsMlkMge97/JafolEAk7B9MvlErLZrIoet87+J5PJft4FcuWWl/S0
58lk8o73fDwe236qqsJ2u/3E+eOe5iAv6dGT+uXeD3rGRr/fh8ViAbqub7CU
SB+LxYBB9Wg0MtET4vG45dftduEUsiwDZpJ5efA/zeFwCJIkWXUkEoF9Go2G
PW+321Aul+msvrH28/L2ej2TcmC/3P3tdDr2/uXzeYhGox/hcPiB/YZzYDA9
ZRBFkevXarVsv1AopCCu50t6yoH9c88L8zrfD7dh6ZvNJvVr6WnOoLpWqx34
BQIB+A2mr9frNLfuMs0ZVFcqFU/vL+mr1SoYhvGO9VMwGAQG8/cy8PxNugN0
TzXt6JMg+Hw+8IhRKBSgVCodcWJov2XG+/mVy+WgWCyeBWlpjd/vFwinH/b4
jKw8ZFrt1tBant+fcPr9AH8y2WM=
                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, PlotRange -> {{0, 20}, {0, 22}}}], 
                    Text[
                    Style["Preview", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]}, Alignment -> Center, Spacings -> 0], 
                    True -> Column[{
                    Graphics[
                    Raster[CompressedData["
1:eJxTTMoPSmJmYGAQA2IRIGYB4v///9MTkwo+4DPvV7Pb/8VhukTjX10B/xaH
6zOAMDbzfnb4/iPFP1D1HkD8HIvbGX60ecHMIwaA1f+5cezN80bfH2uiDFDc
DpZv8QCbtyhQ4z8hDFP/b2LE/w2J5vsXhWhLoLv/e6MLsn9XAzEPPv+C1P9t
cvy/KFhLGpv8t3oHuHl/llX8//f9y10g2wBJDYp/Qer/1tuB3Is1ffyqs0Ww
ywz//+70+//3yfUfQG4aSP0Cb/n/MAw2r8b6358aq/8L/VUh8VOs+58Q/lpm
/P/KpLw52PzztdLi3+8qs/8L/JTB/PkeUv+R8Zc8DTj7Z4Hm/9dZ6v/X+ct9
BfKjsPn3a5nJP5A/gO7FGr5fivXh4XczXv7/Yg+pW/PdxNVhYkD2fxiGqQf5
Yb6XLFbzPhdow82b5yKyFIjxxi9IPcgfQPdjja9PuRro+QMfAKv/kasCci9Y
PYgNw2D5HDUU8+Y6CvzHhWHqv2cpgNjgtAxiwzCI/zFTmaT8C1L/LV3m/+/X
j48B+WZznYT+wzA4vjIVCXgRFXxIV/j3LVXy/4/uoP9/753DCI85ttz/ScQf
3sSL/v+aJIaBCYDnuPy8xUvk7aNIof9fEoSJwiC1ID1zbHkYQBjdPKAb7YH4
JAl+OgnVA9KLzTyKMLp5APZbuCQ=
                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, PlotRange -> {{0, 20}, {0, 22}}}], 
                    Text[
                    Style["Preview", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]}, Alignment -> Center, Spacings -> 0]}, 
                    Dynamic[
                    FrontEnd`CurrentValue["MouseOver"]]], 
                    If[$VersionNumber >= 9, 
                    PaneSelector[{False -> Column[{
                    Graphics[
                    Raster[CompressedData["
1:eJytlDtrYkEUxwey/UIIi7BVvkGqQKq0W6fzhXoRHygEi8XeRiwU3098rYqo
KfwEbrew32JxCy0SuJ3BYk7OP9wJN9dcH5CBH2fOnL9n5n8d5lK7v9POhBDf
mAvmC0NEn0o8HreFTh96LBYTdoxGI+J4NNPpVO7rN5lM9taB2Sv0HH8wK+vB
o9GoGI/HEvFIr6/65XL52Ol0nhOJxLuzRyIR+JWIDB0C/aCfz+eUTCZ/cw9H
OBzGWc6ZEeaDwUAi7sPsF3p8c/b0PRQKYe1ms9n8XywWW+T9fl8i2mH1Cz33
pGAwiNrP9Xq95W9KWMNQ0XonoDcgBfr1ej3JPUnTNDEcDh+azSYdot1uS+gV
Zr+odbtdCgQCggnxHX4uFApUqVSw9hYt6IZ+x2+r1ZLck/x+vzC44rP/S6fT
W+SNRkOaah9BCvSDHh58Pp8w8ZX5hXmtVpOW2g5mv9DX63Xyer0CmA+PnP1K
VbPWP7rP0FerVfJ4PAJgrkBeKpWkqhmQHegHfblcxtzhdrsF5grk/N9IxH2Y
/UJfLBZJ1/U/nF+zJ1K4XC5h7HX0yOfzkqHZbEar1fsnwel0CoZORM9kMpTL
5XY4MFbGfjvvM78DT6lUirLZ7FFAi99Y+yh4j1vm7wmeoL216/fZvADIlEgI

                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, PlotRange -> {{0, 20}, {0, 22}}}], 
                    Text[
                    Style["  Edit   ", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]}, Alignment -> Center, Spacings -> 0], 
                    True -> Column[{
                    Graphics[
                    Raster[CompressedData["
1:eJytlE1IVFEUxy/UzqiYJjMzVOxjSkSF0D6YJkNknLDMoq9NNVSiZgmikEhi
hUQtor3T2FitXBS0bye0iVZRmxBdzCKlyWbGN2+cezr/x7vxfOObD/DBj3PO
O/937vnD5VUH73cFNwkhShk3s5khog1l+nK9I1T8E5u+VCec0B+3EceC0Z91
ysjFWuFE6mlHzj6weoWeo5+J2hePXDgstImARCzQq6Ff/T67GB3v0GauNazZ
PXLeI7QnfonIUD6MeayXL6/Q+5vNn3j3stfn9mMXF/MW+cp4q0TMhdUv9JlH
LfC2Z+psDd4dk/HfC6l3Izrq5NgpieiE3S/0mbGTNHWmEr2hzNxXPT3RTvpD
ryFQ0X4noDchhTFv9IRcHT1O4cBe8e1F70xyqJFSg3U5STw4KqFXWP2ilx5p
orC/XDB3PnRWakt9Byl+z4N3/6ONmKnP8psYPiL14UYKt+0SJg1v2svnftzy
6Kjjg/XS0lsPUmAe9PDwqtUtLGxjIsj/DtRKWy8Lq1/oUwOHKHTaJYB1edTL
/R6pevb+evcZeq1/H4VatguAXIF6+e4BqXom5IQxj/UrvVXIy0K+rQK5AvWf
nhqJmAurX+iT3RWU/rUwy3UTeyLFpHeLSPRU57Fou5jdVTJ5ezdpz7so8/PL
mt6kt0QwVCSxxes7KREszSLPEzXPy/o/fwy4l+avuih+Y0dBQItv7HMUfIaP
+VyEJ2h9TvM2mn/c7xxX
                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, PlotRange -> {{0, 20}, {0, 22}}}], 
                    Text[
                    Style["  Edit   ", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]}, Alignment -> Center, Spacings -> 0]}, 
                    Dynamic[
                    FrontEnd`CurrentValue["MouseOver"]]], 
                    PaneSelector[{False -> Column[{
                    Graphics[
                    Raster[CompressedData["
1:eJy9lD1rwlAUhgPt2LGUQqdOXTt17dq5m6KoUaKiUJzcdXJQ/P6MX0gQdfEf
ZCv4FwpdXLKkkKWgS07PCd6g8TYaCr3wwD3mva/nvfcm9+Lbq3ghCMINco1c
IgDwn3gdhpufoiiQSqXOZj6fm+l0WiB4frPZzPSSZ6d/QTRO78J0OmV+5wxL
v16v9cFgsMlkMge97/JafolEAk7B9MvlErLZrIoet87+J5PJft4FcuWWl/S0
58lk8o73fDwe236qqsJ2u/3E+eOe5iAv6dGT+uXeD3rGRr/fh8ViAbqub7CU
SB+LxYBB9Wg0MtET4vG45dftduEUsiwDZpJ5efA/zeFwCJIkWXUkEoF9Go2G
PW+321Aul+msvrH28/L2ej2TcmC/3P3tdDr2/uXzeYhGox/hcPiB/YZzYDA9
ZRBFkevXarVsv1AopCCu50t6yoH9c88L8zrfD7dh6ZvNJvVr6WnOoLpWqx34
BQIB+A2mr9frNLfuMs0ZVFcqFU/vL+mr1SoYhvGO9VMwGAQG8/cy8PxNugN0
TzXt6JMg+Hw+8IhRKBSgVCodcWJov2XG+/mVy+WgWCyeBWlpjd/vFwinH/b4
jKw8ZFrt1tBant+fcPr9AH8y2WM=
                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, PlotRange -> {{0, 20}, {0, 22}}}], 
                    Text[
                    Style["Preview", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]}, Alignment -> Center, Spacings -> 0], 
                    True -> Column[{
                    Graphics[
                    Raster[CompressedData["
1:eJxTTMoPSmJmYGAQA2IRIGYB4v///9MTkwo+4DPvV7Pb/8VhukTjX10B/xaH
6zOAMDbzfnb4/iPFP1D1HkD8HIvbGX60ecHMIwaA1f+5cezN80bfH2uiDFDc
DpZv8QCbtyhQ4z8hDFP/b2LE/w2J5vsXhWhLoLv/e6MLsn9XAzEPPv+C1P9t
cvy/KFhLGpv8t3oHuHl/llX8//f9y10g2wBJDYp/Qer/1tuB3Is1ffyqs0Ww
ywz//+70+//3yfUfQG4aSP0Cb/n/MAw2r8b6358aq/8L/VUh8VOs+58Q/lpm
/P/KpLw52PzztdLi3+8qs/8L/JTB/PkeUv+R8Zc8DTj7Z4Hm/9dZ6v/X+ct9
BfKjsPn3a5nJP5A/gO7FGr5fivXh4XczXv7/Yg+pW/PdxNVhYkD2fxiGqQf5
Yb6XLFbzPhdow82b5yKyFIjxxi9IPcgfQPdjja9PuRro+QMfAKv/kasCci9Y
PYgNw2D5HDUU8+Y6CvzHhWHqv2cpgNjgtAxiwzCI/zFTmaT8C1L/LV3m/+/X
j48B+WZznYT+wzA4vjIVCXgRFXxIV/j3LVXy/4/uoP9/753DCI85ttz/ScQf
3sSL/v+aJIaBCYDnuPy8xUvk7aNIof9fEoSJwiC1ID1zbHkYQBjdPKAb7YH4
JAl+OgnVA9KLzTyKMLp5APZbuCQ=
                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, PlotRange -> {{0, 20}, {0, 22}}}], 
                    Text[
                    Style["Preview", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]}, Alignment -> Center, Spacings -> 0]}, 
                    Dynamic[
                    FrontEnd`CurrentValue["MouseOver"]]]]], StandardForm]], 
                 ButtonFunction :> If[$VersionNumber >= 9, CurrentValue[
                    ButtonNotebook[], {TaggingRules, "Highlight"}] = Not[
                    CurrentValue[
                    ButtonNotebook[], {TaggingRules, "Highlight"}, True]]; 
                   SetOptions[
                    ButtonNotebook[], ShowCellTags -> If[
                    TrueQ[
                    CurrentValue[
                    ButtonNotebook[], {TaggingRules, "Highlight"}]], True, 
                    False], Editable -> If[
                    TrueQ[
                    CurrentValue[
                    ButtonNotebook[], {TaggingRules, "Highlight"}]], True, 
                    False]]; Null, 
                   MessageDialog[
                   "This feature is not available for current Mathematica \
version. "]], Appearance -> None, Evaluator -> Automatic, Method -> 
                 "Preemptive"], 
                DynamicBox[
                 ToBoxes[
                  If[
                   TrueQ[
                    CurrentValue[
                    ButtonNotebook[], {TaggingRules, "Highlight"}]], 
                   ReportGeneration`Authoring`Private`tooltip["Preview"], 
                   ReportGeneration`Authoring`Private`tooltip["Edit"]], 
                  StandardForm], 
                 Initialization :> {
                  ReportGeneration`Authoring`Private`tooltip["Edit"] := 
                   Module[{}, 
                    Text[
                    Style[
                    "Return to template view.", 
                    ReportGeneration`Authoring`Private`tooltipOpts]]], 
                   ReportGeneration`Authoring`Private`tooltip["Help"] := 
                   Module[{}, 
                    Text[
                    Style[
                    "Show the Report Generation User Guide.", 
                    ReportGeneration`Authoring`Private`tooltipOpts]]], 
                   ReportGeneration`Authoring`Private`tooltip["Palette"] := 
                   Module[{}, 
                    Text[
                    Style[
                    "Show the Report Generation palette.", 
                    ReportGeneration`Authoring`Private`tooltipOpts]]], 
                   ReportGeneration`Authoring`Private`tooltip["Preview"] := 
                   Module[{}, 
                    Text[
                    Style[
                    "Switch to Preview mode. Preview Expressions\nwill \
display in place of Template Variables.", 
                    ReportGeneration`Authoring`Private`tooltipOpts]]], 
                   ReportGeneration`Authoring`Private`tooltipOpts := {
                    FontFamily -> "Sans Serif"}}], TooltipDelay -> 0.6], 
               Annotation[#, 
                Dynamic[
                 If[
                  TrueQ[
                   CurrentValue[
                    ButtonNotebook[], {TaggingRules, "Highlight"}]], 
                  ReportGeneration`Authoring`Private`tooltip["Preview"], 
                  ReportGeneration`Authoring`Private`tooltip["Edit"]], 
                 SaveDefinitions :> True], "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                ButtonBox[
                 PaneSelectorBox[{False -> TagBox[
                    GridBox[{{
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJyVlU9LYlEYxi80XyCYZu8QBAOt5iv0CQZmoaWhlmiJ4qpdLaKoxD+Vf0hE
GrUUETVI+gCRborAYWIW5pAT4yZGhUAQ8p33uVzD9NyhFj/OOfc8z+O557zn
qjE5v5jGJEn6wLxn3jF2u10VItIwZsamgL5mSPMClRz4fj4+PlKtVqNqtSqD
Pp5hTtGMDectLy8/w+NJpnJ7e0vFYpHS6bQQzEHz9PT0nfWfRHncn263262z
szNKpVKvAtpms9mCt5+3tLSEduLh4eE+m83S8fHxm4CHvX+QgTybzSa1Wq3k
yckJHR0djbC9vU2skVvRPCgUCsTvllLWOFUqlXqJRIJE5HK5stVqldCqacDF
xUUPWXxuHozj8biQq6srnKfcqmkAMviMfLy2+uHhIamxsbFBFotFdX4QXuNv
3s9uLBYjNTKZTHlxcVFaX19X1fRBVjKZ7EWjUVLj/Py8ya87vrCwsMV1Rbu7
u6paZIXD4V4kEiE1UGedTucXZ1pMJtNHPpvrUCgk1CIrGAx2Dw4OSATe0eVy
yZk3Nzc4lhXOHPf7/UIP/053Z2fnjnNJBO/xtdFonNnf3yfAniSPJa7jtkjP
NVpfXV31BAIB4nWOwL7y/Py8xPxV+Mpr/MxnNKJFBrIMBsPU2tpar7+GQU5P
T7FvK8yMwlaj0WiLtMhAll6vxx3+5na7aW9v7wX5fJ4uLy+pXq/LcH3J+zSs
g5fvZBL3bW5uDkzw+M7j8RDv9ZuAh733yEDe7Oxsn2mu29bm5ib5fL5XAS08
8Pa/VwN5YJKpOJ1O+Z55vV4hyIEGWngGv6c6nU6EmalwbZDD4ZC9AH0847kf
imbk/0Or1f4PDWNmLApm5dmzZjjvH7PwfgQ=
                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, 
                    PlotRange -> {{0, 20}, {0, 22}}}]}, {
                    InterpretationBox[
                    Cell[
                    BoxData[
                    FormBox[
                    StyleBox["\"Help\"", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif", StripOnInput -> False], TextForm]], 
                    "InlineText"], 
                    Text[
                    Style["Help", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]]}}, 
                    GridBoxAlignment -> {"Columns" -> {{Center}}}, 
                    DefaultBaseStyle -> "Column", 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{0}}}], "Column"], 
                   True -> TagBox[
                    GridBox[{{
                    GraphicsBox[
                    RasterBox[CompressedData["
1:eJyV1W1IE3EcB/ADe2dillpmNqaWpU6LCsMwy6ceNE1Tw6wXbbkQ0zIlgwgR
a0zIVMJAcj4lSRIa5IvRi4QgfedyaoRRPnZqWW7Z1J27+/X/nadMdxf64sP/
7v7f35fbjt3kypspSieKojwJd2IT8fxiqCQAkBMqIluAx/I1mVUkenDuM5gm
AHr1AD0dS/AYr+HeUsbJoS9dsYKc+xNG+Ejmakhcc0oc7mGGtfWRfKB9X1Na
MI8cK7jpMRP3TA3cw9j1wezUNxPOrvSlBuHqYaMHx7lH54Erjd4YMsPSgzR2
8H0p+ylm+nszW5UBbMkJB8acI0Ay/Cq2z6tMB+YX3SLcYwD7WsuxxcdBzHBN
YXdT8j4KV6kMr13DYZe5/0O5rTgCbPePiWLfPsXnya9SGR7pMA90Vcx2PBm1
3QsDKUZ1CDQm+Unu25t9UzVmqbjELN49DFKGq/O6G87Jqd5rQZKZZdhlLYnh
mDsHQYqlrWyGfFy3hniZ9lWyL0zmhUhmsct0O5SzFihACqM5A9zfmSHSqa4/
6+P7IsnXMHsrWDSLXXRBGGPNDwQxA1f9QX9BBsyDOGC7WvGxFNWf9nYbzT0g
OjNZGMYYcsNHFvL2gpgvmkxDfdyOmD85ewAZSjObyTk1rU01i+V7co6O6tXh
5XM3/GBexNfHWd11sZ4U8VuQRu7xkLUsySGLHdhVF+0e0Jfpw81ny2Ctn7pC
/N6KiBiB1jZkMItl+0kHdumitlKtibLGKaU3zF3ftcpCZQYs6quB/fSex7Rp
YD4/yCH3g8y+TNzdjL833Uk35NGe4DViUnnBXNbODcEZMjuOHXxfpOsyRWvc
NhN9xRMsqu3rglmcwdnl95Uu0sWeP2HsTNgC9GV3sCg9RE2QPcxgFmfs36e1
EZvFqAhjS5QLvIt3hU4BHuM1sjcgZBz+P2ojnP9HTpA5Z7VAJVxbyazt+wf3
lDuf
                    "], {{0, 0}, {20, 22}}, {0, 255}, ColorFunction -> 
                    RGBColor], {
                    ImageSize -> {20, 22}, 
                    PlotRange -> {{0, 20}, {0, 22}}}]}, {
                    InterpretationBox[
                    Cell[
                    BoxData[
                    FormBox[
                    StyleBox["\"Help\"", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif", StripOnInput -> False], TextForm]], 
                    "InlineText"], 
                    Text[
                    Style["Help", 10, 
                    RGBColor[0.3882, 0.3882, 0.3882], FontFamily -> 
                    "Sans Serif"]]]}}, 
                    GridBoxAlignment -> {"Columns" -> {{Center}}}, 
                    DefaultBaseStyle -> "Column", 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{0}}}], "Column"]}, 
                  Dynamic[
                   FrontEnd`CurrentValue["MouseOver"]]], ButtonFunction :> 
                 SystemOpen["paclet:ReportGeneration/tutorial/Overview"], 
                 Appearance -> None, Evaluator -> Automatic, Method -> 
                 "Preemptive"], 
                InterpretationBox[
                 Cell[
                  BoxData[
                   FormBox[
                    StyleBox[
                    "\"Show the Report Generation User Guide.\"", {
                    FontFamily -> "Sans Serif"}, StripOnInput -> False], 
                    TextForm]], "InlineText"], 
                 Text[
                  Style[
                  "Show the Report Generation User Guide.", {
                   FontFamily -> "Sans Serif"}]]], TooltipDelay -> 0.6], 
               Annotation[#, 
                Text[
                 Style[
                 "Show the Report Generation User Guide.", {
                  FontFamily -> "Sans Serif"}]], "Tooltip"]& ], "\"   \""}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}}],
            "Grid"], Alignment -> Right, StripOnInput -> False]}}, 
       GridBoxAlignment -> {"Rows" -> {{Bottom}}}, AutoDelete -> False, 
       GridBoxItemSize -> {"Columns" -> {
           Scaled[0.5], 
           Scaled[0.5]}}], "Grid"], ImageMargins -> {{0, -1}, {0, -1}}], 
    Alignment -> {Center, Center}, ImageMargins -> {{0, -1.5}, {0, -0.5}}, 
    FrameMargins -> {{0, 0}, {0, 0}}, Appearance -> Image[CompressedData["
1:eJyd0jsOwjAMBuAIOnAN7sFCj1BO0EqwIhUk1PPm/X6sGUIqFVYrtWT7+z37
PD2HxwEh9DrVMYyf6zyPy62roV/e9+lYcam97vW4Vfkh51y2XFJKoGOMux1C
aLL3vsnOOdDWWtDGGNBaa9BKKdBSyiYLIUBzzkEzxppMKW0yIWS3McaQ/z/8
BQ+BVdQ=
      "], "Byte", ColorSpace -> "RGB", ImageSize -> Magnification[1], 
      Interleaving -> True]]], "TemplateDockedCell"],
TaggingRules->{
 "Highlight" -> True, "ReportTemplateVersion" -> 1., 
  "TemplateVariablesValue" -> {
   "ticker" -> "GE", "name" -> "General Electric", "interestRate" -> 0.002, 
    "expirationYears" -> 1}, 
  "TemplateVariables" -> {
   "ticker" -> "GE", "name" -> 
    Style["General Electric", ShowStringCharacters -> False], "interestRate" -> 
    0.002, "expirationYears" -> 1}},
CellContext->Notebook,
ShowCellTags->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (May 20, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "/company:"->{
  Cell[1896, 53, 378, 10, 133, "Section",
   CellTags->"/company:"],
  Cell[2277, 65, 5472, 109, 414, "Input",
   CellTags->{"/company:", "EvaluateDeleteInput:"}]},
 "EvaluateDeleteInput:"->{
  Cell[2277, 65, 5472, 109, 414, "Input",
   CellTags->{"/company:", "EvaluateDeleteInput:"}]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"/company:", 31290, 655},
 {"EvaluateDeleteInput:", 31482, 660}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 285, 7, 55, "TemplateHeaderCell"],
Cell[CellGroupData[{
Cell[867, 31, 621, 10, 113, "Title"],
Cell[1491, 43, 380, 6, 62, "Subtitle"],
Cell[CellGroupData[{
Cell[1896, 53, 378, 10, 133, "Section",
 CellTags->"/company:"],
Cell[2277, 65, 5472, 109, 414, "Input",
 CellTags->{"/company:", "EvaluateDeleteInput:"}]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
