(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   4141537,      79558]
NotebookOptionsPosition[   4133595,      79290]
NotebookOutlinePosition[   4133967,      79306]
CellTagsIndexPosition[   4133924,      79303]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Report Generation Examples", "Title",
 CellChangeTimes->{{3.583783014205821*^9, 3.5837830283526306`*^9}}],

Cell[CellGroupData[{

Cell["Load packages", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<CUDALink`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Calendar`\>\"", "]"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Code", "Section",
 CellChangeTimes->{{3.520786469854125*^9, 3.52078648436975*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dividends", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<DividendYield\>\"", ",", "\"\<DividendPerShare\>\"", ",", 
     "\"\<Dividend\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"LongTermTrends", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Average200Day\>\"", ",", "\"\<Average50Day\>\"", ",", 
     "\"\<AverageVolume3Month\>\"", ",", "\"\<Change200Day\>\"", ",", 
     "\"\<Change50Day\>\"", ",", "\"\<ChangeHigh52Week\>\"", ",", 
     "\"\<ChangeLow52Week\>\"", ",", "\"\<CumulativeFractionalChange\>\"", 
     ",", "\"\<CumulativeReturn\>\"", ",", "\"\<FractionalChange\>\"", ",", 
     "\"\<FractionalChange200Day\>\"", ",", "\"\<FractionalChange50Day\>\"", 
     ",", "\"\<FractionalChangeHigh52Week\>\"", ",", 
     "\"\<FractionalChangeLow52Week\>\"", ",", "\"\<Volatility20Day\>\"", 
     ",", "\"\<Volatility50Day\>\"", ",", "\"\<High52Week\>\"", ",", 
     "\"\<Low52Week\>\"", ",", "\"\<Range52Week\>\""}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"DailyPriceProperties", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Change\>\"", ",", "\"\<Close\>\"", ",", "\"\<FractionalChange\>\"", 
     ",", "\"\<High\>\"", ",", "\"\<Low\>\"", ",", "\"\<Open\>\"", ",", 
     "\"\<OHLC\>\"", ",", "\"\<OHLCV\>\"", ",", "\"\<Range\>\"", ",", 
     "\"\<Return\>\"", ",", "\"\<Volume\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RecentPriceProperties", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Bid\>\"", ",", "\"\<Ask\>\"", ",", "\"\<LatestTrade\>\"", ",", 
     "\"\<Price\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RawDailyPriceProperties", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<RawClose\>\"", ",", "\"\<RawHigh\>\"", ",", "\"\<RawLow\>\"", ",", 
     "\"\<RawOHLC\>\"", ",", "\"\<RawOpen\>\"", ",", "\"\<RawRange\>\""}], 
    "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Fundamentals", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<BookValuePerShare\>\"", ",", "\"\<FloatShares\>\"", ",", 
     "\"\<ForwardPERatio\>\"", ",", "\"\<MarketCap\>\"", ",", 
     "\"\<PEGRatio\>\"", ",", "\"\<PriceTarget\>\"", ",", 
     "\"\<PriceToBookRatio\>\"", ",", "\"\<PriceToSalesRatio\>\"", ",", 
     "\"\<ShortRatio\>\"", ",", "\"\<YearPERatioEstimate\>\""}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Earnings", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<EarningsPerShare\>\"", ",", "\"\<EBITDA\>\"", ",", 
     "\"\<ForwardEarnings\>\"", ",", "\"\<QuarterForwardEarnings\>\"", ",", 
     "\"\<YearEarningsEstimate\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "financialDataProperties", "]"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "financialDataProperties", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Properties\>\"", "\[Rule]", "All"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "\"\<Dividends\>\"", ",", "\"\<LongTermTrends\>\"", ",", 
      "\"\<DailyPriceProperties\>\"", ",", "\"\<RecentPriceProperties\>\"", 
      ",", "\"\<RawDailyPriceProperties\>\"", ",", "\"\<Fundamentals\>\"", 
      ",", "\"\<Earnings\>\""}], " ", "*)"}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"financialDataProperties", "[", 
   RowBox[{"name_String", ",", 
    RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"optVal", "=", 
       RowBox[{"OptionValue", "[", "\"\<Properties\>\"", "]"}]}], ",", 
      "props", ",", "heading", ",", "cases"}], "}"}], ",", 
    RowBox[{
     RowBox[{"props", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{"optVal", ",", "All", ",", 
        RowBox[{"FinancialData", "[", 
         RowBox[{"name", ",", "\"\<Properties\>\""}], "]"}], ",", 
        "\"\<Dividends\>\"", ",", "Dividends", ",", "\"\<LongTermTrends\>\"", 
        ",", "LongTermTrends", ",", "\"\<DailyPriceProperties\>\"", ",", 
        "DailyPriceProperties", ",", "\"\<RecentPriceProperties\>\"", ",", 
        "RecentPriceProperties", ",", "\"\<RawDailyPriceProperties\>\"", ",", 
        "RawDailyPriceProperties", ",", "\"\<Fundamentals\>\"", ",", 
        "Fundamentals", ",", "\"\<Earnings\>\"", ",", "Earnings", ",", "_", 
        ",", 
        RowBox[{"FinancialData", "[", 
         RowBox[{"name", ",", "\"\<Properties\>\""}], "]"}]}], "]"}]}], ";", 
     RowBox[{"heading", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{
       "optVal", ",", "All", ",", "\"\<All Properties\>\"", ",", 
        "\"\<Dividends\>\"", ",", "\"\<Dividend Properties\>\"", ",", 
        "\"\<LongTermTrends\>\"", ",", "\"\<Long Term Trend Properties\>\"", 
        ",", "\"\<DailyPriceProperties\>\"", ",", 
        "\"\<Daily Price Properties\>\"", ",", 
        "\"\<RecentPriceProperties\>\"", ",", 
        "\"\<Recent Price Properties\>\"", ",", 
        "\"\<RawDailyPriceProperties\>\"", ",", 
        "\"\<Raw Daily Price Properties\>\"", ",", "\"\<Fundamentals\>\"", 
        ",", "\"\<Fundamental Properties\>\"", ",", "\"\<Earnings\>\"", ",", 
        "\"\<Earning Properties\>\"", ",", "_", ",", 
        "\"\<All Properties\>\""}], "]"}]}], ";", 
     RowBox[{"cases", "=", 
      RowBox[{"Cases", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"props", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"FinancialData", "[", 
              RowBox[{"name", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
            "props"}]}], "}"}], "]"}], ",", 
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"_", ",", 
            RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "}"}], 
          "|", 
          RowBox[{"{", 
           RowBox[{"_", ",", "_FinancialData"}], "}"}], "|", 
          RowBox[{"{", 
           RowBox[{"_", ",", 
            RowBox[{"{", 
             RowBox[{"_List", ",", "_"}], "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
     ";", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Grid", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Transpose", " ", "/@", " ", 
            RowBox[{"Switch", "[", 
             RowBox[{"optVal", ",", "\"\<LongTermTrends\>\"", ",", 
              RowBox[{"Partition", "[", 
               RowBox[{"cases", ",", "3", ",", "3", ",", "1", ",", 
                RowBox[{"{", "}"}]}], "]"}], ",", "_", ",", 
              RowBox[{"Partition", "[", 
               RowBox[{"cases", ",", "4", ",", "4", ",", "1", ",", 
                RowBox[{"{", "}"}]}], "]"}]}], "]"}]}], ",", "1"}], "]"}], 
         ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Alignment", "\[Rule]", 
          RowBox[{"{", "Left", "}"}]}], ",", 
         RowBox[{"Background", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"None", ",", 
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Lighter", "[", 
                RowBox[{
                 RowBox[{"Blend", "[", 
                  RowBox[{"{", 
                   RowBox[{"Blue", ",", "Green"}], "}"}], "]"}], ",", ".8"}], 
                "]"}], ",", 
               RowBox[{"Lighter", "[", 
                RowBox[{"Yellow", ",", ".9"}], "]"}]}], "}"}], "}"}]}], 
           "}"}]}]}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"heading", "<>", "\"\< of \>\"", "<>", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"MatchQ", "[", 
             RowBox[{
              RowBox[{"FinancialData", "[", 
               RowBox[{"name", ",", "\"\<Name\>\""}], "]"}], ",", 
              RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "]"}], 
            ",", "name", ",", 
            RowBox[{"FinancialData", "[", 
             RowBox[{"name", ",", "\"\<Name\>\""}], "]"}]}], "]"}]}], ",", 
         RowBox[{"FontColor", "\[Rule]", "Blue"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",",
        "Top"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5838509689830904`*^9, 3.583850993063468*^9}, 
   3.5838512554654765`*^9, {3.5838520716441593`*^9, 3.583852072916232*^9}, {
   3.5838521624123507`*^9, 3.5838521967323136`*^9}, {3.583852299133171*^9, 
   3.5838523065885973`*^9}, {3.5838523373253555`*^9, 
   3.5838523495980573`*^9}, {3.583852383981024*^9, 3.583852401149006*^9}, {
   3.5838524827976756`*^9, 3.583852494798362*^9}, {3.5838526947848005`*^9, 
   3.5838526963358893`*^9}, {3.5838528147526627`*^9, 
   3.5838528517447786`*^9}, {3.5838550212408667`*^9, 3.583855026153147*^9}, {
   3.5838550602170954`*^9, 3.583855109002886*^9}, {3.583868635378916*^9, 
   3.5838686644189568`*^9}, {3.5838687659490986`*^9, 3.5838687747491107`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SimpleMovingAverage", "[", 
     RowBox[{"list_", ",", "n_Integer"}], "]"}], "/;", 
    RowBox[{"(", 
     RowBox[{"n", "<=", " ", 
      RowBox[{"Length", "[", "list", "]"}]}], ")"}]}], ":=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Mean", " ", "/@", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Take", "[", 
         RowBox[{"list", ",", "k"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"MovingAverage", "[", 
      RowBox[{"list", ",", "n"}], "]"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TrendLinesDateListPlot", "[", 
   RowBox[{
   "tickSymbol_String", ",", "proportions_List", ",", "dateRange_List"}], 
   "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"data", "=", 
       RowBox[{"FinancialData", "[", 
        RowBox[{"tickSymbol", ",", "\"\<Close\>\"", ",", "dateRange"}], 
        "]"}]}], ",", 
      RowBox[{"props", "=", "proportions"}], ",", "trdata", ",", "datarange", 
      ",", "x", ",", "lmfns", ",", "lmdata", ",", "titles"}], "}"}], ",", 
    RowBox[{
     RowBox[{"trdata", "=", 
      RowBox[{"Transpose", "[", "data", "]"}]}], ";", 
     RowBox[{"datarange", "=", 
      RowBox[{"Outer", "[", 
       RowBox[{"Times", ",", 
        RowBox[{"Sort", "[", "props", "]"}], ",", 
        RowBox[{"trdata", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";", 
     RowBox[{"lmfns", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"LinearModelFit", "[", 
         RowBox[{"#", ",", "x", ",", "x"}], "]"}], "&"}], " ", "/@", " ", 
       "datarange"}]}], ";", 
     RowBox[{"lmdata", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"Length", "[", "data", "]"}], ",", "1"}], "]"}], 
              "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"lmfns", "[", 
               RowBox[{"[", "k", "]"}], "]"}], "[", 
              RowBox[{"Length", "[", "data", "]"}], "]"}]}], "}"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "[", "lmfns", "]"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"titles", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ToString", "[", "#", "]"}], "<>", "\"\< %\>\""}], "&"}], 
       " ", "/@", " ", 
       RowBox[{"Round", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"props", "-", "1"}], "]"}], " ", "100"}], "]"}]}]}], ";", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Framed", "[", 
        RowBox[{"DateListPlot", "[", 
         RowBox[{
          RowBox[{"Prepend", "[", 
           RowBox[{"lmdata", ",", "data"}], "]"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"Frame", "\[Rule]", "False"}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<dates\>\"", ",", "\"\<Prices\>\""}], "}"}]}], ",", 
          RowBox[{"Epilog", "\[RuleDelayed]", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{
               RowBox[{"titles", "[", 
                RowBox[{"[", "k", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"data", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"-", "2"}], ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"lmfns", "[", 
                   RowBox[{"[", "k", "]"}], "]"}], "[", 
                  RowBox[{"Length", "[", "data", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1", ",", 
               RowBox[{"Length", "[", "lmfns", "]"}]}], "}"}]}], "]"}]}]}], 
         "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MatchQ", "[", 
           RowBox[{
            RowBox[{"FinancialData", "[", 
             RowBox[{"tickSymbol", ",", "\"\<Name\>\""}], "]"}], ",", 
            RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "]"}], 
          ",", "tickSymbol", ",", 
          RowBox[{"FinancialData", "[", 
           RowBox[{"tickSymbol", ",", "\"\<Name\>\""}], "]"}]}], "]"}], "<>", 
        "\"\< with \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"Length", "[", "props", "]"}], "]"}], "<>", 
        "\"\< Trend Lines\>\""}], ",", "Top"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5402394418035975`*^9, 3.5402394524032035`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DailyRangeData", "[", 
   RowBox[{"dataName_String", ",", "numbDaysOfData_Integer"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "data", ",", "rangeData", ",", "dailyGroups", ",", "rangeLists", ",", 
      "days", ",", "name"}], "}"}], ",", 
    RowBox[{
     RowBox[{"data", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"dataName", ",", " ", "\"\<Range\>\"", ",", 
        RowBox[{"DatePlus", "[", 
         RowBox[{"-", "numbDaysOfData"}], "]"}]}], "]"}]}], ";", "\n", 
     RowBox[{"rangeData", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"Subtract", " ", "@@", " ", 
           RowBox[{"Reverse", "[", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "}"}], "&"}], " ", "/@",
        " ", "data"}]}], ";", "\n", 
     RowBox[{"dailyGroups", "=", 
      RowBox[{"GatherBy", "[", 
       RowBox[{"rangeData", ",", 
        RowBox[{
         RowBox[{"DayOfWeek", "[", 
          RowBox[{"First", "[", "#", "]"}], "]"}], "&"}]}], "]"}]}], ";", 
     "\n", 
     RowBox[{"rangeLists", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "&"}], ",", " ", "dailyGroups", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"days", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"DayOfWeek", "[", 
         RowBox[{"First", "[", "#", "]"}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"dailyGroups", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], ";", 
     RowBox[{"name", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"dataName", ",", "\"\<Name\>\""}], "]"}]}], ";", "\n", 
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"BoxWhiskerChart", "[", 
         RowBox[{"rangeLists", ",", 
          RowBox[{"ChartLabels", "\[Rule]", "days"}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{
           "\"\<Box-Whisker plots for \>\"", "<>", "name", "<>", 
            "\"\< daily Ranges\>\""}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"350", ",", "200"}], "}"}]}]}], "]"}], ",", " ", 
        RowBox[{"TableForm", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Through", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
               "Length", ",", "Mean", ",", " ", "Median", ",", 
                "StandardDeviation"}], "}"}], "[", "#", "]"}], "]"}], "&"}], 
           " ", "/@", " ", "rangeLists"}], ",", " ", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"days", ",", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Number\>\"", ",", "Mean", ",", " ", "Median", ",", 
               "StandardDeviation"}], "}"}]}], "}"}]}]}], "]"}]}], "}"}], 
      "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"financialDataComparisons", "[", 
   RowBox[{
    RowBox[{"dataNames", ":", 
     RowBox[{"{", "__String", "}"}]}], ",", "numbDays_Integer"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dataArray1", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"#", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "numbDays"}], "]"}], ",", "\"\<Value\>\""}], "]"}], 
         "&"}], " ", "/@", " ", "dataNames"}]}], ",", 
      RowBox[{"returnArray1", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"#", ",", "\"\<Return\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "numbDays"}], "]"}], ",", "\"\<Value\>\""}], "]"}], 
         "&"}], " ", "/@", " ", "dataNames"}]}], ",", "dataPosns", ",", 
      "returnPosns", ",", "dataArray", ",", "returnArray", ",", "datanames", 
      ",", "stats", ",", "returnStats", ",", "trRetStats", ",", " ", 
      "histograms", ",", "rankedMeans", ",", "rankedSDs", ",", "tableStats", 
      ",", "ranktable", ",", "partNumb"}], "}"}], ",", 
    RowBox[{
     RowBox[{"dataPosns", "=", 
      RowBox[{"Position", "[", 
       RowBox[{"dataArray1", ",", 
        StyleBox[
         RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True]}], 
       StyleBox["]",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}], 
     StyleBox[";",
      ShowSpecialCharacters->False,
      ShowStringCharacters->True,
      NumberMarks->True], 
     RowBox[{"returnPosns", "=", 
      RowBox[{"Position", "[", 
       RowBox[{"returnArray1", ",", 
        StyleBox[
         RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True]}], 
       StyleBox["]",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}], 
     StyleBox[";",
      ShowSpecialCharacters->False,
      ShowStringCharacters->True,
      NumberMarks->True], 
     RowBox[{"dataArray", "=", 
      RowBox[{"Delete", "[", 
       RowBox[{"dataArray1", ",", "dataPosns"}], "]"}]}], ";", 
     RowBox[{"returnArray", "=", 
      RowBox[{"Delete", "[", 
       RowBox[{"returnArray1", ",", "returnPosns"}], "]"}]}], ";", 
     RowBox[{"datanames", "=", 
      RowBox[{"Delete", "[", 
       RowBox[{"dataNames", ",", "returnPosns"}], "]"}]}], ";", 
     RowBox[{"returnStats", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Mean", ",", " ", "StandardDeviation"}], "}"}], "[", "#", 
          "]"}], "]"}], "&"}], " ", "/@", " ", "returnArray"}]}], ";", 
     RowBox[{"stats", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Mean", ",", " ", "Median", ",", "StandardDeviation"}], 
           "}"}], "[", "#", "]"}], "]"}], "&"}], " ", "/@", " ", 
       "dataArray"}]}], ";", 
     RowBox[{"trRetStats", "=", 
      RowBox[{"Transpose", "[", "returnStats", "]"}]}], ";", 
     RowBox[{"partNumb", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "datanames", "]"}], "\[GreaterEqual]", "3"}], 
        ",", "3", ",", "2"}], "]"}]}], ";", 
     RowBox[{"tableStats", "=", 
      RowBox[{"TableForm", "[", 
       RowBox[{"stats", ",", 
        RowBox[{"TableHeadings", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"datanames", ",", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Mean\>\"", ",", " ", "\"\<Median\>\"", ",", 
             "\"\<StandardDeviation\>\""}], "}"}]}], "}"}]}]}], "]"}]}], ";", 
     RowBox[{"rankedMeans", "=", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Sort", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"trRetStats", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "datanames"}], "}"}], 
           "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#1", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ">", 
            RowBox[{"#2", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", 
     RowBox[{"rankedSDs", "=", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Sort", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"trRetStats", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "datanames"}], "}"}], 
           "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#1", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "<", 
            RowBox[{"#2", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", 
     RowBox[{"ranktable", "=", 
      RowBox[{"TableForm", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"rankedMeans", ",", "rankedSDs"}], "}"}], "]"}], ",", 
        RowBox[{"TableHeadings", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"None", ",", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Decr. Ranked \\nReturn Means\>\"", ",", " ", 
             "\"\<Incr. Ranked \\nReturn SDs\>\""}], "}"}]}], "}"}]}]}], 
       "]"}]}], ";", 
     RowBox[{"histograms", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"MapThread", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Histogram", "[", 
              RowBox[{
              "#1", ",", "Automatic", ",", "\"\<ProbabilityDensity\>\"", ",", 
               RowBox[{"PlotLabel", "\[Rule]", 
                RowBox[{"\"\<Prob Density of \>\"", "<>", "#2"}]}]}], "]"}], 
             "&"}], ",", 
            RowBox[{"{", 
             RowBox[{"dataArray", ",", "datanames"}], "}"}]}], "]"}], ",", 
          "partNumb", ",", "partNumb", ",", "1", ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"800", ",", "570"}], "}"}]}]}], "]"}]}], ";", 
     RowBox[{"Column", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Row", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"tableStats", ",", "ranktable"}], "}"}], ",", 
           "\"\<        \>\""}], "]"}], ",", "histograms"}], "}"}], ",", 
       "\"\<      \>\""}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Signer", "[", "x_", "]"}], ":=", 
   RowBox[{"Which", "[", 
    RowBox[{
     RowBox[{"x", ">", "0"}], ",", "\"\<+\>\"", ",", 
     RowBox[{"x", "\[Equal]", "0"}], ",", "\"\< \>\"", ",", "True", ",", 
     "\"\<\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "FromFractionalChangeToPercentString", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<Sign\>\"", "\[Rule]", "True"}], ",", 
      RowBox[{"\"\<DecimalDigits\>\"", "\[Rule]", "2"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FromFractionalChangeToPercentString", "[", 
     RowBox[{"xx_", ",", 
      RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", "=", 
        RowBox[{"Chop", "@", "xx"}]}], "}"}], ",", 
      RowBox[{"StringJoin", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"OptionValue", "[", "\"\<Sign\>\"", "]"}], ",", 
          RowBox[{"Signer", "@", "x"}], ",", "\"\<\>\""}], "]"}], ",", 
        RowBox[{"ToString", "@", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{"100", " ", "x"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", 
             RowBox[{"OptionValue", "@", "\"\<DecimalDigits\>\""}]}], "}"}]}],
           "]"}]}], ",", "\"\<%\>\""}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DeltaGammaHedge", "[", 
    RowBox[{"type_", ",", "a_", ",", " ", "b_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tab", ",", "lower", ",", "upper", ",", 
       RowBox[{"price", "=", 
        RowBox[{"FinancialDerivative", "[", 
         RowBox[{"type", ",", " ", "a", ",", " ", "b", ",", "\"\<Value\>\""}],
          "]"}]}], ",", 
       RowBox[{"delta", "=", 
        RowBox[{"FinancialDerivative", "[", 
         RowBox[{"type", ",", " ", "a", ",", " ", "b", ",", "\"\<Delta\>\""}],
          "]"}]}], ",", 
       RowBox[{"gamma", "=", 
        RowBox[{"FinancialDerivative", "[", 
         RowBox[{"type", ",", " ", "a", ",", " ", "b", ",", "\"\<Gamma\>\""}],
          "]"}]}], ",", "myLinearApproximation", ",", 
       "myParabolicApproximation", ",", 
       RowBox[{"underlyingprice", "=", 
        RowBox[{"\"\<CurrentPrice\>\"", "/.", "b"}]}], ",", 
       RowBox[{"strikeprice", "=", 
        RowBox[{"\"\<StrikePrice\>\"", "/.", "a"}]}], ",", 
       RowBox[{"volatility", "=", 
        RowBox[{"\"\<Volatility\>\"", "/.", "b"}]}], ",", 
       RowBox[{"timetoexpiry", "=", 
        RowBox[{"\"\<Expiration\>\"", "/.", "a"}]}], ",", "underlyingrange"}],
       "}"}], ",", " ", "\n", 
     RowBox[{
      RowBox[{
       RowBox[{"myLinearApproximation", "[", "x_", "]"}], ":=", 
       RowBox[{"price", "+", 
        RowBox[{"delta", "*", 
         RowBox[{"(", 
          RowBox[{"x", "-", "underlyingprice"}], ")"}]}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"myParabolicApproximation", "[", "x_", "]"}], ":=", 
       RowBox[{"price", "+", 
        RowBox[{"delta", "*", 
         RowBox[{"(", 
          RowBox[{"x", "-", "underlyingprice"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"gamma", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "underlyingprice"}], ")"}], "^", "2"}]}], 
          ")"}], "/", "2"}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"underlyingrange", "[", "number_", "]"}], ":=", 
       RowBox[{"underlyingprice", "+", 
        RowBox[{"number", "*", "underlyingprice", "*", "volatility", "*", 
         RowBox[{"Sqrt", "[", "timetoexpiry", "]"}]}]}]}], ";", "\n", 
      RowBox[{"lower", "=", 
       RowBox[{"underlyingprice", "-", 
        RowBox[{"1.5", "*", "strikeprice", "*", "volatility", "*", 
         RowBox[{"Sqrt", "[", "timetoexpiry", "]"}]}]}]}], ";", "\n", 
      RowBox[{"upper", "=", 
       RowBox[{"underlyingprice", "+", 
        RowBox[{"1.5", "*", "strikeprice", "*", "volatility", "*", 
         RowBox[{"Sqrt", "[", "timetoexpiry", "]"}]}]}]}], ";", "\n", 
      RowBox[{"tab", "=", 
       RowBox[{"Transpose", "@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"val", ",", 
              RowBox[{"FinancialDerivative", "[", 
               RowBox[{"type", ",", " ", "a", ",", " ", 
                RowBox[{"b", "/.", 
                 RowBox[{
                  RowBox[{"_", "[", 
                   RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "_"}], "]"}], ":>", 
                  RowBox[{"Rule", "[", 
                   RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "val"}], 
                   "]"}]}]}], ",", "\"\<Value\>\""}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"val", ",", 
              RowBox[{"myLinearApproximation", "[", "val", "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"val", ",", 
              RowBox[{"myParabolicApproximation", "[", "val", "]"}]}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"val", ",", "lower", ",", "upper", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"upper", "-", "lower"}], ")"}], "/", "81"}]}], "}"}]}], 
         "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Column", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{"tab", ",", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<underlying price\>\"", ",", "\"\<value\>\"", ",", "None", 
              ",", "None"}], "}"}]}], ",", 
           RowBox[{"AxesOrigin", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"lower", ",", "0"}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"530", ",", "370"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"FontFamily", "\[Rule]", "\"\<Verdana\>\""}], ",", 
              RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"StringJoin", " ", "@", " ", "type"}], ")"}], "<>", 
             "\"\< \[Delta]-\[Gamma] Hedge\>\""}]}], " ", ",", " ", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Value\>\"", ",", " ", "\"\<Delta\>\"", ",", 
              "\"\<Delta-Gamma\>\""}], "}"}]}]}], "]"}], ",", " ", 
         RowBox[{"Spacer", "[", "20", "]"}], ",", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"t", "=", 
             RowBox[{"Module", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"pricemovements", "=", 
                  RowBox[{"(*", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "0.5"}], ",", "0.5", ",", "1"}], "}"}], 
                   "*)"}], 
                  RowBox[{"Select", "[", 
                   RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{
                    RowBox[{"-", "1.2"}], ",", "1.2", ",", ".2"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Chop", "[", "#", "]"}], "=!=", "1000"}], "&"}]}],
                    "]"}]}], ",", "ranges", ",", "truevalues"}], "}"}], ",", 
               RowBox[{
                RowBox[{"ranges", "=", 
                 RowBox[{"N", "[", 
                  RowBox[{"underlyingrange", "/@", "pricemovements"}], 
                  "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"truevalues", "=", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"FinancialDerivative", "[", 
                    RowBox[{"type", ",", " ", "a", ",", " ", 
                    RowBox[{"b", "/.", 
                    RowBox[{
                    RowBox[{"_", "[", 
                    RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "_"}], "]"}], ":>", 
                    RowBox[{"Rule", "[", 
                    RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "#"}], 
                    "]"}]}]}], ",", "\"\<Value\>\""}], "]"}], "&"}], "/@", 
                  "ranges"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"Grid", "[", 
                 RowBox[{
                  RowBox[{"Join", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Thread", "[", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<price\>\"", ",", 
                    "\"\<shares short for \[Delta]-neutral\>\"", ",", 
                    "\"\<\[Delta]-neutral tracking error\>\"", ",", 
                    "\"\<\[Delta]-\[Gamma] shares short\>\"", ",", 
                    "\"\<\[Delta]-\[Gamma] tracking error\>\""}], "}"}], ",", 
                    " ", "Bold"}], "]"}], "]"}], "}"}], ",", 
                    RowBox[{"Transpose", "@", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"NumberForm", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"10", ",", "2"}], "}"}]}], "]"}], "&"}], ",", 
                    "ranges"}], "]"}], ",", 
                    RowBox[{"Array", "[", 
                    RowBox[{
                    RowBox[{"delta", "&"}], ",", 
                    RowBox[{"Length", "@", "ranges"}]}], "]"}], ",", 
                    RowBox[{"Map", "[", 
                    RowBox[{"FromFractionalChangeToPercentString", ",", 
                    RowBox[{
                    RowBox[{"1", "/", "price"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"delta", " ", 
                    RowBox[{"(", 
                    RowBox[{"ranges", "-", "underlyingprice"}], ")"}]}], "-", 
                    RowBox[{"(", 
                    RowBox[{"truevalues", "-", "price"}], ")"}]}], ")"}]}]}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"delta", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}], " ", "gamma", " ", 
                    RowBox[{"(", 
                    RowBox[{"#", "-", "underlyingprice"}], ")"}]}]}], ")"}], 
                    "&"}], ",", "ranges"}], "]"}], ",", 
                    RowBox[{"Map", "[", 
                    RowBox[{"FromFractionalChangeToPercentString", ",", 
                    RowBox[{
                    RowBox[{"1", "/", "price"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"delta", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}], " ", "gamma", " ", 
                    RowBox[{"(", 
                    RowBox[{"#", "-", "underlyingprice"}], ")"}]}]}], ")"}], 
                    "&"}], ",", "ranges"}], "]"}], 
                    RowBox[{"(*", 
                    RowBox[{
                    RowBox[{
                    "the", " ", "preceding", " ", "is", " ", "the", " ", 
                    "quantity", " ", "of", " ", "shares", " ", "per", " ", 
                    "option", " ", "contract", " ", "to", " ", "obtain", " ", 
                    "a", " ", "delta"}], "-", 
                    RowBox[{"gamma", " ", "hedged", " ", "portfolio"}]}], 
                    "*)"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"ranges", "-", "underlyingprice"}], ")"}]}], "-", 
                    RowBox[{"(", 
                    RowBox[{"truevalues", "-", "price"}], ")"}]}], ")"}]}]}], 
                    "]"}]}], "}"}]}]}], "]"}], ",", " ", 
                  RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]}]}], "]"}]}], 
            "}"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"FreeQ", "[", 
              RowBox[{"t", ",", "Indeterminate", ",", "Infinity"}], "]"}], 
             ",", "t", ",", "$Failed"}], "]"}]}], "]"}]}], "}"}], "]"}]}]}], 
    "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.5837831496415677`*^9, {3.591408245606044*^9, 3.591408246417245*^9}, {
   3.591408405663325*^9, 3.5914084130421376`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PFEBackTest", "[", 
    RowBox[{"OHLCVData_List", ",", "a_", ",", "b_"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "OHLCVData", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ")"}]}], ":=", 
  RowBox[{
   RowBox[{"Charting`BackTesting", "[", 
    RowBox[{"OHLCVData", ",", " ", "\"\<PFE\>\"", ",", 
     RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b"}], "}"}]}], ",", " ", 
     RowBox[{"\"\<Threshold\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"15", ",", "0.8", ",", "25", ",", 
        RowBox[{"-", "15"}]}], "}"}]}], ",", 
     RowBox[{"\"\<StopLoss\>\"", "\[Rule]", "0.1"}], ",", 
     RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", " ", 
     RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
     RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "50000"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "9", ",", "1", ",", "1", ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.499626226271566*^9, 3.499626299845377*^9}, {
   3.49962705281682*^9, 3.499627067597726*^9}, 3.5354823483060827`*^9, {
   3.5355552977200193`*^9, 3.5355553027910194`*^9}, {3.5355722056660194`*^9, 
   3.5355722059700193`*^9}, {3.5379954165271034`*^9, 3.537995421345585*^9}, {
   3.5379955401244617`*^9, 3.53799555510896*^9}, {3.5379956793482137`*^9, 
   3.5379957071882133`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MACDBackTest", "[", 
    RowBox[{"OHLCVData_List", ",", "s_", ",", "l_"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "OHLCVData", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ")"}]}], ":=", " ", 
  RowBox[{
   RowBox[{"Charting`BackTesting", "[", 
    RowBox[{"OHLCVData", ",", " ", "\"\<MACD\>\"", ",", 
     RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"s", ",", "l"}], "}"}]}], ",", " ", 
     RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", " ", 
     RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
     RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "50000"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "9", ",", "1", ",", "1", ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.499627088795846*^9, 3.499627120689699*^9}, 
   3.499627165482944*^9, {3.4996286297210293`*^9, 3.499628632824604*^9}, {
   3.49962874635847*^9, 3.499628776738965*^9}, 3.53548233387464*^9, {
   3.5355554366390195`*^9, 3.5355554405430193`*^9}, {3.5355723275310197`*^9, 
   3.5355723279300194`*^9}, {3.5379954278062305`*^9, 3.537995433015752*^9}, {
   3.5379955605305023`*^9, 3.537995563757825*^9}, 3.5379957356952133`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"LRSBackTest", "[", 
    RowBox[{"OHLCVData_List", ",", "a_", ",", "b_"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "OHLCVData", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ")"}]}], ":=", " ", 
  RowBox[{
   RowBox[{"Charting`BackTesting", "[", 
    RowBox[{"OHLCVData", ",", " ", "\"\<LRS\>\"", ",", 
     RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", "a"}], ",", " ", 
     RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
     RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
     RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "b"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "9", ",", "1", ",", "1", ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.499627088795846*^9, 3.499627120689699*^9}, 
   3.499627165482944*^9, {3.4996286297210293`*^9, 3.499628632824604*^9}, {
   3.49962874635847*^9, 3.499628776738965*^9}, 3.53548233387464*^9, {
   3.5355554366390195`*^9, 3.5355554405430193`*^9}, {3.53555571990302*^9, 
   3.5355557207350197`*^9}, {3.53555579562702*^9, 3.5355558062980194`*^9}, {
   3.5355559032370195`*^9, 3.5355559228520193`*^9}, {3.5379954416226125`*^9, 
   3.537995445036954*^9}, {3.5379955673241816`*^9, 3.537995570242473*^9}, 
   3.5379957422292137`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Data", "Section",
 CellChangeTimes->{{3.520786469854125*^9, 3.52078648436975*^9}, {
  3.52121936621875*^9, 3.521219370578125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"stocksUS", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<AAPL\>\"", ",", "\"\<GOOG\>\"", ",", "\"\<CTSH\>\"", ",", 
     "\"\<GRMN\>\"", ",", "\"\<AMZN\>\"", ",", "\"\<DLB\>\"", ",", 
     "\"\<COH\>\"", ",", "\"\<INFY\>\"", ",", "\"\<DECK\>\"", ",", 
     "\"\<BIDU\>\"", ",", "\"\<SYK\>\"", ",", "\"\<NVDA\>\"", ",", 
     "\"\<EBIX\>\"", ",", "\"\<DV\>\"", ",", "\"\<FCX\>\"", ",", 
     "\"\<AFAM\>\"", ",", "\"\<GILD\>\"", ",", "\"\<FSLR\>\"", ",", 
     "\"\<MIDD\>\"", ",", "\"\<ORCL\>\"", ",", "\"\<QSII\>\"", ",", 
     "\"\<MSFT\>\"", ",", "\"\<NFLX\>\"", ",", "\"\<WDC\>\"", ",", 
     "\"\<LULU\>\"", ",", "\"\<PG\>\"", ",", "\"\<ARO\>\"", ",", 
     "\"\<GE\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.539714494578482*^9, {3.5796246127315426`*^9, 3.57962462265316*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"stocksForeign", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<F:UTDI\>\"", ",", "\"\<F:S92\>\"", ",", "\"\<TSX:RIM\>\"", ",", 
     "\"\<F:SWV\>\"", ",", "\"\<F:NDA\>\"", ",", "\"\<F:SZG\>\"", ",", 
     "\"\<F:SDF\>\"", ",", "\"\<F:MAN\>\"", ",", "\"\<F:DBK\>\"", ",", 
     "\"\<F:DAI\>\"", ",", "\"\<ASX:WOW\>\"", ",", "\"\<F:VIA\>\"", ",", 
     "\"\<F:APC\>\"", ",", "\"\<F:BMW\>\"", ",", "\"\<F:ALV\>\"", ",", 
     "\"\<F:SAP\>\"", ",", "\"\<F:SIE\>\"", ",", "\"\<F:WDI\>\"", ",", 
     "\"\<F:CBK\>\"", ",", "\"\<F:IFX\>\"", ",", "\"\<ASX:BHP\>\"", ",", 
     "\"\<F:DB1\>\"", ",", "\"\<F:BAS\>\"", ",", "\"\<F:LHA\>\"", ",", 
     "\"\<F:ADS\>\"", ",", "\"\<F:EOAN\>\"", ",", "\"\<F:MUV2\>\"", ",", 
     "\"\<TSX:POT\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.539618721102978*^9, 3.579624647036003*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"indices", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<^AORD\>\"", ",", "\"\<^ATX\>\"", ",", "\"\<^SSEC\>\"", ",", 
     "\"\<^HSI\>\"", ",", "\"\<^N225\>\"", ",", "\"\<^BFX\>\"", ",", 
     "\"\<^BSESN\>\"", ",", "\"\<^FCHI\>\"", ",", "\"\<^BXD\>\"", ",", 
     "\"\<^BXM\>\"", ",", "\"\<^VIX\>\"", ",", "\"\<^VXN\>\"", ",", 
     "\"\<FTSE100\>\"", ",", "\"\<FTSE250\>\"", ",", "\"\<FTSE350\>\"", ",", 
     "\"\<^DJI\>\"", ",", "\"\<SP100\>\"", ",", "\"\<SP400\>\"", ",", 
     "\"\<SP500\>\"", ",", "\"\<SP600\>\"", ",", "\"\<^SSMI\>\"", ",", 
     "\"\<^OSEAX\>\"", ",", "\"\<^GDAXI\>\"", ",", "\"\<^OMXSPI\>\"", ",", 
     "\"\<^KLSE\>\"", ",", "\"\<^NZ50\>\"", ",", "\"\<^KS11\>\"", ",", 
     "\"\<^JKSE\>\"", ",", "\"\<^MXX\>\"", ",", "\"\<^MERV\>\"", ",", 
     "\"\<^BVSP\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.546793950903283*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Feedback", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583840256114871*^9, 3.5838402579229746`*^9}}],

Cell["\<\
Required: Interactivity - Manipulate. What\[CloseCurlyQuote]s special? Pitch \
at top of Examples, Captions explaining material. \
\>", "Text",
 CellChangeTimes->{{3.583840303635589*^9, 3.583840325907863*^9}, {
  3.5838405268843584`*^9, 3.583840534900817*^9}, {3.5838419558180885`*^9, 
  3.583841961034387*^9}, {3.583874610463281*^9, 3.5838746111832824`*^9}, {
  3.5841544143965464`*^9, 3.5841544374208636`*^9}, {3.5841545720455637`*^9, 
  3.5841545822211456`*^9}}],

Cell["\<\
Focal points:

1)      What is the _added_ value we offer that others don\[CloseCurlyQuote]t \
in the market

2)      Brief captions and not descriptions

3)      Why we are better\
\>", "Text",
 CellChangeTimes->{
  3.5838442803425217`*^9, {3.5841544436292186`*^9, 3.5841544510686445`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 1: Properties of Stocks\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}}],

Cell[CellGroupData[{

Cell["Template Structure", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5841543458306246`*^9, 3.5841543843868303`*^9}}],

Cell["\<\
Template Groups -> { \[OpenCurlyDoubleQuote]Stocks\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]Properties\[CloseCurlyDoubleQuote] }, Template \
Variables -> { \[OpenCurlyDoubleQuote]Stock\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]Property\[CloseCurlyDoubleQuote],\
\[OpenCurlyDoubleQuote]Dividends\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]LongTermTrends\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]DailyPriceProperties\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]RecentPriceProperties\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]RawDailyPriceProperties\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]Fundamentals\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]Earnings\[CloseCurlyDoubleQuote] }, 
EvaluateExpression -> financialDataProperties[\"Stock\", \"Properties\" -> \
\"Property\"]\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5837838408451023`*^9, 3.5837838762531276`*^9}, {
   3.583784035710248*^9, 3.583784057405489*^9}, 3.5837842152965193`*^9, {
   3.5837843077438073`*^9, 3.5837843109439907`*^9}, 3.5838044148538685`*^9, 
   3.5841543843868303`*^9}]
}, Closed]],

Cell["\<\
1)  Added Value: the WFP makes it possible to collect all the relevant data \
about companies in one place with one simple command.

2)  Caption: Every company has a wide range of financial data associated with \
it, which makes it difficult to collate and present meaningfully. Merely by \
specifying the list of companies that one is interested in, it is possible \
with the Wolfram Finance Platform to automatically generate tables and graphs \
which parse and display the data.

3)  Why we are better: Ease of use and comprehensiveness of financial data \
especially if one uses BloombergLink.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, 3.5841545102050266`*^9}],

Cell[CellGroupData[{

Cell["Company : General Electric", "Subsection",
 CellChangeTimes->{{3.5838031777391095`*^9, 3.583803197017212*^9}, {
  3.583804300438324*^9, 3.5838043052696004`*^9}}],

Cell[CellGroupData[{

Cell["Properties", "Subsubsection",
 CellChangeTimes->{{3.583803357362383*^9, 3.583803359682516*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Column", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"financialDataProperties", "[", 
      RowBox[{"\"\<GE\>\"", ",", 
       RowBox[{"\"\<Properties\>\"", "\[Rule]", "#"}]}], "]"}], "&"}], " ", "/@",
     " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<DailyPriceProperties\>\"", ",", "\"\<LongTermTrends\>\"", ",", 
      "\"\<Fundamentals\>\"", ",", "\"\<Earnings\>\"", ",", 
      "\"\<RawDailyPriceProperties\>\"", ",", "\"\<Dividends\>\""}], "}"}]}], 
   ",", 
   RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5838504909127464`*^9, 3.5838505205664425`*^9}, {
  3.5838505599536953`*^9, 3.5838506095705333`*^9}, {3.583851086164793*^9, 
  3.5838511857134867`*^9}, {3.5838683602985306`*^9, 3.5838683646885366`*^9}, {
  3.5838686887189903`*^9, 3.583868691768995*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"Change\"", "\"Close\"", "\"FractionalChange\"", "\"High\""}, {
           RowBox[{"-", "0.04`"}], "24.69`", 
           RowBox[{"-", "0.0016`"}], "24.66`"}, {
          "\"Low\"", "\"Open\"", "\"OHLC\"", "\"OHLCV\""}, {"24.5`", "24.65`", 
           RowBox[{"{", 
             RowBox[{"24.65`", ",", "24.66`", ",", "24.5`", ",", "24.69`"}], 
             "}"}], 
           RowBox[{"{", 
             
             RowBox[{"24.65`", ",", "24.66`", ",", "24.5`", ",", "24.69`", 
               ",", "31118412"}], "}"}]}, {
          "\"Range\"", "\"Volume\"", "", ""}, {
           RowBox[{"{", 
             RowBox[{"24.5`", ",", "24.66`"}], "}"}], "31118412", "", ""}}, 
         AutoDelete -> False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Daily Price Properties of General Electric Company\"", StripOnInput -> 
        False, FontFamily -> "Helvetica", FontColor -> RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"Average200Day\"", "\"Average50Day\"", 
           "\"AverageVolume3Month\""}, {"23.0299`", "23.6626`", "39737900"}, {
          "\"Change200Day\"", "\"Change50Day\"", "\"ChangeHigh52Week\""}, {
          "1.6201`", "0.9874`", 
           RowBox[{"-", "0.3`"}]}, {
          "\"ChangeLow52Week\"", "\"FractionalChange\"", 
           "\"FractionalChange200Day\""}, {"4.78`", 
           RowBox[{"-", "0.0016`"}], "0.0703`"}, {
          "\"FractionalChange50Day\"", "\"FractionalChangeHigh52Week\"", 
           "\"FractionalChangeLow52Week\""}, {"0.0417`", 
           RowBox[{"-", "0.012`"}], "0.24059999999999998`"}, {
          "\"Volatility20Day\"", "\"Volatility50Day\"", "\"High52Week\""}, {
          "0.213574860637641`", "0.18672391159447785`", "24.95`"}, {
          "\"Low52Week\"", "\"Range52Week\"", ""}, {"19.87`", 
           RowBox[{"{", 
             RowBox[{"19.87`", ",", "24.95`"}], "}"}], ""}}, AutoDelete -> 
         False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Long Term Trend Properties of General Electric Company\"", 
        StripOnInput -> False, FontFamily -> "Helvetica", FontColor -> 
        RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"BookValuePerShare\"", "\"FloatShares\"", "\"ForwardPERatio\"", 
           "\"MarketCap\""}, {
          "11.936`", "10256944000", "13.57`", "2.53`*^11"}, {
          "\"PEGRatio\"", "\"PriceTarget\"", "\"PriceToBookRatio\"", 
           "\"PriceToSalesRatio\""}, {"1.45`", "25.86`", "2.07`", "1.74`"}, {
          "\"ShortRatio\"", "\"YearPERatioEstimate\"", "", ""}, {
          "2.`", "14.87`", "", ""}}, AutoDelete -> False, 
         GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Fundamental Properties of General Electric Company\"", StripOnInput -> 
        False, FontFamily -> "Helvetica", FontColor -> RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"EarningsPerShare\"", "\"EBITDA\"", "\"ForwardEarnings\"", 
           "\"QuarterForwardEarnings\""}, {
          "1.351`", "2.8828`*^10", "1.82`", "0.53`"}, {
          "\"YearEarningsEstimate\"", "", "", ""}, {"1.66`", "", "", ""}}, 
         AutoDelete -> False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Earning Properties of General Electric Company\"", StripOnInput -> 
        False, FontFamily -> "Helvetica", FontColor -> RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"RawClose\"", "\"RawHigh\"", "\"RawLow\"", "\"RawOHLC\""}, {
          "24.69`", "24.66`", "24.5`", 
           RowBox[{"{", 
             RowBox[{"24.65`", ",", "24.66`", ",", "24.5`", ",", "24.69`"}], 
             "}"}]}, {"\"RawOpen\"", "\"RawRange\"", "", ""}, {"24.65`", 
           RowBox[{"{", 
             RowBox[{"24.5`", ",", "24.66`"}], "}"}], "", ""}}, AutoDelete -> 
         False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Raw Daily Price Properties of General Electric Company\"", 
        StripOnInput -> False, FontFamily -> "Helvetica", FontColor -> 
        RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"DividendYield\"", "\"DividendPerShare\"", "\"Dividend\""}, {
          "0.03`", "0.74`", "0.19`"}}, AutoDelete -> False, 
         GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Dividend Properties of General Electric Company\"", StripOnInput -> 
        False, FontFamily -> "Helvetica", FontColor -> RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{
  3.5838506282526016`*^9, {3.583851152575591*^9, 3.5838511857134867`*^9}, 
   3.5838683744685507`*^9, 3.5838687108590217`*^9, 3.5838688044391527`*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphs", "Subsubsection",
 CellChangeTimes->{{3.5838034744190784`*^9, 3.5838034756341476`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<GE\>\"", ",", "\"\<High\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", "\"\< \>\"", ",", "\"\<High\>\""}], 
            "}"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<GE\>\"", ",", "\"\<Low\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", "\"\< \>\"", ",", "\"\<Low\>\""}], 
            "}"}], "]"}]}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<GE\>\"", ",", "\"\<Close\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", "\"\< \>\"", ",", "\"\<Close\>\""}], 
            "}"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<GE\>\"", ",", "\"\<Return\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", "\"\< \>\"", ",", "\"\<Return\>\""}], 
            "}"}], "]"}]}]}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"700", ",", "440"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5838034901159763`*^9, 3.5838035144683695`*^9}, {
  3.583803716564928*^9, 3.583803790279145*^9}, {3.58380385821603*^9, 
  3.5838038670645366`*^9}, {3.5838039376875763`*^9, 3.5838039403277273`*^9}, {
  3.583803993608774*^9, 3.5838039959119062`*^9}, {3.5838041096094093`*^9, 
  3.583804138680072*^9}, {3.5838041699128585`*^9, 3.5838042027607374`*^9}, {
  3.583817205234436*^9, 3.583817212066827*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxV13s81fcfB/CjH0uRVFaj6DSJVppItCJfFJXN5deFJU4aEx6oaDHLpeSy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           "]]}}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       AxesOrigin->{3552681600, 19.6},
       Frame->True,
       FrameLabel->{None, None},
       FrameTicks->{{Automatic, Automatic}, {{{3550089600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3558038400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3565987200, 
            FormBox["\"Jan\"", TraditionalForm]}, {3573763200, 
            FormBox["\"Apr\"", TraditionalForm]}, {3581625600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3589574400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}, {{3550089600, 
            FormBox["\"\"", TraditionalForm]}, {3558038400, 
            FormBox["\"\"", TraditionalForm]}, {3565987200, 
            FormBox["\"\"", TraditionalForm]}, {3573763200, 
            FormBox["\"\"", TraditionalForm]}, {3581625600, 
            FormBox["\"\"", TraditionalForm]}, {3589574400, 
            FormBox["\"\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}}},
       GridLines->{{{3550089600, 
           GrayLevel[0.8]}, {3558038400, 
           GrayLevel[0.8]}, {3565987200, 
           GrayLevel[0.8]}, {3573763200, 
           GrayLevel[0.8]}, {3581625600, 
           GrayLevel[0.8]}, {3589574400, 
           GrayLevel[0.8]}}, None},
       Method->{},
       PlotLabel->FormBox[
         TemplateBox[{"\"GE\"", "\" \"", "\"High\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{{3552681600, 3.5836992*^9}, {19.689007444168734`, 24.95}},
       PlotRangeClipping->True,
       PlotRangePadding->{{620352., 620352.}, {0.10521985111662531`, 
        0.10521985111662531`}},
       Ticks->None], {192., -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxV13k4VHsYB/CRW0pCpUUpo7iUyriYLMWcVJQlaVXUpNuNUKRVyZC9LJHs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           "]]}}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       AxesOrigin->{3552681600, 19.400000000000002`},
       Frame->True,
       FrameLabel->{None, None},
       FrameTicks->{{Automatic, Automatic}, {{{3550089600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3558038400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3565987200, 
            FormBox["\"Jan\"", TraditionalForm]}, {3573763200, 
            FormBox["\"Apr\"", TraditionalForm]}, {3581625600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3589574400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}, {{3550089600, 
            FormBox["\"\"", TraditionalForm]}, {3558038400, 
            FormBox["\"\"", TraditionalForm]}, {3565987200, 
            FormBox["\"\"", TraditionalForm]}, {3573763200, 
            FormBox["\"\"", TraditionalForm]}, {3581625600, 
            FormBox["\"\"", TraditionalForm]}, {3589574400, 
            FormBox["\"\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}}},
       GridLines->{{{3550089600, 
           GrayLevel[0.8]}, {3558038400, 
           GrayLevel[0.8]}, {3565987200, 
           GrayLevel[0.8]}, {3573763200, 
           GrayLevel[0.8]}, {3581625600, 
           GrayLevel[0.8]}, {3589574400, 
           GrayLevel[0.8]}}, None},
       Method->{},
       PlotLabel->FormBox[
         TemplateBox[{"\"GE\"", "\" \"", "\"Low\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{{3552681600, 3.5836992*^9}, {19.376947890818858`, 24.73}},
       PlotRangeClipping->True,
       PlotRangePadding->{{620352., 620352.}, {0.10706104218362285`, 
        0.10706104218362285`}},
       Ticks->None], {576., -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxVVwtsU1UYriSKAkJREhPEUUAQY4LF8ZgakhbBAaIUogIyoEAkKAaKIIEB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           "]]}}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       AxesOrigin->{3552681600, 19.6},
       Frame->True,
       FrameLabel->{None, None},
       FrameTicks->{{Automatic, Automatic}, {{{3550089600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3558038400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3565987200, 
            FormBox["\"Jan\"", TraditionalForm]}, {3573763200, 
            FormBox["\"Apr\"", TraditionalForm]}, {3581625600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3589574400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}, {{3550089600, 
            FormBox["\"\"", TraditionalForm]}, {3558038400, 
            FormBox["\"\"", TraditionalForm]}, {3565987200, 
            FormBox["\"\"", TraditionalForm]}, {3573763200, 
            FormBox["\"\"", TraditionalForm]}, {3581625600, 
            FormBox["\"\"", TraditionalForm]}, {3589574400, 
            FormBox["\"\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}}},
       GridLines->{{{3550089600, 
           GrayLevel[0.8]}, {3558038400, 
           GrayLevel[0.8]}, {3565987200, 
           GrayLevel[0.8]}, {3573763200, 
           GrayLevel[0.8]}, {3581625600, 
           GrayLevel[0.8]}, {3589574400, 
           GrayLevel[0.8]}}, None},
       Method->{},
       PlotLabel->FormBox[
         TemplateBox[{"\"GE\"", "\" \"", "\"Close\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{{3552681600, 3.5836992*^9}, {19.51, 24.86}},
       PlotRangeClipping->True,
       PlotRangePadding->{{620352., 620352.}, {0.10699999999999996`, 
        0.10699999999999996`}},
       Ticks->None], {192., -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxVlwlQVFcWhl8zKIkm0hpMJbi1BkajJMF9jbYLEgWkSURFFhuj4ILSoOwC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           "]]}}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       AxesOrigin->{3552768000, 0},
       Frame->True,
       FrameLabel->{None, None},
       FrameTicks->{{Automatic, Automatic}, {{{3550089600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3558038400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3565987200, 
            FormBox["\"Jan\"", TraditionalForm]}, {3573763200, 
            FormBox["\"Apr\"", TraditionalForm]}, {3581625600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3589574400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}, {{3550089600, 
            FormBox["\"\"", TraditionalForm]}, {3558038400, 
            FormBox["\"\"", TraditionalForm]}, {3565987200, 
            FormBox["\"\"", TraditionalForm]}, {3573763200, 
            FormBox["\"\"", TraditionalForm]}, {3581625600, 
            FormBox["\"\"", TraditionalForm]}, {3589574400, 
            FormBox["\"\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}}},
       GridLines->{{{3550089600, 
           GrayLevel[0.8]}, {3558038400, 
           GrayLevel[0.8]}, {3565987200, 
           GrayLevel[0.8]}, {3573763200, 
           GrayLevel[0.8]}, {3581625600, 
           GrayLevel[0.8]}, {3589574400, 
           GrayLevel[0.8]}}, None},
       Method->{},
       PlotLabel->FormBox[
         TemplateBox[{"\"GE\"", "\" \"", "\"Return\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{{3552768000, 3.5836992*^9}, {-0.040462427745664664`, 
         0.046127803639441245`}},
       PlotRangeClipping->True,
       PlotRangePadding->{{618624., 618624.}, {0.0017318046277021181`, 
        0.0017318046277021181`}},
       Ticks->None], {576., -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->{700, 440},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5838037237363386`*^9, 3.5838039999081345`*^9, 
  3.5838041415192347`*^9, 3.583804181072497*^9, 3.583817221174348*^9}]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Company : Microsoft", "Subsection",
 CellChangeTimes->{{3.5838031777391095`*^9, 3.583803197017212*^9}, {
  3.5838042920858464`*^9, 3.5838043122299986`*^9}}],

Cell[CellGroupData[{

Cell["Properties", "Subsubsection",
 CellChangeTimes->{{3.583803357362383*^9, 3.583803359682516*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Column", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"financialDataProperties", "[", 
      RowBox[{"\"\<MSFT\>\"", ",", 
       RowBox[{"\"\<Properties\>\"", "\[Rule]", "#"}]}], "]"}], "&"}], " ", "/@",
     " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<DailyPriceProperties\>\"", ",", "\"\<LongTermTrends\>\"", ",", 
      "\"\<Fundamentals\>\"", ",", "\"\<Earnings\>\"", ",", 
      "\"\<RawDailyPriceProperties\>\"", ",", "\"\<Dividends\>\""}], "}"}]}], 
   ",", 
   RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5838504909127464`*^9, 3.5838505205664425`*^9}, {
   3.5838505599536953`*^9, 3.5838506095705333`*^9}, {3.583851086164793*^9, 
   3.5838511857134867`*^9}, {3.5838683602985306`*^9, 
   3.5838683646885366`*^9}, {3.5838686887189903`*^9, 3.583868691768995*^9}, {
   3.583868849869216*^9, 3.5838688521392193`*^9}, 3.5838690544795027`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"Change\"", "\"Close\"", "\"FractionalChange\"", "\"High\""}, {
          "0.23`", "31.39`", "0.0073`", "31.62`"}, {
          "\"Low\"", "\"Open\"", "\"OHLC\"", "\"OHLCV\""}, {
          "31.205`", "31.26`", 
           RowBox[{"{", 
             RowBox[{"31.26`", ",", "31.62`", ",", "31.205`", ",", "31.39`"}],
              "}"}], 
           RowBox[{"{", 
             
             RowBox[{"31.26`", ",", "31.62`", ",", "31.205`", ",", "31.39`", 
               ",", "38634716"}], "}"}]}, {
          "\"Range\"", "\"Volume\"", "", ""}, {
           RowBox[{"{", 
             RowBox[{"31.205`", ",", "31.62`"}], "}"}], "38634716", "", ""}}, 
         AutoDelete -> False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Daily Price Properties of Microsoft Corporation\"", StripOnInput -> 
        False, FontFamily -> "Helvetica", FontColor -> RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"Average200Day\"", "\"Average50Day\"", 
           "\"AverageVolume3Month\""}, {"30.8615`", "34.3071`", "50048000"}, {
          "\"Change200Day\"", "\"Change50Day\"", "\"ChangeHigh52Week\""}, {
          "0.7585`", 
           RowBox[{"-", "2.6871`"}], 
           RowBox[{"-", "4.81`"}]}, {
          "\"ChangeLow52Week\"", "\"FractionalChange\"", 
           "\"FractionalChange200Day\""}, {"5.36`", "0.0073`", "0.0246`"}, {
          "\"FractionalChange50Day\"", "\"FractionalChangeHigh52Week\"", 
           "\"FractionalChangeLow52Week\""}, {
           RowBox[{"-", "0.07830000000000001`"}], 
           RowBox[{"-", "0.132`"}], "0.2041`"}, {
          "\"Volatility20Day\"", "\"Volatility50Day\"", "\"High52Week\""}, {
          "0.4807939468360146`", "0.34083182210190216`", "36.43`"}, {
          "\"Low52Week\"", "\"Range52Week\"", ""}, {"26.26`", 
           RowBox[{"{", 
             RowBox[{"26.26`", ",", "36.43`"}], "}"}], ""}}, AutoDelete -> 
         False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Long Term Trend Properties of Microsoft Corporation\"", 
        StripOnInput -> False, FontFamily -> "Helvetica", FontColor -> 
        RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"BookValuePerShare\"", "\"FloatShares\"", "\"ForwardPERatio\"", 
           "\"MarketCap\""}, {
          "9.479`", "7991798000", "10.36`", "2.633`*^11"}, {
          "\"PEGRatio\"", "\"PriceTarget\"", "\"PriceToBookRatio\"", 
           "\"PriceToSalesRatio\""}, {"1.32`", "34.92`", "3.31`", "3.36`"}, {
          "\"ShortRatio\"", "\"YearPERatioEstimate\"", "", ""}, {
          "1.6`", "11.37`", "", ""}}, AutoDelete -> False, 
         GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Fundamental Properties of Microsoft Corporation\"", StripOnInput -> 
        False, FontFamily -> "Helvetica", FontColor -> RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"EarningsPerShare\"", "\"EBITDA\"", "\"ForwardEarnings\"", 
           "\"QuarterForwardEarnings\""}, {
          "2.58`", "3.0519`*^10", "3.03`", "0.78`"}, {
          "\"YearEarningsEstimate\"", "", "", ""}, {"2.76`", "", "", ""}}, 
         AutoDelete -> False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Earning Properties of Microsoft Corporation\"", StripOnInput -> 
        False, FontFamily -> "Helvetica", FontColor -> RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"RawClose\"", "\"RawHigh\"", "\"RawLow\"", "\"RawOHLC\""}, {
          "31.39`", "31.62`", "31.205`", 
           RowBox[{"{", 
             RowBox[{"31.26`", ",", "31.62`", ",", "31.205`", ",", "31.39`"}],
              "}"}]}, {"\"RawOpen\"", "\"RawRange\"", "", ""}, {"31.26`", 
           RowBox[{"{", 
             RowBox[{"31.205`", ",", "31.62`"}], "}"}], "", ""}}, AutoDelete -> 
         False, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Raw Daily Price Properties of Microsoft Corporation\"", 
        StripOnInput -> False, FontFamily -> "Helvetica", FontColor -> 
        RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
    {
     TemplateBox[{TagBox[
        GridBox[{{
          "\"DividendYield\"", "\"DividendPerShare\"", "\"Dividend\""}, {
          "0.028399999999999998`", "0.89`", "0.23`"}}, AutoDelete -> False, 
         GridBoxAlignment -> {"Columns" -> {{Left}}}, 
         GridBoxBackground -> {"Columns" -> {{None}}, "Rows" -> {{
              RGBColor[0.8, 0.9, 0.9], 
              RGBColor[1., 1., 0.9]}}}, 
         GridBoxFrame -> {"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}}, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"],
       StyleBox[
       "\"Dividend Properties of Microsoft Corporation\"", StripOnInput -> 
        False, FontFamily -> "Helvetica", FontColor -> RGBColor[0, 0, 1]]},
      "Labeled",
      DisplayFunction->(GridBox[{{
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        BaselinePosition -> {2, 1}]& ),
      InterpretationFunction->(RowBox[{"Labeled", "[", 
         RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.583868863399235*^9, 3.5838690544795027`*^9}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphs", "Subsubsection",
 CellChangeTimes->{{3.5838034744190784`*^9, 3.5838034756341476`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<MSFT\>\"", ",", "\"\<High\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", "\"\< \>\"", ",", "\"\<High\>\""}], 
            "}"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<MSFT\>\"", ",", "\"\<Low\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", "\"\< \>\"", ",", "\"\<Low\>\""}], 
            "}"}], "]"}]}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<MSFT\>\"", ",", "\"\<Close\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", "\"\< \>\"", ",", "\"\<Close\>\""}], 
            "}"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<MSFT\>\"", ",", "\"\<Return\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", "\"\< \>\"", ",", "\"\<Return\>\""}],
             "}"}], "]"}]}]}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"700", ",", "440"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5838034901159763`*^9, 3.5838035144683695`*^9}, {
  3.583803716564928*^9, 3.583803790279145*^9}, {3.58380385821603*^9, 
  3.5838038670645366`*^9}, {3.5838039376875763`*^9, 3.5838039403277273`*^9}, {
  3.583803993608774*^9, 3.5838039959119062`*^9}, {3.5838041096094093`*^9, 
  3.583804138680072*^9}, {3.5838041699128585`*^9, 3.5838042027607374`*^9}, {
  3.583804355752488*^9, 3.5838043600807357`*^9}, {3.583817232017968*^9, 
  3.5838172362902126`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxV1ntcTOsaB/DINZXsIifJKEqOrUm5RDKrbKR0oVKEOKJTYXLdtsoo6aLL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           "]]}}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       AxesOrigin->{3552681600, 26.5},
       Frame->True,
       FrameLabel->{None, None},
       FrameTicks->{{Automatic, Automatic}, {{{3550089600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3558038400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3565987200, 
            FormBox["\"Jan\"", TraditionalForm]}, {3573763200, 
            FormBox["\"Apr\"", TraditionalForm]}, {3581625600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3589574400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}, {{3550089600, 
            FormBox["\"\"", TraditionalForm]}, {3558038400, 
            FormBox["\"\"", TraditionalForm]}, {3565987200, 
            FormBox["\"\"", TraditionalForm]}, {3573763200, 
            FormBox["\"\"", TraditionalForm]}, {3581625600, 
            FormBox["\"\"", TraditionalForm]}, {3589574400, 
            FormBox["\"\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}}},
       GridLines->{{{3550089600, 
           GrayLevel[0.8]}, {3558038400, 
           GrayLevel[0.8]}, {3565987200, 
           GrayLevel[0.8]}, {3573763200, 
           GrayLevel[0.8]}, {3581625600, 
           GrayLevel[0.8]}, {3589574400, 
           GrayLevel[0.8]}}, None},
       Method->{},
       PlotLabel->FormBox[
         TemplateBox[{"\"MSFT\"", "\" \"", "\"High\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{{3552681600, 3.5836992*^9}, {26.226056124383767`, 36.43}},
       PlotRangeClipping->True,
       PlotRangePadding->{{620352., 620352.}, {0.20407887751232465`, 
        0.20407887751232465`}},
       Ticks->None], {192., -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxV1nlYTPsfB/ARkXap7r0hU0hZanBLcmkOshWNHi22GrpEhaFwhdsULdaG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           "]]}}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       AxesOrigin->{3552681600, 26.},
       Frame->True,
       FrameLabel->{None, None},
       FrameTicks->{{Automatic, Automatic}, {{{3550089600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3558038400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3565987200, 
            FormBox["\"Jan\"", TraditionalForm]}, {3573763200, 
            FormBox["\"Apr\"", TraditionalForm]}, {3581625600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3589574400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}, {{3550089600, 
            FormBox["\"\"", TraditionalForm]}, {3558038400, 
            FormBox["\"\"", TraditionalForm]}, {3565987200, 
            FormBox["\"\"", TraditionalForm]}, {3573763200, 
            FormBox["\"\"", TraditionalForm]}, {3581625600, 
            FormBox["\"\"", TraditionalForm]}, {3589574400, 
            FormBox["\"\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}}},
       GridLines->{{{3550089600, 
           GrayLevel[0.8]}, {3558038400, 
           GrayLevel[0.8]}, {3565987200, 
           GrayLevel[0.8]}, {3573763200, 
           GrayLevel[0.8]}, {3581625600, 
           GrayLevel[0.8]}, {3589574400, 
           GrayLevel[0.8]}}, None},
       Method->{},
       PlotLabel->FormBox[
         TemplateBox[{"\"MSFT\"", "\" \"", "\"Low\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{{3552681600, 3.5836992*^9}, {25.86614923134608, 35.96}},
       PlotRangeClipping->True,
       PlotRangePadding->{{620352., 620352.}, {0.20187701537307845`, 
        0.20187701537307845`}},
       Ticks->None], {576., -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxVlntsU1Ucxwt/iA6EIjMmE6GAID6CxTl5CbQIjpdQiArIgILRoJBR5CFs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           "]]}}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       AxesOrigin->{3552681600, 26.},
       Frame->True,
       FrameLabel->{None, None},
       FrameTicks->{{Automatic, Automatic}, {{{3550089600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3558038400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3565987200, 
            FormBox["\"Jan\"", TraditionalForm]}, {3573763200, 
            FormBox["\"Apr\"", TraditionalForm]}, {3581625600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3589574400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}, {{3550089600, 
            FormBox["\"\"", TraditionalForm]}, {3558038400, 
            FormBox["\"\"", TraditionalForm]}, {3565987200, 
            FormBox["\"\"", TraditionalForm]}, {3573763200, 
            FormBox["\"\"", TraditionalForm]}, {3581625600, 
            FormBox["\"\"", TraditionalForm]}, {3589574400, 
            FormBox["\"\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}}},
       GridLines->{{{3550089600, 
           GrayLevel[0.8]}, {3558038400, 
           GrayLevel[0.8]}, {3565987200, 
           GrayLevel[0.8]}, {3573763200, 
           GrayLevel[0.8]}, {3581625600, 
           GrayLevel[0.8]}, {3589574400, 
           GrayLevel[0.8]}}, None},
       Method->{},
       PlotLabel->FormBox[
         TemplateBox[{"\"MSFT\"", "\" \"", "\"Close\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{{3552681600, 3.5836992*^9}, {25.97, 36.27}},
       PlotRangeClipping->True,
       PlotRangePadding->{{620352., 620352.}, {0.2060000000000001, 
        0.2060000000000001}},
       Ticks->None], {192., -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJxV1ntQU2cWAPCLj4oiGJVqJeomVYu6PsIWxGe9KGCk1Ia1IiJCQBSlisEE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           "]], LineBox[CompressedData["
1:eJxF1HtIU3EUB/CbRqaWuTKtZbkEpQjEWr4ybHPlOxtCNdHmkJIk8VWmpOmd
Oh9Z+SBNZw9N07l8bIr0QPESBlmRMyyyLJeZmaipFBqWdM7pj/4Y47Pv7+ye
e+7ZtkcnhJ0yYRjGD174PpZ/YdnmzqS4MtVYNWxa3wMf1XiBGT5P0KVIQbs+
QGfXqSWNcWjFKJgNlzt3CnIPgEvW1IHb7voWz5zFnHMHM+esPU3HjqFnFWBj
mPNvJqoWz7MjYM5EE+sUeQetM6+H+uPu4tDeTDxvFIIV69Wq+ag6zK3lYKZw
JF+iSEWLCvC8qj2hQk7XM6y6C3lBo/v4ITXmzG5093Dv3J+raNcIMDtlXO3Y
kk/9qzBvtR/c31VE/behK2aiVuXR/QhcGsAeXz9q+jLRUhmY1d5Wa/wvYT2b
jXmVbWdnfw5a14wOqrUJqs2l/t+gA1bKLaWhWJ94tBHqe1v33jqrQtdkgZlt
BSPKxZtoQxPm1eq2+qIc6n8Q8yxNc/dgOvW/DOZCOKO+6zqay9BAnlAo/aZN
Q882gFnhrhvT7y7g9QUDaHt21sUtAy1dQstKFwI9i6h/pyaoN5E1CPviaJ4v
waLk1CKz2ArqdxFzx+LqiahE2gdHLe5DU2XEzSTqNwRtSBZyMfE0z+dgVv90
xzOfazTPn2DFqJ4XIymlfXC4B/njcQtxeRrtQyCYEb5v6duTQvM+h944NTT8
nOp183he4jEqXThP87RvnhTX1IWH8VzL0Nb+YMYq3EzZn0z9J4FF2rlXh6NZ
zBOrwRwbzDkZs9EMvwXnvzXJf7iU5nkQzMhO5Fx86Ev9x6NTS3inX+ehSypb
cD/7XngH1FD/jzH/HLpp3wTNVypuhe9LWSiJ7KD9Yc+AmR+/PxwJltE+lKOD
V/yStNL9GHvwfI9DtsVmlvZ5EvNDVyf5M9E039Nt4HUnP2fK6PdmKAOLJr4r
61cXUv/dmMs70kO+KLBewdOBA736/W3/Pf9itGP/rF8XPU/BI7RgrcHCTkL7
O4Y2SeHbfaT9Zq30OB99sLkH7Z/OU4+/V5+dA5E0D9F9tM0TvlPnZdqHT+i3
oeMWDTG0v5btcD9hUq3X9BXq1w2t3MINuSp7vJdUG3zb//+f/AWMB8q9
           "]], 
          LineBox[{{3.5833263154218445`*^9, -0.03909196260813913}, {
           3.58344*^9, 0.019426751592356517`}, {
           3.5835264*^9, -0.005935645110902832}, {3.5836128*^9, 
           0.004399748585795171}, {
           3.5836992*^9, -0.017834793491864787`}}]}}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       AxesOrigin->{3552768000, 0},
       Frame->True,
       FrameLabel->{None, None},
       FrameTicks->{{Automatic, Automatic}, {{{3550089600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3558038400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3565987200, 
            FormBox["\"Jan\"", TraditionalForm]}, {3573763200, 
            FormBox["\"Apr\"", TraditionalForm]}, {3581625600, 
            FormBox["\"Jul\"", TraditionalForm]}, {3589574400, 
            FormBox["\"Oct\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}, {{3550089600, 
            FormBox["\"\"", TraditionalForm]}, {3558038400, 
            FormBox["\"\"", TraditionalForm]}, {3565987200, 
            FormBox["\"\"", TraditionalForm]}, {3573763200, 
            FormBox["\"\"", TraditionalForm]}, {3581625600, 
            FormBox["\"\"", TraditionalForm]}, {3589574400, 
            FormBox["\"\"", TraditionalForm]}, {3552768000, 
            FormBox["\"\"", TraditionalForm]}, {3555446400, 
            FormBox["\"\"", TraditionalForm]}, {3560716800, 
            FormBox["\"\"", TraditionalForm]}, {3563308800, 
            FormBox["\"\"", TraditionalForm]}, {3568665600, 
            FormBox["\"\"", TraditionalForm]}, {3571084800, 
            FormBox["\"\"", TraditionalForm]}, {3576355200, 
            FormBox["\"\"", TraditionalForm]}, {3579033600, 
            FormBox["\"\"", TraditionalForm]}, {3584304000, 
            FormBox["\"\"", TraditionalForm]}}}},
       GridLines->{{{3550089600, 
           GrayLevel[0.8]}, {3558038400, 
           GrayLevel[0.8]}, {3565987200, 
           GrayLevel[0.8]}, {3573763200, 
           GrayLevel[0.8]}, {3581625600, 
           GrayLevel[0.8]}, {3589574400, 
           GrayLevel[0.8]}}, None},
       Method->{},
       PlotLabel->FormBox[
         TemplateBox[{"\"MSFT\"", "\" \"", "\"Return\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{{3552768000, 3.5836992*^9}, {-0.03909196260813913, 
         0.03784139519578811}},
       PlotRangeClipping->True,
       PlotRangePadding->{{618624., 618624.}, {0.0015386671560785447`, 
        0.0015386671560785447`}},
       Ticks->None], {576., -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->{700, 440},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5838037237363386`*^9, 3.5838039999081345`*^9, 
  3.5838041415192347`*^9, 3.583804181072497*^9, 3.58381724079047*^9}]
}, {2}]]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2: Ranking of Stocks", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}}],

Cell["\<\
1)  Added Value: Unlike other finance programs, the WFP has advanced \
statistical tools like distribution estimation that makes it possible to \
determine the probability density of any stock\[CloseCurlyQuote]s historical \
data.

2)  Caption: One of the most important criteria in the selection of stocks \
for a portfolio is a ranking system that allows one to see at a glance which \
stocks are better than others in terms of higher returns and lower \
volatilities. In addition one can use the WFP\[CloseCurlyQuote]s \
sophisticated statistical techniques to calculate the probability density of \
any stock from its historical data which reveals its structure.

3)  Why we are better: Rapid parallel calculation of PDFs and ranking \
criteria from easily accessible data.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Ranking of Stocks by Returns and Volatilities with corresponding PDFs\
\>", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}}],

Cell[CellGroupData[{

Cell["Stocks to be Analyzed", "Subsubsection",
 CellChangeTimes->{{3.583804972793781*^9, 3.5838049820253086`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Framed", "[", 
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"FinancialData", "[", 
       RowBox[{"#", ",", "\"\<Name\>\""}], "]"}], "&"}], " ", "/@", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SP100\>\"", ",", "\"\<SP500\>\"", ",", "\"\<^DJI\>\"", ",", 
       "\"\<SPY\>\"", ",", "\"\<^N225\>\"", ",", "\"\<FTSE100\>\"", ",", 
       "\"\<GE\>\""}], "}"}]}], ",", 
    RowBox[{"TableDirections", "\[Rule]", "Row"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.583804707444604*^9, 3.5838047239615483`*^9}, {
  3.583805005530653*^9, 3.583805010682948*^9}, {3.583805084603176*^9, 
  3.583805094794759*^9}}],

Cell[BoxData[
 FrameBox[
  TagBox[
   TagBox[GridBox[{
      {"\<\"S&P 100\"\>", "\<\"S&P 500\"\>", "\<\"Dow Jones Industrials\"\>", \
"\<\"SPDR S&P 500\"\>", "\<\"Nikkei 225\"\>", "\<\"FTSE 100\"\>", \
"\<\"General Electric Company\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Row],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$, TableDirections -> Row]]],
  StripOnInput->False]], "Output",
 CellChangeTimes->{
  3.5838047275667543`*^9, 3.583805011157975*^9, {3.5838050872253256`*^9, 
   3.58380509534879*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Statistics, Ranks and Probability Densities\
\>", "Subsubsection",
 CellChangeTimes->{{3.583804972793781*^9, 3.5838049820253086`*^9}, {
  3.5838051408423924`*^9, 3.5838051549862013`*^9}, {3.5838145849315634`*^9, 
  3.583814585603602*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"financialDataComparisons", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<SP100\>\"", ",", "\"\<SP500\>\"", ",", "\"\<^DJI\>\"", ",", 
     "\"\<SPY\>\"", ",", "\"\<^N225\>\"", ",", "\"\<FTSE100\>\"", ",", 
     "\"\<GE\>\""}], "}"}], ",", "365"}], "]"}]], "Input",
 CellChangeTimes->{{3.520025262367125*^9, 3.520025268304625*^9}, {
  3.5200280382265*^9, 3.52002803844525*^9}, {3.520030385664*^9, 
  3.5200303861015*^9}, {3.5200313647265*^9, 3.5200313663515*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{TagBox[
        TagBox[
         GridBox[{{
            StyleBox["\[Null]", ShowStringCharacters -> False], 
            TagBox["\"Mean\"", HoldForm], 
            TagBox["\"Median\"", HoldForm], 
            TagBox["\"StandardDeviation\"", HoldForm]}, {
            TagBox["\"SP100\"", HoldForm], "571.9730555555556`", 
            "577.3399999999999`", "28.561463544253648`"}, {
            TagBox["\"SP500\"", HoldForm], "1272.4519047619058`", "1285.63`", 
            "66.69212986551608`"}, {
            TagBox["\"^DJI\"", HoldForm], "12087.733968253971`", 
            "12170.369999999999`", "576.071433680681`"}, {
            TagBox["\"SPY\"", HoldForm], "126.25317460317463`", "127.345`", 
            "6.5643359917981785`"}, {
            TagBox["\"^N225\"", HoldForm], "9155.229469387752`", "9050.47`", 
            "552.6150223013105`"}, {
            TagBox["\"FTSE100\"", HoldForm], "5646.829365079364`", "5714.35`",
             "289.77513072251844`"}, {
            TagBox["\"GE\"", HoldForm], "17.510714285714297`", "17.975`", 
            "1.6314572854406626`"}}, 
          GridBoxAlignment -> {
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
          GridBoxDividers -> {
           "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {},
             "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}, 
          GridBoxSpacings -> {"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[2.0999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}], {
         OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
        Function[BoxForm`e$, 
         TableForm[
         BoxForm`e$, 
          TableHeadings -> {{
            "SP100", "SP500", "^DJI", "SPY", "^N225", "FTSE100", "GE"}, {
            "Mean", "Median", "StandardDeviation"}}]]],TagBox[
        TagBox[
         GridBox[{{
            TagBox["\"Decr. Ranked \\nReturn Means\"", HoldForm], 
            TagBox["\"Incr. Ranked \\nReturn SDs\"", HoldForm]}, {
           "\"SPY\"", "\"^DJI\""}, {"\"^DJI\"", "\"FTSE100\""}, {
           "\"SP100\"", "\"SP100\""}, {"\"SP500\"", "\"SPY\""}, {
           "\"GE\"", "\"SP500\""}, {"\"FTSE100\"", "\"^N225\""}, {
           "\"^N225\"", "\"GE\""}}, 
          GridBoxAlignment -> {
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
          GridBoxDividers -> {
           "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}, 
          GridBoxSpacings -> {"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[2.0999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}], {
         None, OutputFormsDump`HeadedColumns}], 
        Function[BoxForm`e$, 
         TableForm[
         BoxForm`e$, 
          TableHeadings -> {
           None, {"Decr. Ranked \nReturn Means", 
             "Incr. Ranked \nReturn SDs"}}]]]},
      "Row",
      DisplayFunction->(RowBox[{#, "        ", #2}]& ),
      InterpretationFunction->(RowBox[{"Row", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", "\"        \""}], "]"}]& )]},
    {
     GraphicsBox[{{}, {{InsetBox[
          GraphicsBox[
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.7]], {}, 
            {RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458], 
             EdgeForm[Opacity[0.7]], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{500., 0.}, {520., 0.002380952380952381}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{35.48522379649629, 
                  64.93955894761066}, {-32.299584357338006`, \
-15.735188250423533`}}],
                StatusArea[#, 0.002380952380952381]& ,
                TagBoxNote->"0.002380952380952381"],
               StyleBox["0.002380952380952381`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.002380952380952381, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{520., 0.}, {540., 0.005753968253968254}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{63.939558947610664`, 
                  93.39389409872516}, {-54.34914550880015, \
-15.735188250423533`}}],
                StatusArea[#, 0.005753968253968254]& ,
                TagBoxNote->"0.005753968253968254"],
               StyleBox["0.005753968253968254`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.005753968253968254, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{540., 0.}, {560., 0.007142857142857143}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{92.39389409872516, 
                  121.84822924983953`}, {-63.42837657116692, \
-15.735188250423533`}}],
                StatusArea[#, 0.007142857142857143]& ,
                TagBoxNote->"0.007142857142857143"],
               StyleBox["0.007142857142857143`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.007142857142857143, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{560., 0.}, {580., 0.010714285714285714`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{120.84822924983953`, 
                  150.30256440095403`}, {-86.77497073153862, \
-15.735188250423533`}}],
                StatusArea[#, 0.010714285714285714`]& ,
                TagBoxNote->"0.010714285714285714"],
               StyleBox["0.010714285714285714`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.010714285714285714`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{580., 0.}, {600., 0.017261904761904763`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{149.30256440095403`, 
                  178.7568995520684}, {-129.5770600255534, \
-15.735188250423533`}}],
                StatusArea[#, 0.017261904761904763`]& ,
                TagBoxNote->"0.017261904761904763"],
               StyleBox["0.017261904761904763`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.017261904761904763`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{600., 0.}, {620., 0.006150793650793651}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{177.7568995520684, 
                  207.2112347031829}, {-56.94321152661922, \
-15.735188250423533`}}],
                StatusArea[#, 0.006150793650793651]& ,
                TagBoxNote->"0.006150793650793651"],
               StyleBox["0.006150793650793651`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.006150793650793651, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  RectangleBox[{620., 0.}, {640., 0.0005952380952380953}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{206.2112347031829, 
                  235.66556985429727`}, {-20.626287277152144`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0005952380952380953]& ,
                TagBoxNote->"0.0005952380952380953"],
               StyleBox["0.0005952380952380953`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0005952380952380953, {
                 GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
           AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
           Axes->{True, True},
           AxesOrigin->{500., 0.},
           FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
           GridLines->{None, None},
           PlotLabel->FormBox["\"Prob Density of SP100\"", TraditionalForm],
           PlotRange->{{500., 640.}, {All, All}},
           PlotRangePadding->{{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.02], 
              Scaled[0.1]}},
           Ticks->{Automatic, Automatic}], {193.5, -119.58957682310464`}, 
          ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
          GraphicsBox[
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.7]], {}, 
            {RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458], 
             EdgeForm[Opacity[0.7]], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{1050., 0.}, {1100., 0.00007936507936507937}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{34.23522379649637, 
                  63.68955894761086}, {-18.062739683072124`, \
-15.735188250423533`}}],
                StatusArea[#, 0.00007936507936507937]& ,
                TagBoxNote->"0.00007936507936507937"],
               StyleBox["0.00007936507936507937`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00007936507936507937, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{1100., 0.}, {1150., 0.0007936507936507937}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{62.68955894761086, 
                  92.14389409872524}, {-30.01070257690941, \
-15.735188250423533`}}],
                StatusArea[#, 0.0007936507936507937]& ,
                TagBoxNote->"0.0007936507936507937"],
               StyleBox["0.0007936507936507937`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0007936507936507937, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{1150., 0.}, {1200., 0.002619047619047619}, 
                   "RoundingRadius" -> 0]},
                 ImageSizeCache->{{91.14389409872524, 
                  120.59822924983973`}, {-60.544385527826904`, \
-15.735188250423533`}}],
                StatusArea[#, 0.002619047619047619]& ,
                TagBoxNote->"0.002619047619047619"],
               StyleBox["0.002619047619047619`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.002619047619047619, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{1200., 0.}, {1250., 0.0031746031746031746`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{119.59822924983973`, 
                  149.0525644009541}, {-69.83724555636704, \
-15.735188250423533`}}],
                StatusArea[#, 0.0031746031746031746`]& ,
                TagBoxNote->"0.0031746031746031746"],
               StyleBox["0.0031746031746031746`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0031746031746031746`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{1250., 0.}, {1300., 0.004761904761904762}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{148.0525644009541, 
                  
                  177.5068995520685}, {-96.38827420933879, \
-15.735188250423533`}}],
                StatusArea[#, 0.004761904761904762]& ,
                TagBoxNote->"0.004761904761904762"],
               StyleBox["0.004761904761904762`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.004761904761904762, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{1300., 0.}, {1350., 0.006746031746031746}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{176.5068995520685, 
                  205.96123470318298`}, {-129.57706002555344`, \
-15.735188250423533`}}],
                StatusArea[#, 0.006746031746031746]& ,
                TagBoxNote->"0.006746031746031746"],
               StyleBox["0.006746031746031746`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.006746031746031746, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{1350., 0.}, {1400., 0.0018253968253968255`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{204.96123470318298`, 
                  234.41556985429736`}, {-47.26887120134104, \
-15.735188250423533`}}],
                StatusArea[#, 0.0018253968253968255`]& ,
                TagBoxNote->"0.0018253968253968255"],
               StyleBox["0.0018253968253968255`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0018253968253968255`, {
                 GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
           AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
           Axes->{True, True},
           AxesOrigin->{1050., 0.},
           FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
           GridLines->{None, None},
           PlotLabel->FormBox["\"Prob Density of SP500\"", TraditionalForm],
           PlotRange->{{1050., 1400.}, {All, All}},
           PlotRangePadding->{{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.02], 
              Scaled[0.1]}},
           Ticks->{Automatic, Automatic}], {580.5, -119.58957682310464`}, 
          ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
          GraphicsBox[
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.7]], {}, 
            {RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458], 
             EdgeForm[Opacity[0.7]], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{10600., 0.}, {10800., 0.00007936507936507937},
                    "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{39.61042852506091, 
                  55.93199360643018}, {-28.308713560693263`, \
-15.735188250423533`}}],
                StatusArea[#, 0.00007936507936507937]& ,
                TagBoxNote->"0.00007936507936507937"],
               StyleBox["0.00007936507936507937`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00007936507936507937, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{10800., 0.}, {11000., 
                   0.00015873015873015873`}, "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{54.93199360643018, 
                  71.25355868779957}, {-39.88223887096301, \
-15.735188250423533`}}],
                StatusArea[#, 0.00015873015873015873`]& ,
                TagBoxNote->"0.00015873015873015873"],
               StyleBox["0.00015873015873015873`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00015873015873015873`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{11000., 0.}, {11200., 
                   0.00025793650793650796`}, "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{70.25355868779957, 
                  86.57512376916884}, {-54.34914550880018, \
-15.735188250423533`}}],
                StatusArea[#, 0.00025793650793650796`]& ,
                TagBoxNote->"0.00025793650793650796"],
               StyleBox["0.00025793650793650796`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00025793650793650796`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{11200., 0.}, {11400., 
                   0.00021825396825396825`}, "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{85.57512376916884, 
                  101.89668885053811`}, {-48.5623828536653, \
-15.735188250423533`}}],
                StatusArea[#, 0.00021825396825396825`]& ,
                TagBoxNote->"0.00021825396825396825"],
               StyleBox["0.00021825396825396825`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00021825396825396825`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{11400., 0.}, {11600., 0.0004563492063492064}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{100.89668885053811`, 
                  117.2182539319075}, {-83.28295878447452, \
-15.735188250423533`}}],
                StatusArea[#, 0.0004563492063492064]& ,
                TagBoxNote->"0.0004563492063492064"],
               StyleBox["0.0004563492063492064`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0004563492063492064, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{11600., 0.}, {11800., 0.0001984126984126984}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{116.2182539319075, 
                  132.53981901327677`}, {-45.66900152609787, \
-15.735188250423533`}}],
                StatusArea[#, 0.0001984126984126984]& ,
                TagBoxNote->"0.0001984126984126984"],
               StyleBox["0.0001984126984126984`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0001984126984126984, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{11800., 0.}, {12000., 0.0004761904761904762}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{131.53981901327677`, 
                  147.86138409464616`}, {-86.17634011204194, \
-15.735188250423533`}}],
                StatusArea[#, 0.0004761904761904762]& ,
                TagBoxNote->"0.0004761904761904762"],
               StyleBox["0.0004761904761904762`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0004761904761904762, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{12000., 0.}, {12200., 0.0007738095238095238}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{146.86138409464616`, 
                  163.18294917601543`}, {-129.57706002555344`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0007738095238095238]& ,
                TagBoxNote->"0.0007738095238095238"],
               StyleBox["0.0007738095238095238`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0007738095238095238, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{12200., 0.}, {12400., 0.0006547619047619047}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{162.18294917601543`, 
                  178.5045142573848}, {-112.21677206014883`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0006547619047619047]& ,
                TagBoxNote->"0.0006547619047619047"],
               StyleBox["0.0006547619047619047`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0006547619047619047, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{12400., 0.}, {12600., 0.0007142857142857143}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{177.5045142573848, 
                  193.82607933875408`}, {-120.89691604285113`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0007142857142857143]& ,
                TagBoxNote->"0.0007142857142857143"],
               StyleBox["0.0007142857142857143`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0007142857142857143, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{12600., 0.}, {12800., 0.0005357142857142857}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{192.82607933875408`, 
                  209.14764442012336`}, {-94.85648409474425, \
-15.735188250423533`}}],
                StatusArea[#, 0.0005357142857142857]& ,
                TagBoxNote->"0.0005357142857142857"],
               StyleBox["0.0005357142857142857`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0005357142857142857, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{12800., 0.}, {13000., 0.0004563492063492064}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{208.14764442012336`, 
                  224.46920950149274`}, {-83.28295878447452, \
-15.735188250423533`}}],
                StatusArea[#, 0.0004563492063492064]& ,
                TagBoxNote->"0.0004563492063492064"],
               StyleBox["0.0004563492063492064`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0004563492063492064, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{13000., 0.}, {13200., 0.00001984126984126984},
                    "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{223.46920950149274`, 
                  239.790774582862}, {-19.628569577990973`, \
-15.735188250423533`}}],
                StatusArea[#, 0.00001984126984126984]& ,
                TagBoxNote->"0.00001984126984126984"],
               StyleBox["0.00001984126984126984`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00001984126984126984, {
                 GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
           AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
           Axes->{True, True},
           AxesOrigin->{10600., 0.},
           FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
           GridLines->{None, None},
           PlotLabel->FormBox["\"Prob Density of ^DJI\"", TraditionalForm],
           PlotRange->{{10600., 13200.}, {All, All}},
           PlotRangePadding->{{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.02], 
              Scaled[0.1]}},
           Ticks->{Automatic, Automatic}], {967.5, -119.58957682310464`}, 
          ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
          GraphicsBox[
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.7]], {}, 
            {RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458], 
             EdgeForm[Opacity[0.7]], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{105., 0.}, {110., 0.0007936507936507937}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{32.98522379649629, 
                  62.439558947610784`}, {-18.239746540758603`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0007936507936507937]& ,
                TagBoxNote->"0.0007936507936507937"],
               StyleBox["0.0007936507936507937`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0007936507936507937, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{110., 0.}, {115., 0.011111111111111112`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{61.439558947610784`, 
                  90.89389409872527}, {-37.799004315114445`, \
-15.735188250423533`}}],
                StatusArea[#, 0.011111111111111112`]& ,
                TagBoxNote->"0.011111111111111112"],
               StyleBox["0.011111111111111112`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.011111111111111112`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{115., 0.}, {120., 0.03015873015873016}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{89.89389409872527, 
                  119.34822924983965`}, {-73.90840328315602, \
-15.735188250423533`}}],
                StatusArea[#, 0.03015873015873016]& ,
                TagBoxNote->"0.03015873015873016"],
               StyleBox["0.03015873015873016`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.03015873015873016, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{120., 0.}, {125., 0.030952380952380953`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{118.34822924983965`, 
                  147.80256440095414`}, {-75.41296157349109, \
-15.735188250423533`}}],
                StatusArea[#, 0.030952380952380953`]& ,
                TagBoxNote->"0.030952380952380953"],
               StyleBox["0.030952380952380953`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.030952380952380953`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{125., 0.}, {130., 0.05952380952380952}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{146.80256440095414`, 
                  176.25689955206852`}, {-129.57706002555344`, \
-15.735188250423533`}}],
                StatusArea[#, 0.05952380952380952]& ,
                TagBoxNote->"0.05952380952380952"],
               StyleBox["0.05952380952380952`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.05952380952380952, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{130., 0.}, {135., 0.05396825396825397}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{175.25689955206852`, 
                  204.711234703183}, {-119.04515199320798`, \
-15.735188250423533`}}],
                StatusArea[#, 0.05396825396825397]& ,
                TagBoxNote->"0.05396825396825397"],
               StyleBox["0.05396825396825397`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.05396825396825397, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{135., 0.}, {140., 0.013492063492063493`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{203.711234703183, 
                  233.1655698542974}, {-42.31267918611965, \
-15.735188250423533`}}],
                StatusArea[#, 0.013492063492063493`]& ,
                TagBoxNote->"0.013492063492063493"],
               StyleBox["0.013492063492063493`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.013492063492063493`, {
                 GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
           AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
           Axes->{True, True},
           AxesOrigin->{105., 0.},
           FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
           GridLines->{None, None},
           PlotLabel->FormBox["\"Prob Density of SPY\"", TraditionalForm],
           PlotRange->{{105., 140.}, {All, All}},
           PlotRangePadding->{{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.02], 
              Scaled[0.1]}},
           Ticks->{Automatic, Automatic}], {193.5, -358.76873046931394`}, 
          ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
          GraphicsBox[
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.7]], {}, 
            {RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458], 
             EdgeForm[Opacity[0.7]], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{8000., 0.}, {8200., 0.000040816326530612245`},
                    "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{43.31156508267418, 
                  58.91377816150987}, {-21.62354791367156, \
-15.735188250423533`}}],
                StatusArea[#, 0.000040816326530612245`]& ,
                TagBoxNote->"0.000040816326530612245"],
               StyleBox["0.000040816326530612245`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.000040816326530612245`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{8200., 0.}, {8400., 0.00028571428571428574`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{57.91377816150987, 
                  73.51599124034544}, {-50.953705893159665`, \
-15.735188250423533`}}],
                StatusArea[#, 0.00028571428571428574`]& ,
                TagBoxNote->"0.00028571428571428574"],
               StyleBox["0.00028571428571428574`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00028571428571428574`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{8400., 0.}, {8600., 0.0006326530612244898}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{72.51599124034544, 
                  88.11820431918102}, {-92.50476303076783, \
-15.735188250423533`}}],
                StatusArea[#, 0.0006326530612244898]& ,
                TagBoxNote->"0.0006326530612244898"],
               StyleBox["0.0006326530612244898`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0006326530612244898, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{8600., 0.}, {8800., 0.0008979591836734694}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{87.11820431918102, 
                  102.7204173980166}, {-124.27910084187995`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0008979591836734694]& ,
                TagBoxNote->"0.0008979591836734694"],
               StyleBox["0.0008979591836734694`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0008979591836734694, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{8800., 0.}, {9000., 0.0005714285714285715}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{101.7204173980166, 
                  117.32263047685228`}, {-85.1722235358958, \
-15.735188250423533`}}],
                StatusArea[#, 0.0005714285714285715]& ,
                TagBoxNote->"0.0005714285714285715"],
               StyleBox["0.0005714285714285715`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0005714285714285715, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{9000., 0.}, {9200., 0.00022448979591836734`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{116.32263047685228`, 
                  131.92484355568786`}, {-43.62116639828764, \
-15.735188250423533`}}],
                StatusArea[#, 0.00022448979591836734`]& ,
                TagBoxNote->"0.00022448979591836734"],
               StyleBox["0.00022448979591836734`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00022448979591836734`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{9200., 0.}, {9400., 0.00016326530612244898`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{130.92484355568786`, 
                  146.52705663452343`}, {-36.288626903415604`, \
-15.735188250423533`}}],
                StatusArea[#, 0.00016326530612244898`]& ,
                TagBoxNote->"0.00016326530612244898"],
               StyleBox["0.00016326530612244898`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00016326530612244898`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{9400., 0.}, {9600., 0.0007755102040816326}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{145.52705663452343`, 
                  161.129269713359}, {-109.61402185213589`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0007755102040816326]& ,
                TagBoxNote->"0.0007755102040816326"],
               StyleBox["0.0007755102040816326`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0007755102040816326, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{9600., 0.}, {9800., 0.0007755102040816326}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{160.129269713359, 
                  175.73148279219458`}, {-109.61402185213589`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0007755102040816326]& ,
                TagBoxNote->"0.0007755102040816326"],
               StyleBox["0.0007755102040816326`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0007755102040816326, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{9800., 0.}, {10000., 0.0003469387755102041}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{174.73148279219458`, 
                  190.33369587103027`}, {-58.286245388031695`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0003469387755102041]& ,
                TagBoxNote->"0.0003469387755102041"],
               StyleBox["0.0003469387755102041`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0003469387755102041, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{10000., 0.}, {10200., 
                   0.00022448979591836734`}, "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{189.33369587103027`, 
                  204.93590894986585`}, {-43.62116639828764, \
-15.735188250423533`}}],
                StatusArea[#, 0.00022448979591836734`]& ,
                TagBoxNote->"0.00022448979591836734"],
               StyleBox["0.00022448979591836734`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00022448979591836734`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{10200., 0.}, {10400., 
                   0.000020408163265306123`}, "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{203.93590894986585`, 
                  219.53812202870142`}, {-19.179368082047546`, \
-15.735188250423533`}}],
                StatusArea[#, 0.000020408163265306123`]& ,
                TagBoxNote->"0.000020408163265306123"],
               StyleBox["0.000020408163265306123`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.000020408163265306123`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{10400., 0.}, {10600., 
                   0.000040816326530612245`}, "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{218.53812202870142`, 
                  234.140335107537}, {-21.62354791367156, \
-15.735188250423533`}}],
                StatusArea[#, 0.000040816326530612245`]& ,
                TagBoxNote->"0.000040816326530612245"],
               StyleBox["0.000040816326530612245`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.000040816326530612245`, {
                 GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
           AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
           Axes->{True, True},
           AxesOrigin->{8000., 0.},
           FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
           GridLines->{None, None},
           PlotLabel->FormBox["\"Prob Density of ^N225\"", TraditionalForm],
           PlotRange->{{8000., 10600.}, {All, All}},
           PlotRangePadding->{{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.02], 
              Scaled[0.1]}},
           Ticks->{Automatic, Automatic}], {580.5, -358.76873046931394`}, 
          ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
          GraphicsBox[
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.7]], {}, 
            {RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458], 
             EdgeForm[Opacity[0.7]], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{4800., 0.}, {5000., 0.00001984126984126984}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{36.735223796496484`, 
                  66.18955894761098}, {-18.16356637415936, \
-15.735188250423533`}}],
                StatusArea[#, 0.00001984126984126984]& ,
                TagBoxNote->"0.00001984126984126984"],
               StyleBox["0.00001984126984126984`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.00001984126984126984, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{5000., 0.}, {5200., 0.0004761904761904762}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{65.18955894761098, 
                  94.64389409872535}, {-51.01626322008325, \
-15.735188250423533`}}],
                StatusArea[#, 0.0004761904761904762]& ,
                TagBoxNote->"0.0004761904761904762"],
               StyleBox["0.0004761904761904762`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0004761904761904762, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{5200., 0.}, {5400., 0.0006944444444444445}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{93.64389409872535, 
                  123.09822924983973`}, {-66.72842258117728, \
-15.735188250423533`}}],
                StatusArea[#, 0.0006944444444444445]& ,
                TagBoxNote->"0.0006944444444444445"],
               StyleBox["0.0006944444444444445`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0006944444444444445, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{5400., 0.}, {5600., 0.000873015873015873}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{122.09822924983973`, 
                  151.55256440095422`}, {-79.58382569479969, \
-15.735188250423533`}}],
                StatusArea[#, 0.000873015873015873]& ,
                TagBoxNote->"0.000873015873015873"],
               StyleBox["0.000873015873015873`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.000873015873015873, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{5600., 0.}, {5800., 0.000992063492063492}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{150.55256440095422`, 
                  180.0068995520686}, {-88.15409443721461, \
-15.735188250423533`}}],
                StatusArea[#, 0.000992063492063492]& ,
                TagBoxNote->"0.000992063492063492"],
               StyleBox["0.000992063492063492`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.000992063492063492, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{5800., 0.}, {6000., 0.0015674603174603175`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{179.0068995520686, 
                  208.4612347031831}, {-129.57706002555344`, \
-15.735188250423533`}}],
                StatusArea[#, 0.0015674603174603175`]& ,
                TagBoxNote->"0.0015674603174603175"],
               StyleBox["0.0015674603174603175`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.0015674603174603175`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{6000., 0.}, {6200., 0.000376984126984127}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{207.4612347031831, 
                  236.91556985429747`}, {-43.87437260140415, \
-15.735188250423533`}}],
                StatusArea[#, 0.000376984126984127]& ,
                TagBoxNote->"0.000376984126984127"],
               StyleBox["0.000376984126984127`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.000376984126984127, {
                 GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
           AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
           Axes->{True, True},
           AxesOrigin->{4800., 0.},
           FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
           GridLines->{None, None},
           PlotLabel->FormBox["\"Prob Density of FTSE100\"", TraditionalForm],
           PlotRange->{{4800., 6200.}, {All, All}},
           PlotRangePadding->{{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.02], 
              Scaled[0.1]}},
           Ticks->{Automatic, Automatic}], {967.5, -358.76873046931394`}, 
          ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
          GraphicsBox[
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.7]], {}, 
            {RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458], 
             EdgeForm[Opacity[0.7]], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{14., 0.}, {15., 0.07936507936507936}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{35.95492406426158, 
                  69.57841498463998}, {-48.419000882586545`, \
-15.735188250423448`}}],
                StatusArea[#, 0.07936507936507936]& ,
                TagBoxNote->"0.07936507936507936"],
               StyleBox["0.07936507936507936`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.07936507936507936, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{15., 0.}, {16., 0.18253968253968253`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{68.57841498463998, 
                  102.20190590501838`}, {-89.60795730439861, \
-15.735188250423448`}}],
                StatusArea[#, 0.18253968253968253`]& ,
                TagBoxNote->"0.18253968253968253"],
               StyleBox["0.18253968253968253`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.18253968253968253`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{16., 0.}, {17., 0.12698412698412698`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{101.20190590501838`, 
                  134.82539682539672`}, {-67.42928846188443, \
-15.735188250423448`}}],
                StatusArea[#, 0.12698412698412698`]& ,
                TagBoxNote->"0.12698412698412698"],
               StyleBox["0.12698412698412698`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.12698412698412698`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{17., 0.}, {18., 0.11507936507936507`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{133.82539682539672`, 
                  167.44888774577518`}, {-62.67671656705994, \
-15.735188250423448`}}],
                StatusArea[#, 0.11507936507936507`]& ,
                TagBoxNote->"0.11507936507936507"],
               StyleBox["0.11507936507936507`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.11507936507936507`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{18., 0.}, {19., 0.2777777777777778}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{166.44888774577518`, 
                  200.07237866615353`}, {-127.62853246299434`, \
-15.735188250423448`}}],
                StatusArea[#, 0.2777777777777778]& ,
                TagBoxNote->"0.2777777777777778"],
               StyleBox["0.2777777777777778`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.2777777777777778, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                DynamicBox[{
                  FEPrivate`If[
                   CurrentValue["MouseOver"], 
                   EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                  
                  RectangleBox[{19., 0.}, {20., 0.21825396825396826`}, 
                   "RoundingRadius" -> 0]},
                 
                 ImageSizeCache->{{199.07237866615353`, 
                  232.69586958653198`}, {-103.865672988872, \
-15.735188250423448`}}],
                StatusArea[#, 0.21825396825396826`]& ,
                TagBoxNote->"0.21825396825396826"],
               StyleBox["0.21825396825396826`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[0.21825396825396826`, {
                 GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
           AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
           Axes->{True, True},
           AxesOrigin->{14., 0.},
           FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
           GridLines->{None, None},
           PlotLabel->FormBox["\"Prob Density of GE\"", TraditionalForm],
           PlotRange->{{14., 20.}, {All, All}},
           PlotRangePadding->{{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.02], 
              Scaled[0.1]}},
           Ticks->{Automatic, Automatic}], {193.5, -597.9478841155233}, 
          ImageScaled[{0.5, 0.5}], {360., 222.4922359499622}], 
         TagBox[InsetBox["", {580.5, -597.9478841155233}, {Center, Center}, {360., 222.4922359499622}],
          "InsetString"], 
         TagBox[InsetBox["", {967.5, -597.9478841155233}, {Center, Center}, {360., 222.4922359499622}],
          "InsetString"]}}, {}},
      ContentSelectable->True,
      ImageSize->{800, 570},
      PlotRangePadding->{6, 5}]}
   },
   GridBoxAlignment->{"Columns" -> {{"      "}}, "Rows" -> {{"      "}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{
  3.52002528638275*^9, 3.520027256414*^9, {3.5200278592265*^9, 
   3.52002787750775*^9}, 3.5200280518515*^9, 3.52003040513275*^9, 
   3.520030866960875*^9, 3.520031249617125*^9, 3.520031381585875*^9, 
   3.52003174257025*^9, 3.52003182257025*^9, 3.52003229469525*^9, 
   3.521397306953125*^9, 3.521403880984375*^9, 3.5402386077538924`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 3: Daily Ranges and Trend Lines for Stocks\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}}],

Cell["\<\
1)  Added Value: Quick graphical representation of daily price ranges and \
future trend lines.

2)  Caption: For the purposes of trading it is often necessary to identify \
the pattern of daily price behavior which will help organize the trading \
along more profitable strategies. For instance the daily price ranges below \
suggest that it is best to sell around the high levels on Friday and buy at \
the lower levels on  Monday. Long term trading strategies however need to \
track the price changes that indicate percentage variability away from the \
mean behavior.  

3)  Why we are better: Tooltip Box-Whisker plots and superimposed labeled \
regression lines are easy to calculate as well as informative about the \
behavior of a stock at a glance.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}}],

Cell[CellGroupData[{

Cell["Comany: General Electric", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9}],

Cell["\<\
Point: Intra-day behaviour, Required: Easier with M than other programs\
\>", "Text",
 CellChangeTimes->{{3.5838406126282625`*^9, 3.583840661253044*^9}, 
   3.5838409967742343`*^9, {3.5838410424388466`*^9, 3.583841061622944*^9}, {
   3.5838413737517967`*^9, 3.583841397784171*^9}}],

Cell[CellGroupData[{

Cell["Daily Range", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DailyRangeData", "[", 
  RowBox[{"\"\<GE\>\"", ",", "365"}], "]"}]], "Input",
 CellChangeTimes->{{3.5838053652432275`*^9, 3.583805372795659*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{
      Opacity[0], 
      PointBox[{{0.526383489669507, 0.05911931818181912}, {5.473616510330492, 
       0.8876609848484825}}]}, {
      RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
       RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{0.7150371318512823, 0.3997160435399927}, {
               1.2849628681487177`, 0.3997160435399927}, {1.2849628681487177`,
                0.23615658362989222`}, {0.7150371318512823, 
               0.23615658362989222`}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{1.2849628681487177`, 0.3022833891814294}, {
                0.7150371318512823, 0.3022833891814294}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{1., 0.23615658362989222`}, {1., 
                0.1548062015503895}}, {{1., 0.3997160435399927}, {1., 
                0.7116937967443917}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{1.1424814340743588`, 0.1548062015503895}, {
                0.8575185659256411, 0.1548062015503895}}, {{
                1.1424814340743588`, 0.7116937967443917}, {0.8575185659256411,
                 0.7116937967443917}}}]}, {}}]}, 
           ImageSizeCache -> {{54.58578643762691, 
            87.4142135623731}, {-47.41421356237309, 62.41421356237309}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "0.7116937967443917`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.3997160435399927`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.3022833891814294`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.23615658362989222`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.1548062015503895`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 0.7116937967443917}, {
              Style["75%", Bold], 0.3997160435399927}, {
              Style["median", Bold], 0.3022833891814294}, {
              Style["25%", Bold], 0.23615658362989222`}, {
              Style["min", Bold], 0.1548062015503895}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], "Tooltip"]& ]}, {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{1.7150371318512823`, 0.4095541999061467}, {
               2.2849628681487175`, 0.4095541999061467}, {2.2849628681487175`,
                0.21646000946521582`}, {1.7150371318512823`, 
               0.21646000946521582`}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{2.2849628681487175`, 0.2925266903914583}, {
                1.7150371318512825`, 0.2925266903914583}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{2., 0.21646000946521582`}, {2., 
                0.10643809523809367`}}, {{2., 0.4095541999061467}, {2., 
                0.8499999999999979}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{2.1424814340743588`, 0.10643809523809367`}, {
                1.8575185659256412`, 0.10643809523809367`}}, {{
                2.1424814340743588`, 0.8499999999999979}, {
                1.8575185659256412`, 0.8499999999999979}}}]}, {}}]}, 
           ImageSizeCache -> {{105.5857864376269, 
            138.4142135623731}, {-74.4142135623731, 71.4142135623731}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "0.8499999999999979`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.4095541999061467`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.2925266903914583`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.21646000946521582`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.10643809523809367`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 0.8499999999999979}, {
              Style["75%", Bold], 0.4095541999061467}, {
              Style["median", Bold], 0.2925266903914583}, {
              Style["25%", Bold], 0.21646000946521582`}, {
              Style["min", Bold], 0.10643809523809367`}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], "Tooltip"]& ]}, {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{2.7150371318512825`, 0.3174490699734278}, {
               3.2849628681487175`, 0.3174490699734278}, {3.2849628681487175`,
                0.18382704252269733`}, {2.7150371318512825`, 
               0.18382704252269733`}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{3.2849628681487175`, 0.25352800382958307`}, {
                2.7150371318512825`, 0.25352800382958307`}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{3., 0.18382704252269733`}, {3., 
                0.12898613518197877`}}, {{3., 0.3174490699734278}, {3., 
                0.7280133396855639}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{3.1424814340743588`, 0.12898613518197877`}, {
                2.8575185659256412`, 0.12898613518197877`}}, {{
                3.1424814340743588`, 0.7280133396855639}, {
                2.8575185659256412`, 0.7280133396855639}}}]}, {}}]}, 
           ImageSizeCache -> {{157.5857864376269, 
            190.4142135623731}, {-50.41421356237311, 67.4142135623731}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "0.7280133396855639`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.3174490699734278`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.25352800382958307`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.18382704252269733`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.12898613518197877`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 0.7280133396855639}, {
              Style["75%", Bold], 0.3174490699734278}, {
              Style["median", Bold], 0.25352800382958307`}, {
              Style["25%", Bold], 0.18382704252269733`}, {
              Style["min", Bold], 0.12898613518197877`}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], "Tooltip"]& ]}, {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{3.7150371318512825`, 0.33000000000000185`}, {
               4.2849628681487175`, 0.33000000000000185`}, {
               4.2849628681487175`, 0.1984415584415622}, {3.7150371318512825`,
                0.1984415584415622}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{4.2849628681487175`, 0.2709352517985586}, {
                3.7150371318512825`, 0.2709352517985586}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{4., 0.1984415584415622}, {4., 
                0.09678030303030383}}, {{4., 0.33000000000000185`}, {4., 
                0.6746896835182916}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{4.142481434074359, 0.09678030303030383}, {
                3.8575185659256412`, 0.09678030303030383}}, {{
                4.142481434074359, 0.6746896835182916}, {3.8575185659256412`, 
                0.6746896835182916}}}]}, {}}]}, 
           ImageSizeCache -> {{209.5857864376269, 
            242.4142135623731}, {-40.41421356237311, 73.4142135623731}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "0.6746896835182916`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.33000000000000185`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.2709352517985586`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.1984415584415622`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.09678030303030383`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 0.6746896835182916}, {
              Style["75%", Bold], 0.33000000000000185`}, {
              Style["median", Bold], 0.2709352517985586}, {
              Style["25%", Bold], 0.1984415584415622}, {
              Style["min", Bold], 0.09678030303030383}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], "Tooltip"]& ]}, {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{4.7150371318512825`, 0.37705828779599315`}, {
               5.2849628681487175`, 0.37705828779599315`}, {
               5.2849628681487175`, 0.214515522107245}, {4.7150371318512825`, 
               0.214515522107245}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{5.2849628681487175`, 0.2975888324873104}, {
                4.7150371318512825`, 0.2975888324873104}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{5., 0.214515522107245}, {5., 
                0.11902937420178716`}}, {{5., 0.37705828779599315`}, {5., 
                0.7800099950025015}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{5.142481434074359, 0.11902937420178716`}, {
                4.857518565925641, 0.11902937420178716`}}, {{
                5.142481434074359, 0.7800099950025015}, {4.857518565925641, 
                0.7800099950025015}}}]}, {}}]}, 
           ImageSizeCache -> {{261.5857864376269, 
            294.4142135623731}, {-60.41421356237311, 69.4142135623731}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "0.7800099950025015`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.37705828779599315`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.2975888324873104`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.214515522107245`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.11902937420178716`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 0.7800099950025015}, {
              Style["75%", Bold], 0.37705828779599315`}, {
              Style["median", Bold], 0.2975888324873104}, {
              Style["25%", Bold], 0.214515522107245}, {
              Style["min", Bold], 0.11902937420178716`}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], 
          "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}, {}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False}, 
    Frame -> True, FrameLabel -> {None, None}, 
    FrameTicks -> {{Automatic, Automatic}, {{{0.7150371318512823, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0, 0}}, {5.2849628681487175`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0, 0}}, {1., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
         FormBox["Thursday", TraditionalForm], 0}, {2., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
         FormBox["Friday", TraditionalForm], 0}, {3., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
         FormBox["Monday", TraditionalForm], 0}, {4., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
         FormBox["Tuesday", TraditionalForm], 0}, {5., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
         FormBox["Wednesday", TraditionalForm], 0}}, {{0.7150371318512823, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0, 0}}, {5.2849628681487175`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0, 0}}, {1., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}}}}, 
    ImageSize -> {350, 200}, PlotLabel -> 
    FormBox["\"Box-Whisker plots for General Electric Company daily Ranges\"",
       TraditionalForm], PlotRangePadding -> Scaled[0.02], 
    Ticks -> {None, Automatic}],TagBox[
    TagBox[
     GridBox[{{
        StyleBox["\[Null]", ShowStringCharacters -> False], 
        TagBox["\"Number\"", HoldForm], 
        TagBox["Mean", HoldForm], 
        TagBox["Median", HoldForm], 
        TagBox["StandardDeviation", HoldForm]}, {
        TagBox["Thursday", HoldForm], "51", "0.31904930236958784`", 
        "0.3022833891814294`", "0.11655383613287233`"}, {
        TagBox["Friday", HoldForm], "51", "0.31471180550276817`", 
        "0.2925266903914583`", "0.1433781236863044`"}, {
        TagBox["Monday", HoldForm], "47", "0.2864975665988313`", 
        "0.25352800382958307`", "0.1502109355856865`"}, {
        TagBox["Tuesday", HoldForm], "49", "0.2787614985381846`", 
        "0.2709352517985586`", "0.10228747880958584`"}, {
        TagBox["Wednesday", HoldForm], "52", "0.31918390553289755`", 
        "0.3025412247542931`", "0.14254312487517953`"}}, 
      GridBoxAlignment -> {
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}}, 
      GridBoxDividers -> {
       "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}, 
      GridBoxSpacings -> {"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], {
     OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, 
      TableHeadings -> {{Thursday, Friday, Monday, Tuesday, Wednesday}, {
        "Number", Mean, Median, StandardDeviation}}]]]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.583805384590334*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trend Lines", "Subsubsection",
 CellChangeTimes->{{3.5838054368433228`*^9, 3.5838054399314995`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrendLinesDateListPlot", "[", 
  RowBox[{"\"\<GE\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
    "0.87", ",", "0.9", ",", "0.95", ",", "0.98", ",", "1.0", ",", "1.02", 
     ",", "1.05"}], "}"}], ",", 
   RowBox[{"DatePlus", "[", 
    RowBox[{"-", "60"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.519749287906933*^9, 3.519749346344533*^9}, {
  3.5218488029698763`*^9, 3.521848853752781*^9}, {3.5402189332456064`*^9, 
  3.5402189598571286`*^9}, {3.5838053552276545`*^9, 3.5838053555956755`*^9}}],

Cell[BoxData[
 TemplateBox[{FrameBox[
    GraphicsBox[{{}, {{}, {}, {
        RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[CompressedData["
1:eJxV0TFIAlEYB/CjKQqiwCkkrZZqkqJyEe4gkCAoJWgxkKIQAlNqiCBwaWlR
pCgIwrAlzfM8iSSIxLaCcHOJUIiIK0ICo7H/+95zeA+O48e9973/993gyqZ/
rUNRlDE87I2lPl9a2mggXmmFplU48gdPsLVFTg1lpO/VOfgi4umqDZODTxlp
f6IFlwb2P3075LIjK+1vzsJRMO0iO7fhLx9OZMnGD1xL48AxuW6/EudXyb1e
GGlGAvNkNQqzcpE9nv8Utunexu4iWenPCR+SXTO5dh435Q/D7Ljnkec/gflk
eP4KHKALyQuabmmsnO17ijm2oYvvdp7/SJfO1+9hPw2E57d0qf9UKC/6XeLz
TcLrbL1TfeUuL+b/QQ72GaJfD59n3JDqO29hB1Q643nfDNHfATnWUxD3N3le
N/yA7uIVPs8bGN3p3nM+z0ZB9BvmebtNqV510pT2K0FT/P8SzTfxaor5vJDL
nUVL+2XXXZOb48V2XrJzuSjyGW71Hx0w/rY=
         "]]}, {
        RGBColor[0.6, 0.24, 0.4428931686004542], 
        LineBox[{{3.578688*^9, 23.41}, {3.581361126937473*^9, 22.065}}]}, {
        RGBColor[0.6, 0.5470136627990908, 0.24], 
        LineBox[{{3.578688*^9, 23.41}, {3.582430152378458*^9, 22.065}}]}, {
        RGBColor[0.24, 0.6, 0.33692049419863584`], 
        LineBox[{{3.578688*^9, 23.41}, {3.5836992*^9, 
         22.809373754152823`}}]}, {
        RGBColor[0.24, 0.3531726744018182, 0.6], 
        LineBox[{{3.578688*^9, 23.41}, {3.5836992*^9, 
         23.529669767441863`}}]}, {
        RGBColor[0.6, 0.24, 0.5632658430022722], 
        LineBox[{{3.578688*^9, 23.41}, {3.5836992*^9, 24.00986710963455}}]}, {
        RGBColor[0.6, 0.42664098839727194`, 0.24], 
        LineBox[{{3.578688*^9, 23.41}, {3.5836992*^9, 
         24.490064451827248`}}]}, {
        RGBColor[0.2634521802031821, 0.6, 0.24], 
        LineBox[{{3.578688*^9, 23.41}, {3.5836992*^9, 
         25.210360465116274`}}]}}, {}}, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, AxesLabel -> {
       FormBox["\"dates\"", TraditionalForm], 
       FormBox["\"Prices\"", TraditionalForm]}, 
     AxesOrigin -> {3578688000, 22.1}, Epilog -> {
       InsetBox[
        FormBox["\"-13 %\"", TraditionalForm], {
        3583612800, 20.888584385382067`}, {0, 1}], 
       InsetBox[
        FormBox["\"-10 %\"", TraditionalForm], {
        3583612800, 21.608880398671094`}, {0, 1}], 
       InsetBox[
        FormBox["\"-5 %\"", TraditionalForm], {
        3583612800, 22.809373754152823`}, {0, 1}], 
       InsetBox[
        FormBox["\"-2 %\"", TraditionalForm], {
        3583612800, 23.529669767441863`}, {0, 1}], 
       InsetBox[
        FormBox["\"0 %\"", TraditionalForm], {
        3583612800, 24.00986710963455}, {0, 1}], 
       InsetBox[
        FormBox["\"2 %\"", TraditionalForm], {
        3583612800, 24.490064451827248`}, {0, 1}], 
       InsetBox[
        FormBox["\"5 %\"", TraditionalForm], {
        3583612800, 25.210360465116274`}, {0, 1}]}, FrameTicks -> None, 
     GridLines -> {{{3579033600, 
         GrayLevel[0.8]}, {3581625600, 
         GrayLevel[0.8]}}, None}, ImageSize -> {435., Automatic}, 
     Method -> {}, 
     PlotRange -> {{3578688000, 3.5836992*^9}, {22.065, 25.210360465116274`}},
      PlotRangeClipping -> True, 
     PlotRangePadding -> {{100224., 100224.}, {0.06290720930232546, 
      0.06290720930232546}}, Ticks -> {{{3579033600, 
         FormBox["\"Jun\"", TraditionalForm], {0.020601132958329826`, 0}}, {
        3581625600, 
         FormBox["\"Jul\"", TraditionalForm], {0.020601132958329826`, 0}}, {
        3580243200, 
         FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
        3582835200, 
         FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
       Automatic}], StripOnInput -> False],
   "\"General Electric Company with 7 Trend Lines\""},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {2, 1}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.521848815424589*^9, 3.521848854733837*^9}, {
   3.540218935972762*^9, 3.5402189605851703`*^9}, 3.5402388226501837`*^9, 
   3.5402395067753134`*^9, 3.5838054511281395`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comany: Microsoft", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
  3.5838053417868857`*^9, 3.583805349706339*^9}, {3.5838054808598404`*^9, 
  3.5838054829869623`*^9}}],

Cell[CellGroupData[{

Cell["Daily Range", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DailyRangeData", "[", 
  RowBox[{"\"\<MSFT\>\"", ",", "365"}], "]"}]], "Input",
 CellChangeTimes->{{3.5838053652432275`*^9, 3.583805372795659*^9}, {
  3.583805491149429*^9, 3.5838054935165644`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{
      Opacity[0], 
      PointBox[{{0.526383489669507, 0.07134782608695661}, {5.473616510330492, 
       1.7251739130434804`}}]}, {
      RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
       RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{0.7150371318512823, 0.6000000000000014}, {
               1.2849628681487177`, 0.6000000000000014}, {1.2849628681487177`,
                0.3644631500187039}, {0.7150371318512823, 
               0.3644631500187039}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{1.2849628681487177`, 0.47666550885724135`}, {
                0.7150371318512823, 0.47666550885724135`}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{1., 0.3644631500187039}, {1., 
                0.1871540656205397}}, {{1., 0.6000000000000014}, {1., 
                1.2910457107075786`}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{1.1424814340743588`, 0.1871540656205397}, {
                0.8575185659256411, 0.1871540656205397}}, {{
                1.1424814340743588`, 1.2910457107075786`}, {
                0.8575185659256411, 1.2910457107075786`}}}]}, {}}]}, 
           ImageSizeCache -> {{55.58578643762691, 
            88.4142135623731}, {-39.41421356237309, 69.41421356237309}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "1.2910457107075786`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.6000000000000014`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.47666550885724135`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.3644631500187039`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.1871540656205397`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 1.2910457107075786`}, {
              Style["75%", Bold], 0.6000000000000014}, {
              Style["median", Bold], 0.47666550885724135`}, {
              Style["25%", Bold], 0.3644631500187039}, {
              Style["min", Bold], 0.1871540656205397}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], "Tooltip"]& ]}, {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{1.7150371318512823`, 0.566638546398444}, {
               2.2849628681487175`, 0.566638546398444}, {2.2849628681487175`, 
               0.3711689212625764}, {1.7150371318512823`, 
               0.3711689212625764}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{2.2849628681487175`, 0.44999999999999574`}, {
                1.7150371318512825`, 0.44999999999999574`}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{2., 0.3711689212625764}, {2., 
                0.17871611982881674`}}, {{2., 0.566638546398444}, {2., 
                1.6500000000000021`}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{2.1424814340743588`, 0.17871611982881674`}, {
                1.8575185659256412`, 0.17871611982881674`}}, {{
                2.1424814340743588`, 1.6500000000000021`}, {
                1.8575185659256412`, 1.6500000000000021`}}}]}, {}}]}, 
           ImageSizeCache -> {{107.5857864376269, 
            140.4142135623731}, {-73.4142135623731, 70.4142135623731}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "1.6500000000000021`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.566638546398444`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.44999999999999574`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.3711689212625764`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.17871611982881674`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 1.6500000000000021`}, {
              Style["75%", Bold], 0.566638546398444}, {
              Style["median", Bold], 0.44999999999999574`}, {
              Style["25%", Bold], 0.3711689212625764}, {
              Style["min", Bold], 0.17871611982881674`}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], "Tooltip"]& ]}, {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{2.7150371318512825`, 0.5910349854227377}, {
               3.2849628681487175`, 0.5910349854227377}, {3.2849628681487175`,
                0.3493117408906876}, {2.7150371318512825`, 
               0.3493117408906876}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{3.2849628681487175`, 0.420081221572449}, {
                2.7150371318512825`, 0.420081221572449}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{3., 0.3493117408906876}, {3., 
                0.21492470362063543`}}, {{3., 0.5910349854227377}, {3., 
                1.6300000000000026`}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{3.1424814340743588`, 0.21492470362063543`}, {
                2.8575185659256412`, 0.21492470362063543`}}, {{
                3.1424814340743588`, 1.6300000000000026`}, {
                2.8575185659256412`, 1.6300000000000026`}}}]}, {}}]}, 
           ImageSizeCache -> {{159.5857864376269, 
            192.4142135623731}, {-72.4142135623731, 66.4142135623731}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "1.6300000000000026`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.5910349854227377`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.420081221572449`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.3493117408906876`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.21492470362063543`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 1.6300000000000026`}, {
              Style["75%", Bold], 0.5910349854227377}, {
              Style["median", Bold], 0.420081221572449}, {
              Style["25%", Bold], 0.3493117408906876}, {
              Style["min", Bold], 0.21492470362063543`}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], "Tooltip"]& ]}, {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{3.7150371318512825`, 0.5416758951642677}, {
               4.2849628681487175`, 0.5416758951642677}, {4.2849628681487175`,
                0.32502824858756796`}, {3.7150371318512825`, 
               0.32502824858756796`}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{4.2849628681487175`, 0.43339677891654205`}, {
                3.7150371318512825`, 0.43339677891654205`}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{4., 0.32502824858756796`}, {4., 
                0.17584348941629102`}}, {{4., 0.5416758951642677}, {4., 
                1.1319148936170222`}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{4.142481434074359, 0.17584348941629102`}, {
                3.8575185659256412`, 0.17584348941629102`}}, {{
                4.142481434074359, 1.1319148936170222`}, {3.8575185659256412`,
                 1.1319148936170222`}}}]}, {}}]}, 
           ImageSizeCache -> {{211.5857864376269, 
            244.4142135623731}, {-24.414213562373106`, 70.4142135623731}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "1.1319148936170222`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.5416758951642677`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.43339677891654205`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.32502824858756796`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.17584348941629102`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 1.1319148936170222`}, {
              Style["75%", Bold], 0.5416758951642677}, {
              Style["median", Bold], 0.43339677891654205`}, {
              Style["25%", Bold], 0.32502824858756796`}, {
              Style["min", Bold], 0.17584348941629102`}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], "Tooltip"]& ]}, {
        RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        TagBox[
         TooltipBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            GraphicsGroupBox[{Antialiasing -> False, 
              
              PolygonBox[{{4.7150371318512825`, 0.5318722466960395}, {
               5.2849628681487175`, 0.5318722466960395}, {5.2849628681487175`,
                0.31262915432708027`}, {4.7150371318512825`, 
               0.31262915432708027`}}], {}, {{}, {}}, {}, {
               GrayLevel[0], 
               GrayLevel[1], 
               
               LineBox[{{5.2849628681487175`, 0.4396198830409368}, {
                4.7150371318512825`, 0.4396198830409368}}]}, {}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{5., 0.31262915432708027`}, {5., 
                0.14652173913043498`}}, {{5., 0.5318722466960395}, {5., 
                1.310856423173803}}}]}, {
               GrayLevel[0], 
               GrayLevel[0.5], 
               
               LineBox[{{{5.142481434074359, 0.14652173913043498`}, {
                4.857518565925641, 0.14652173913043498`}}, {{
                5.142481434074359, 1.310856423173803}, {4.857518565925641, 
                1.310856423173803}}}]}, {}}]}, 
           ImageSizeCache -> {{263.5857864376269, 
            296.4142135623731}, {-41.41421356237311, 73.4142135623731}}], 
          StyleBox[
           TagBox[
            GridBox[{{
               StyleBox["\"max\"", Bold, StripOnInput -> False], 
               "1.310856423173803`"}, {
               StyleBox["\"75%\"", Bold, StripOnInput -> False], 
               "0.5318722466960395`"}, {
               StyleBox["\"median\"", Bold, StripOnInput -> False], 
               "0.4396198830409368`"}, {
               StyleBox["\"25%\"", Bold, StripOnInput -> False], 
               "0.31262915432708027`"}, {
               StyleBox["\"min\"", Bold, StripOnInput -> False], 
               "0.14652173913043498`"}}, 
             GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
             AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, "Rows" -> {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, 
             GridBoxFrame -> {
              "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
             Directive[
               AbsoluteThickness[1], 
               Dashing[{}]]], "Grid"], {
            GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
          Style[
           Grid[{{
              Style["max", Bold], 1.310856423173803}, {
              Style["75%", Bold], 0.5318722466960395}, {
              Style["median", Bold], 0.4396198830409368}, {
              Style["25%", Bold], 0.31262915432708027`}, {
              Style["min", Bold], 0.14652173913043498`}}, Dividers -> {{
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
            Frame -> GrayLevel[0], BaseStyle -> Directive[
              AbsoluteThickness[1], 
              Dashing[{}]]], {
            GrayLevel[0]}], 
          "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}, {}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False}, 
    Frame -> True, FrameLabel -> {None, None}, 
    FrameTicks -> {{Automatic, Automatic}, {{{0.7150371318512823, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0, 0}}, {5.2849628681487175`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0, 0}}, {1., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
         FormBox["Thursday", TraditionalForm], 0}, {2., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
         FormBox["Friday", TraditionalForm], 0}, {3., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
         FormBox["Monday", TraditionalForm], 0}, {4., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
         FormBox["Tuesday", TraditionalForm], 0}, {5., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
         FormBox["Wednesday", TraditionalForm], 0}}, {{0.7150371318512823, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0, 0}}, {5.2849628681487175`, 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0, 0}}, {1., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
         FormBox[
          InterpretationBox[
           StyleBox[
            
            GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
             Baseline], "CacheGraphics" -> False], 
           Spacer[0]], TraditionalForm], {0.008, 0}}}}}, 
    ImageSize -> {350, 200}, PlotLabel -> 
    FormBox["\"Box-Whisker plots for Microsoft Corporation daily Ranges\"", 
      TraditionalForm], PlotRangePadding -> Scaled[0.02], 
    Ticks -> {None, Automatic}],TagBox[
    TagBox[
     GridBox[{{
        StyleBox["\[Null]", ShowStringCharacters -> False], 
        TagBox["\"Number\"", HoldForm], 
        TagBox["Mean", HoldForm], 
        TagBox["Median", HoldForm], 
        TagBox["StandardDeviation", HoldForm]}, {
        TagBox["Thursday", HoldForm], "51", "0.5061714495272296`", 
        "0.47666550885724135`", "0.20762423454779017`"}, {
        TagBox["Friday", HoldForm], "51", "0.4972479693918254`", 
        "0.44999999999999574`", "0.2156956408407378`"}, {
        TagBox["Monday", HoldForm], "47", "0.4970623155673158`", 
        "0.420081221572449`", "0.24902557194084018`"}, {
        TagBox["Tuesday", HoldForm], "49", "0.4626102177263247`", 
        "0.43339677891654205`", "0.20736028563689293`"}, {
        TagBox["Wednesday", HoldForm], "52", "0.4629021437676751`", 
        "0.44320794792844254`", "0.19862240219389962`"}}, 
      GridBoxAlignment -> {
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}}, 
      GridBoxDividers -> {
       "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}, 
      GridBoxSpacings -> {"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], {
     OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, 
      TableHeadings -> {{Thursday, Friday, Monday, Tuesday, Wednesday}, {
        "Number", Mean, Median, StandardDeviation}}]]]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.583805384590334*^9, 3.58380549606371*^9}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trend Lines", "Subsubsection",
 CellChangeTimes->{{3.5838054368433228`*^9, 3.5838054399314995`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrendLinesDateListPlot", "[", 
  RowBox[{"\"\<MSFT\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
    "0.87", ",", "0.9", ",", "0.95", ",", "0.98", ",", "1.0", ",", "1.02", 
     ",", "1.05"}], "}"}], ",", 
   RowBox[{"DatePlus", "[", 
    RowBox[{"-", "60"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.519749287906933*^9, 3.519749346344533*^9}, {
  3.5218488029698763`*^9, 3.521848853752781*^9}, {3.5402189332456064`*^9, 
  3.5402189598571286`*^9}, {3.5838053552276545`*^9, 3.5838053555956755`*^9}, {
  3.583805499228891*^9, 3.583805500396958*^9}}],

Cell[BoxData[
 TemplateBox[{FrameBox[
    GraphicsBox[{{}, {{}, {}, {
        RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[CompressedData["
1:eJxV0j1IAmEYB/CrKQqiwBYJNSeRiEiCFvEuComC1C0wkKIIhFJqKgopnI0g
6GORaqm869Qhib6w0YoaooaQhKazQYILx557nucGX5Dj59097//9cz0zS6G5
ZkEQ3PAzrrDE51NNetBd4dSmJIJjdXDc2/p+HEOnnWeadBKDP7bQLxNgj7GW
0ZES+CdYsCVL6G0dbE9Wg4UN9L39nN+fRdfGwGsWxV9ZRTtWwH+wffENrf6C
QbrrGv3VneH5UXSHH4zJE2gxnuHnw5T/MMP5PGjBKjc83z8CxuOtU/5FmeeP
U/49mfPfipi/KHM/R+iApPB+n+hEVDHzo9Vd8NMjrF7KfwfGeJOUXwMb422j
1O/ChSYZbVj6qN8dMKSpBus4T7gBw13F30R5O1Xuz0p9psDGcbxu6vNKbdg/
8A0+2Ic1hU60Z3n+B/U9lG3oX7w03TWMfVayfH4nOt2W437KlHcwx/MK1HcE
PI/Lh32Wc2Z+6rMlr0kh44VXvF8byPN+OtoxnTe/F5/4D4o1B28=
         "]]}, {
        RGBColor[0.6, 0.24, 0.4428931686004542], 
        LineBox[{{3.578688*^9, 35.02}, {3.5836992*^9, 
         29.181620930232544`}}]}, {
        RGBColor[0.6, 0.5470136627990908, 0.24], 
        LineBox[{{3.578688*^9, 35.02}, {3.5836992*^9, 30.18788372093023}}]}, {
        RGBColor[0.24, 0.6, 0.33692049419863584`], 
        LineBox[{{3.578688*^9, 35.02}, {3.5836992*^9, 
         31.864988372093016`}}]}, {
        RGBColor[0.24, 0.3531726744018182, 0.6], 
        LineBox[{{3.578688*^9, 35.02}, {3.5836992*^9, 32.87125116279069}}]}, {
        RGBColor[0.6, 0.24, 0.5632658430022722], 
        LineBox[{{3.578688*^9, 35.02}, {3.5836992*^9, 33.54209302325581}}]}, {
        RGBColor[0.6, 0.42664098839727194`, 0.24], 
        LineBox[{{3.578688*^9, 35.02}, {3.5836992*^9, 34.21293488372092}}]}, {
        RGBColor[0.2634521802031821, 0.6, 0.24], 
        LineBox[{{3.578688*^9, 35.02}, {3.5836992*^9, 
         35.219197674418595`}}]}}, {}}, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, AxesLabel -> {
       FormBox["\"dates\"", TraditionalForm], 
       FormBox["\"Prices\"", TraditionalForm]}, 
     AxesOrigin -> {3578688000, 29.200000000000003`}, Epilog -> {
       InsetBox[
        FormBox["\"-13 %\"", TraditionalForm], {
        3583612800, 29.181620930232544`}, {0, 1}], 
       InsetBox[
        FormBox["\"-10 %\"", TraditionalForm], {
        3583612800, 30.18788372093023}, {0, 1}], 
       InsetBox[
        FormBox["\"-5 %\"", TraditionalForm], {
        3583612800, 31.864988372093016`}, {0, 1}], 
       InsetBox[
        FormBox["\"-2 %\"", TraditionalForm], {
        3583612800, 32.87125116279069}, {0, 1}], 
       InsetBox[
        FormBox["\"0 %\"", TraditionalForm], {
        3583612800, 33.54209302325581}, {0, 1}], 
       InsetBox[
        FormBox["\"2 %\"", TraditionalForm], {
        3583612800, 34.21293488372092}, {0, 1}], 
       InsetBox[
        FormBox["\"5 %\"", TraditionalForm], {
        3583612800, 35.219197674418595`}, {0, 1}]}, FrameTicks -> None, 
     GridLines -> {{{3579033600, 
         GrayLevel[0.8]}, {3581625600, 
         GrayLevel[0.8]}}, None}, ImageSize -> {451., Automatic}, 
     Method -> {}, 
     PlotRange -> {{3578688000, 3.5836992*^9}, {29.181620930232544`, 36.27}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{100224., 100224.}, {0.14176758139534917`, 
      0.14176758139534917`}}, Ticks -> {{{3579033600, 
         FormBox["\"Jun\"", TraditionalForm], {0.020601132958329826`, 0}}, {
        3581625600, 
         FormBox["\"Jul\"", TraditionalForm], {0.020601132958329826`, 0}}, {
        3580243200, 
         FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
        3582835200, 
         FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, 
       Automatic}], StripOnInput -> False],
   "\"Microsoft Corporation with 7 Trend Lines\""},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {2, 1}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.521848815424589*^9, 3.521848854733837*^9}, {
   3.540218935972762*^9, 3.5402189605851703`*^9}, 3.5402388226501837`*^9, 
   3.5402395067753134`*^9, 3.5838054511281395`*^9, 3.58380550217906*^9}]
}, {2}]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example 4: Candlestick and Trend Charts for Stocks\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}, {3.583805545995566*^9, 
  3.583805546363587*^9}, {3.5838068151691585`*^9, 3.583806822049552*^9}}],

Cell["\<\
1)  Added Value: A grid of popular price change plots that provide a number \
of different ways of viewing the persistence of trends in data by the use of \
reversal thresholds.

2)  Caption: A table of popular financial charts that are designed to show \
trends in the data and to indicate when thershold reversals occur. These \
structures are important because the pivot points suggest buy/sell \
possibilities for trading. 

3)  Why we are better: Not only do we have these popular price charts but we \
also include the added flexibility of changing the threshold reversal level.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}, {
   3.5841523050128965`*^9, 3.584152336611704*^9}, {3.5841524176203375`*^9, 
   3.584152584884905*^9}}],

Cell[CellGroupData[{

Cell["Candlestick and Trend Charts", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9, 
   3.5838068609627776`*^9}],

Cell[CellGroupData[{

Cell["Comany: General Electric", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"SameQ", "[", 
          RowBox[{"fChart", ",", "CandlestickChart"}], "]"}], ",", 
         RowBox[{"fChart", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", 
             RowBox[{"DatePlus", "[", 
              RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"fChart", ",", "\"\< of \>\"", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MatchQ", "[", 
                  RowBox[{
                   RowBox[{"FinancialData", "[", 
                    RowBox[{"\"\<GE\>\"", ",", "\"\<Name\>\""}], "]"}], ",", 
                   RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], 
                  "]"}], ",", "\"\<GE\>\"", ",", 
                 RowBox[{"FinancialData", "[", 
                  RowBox[{"\"\<GE\>\"", ",", "\"\<Name\>\""}], "]"}]}], "]"}],
                ",", " ", "\"\< for last \>\"", ",", "365", ",", 
               "\"\< days\>\""}], " ", "}"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"fChart", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", 
             RowBox[{"DatePlus", "[", 
              RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
           RowBox[{"Switch", "[", 
            RowBox[{
            "fChart", ",", "KagiChart", ",", "0.02", ",", "RenkoChart", ",", 
             "0.1", ",", "LineBreakChart", ",", "3", ",", "PointFigureChart", 
             ",", "0.03", ",", "CandlestickChart", ",", "0.02"}], "]"}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"fChart", ",", "\"\< of \>\"", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MatchQ", "[", 
                  RowBox[{
                   RowBox[{"FinancialData", "[", 
                    RowBox[{"\"\<GE\>\"", ",", "\"\<Name\>\""}], "]"}], ",", 
                   RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], 
                  "]"}], ",", "\"\<GE\>\"", ",", 
                 RowBox[{"FinancialData", "[", 
                  RowBox[{"\"\<GE\>\"", ",", "\"\<Name\>\""}], "]"}]}], "]"}],
                ",", " ", "\"\< for last \>\"", ",", "365", ",", 
               "\"\< days\>\""}], " ", "}"}], "]"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"fChart", ",", 
         RowBox[{"{", 
          RowBox[{
          "CandlestickChart", ",", "KagiChart", ",", "RenkoChart", ",", 
           "LineBreakChart", ",", "PointFigureChart"}], "}"}]}], "}"}]}], 
      "]"}], ",", "2", ",", "2", ",", "1", ",", 
     RowBox[{"{", "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"730", ",", "700"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5838061314880543`*^9, 3.583806196384766*^9}, 
   3.583806313122443*^9, {3.58380634593832*^9, 3.583806363509325*^9}, {
   3.5838064848982677`*^9, 3.5838064920106745`*^9}, {3.583806608773353*^9, 
   3.5838066183078985`*^9}, {3.5838066706608934`*^9, 3.5838067433320494`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        DynamicModuleBox[{System`CandlestickChartDump`$indicatorpos$201102 = 
         Clip[
          Ceiling[-0.5 + True], {1, 250}], 
         System`CandlestickChartDump`$closevalue$201102, 
         System`CandlestickChartDump`$timestampQ$201102 = True, 
         System`CandlestickChartDump`$textstyle$201102 = {}, 
         System`CandlestickChartDump`$timestampdepth$201102 = "Full", 
         System`CandlestickChartDump`pp$201102 = CompressedData["
1:eJxdVF2EVVEUvkViRCJ6yc2IUSJx9s95uSyRksgdQ2IM0+iKqEkvmQwj5mUM
VwyZJFISQ2LE6Cm3h0hJDCMSIxKTEZlknjpnf9/ay+1w7z57n/XzrW99aw9e
uj58eUej0diufp36+V5Io37EyfrU/uenB51U/9Wrk25v68joXiej9cuXQs4k
AycDa48nW2ed3GjVb7Qfof+4k5/tlebsVfqfd/KmWronXfY/NLvRXhlzMlyZ
bbRdzp/SHme+g07S579FxqXfn0xWiQ87SfiHzC7hGnByf7F6Phdyuwa2XSDf
Q/p9I/53tkdcT7wecTteUrgLXmr35qyXP1UZvZce8b565vXy4X39eNTZ437e
y9FUSCDOIImuVoBfGRg/kLcAXHMB+C8G8h9yvqJ+fnvwu+HZp5BXjad5Uv1T
isOD59cO569sTWYL5GWOffvIfr1lX9cd6trjgW/R+og8tk/4jrHvdwrE6xbg
4WmR+6Z9VnvwbDjAA+0euJxX14TnnGPdDvwsc7/Gvm6qflUnjvwof7aiD+z/
kIfdtGPfmW/e5XPVf4o/avWgTuq6obowHKq/pP+7Lusz4Vi178q/+uk+4dli
/hfs7zPq9R51suxZv+e8hLyqnlRHmM+Q9YV5MF0l+6b5pzwHTMfp867I+YuM
S78xO0e8iDxFBN+PFE9gXrNPuHZG5oucy0i9RfaBcRci/K9F4orUR0QfZrhK
BO/7IuuJwH8qsn8x48D8RfD8K+S6dI/7M3C+GPeTnWPezB5zRB4nrB7Nr3xo
HtTFeZ7Wvc/3Fe5dT7146oPrbusT6gr5vurTwwTxdoh3hnlWeQ8t0m+FuJbs
u/Kj/emrY5x9uEU9LNke8xrB2xXq4abttS96rn56nvg8YXGh+5h5xT3+nz5G
TCeIU5I30wXmmP3fDFkPfbppW36to08HP/T+NXvMN3U9p3qivnvad9Ov2uk5
+C95D5S8j0rGLXkPlPIPQ642Ew==
         "], System`CandlestickChartDump`$ohlclabel$201102 = Grid[{{
            Style[
            "O: ", 12, {}, FontFamily -> "Times", LineBreakWithin -> False], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$opens$201102, 
               System`CandlestickChartDump`$indicatorpos$201102]], 12, {}, 
             FontFamily -> "Times"], 
            Style[
            "H: ", 12, {}, FontFamily -> "Times", LineBreakWithin -> False], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$highs$201102, 
               System`CandlestickChartDump`$indicatorpos$201102]], 12, {}, 
             FontFamily -> "Times"], 
            Style[
            "L: ", 12, {}, FontFamily -> "Times", LineBreakWithin -> False], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$lows$201102, 
               System`CandlestickChartDump`$indicatorpos$201102]], 12, {}, 
             FontFamily -> "Times"], 
            Style[
            "C: ", 12, {}, FontFamily -> "Times", LineBreakWithin -> False], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$closes$201102, 
               System`CandlestickChartDump`$indicatorpos$201102]], 12, {}, 
             FontFamily -> "Times"], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$dates$201102, 
               System`CandlestickChartDump`$indicatorpos$201102]], 12, {}, 
             FontFamily -> "Times", LineBreakWithin -> False]}}, ItemSize -> 
          Automatic, Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
          False], System`CandlestickChartDump`$highlightstyle$201102 = 
         Directive[
          AbsolutePointSize[5], 
          GrayLevel[0]], 
         System`CandlestickChartDump`$axishighlightmin$201102 = 
         19.0982952853598, System`CandlestickChartDump`$closemarkerQ$201102 = 
         False, System`CandlestickChartDump`$timestampstyle$201102 = Directive[
          GrayLevel[0.75], 
          Opacity[0.25]], System`CandlestickChartDump`$bouncingballQ$201102 = 
         True, System`CandlestickChartDump`$tooltipstyle$201102 = {
         FrameStyle -> GrayLevel[0.7], Background -> RGBColor[1, 1, 0.7], 
          ContentPadding -> False}, System`CandlestickChartDump`$xmin$201102 =
          0.5, System`CandlestickChartDump`$xmax$201102 = 250.5, 
         System`CandlestickChartDump`$fastpos$201102 = True, 
         System`CandlestickChartDump`$mouseQ$201102 = False, 
         System`CandlestickChartDump`$tooltipvalue$201102, 
         System`CandlestickChartDump`$tpp$201102 = CompressedData["
1:eJxdVF2EVVEUvkViRCJ6yc2IUSJx9s95uSyRksgdQ2IM0+iKqEkvmQwj5mUM
VwyZJFISQ2LE6Cm3h0hJDCMSIxKTEZlknjpnf9/ay+1w7z57n/XzrW99aw9e
uj58eUej0diufp36+V5Io37EyfrU/uenB51U/9Wrk25v68joXiej9cuXQs4k
AycDa48nW2ed3GjVb7Qfof+4k5/tlebsVfqfd/KmWronXfY/NLvRXhlzMlyZ
bbRdzp/SHme+g07S579FxqXfn0xWiQ87SfiHzC7hGnByf7F6Phdyuwa2XSDf
Q/p9I/53tkdcT7wecTteUrgLXmr35qyXP1UZvZce8b565vXy4X39eNTZ437e
y9FUSCDOIImuVoBfGRg/kLcAXHMB+C8G8h9yvqJ+fnvwu+HZp5BXjad5Uv1T
isOD59cO569sTWYL5GWOffvIfr1lX9cd6trjgW/R+og8tk/4jrHvdwrE6xbg
4WmR+6Z9VnvwbDjAA+0euJxX14TnnGPdDvwsc7/Gvm6qflUnjvwof7aiD+z/
kIfdtGPfmW/e5XPVf4o/avWgTuq6obowHKq/pP+7Lusz4Vi178q/+uk+4dli
/hfs7zPq9R51suxZv+e8hLyqnlRHmM+Q9YV5MF0l+6b5pzwHTMfp867I+YuM
S78xO0e8iDxFBN+PFE9gXrNPuHZG5oucy0i9RfaBcRci/K9F4orUR0QfZrhK
BO/7IuuJwH8qsn8x48D8RfD8K+S6dI/7M3C+GPeTnWPezB5zRB4nrB7Nr3xo
HtTFeZ7Wvc/3Fe5dT7146oPrbusT6gr5vurTwwTxdoh3hnlWeQ8t0m+FuJbs
u/Kj/emrY5x9uEU9LNke8xrB2xXq4abttS96rn56nvg8YXGh+5h5xT3+nz5G
TCeIU5I30wXmmP3fDFkPfbppW36to08HP/T+NXvMN3U9p3qivnvad9Ov2uk5
+C95D5S8j0rGLXkPlPIPQ642Ew==
         "], System`CandlestickChartDump`$opens$201102 = CompressedData["
1:eJxFVQ00ldkaPkXFIFF+KzlxSkzKOfvbW4p5LiVERI1b5A5nlK5GJkspofw0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         "], System`CandlestickChartDump`$highs$201102 = CompressedData["
1:eJxFVQs8ldkWp8t0RJqkh4qpK1Gcptjf3qfJ44+K1B2ckbhjkHISbvTQ5IxJ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         "], System`CandlestickChartDump`$lows$201102 = CompressedData["
1:eJxFVQs8VtkWJxMl0UNJSdz5ur5IuGeffbz9S4bKo9RUGpowDQbjNZMiCZFH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         "], System`CandlestickChartDump`$closes$201102 = CompressedData["
1:eJxdVF2EVVEUvkViRCJ6yc2IUSJx9s95uSyRksgdQ2IM0+iKqEkvmQwj5mUM
VwyZJFISQ2LE6Cm3h0hJDCMSIxKTEZlknjpnf9/ay+1w7z57n/XzrW99aw9e
uj58eUej0diufp36+V5Io37EyfrU/uenB51U/9Wrk25v68joXiej9cuXQs4k
AycDa48nW2ed3GjVb7Qfof+4k5/tlebsVfqfd/KmWronXfY/NLvRXhlzMlyZ
bbRdzp/SHme+g07S579FxqXfn0xWiQ87SfiHzC7hGnByf7F6Phdyuwa2XSDf
Q/p9I/53tkdcT7wecTteUrgLXmr35qyXP1UZvZce8b565vXy4X39eNTZ437e
y9FUSCDOIImuVoBfGRg/kLcAXHMB+C8G8h9yvqJ+fnvwu+HZp5BXjad5Uv1T
isOD59cO569sTWYL5GWOffvIfr1lX9cd6trjgW/R+og8tk/4jrHvdwrE6xbg
4WmR+6Z9VnvwbDjAA+0euJxX14TnnGPdDvwsc7/Gvm6qflUnjvwof7aiD+z/
kIfdtGPfmW/e5XPVf4o/avWgTuq6obowHKq/pP+7Lusz4Vi178q/+uk+4dli
/hfs7zPq9R51suxZv+e8hLyqnlRHmM+Q9YV5MF0l+6b5pzwHTMfp867I+YuM
S78xO0e8iDxFBN+PFE9gXrNPuHZG5oucy0i9RfaBcRci/K9F4orUR0QfZrhK
BO/7IuuJwH8qsn8x48D8RfD8K+S6dI/7M3C+GPeTnWPezB5zRB4nrB7Nr3xo
HtTFeZ7Wvc/3Fe5dT7146oPrbusT6gr5vurTwwTxdoh3hnlWeQ8t0m+FuJbs
u/Kj/emrY5x9uEU9LNke8xrB2xXq4abttS96rn56nvg8YXGh+5h5xT3+nz5G
TCeIU5I30wXmmP3fDFkPfbppW36to08HP/T+NXvMN3U9p3qivnvad9Ov2uk5
+C95D5S8j0rGLXkPlPIPQ642Ew==
         "], System`CandlestickChartDump`$dates$201102 = {
         "Thu. Jul 26, 2012", "Fri. Jul 27, 2012", "Mon. Jul 30, 2012", 
          "Tue. Jul 31, 2012", "Wed. Aug 01, 2012", "Thu. Aug 02, 2012", 
          "Fri. Aug 03, 2012", "Mon. Aug 06, 2012", "Tue. Aug 07, 2012", 
          "Wed. Aug 08, 2012", "Thu. Aug 09, 2012", "Fri. Aug 10, 2012", 
          "Mon. Aug 13, 2012", "Tue. Aug 14, 2012", "Wed. Aug 15, 2012", 
          "Thu. Aug 16, 2012", "Fri. Aug 17, 2012", "Mon. Aug 20, 2012", 
          "Tue. Aug 21, 2012", "Wed. Aug 22, 2012", "Thu. Aug 23, 2012", 
          "Fri. Aug 24, 2012", "Mon. Aug 27, 2012", "Tue. Aug 28, 2012", 
          "Wed. Aug 29, 2012", "Thu. Aug 30, 2012", "Fri. Aug 31, 2012", 
          "Tue. Sep 04, 2012", "Wed. Sep 05, 2012", "Thu. Sep 06, 2012", 
          "Fri. Sep 07, 2012", "Mon. Sep 10, 2012", "Tue. Sep 11, 2012", 
          "Wed. Sep 12, 2012", "Thu. Sep 13, 2012", "Fri. Sep 14, 2012", 
          "Mon. Sep 17, 2012", "Tue. Sep 18, 2012", "Wed. Sep 19, 2012", 
          "Thu. Sep 20, 2012", "Fri. Sep 21, 2012", "Mon. Sep 24, 2012", 
          "Tue. Sep 25, 2012", "Wed. Sep 26, 2012", "Thu. Sep 27, 2012", 
          "Fri. Sep 28, 2012", "Mon. Oct 01, 2012", "Tue. Oct 02, 2012", 
          "Wed. Oct 03, 2012", "Thu. Oct 04, 2012", "Fri. Oct 05, 2012", 
          "Mon. Oct 08, 2012", "Tue. Oct 09, 2012", "Wed. Oct 10, 2012", 
          "Thu. Oct 11, 2012", "Fri. Oct 12, 2012", "Mon. Oct 15, 2012", 
          "Tue. Oct 16, 2012", "Wed. Oct 17, 2012", "Thu. Oct 18, 2012", 
          "Fri. Oct 19, 2012", "Mon. Oct 22, 2012", "Tue. Oct 23, 2012", 
          "Wed. Oct 24, 2012", "Thu. Oct 25, 2012", "Fri. Oct 26, 2012", 
          "Wed. Oct 31, 2012", "Thu. Nov 01, 2012", "Fri. Nov 02, 2012", 
          "Mon. Nov 05, 2012", "Tue. Nov 06, 2012", "Wed. Nov 07, 2012", 
          "Thu. Nov 08, 2012", "Fri. Nov 09, 2012", "Mon. Nov 12, 2012", 
          "Tue. Nov 13, 2012", "Wed. Nov 14, 2012", "Thu. Nov 15, 2012", 
          "Fri. Nov 16, 2012", "Mon. Nov 19, 2012", "Tue. Nov 20, 2012", 
          "Wed. Nov 21, 2012", "Fri. Nov 23, 2012", "Mon. Nov 26, 2012", 
          "Tue. Nov 27, 2012", "Wed. Nov 28, 2012", "Thu. Nov 29, 2012", 
          "Fri. Nov 30, 2012", "Mon. Dec 03, 2012", "Tue. Dec 04, 2012", 
          "Wed. Dec 05, 2012", "Thu. Dec 06, 2012", "Fri. Dec 07, 2012", 
          "Mon. Dec 10, 2012", "Tue. Dec 11, 2012", "Wed. Dec 12, 2012", 
          "Thu. Dec 13, 2012", "Fri. Dec 14, 2012", "Mon. Dec 17, 2012", 
          "Tue. Dec 18, 2012", "Wed. Dec 19, 2012", "Thu. Dec 20, 2012", 
          "Fri. Dec 21, 2012", "Mon. Dec 24, 2012", "Wed. Dec 26, 2012", 
          "Thu. Dec 27, 2012", "Fri. Dec 28, 2012", "Mon. Dec 31, 2012", 
          "Wed. Jan 02, 2013", "Thu. Jan 03, 2013", "Fri. Jan 04, 2013", 
          "Mon. Jan 07, 2013", "Tue. Jan 08, 2013", "Wed. Jan 09, 2013", 
          "Thu. Jan 10, 2013", "Fri. Jan 11, 2013", "Mon. Jan 14, 2013", 
          "Tue. Jan 15, 2013", "Wed. Jan 16, 2013", "Thu. Jan 17, 2013", 
          "Fri. Jan 18, 2013", "Tue. Jan 22, 2013", "Wed. Jan 23, 2013", 
          "Thu. Jan 24, 2013", "Fri. Jan 25, 2013", "Mon. Jan 28, 2013", 
          "Tue. Jan 29, 2013", "Wed. Jan 30, 2013", "Thu. Jan 31, 2013", 
          "Fri. Feb 01, 2013", "Mon. Feb 04, 2013", "Tue. Feb 05, 2013", 
          "Wed. Feb 06, 2013", "Thu. Feb 07, 2013", "Fri. Feb 08, 2013", 
          "Mon. Feb 11, 2013", "Tue. Feb 12, 2013", "Wed. Feb 13, 2013", 
          "Thu. Feb 14, 2013", "Fri. Feb 15, 2013", "Tue. Feb 19, 2013", 
          "Wed. Feb 20, 2013", "Thu. Feb 21, 2013", "Fri. Feb 22, 2013", 
          "Mon. Feb 25, 2013", "Tue. Feb 26, 2013", "Wed. Feb 27, 2013", 
          "Thu. Feb 28, 2013", "Fri. Mar 01, 2013", "Mon. Mar 04, 2013", 
          "Tue. Mar 05, 2013", "Wed. Mar 06, 2013", "Thu. Mar 07, 2013", 
          "Fri. Mar 08, 2013", "Mon. Mar 11, 2013", "Tue. Mar 12, 2013", 
          "Wed. Mar 13, 2013", "Thu. Mar 14, 2013", "Fri. Mar 15, 2013", 
          "Mon. Mar 18, 2013", "Tue. Mar 19, 2013", "Wed. Mar 20, 2013", 
          "Thu. Mar 21, 2013", "Fri. Mar 22, 2013", "Mon. Mar 25, 2013", 
          "Tue. Mar 26, 2013", "Wed. Mar 27, 2013", "Thu. Mar 28, 2013", 
          "Mon. Apr 01, 2013", "Tue. Apr 02, 2013", "Wed. Apr 03, 2013", 
          "Thu. Apr 04, 2013", "Fri. Apr 05, 2013", "Mon. Apr 08, 2013", 
          "Tue. Apr 09, 2013", "Wed. Apr 10, 2013", "Thu. Apr 11, 2013", 
          "Fri. Apr 12, 2013", "Mon. Apr 15, 2013", "Tue. Apr 16, 2013", 
          "Wed. Apr 17, 2013", "Thu. Apr 18, 2013", "Fri. Apr 19, 2013", 
          "Mon. Apr 22, 2013", "Tue. Apr 23, 2013", "Wed. Apr 24, 2013", 
          "Thu. Apr 25, 2013", "Fri. Apr 26, 2013", "Mon. Apr 29, 2013", 
          "Tue. Apr 30, 2013", "Wed. May 01, 2013", "Thu. May 02, 2013", 
          "Fri. May 03, 2013", "Mon. May 06, 2013", "Tue. May 07, 2013", 
          "Wed. May 08, 2013", "Thu. May 09, 2013", "Fri. May 10, 2013", 
          "Mon. May 13, 2013", "Tue. May 14, 2013", "Wed. May 15, 2013", 
          "Thu. May 16, 2013", "Fri. May 17, 2013", "Mon. May 20, 2013", 
          "Tue. May 21, 2013", "Wed. May 22, 2013", "Thu. May 23, 2013", 
          "Fri. May 24, 2013", "Tue. May 28, 2013", "Wed. May 29, 2013", 
          "Thu. May 30, 2013", "Fri. May 31, 2013", "Mon. Jun 03, 2013", 
          "Tue. Jun 04, 2013", "Wed. Jun 05, 2013", "Thu. Jun 06, 2013", 
          "Fri. Jun 07, 2013", "Mon. Jun 10, 2013", "Tue. Jun 11, 2013", 
          "Wed. Jun 12, 2013", "Thu. Jun 13, 2013", "Fri. Jun 14, 2013", 
          "Mon. Jun 17, 2013", "Tue. Jun 18, 2013", "Wed. Jun 19, 2013", 
          "Thu. Jun 20, 2013", "Fri. Jun 21, 2013", "Mon. Jun 24, 2013", 
          "Tue. Jun 25, 2013", "Wed. Jun 26, 2013", "Thu. Jun 27, 2013", 
          "Fri. Jun 28, 2013", "Mon. Jul 01, 2013", "Tue. Jul 02, 2013", 
          "Wed. Jul 03, 2013", "Fri. Jul 05, 2013", "Mon. Jul 08, 2013", 
          "Tue. Jul 09, 2013", "Wed. Jul 10, 2013", "Thu. Jul 11, 2013", 
          "Fri. Jul 12, 2013", "Mon. Jul 15, 2013", "Tue. Jul 16, 2013", 
          "Wed. Jul 17, 2013", "Thu. Jul 18, 2013", "Fri. Jul 19, 2013", 
          "Mon. Jul 22, 2013", "Tue. Jul 23, 2013", "Wed. Jul 24, 2013", 
          "Thu. Jul 25, 2013"}, System`CandlestickChartDump`$OHLCQ$201102 = 
         False}, {
          
          DynamicBox[Typeset`ToBoxes[
           System`CandlestickChartDump`$fastpos$201102 = First[
               MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
            System`CandlestickChartDump`$indicatorpos$201102 = 
             If[System`CandlestickChartDump`$fastpos$201102 =!= False, 
               Clip[
                Ceiling[System`CandlestickChartDump`$fastpos$201102 - 0.5], {
                 Ceiling[System`CandlestickChartDump`$xmin$201102], 
                 Floor[System`CandlestickChartDump`$xmax$201102]}], 
               System`CandlestickChartDump`$indicatorpos$201102]; 
            System`CandlestickChartDump`$mouseQ$201102 = Not[
               TrueQ[System`CandlestickChartDump`$fastpos$201102]]; 
            System`CandlestickChartDump`$ohlclabel$201102 = Grid[{{
                 Style[
                 "O: ", 12, System`CandlestickChartDump`$textstyle$201102, 
                  FontFamily -> "Times", LineBreakWithin -> False], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$opens$201102, 
                    System`CandlestickChartDump`$indicatorpos$201102]], 12, 
                  System`CandlestickChartDump`$textstyle$201102, FontFamily -> 
                  "Times"], 
                 Style[
                 "H: ", 12, System`CandlestickChartDump`$textstyle$201102, 
                  FontFamily -> "Times", LineBreakWithin -> False], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$highs$201102, 
                    System`CandlestickChartDump`$indicatorpos$201102]], 12, 
                  System`CandlestickChartDump`$textstyle$201102, FontFamily -> 
                  "Times"], 
                 Style[
                 "L: ", 12, System`CandlestickChartDump`$textstyle$201102, 
                  FontFamily -> "Times", LineBreakWithin -> False], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$lows$201102, 
                    System`CandlestickChartDump`$indicatorpos$201102]], 12, 
                  System`CandlestickChartDump`$textstyle$201102, FontFamily -> 
                  "Times"], 
                 Style[
                 "C: ", 12, System`CandlestickChartDump`$textstyle$201102, 
                  FontFamily -> "Times", LineBreakWithin -> False], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$closes$201102, 
                    System`CandlestickChartDump`$indicatorpos$201102]], 12, 
                  System`CandlestickChartDump`$textstyle$201102, FontFamily -> 
                  "Times"], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$dates$201102, 
                    System`CandlestickChartDump`$indicatorpos$201102]], 12, 
                  System`CandlestickChartDump`$textstyle$201102, FontFamily -> 
                  "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic,
                Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
               False]; If[System`CandlestickChartDump`$mouseQ$201102, 
              If[
              System`CandlestickChartDump`$timestampQ$201102, {
               System`CandlestickChartDump`$timestampstyle$201102, 
                Dynamic[
                 Deploy[
                  
                  Rectangle[{
                   System`CandlestickChartDump`$indicatorpos$201102 - 0.5, 
                    System`CandlestickChartDump`$axishighlightmin$201102}, 
                   If[
                   System`CandlestickChartDump`$timestampdepth$201102 === 
                    "Full", 
                    
                    Scaled[{0, 1}, {
                    System`CandlestickChartDump`$indicatorpos$201102 + 0.5, 
                    System`CandlestickChartDump`$axishighlightmin$201102}], 
                    
                    Offset[{
                    0, System`CandlestickChartDump`$timestampdepth$201102}, {
                    System`CandlestickChartDump`$indicatorpos$201102 + 0.5, 
                    System`CandlestickChartDump`$axishighlightmin$201102}]]]]]\
}, {}], 
              If[System`CandlestickChartDump`$timestampQ$201102, {
                Opacity[0], 
                
                Rectangle[{
                 System`CandlestickChartDump`$xmin$201102, 
                  System`CandlestickChartDump`$axishighlightmin$201102}, 
                 If[
                 System`CandlestickChartDump`$timestampdepth$201102 === 
                  "Full", 
                  
                  Scaled[{0, 1}, {
                   System`CandlestickChartDump`$xmin$201102 + 1, 
                    System`CandlestickChartDump`$axishighlightmin$201102}], 
                  
                  Offset[{
                   0, System`CandlestickChartDump`$timestampdepth$201102}, {
                   System`CandlestickChartDump`$xmin$201102 + 1, 
                    System`CandlestickChartDump`$axishighlightmin$201102}]]]},\
 {}]], StandardForm, Graphics],
           
           ImageSizeCache->{{41.129813805792274`, 
            42.65766239212014}, {-254.24458629147352`, \
-18.178997287950438`}}], {{}, 
           StyleBox[{
             {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1], 
              LineBox[CompressedData["
1:eJxlmglczWkXx2/W7PuSl9RLZClS3WtQPcooqUkLiVT3tt5uC5ooBo09IVt6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               "]]}, 
             {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1], 
              LineBox[CompressedData["
1:eJyFmndUVNcWxkfFhihRiF0CAoKABikjiOJRmgrCUJUqMDAgzUKMihKwRohi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               "]]}},
            Antialiasing->True], {}, {}}, {}, {}, 
          DynamicBox[Typeset`ToBoxes[
            If[System`CandlestickChartDump`$mouseQ$201102, {
              Dynamic[
               If[
               System`CandlestickChartDump`$bouncingballQ$201102, {
                System`CandlestickChartDump`$highlightstyle$201102, 
                 Deploy[
                  Point[{
                    Dynamic[System`CandlestickChartDump`$indicatorpos$201102],
                     System`CandlestickChartDump`$tooltipvalue$201102 = 
                    Dynamic[
                    FEPrivate`Part[
                    System`CandlestickChartDump`$tpp$201102, 
                    System`CandlestickChartDump`$indicatorpos$201102]]; 
                    System`CandlestickChartDump`$closevalue$201102 = Dynamic[
                    FEPrivate`Part[
                    System`CandlestickChartDump`pp$201102, 
                    System`CandlestickChartDump`$indicatorpos$201102]]}]]}, 
                System`CandlestickChartDump`$tooltipvalue$201102 = Dynamic[
                   FEPrivate`Part[
                   System`CandlestickChartDump`$tpp$201102, 
                    System`CandlestickChartDump`$indicatorpos$201102]]; 
                System`CandlestickChartDump`$closevalue$201102 = Dynamic[
                   FEPrivate`Part[
                   System`CandlestickChartDump`pp$201102, 
                    System`CandlestickChartDump`$indicatorpos$201102]]; {}]], 
              Dynamic[
               If[System`CandlestickChartDump`$closemarkerQ$201102, {
                 Inset[
                  Framed[
                   Style[
                   System`CandlestickChartDump`$tooltipvalue$201102, 10, 
                    FontFamily -> "Helvetica"], 
                   System`CandlestickChartDump`$tooltipstyle$201102], 
                  Offset[{
                    Dynamic[
                    FEPrivate`If[
                    FEPrivate`Greater[
                    System`CandlestickChartDump`$indicatorpos$201102 + 
                    0.5, (System`CandlestickChartDump`$xmax$201102 + 
                    System`CandlestickChartDump`$xmin$201102)/2], -5, 
                    5]], -5}, {
                   System`CandlestickChartDump`$indicatorpos$201102, 
                    System`CandlestickChartDump`$closevalue$201102}], {
                   Dynamic[
                    FEPrivate`If[
                    FEPrivate`Greater[
                    System`CandlestickChartDump`$indicatorpos$201102, (
                    System`CandlestickChartDump`$xmax$201102 + 
                    System`CandlestickChartDump`$xmin$201102)/2], 1, -1]], 
                   1}]}, {}]]}, {}], StandardForm, Graphics],
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}},
           TrackedSymbols:>{System`CandlestickChartDump`$mouseQ$201102}], {}},
         DynamicModuleValues:>{}], 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 19.0982952853598}, {250.5, 
             19.0982952853598}}], {}}, {{
             LineBox[{{0.5, 19.0982952853598}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 
                19.0982952853598}]}], 
             LineBox[{{250.5, 19.0982952853598}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {250.5, 
                19.0982952853598}]}], {{}, {}, {
               LineBox[{{108.5, 19.0982952853598}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {108.5, 
                  19.0982952853598}]}], 
               LineBox[{{108.5, 19.0982952853598}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {108.5, 
                  19.0982952853598}]}]}}}, {
             InsetBox["\<\"`12\"\>", 
              Offset[{0., -2.}, {54.5, 19.0982952853598}], {0, 1}, 
              Automatic, {1, 0}], 
             InsetBox["\<\"`13\"\>", 
              Offset[{0., -2.}, {179.5, 19.0982952853598}], {0, 1}, 
              Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->False],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, Automatic},
       Frame->{{False, False}, {False, False}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->
        FrontEndValueCache[{{{4.5, {}}, {27.5, {}}, {46.5, {}}, {67.5, {}}, {
           88.5, {}}, {108.5, {}}, {129.5, {}}, {148.5, {}}, {168.5, {}}, {
           190.5, {}}, {212.5, {}}, {232.5, {}}, {108.5, 
            Directive[
             Opacity[0.4], 
             Dashing[{}]]}}, 
          FindDivisions[{19.0982952853598, #2}, 6]& }, {{{4.5, {}}, {
           27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
           129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
           232.5, {}}, {108.5, 
            Directive[
             Opacity[0.4], 
             Dashing[{}]]}}, {19., 20., 21., 22., 23., 24., 25., 26.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "CandlestickChart", "\" of \"", "\"General Electric Company\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.02]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            Identity[#], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[19.0982952853598]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{19., 
            FormBox["19.`", TraditionalForm]}, {20., 
            FormBox["20.`", TraditionalForm]}, {21., 
            FormBox["21.`", TraditionalForm]}, {22., 
            FormBox["22.`", TraditionalForm]}, {23., 
            FormBox["23.`", TraditionalForm]}, {24., 
            FormBox["24.`", TraditionalForm]}, {25., 
            FormBox["25.`", TraditionalForm]}, {26., 
            FormBox["26.`", TraditionalForm]}}}]], {192., -119.58957682310464`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{0.5, 20.56}, {0.5, 20.92}}]},
              ImageSizeCache->{{36.58578643762691, 
               39.4142135623731}, {-68.4142135623731, -49.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 8, 1}, 20.73}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 20.56}, \" ~ \", {{2012, 8, 1}, 20.73}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "20.56`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "1"}], "}"}], ",", 
                   "20.73`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 8, 1}, 20.73}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{0.5, 20.92}, {1.5, 20.92}}]},
              
              ImageSizeCache->{{36.58578643762691, 
               52.4142135623731}, {-68.41421356237309, -65.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 8, 1}, 20.73}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 20.56}, \" ~ \", {{2012, 8, 1}, 20.73}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "20.56`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "1"}], "}"}], ",", 
                   "20.73`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 8, 1}, 20.73}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{1.5, 20.56}, {1.5, 20.92}}]},
              
              ImageSizeCache->{{48.58578643762691, 
               51.4142135623731}, {-68.4142135623731, -49.58578643762691}}],
             StatusArea[#, {{2012, 8, 2}, 20.52}]& ,
             TagBoxNote->"{{2012, 8, 2}, 20.52}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "2"}], "}"}], ",", 
                 "20.52`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 2}, 20.52}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{1.5, 20.52}, {1.5, 20.56}}]},
              
              ImageSizeCache->{{48.58578643762691, 
               51.4142135623731}, {-53.4142135623731, -48.58578643762691}}],
             StatusArea[#, {{2012, 8, 2}, 20.52}]& ,
             TagBoxNote->"{{2012, 8, 2}, 20.52}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "2"}], "}"}], ",", 
                 "20.52`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 2}, 20.52}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{1.5, 20.52}, {2.5, 20.52}}]},
              
              ImageSizeCache->{{48.58578643762691, 
               64.41421356237309}, {-51.4142135623731, -48.58578643762691}}],
             StatusArea[#, {{2012, 8, 2}, 20.52}]& ,
             TagBoxNote->"{{2012, 8, 2}, 20.52}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "2"}], "}"}], ",", 
                 "20.52`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 2}, 20.52}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{2.5, 20.52}, {2.5, 20.92}}]},
              
              ImageSizeCache->{{61.58578643762691, 
               64.41421356237309}, {-68.4142135623731, -48.58578643762691}}],
             StatusArea[#, {{2012, 8, 3}, 20.96}]& ,
             TagBoxNote->"{{2012, 8, 3}, 20.96}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "3"}], "}"}], ",", 
                 "20.96`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 3}, 20.96}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{2.5, 20.92}, {2.5, 21.12}}]},
              
              ImageSizeCache->{{61.58578643762691, 
               64.41421356237309}, {-77.41421356237309, -65.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 8, 3}, 20.96}, " ~ ", {{2012, 8, 22}, 20.78}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 3}, 20.96}, \" ~ \", {{2012, 8, 22}, 20.78}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "3"}], "}"}], ",", 
                   "20.96`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "22"}], "}"}], ",", 
                   "20.78`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 3}, 20.96}, " ~ ", {{2012, 8, 22}, 20.78}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{2.5, 21.12}, {3.5, 21.12}}]},
              
              ImageSizeCache->{{61.58578643762691, 
               77.41421356237309}, {-76.41421356237309, -73.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 8, 3}, 20.96}, " ~ ", {{2012, 8, 22}, 20.78}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 3}, 20.96}, \" ~ \", {{2012, 8, 22}, 20.78}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "3"}], "}"}], ",", 
                   "20.96`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "22"}], "}"}], ",", 
                   "20.78`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 3}, 20.96}, " ~ ", {{2012, 8, 22}, 20.78}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{3.5, 20.52}, {3.5, 21.12}}]},
              
              ImageSizeCache->{{74.58578643762691, 
               77.41421356237309}, {-77.4142135623731, -48.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 8, 23}, 20.64}, " ~ ", {{2012, 9, 4}, 20.51}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 23}, 20.64}, \" ~ \", {{2012, 9, 4}, 20.51}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "23"}], "}"}], ",", 
                   "20.64`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "4"}], "}"}], ",", 
                   "20.51`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 23}, 20.64}, " ~ ", {{2012, 9, 4}, 20.51}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{3.5, 20.51}, {3.5, 20.52}}]},
              
              ImageSizeCache->{{74.58578643762691, 
               77.41421356237309}, {-51.4142135623731, -47.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 8, 23}, 20.64}, " ~ ", {{2012, 9, 5}, 20.65}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 23}, 20.64}, \" ~ \", {{2012, 9, 5}, 20.65}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "23"}], "}"}], ",", 
                   "20.64`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "5"}], "}"}], ",", 
                   "20.65`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 23}, 20.64}, " ~ ", {{2012, 9, 5}, 20.65}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{3.5, 20.51}, {4.5, 20.51}}]},
              
              ImageSizeCache->{{74.58578643762691, 
               90.41421356237309}, {-50.4142135623731, -47.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 8, 23}, 20.64}, " ~ ", {{2012, 9, 5}, 20.65}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 23}, 20.64}, \" ~ \", {{2012, 9, 5}, 20.65}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "23"}], "}"}], ",", 
                   "20.64`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "5"}], "}"}], ",", 
                   "20.65`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 23}, 20.64}, " ~ ", {{2012, 9, 5}, 20.65}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{4.5, 20.51}, {4.5, 21.12}}]},
              
              ImageSizeCache->{{86.58578643762691, 
               89.41421356237309}, {-76.4142135623731, -47.58578643762691}}],
             StatusArea[#, {{2012, 9, 6}, 21.31}]& ,
             TagBoxNote->"{{2012, 9, 6}, 21.31}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "6"}], "}"}], ",", 
                 "21.31`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 6}, 21.31}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{4.5, 21.12}, {4.5, 22.53}}]},
              
              ImageSizeCache->{{86.5857864376269, 
               89.4142135623731}, {-136.4142135623731, -73.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 6}, 21.31}, " ~ ", {{2012, 9, 25}, 22.31}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 6}, 21.31}, \" ~ \", {{2012, 9, 25}, 22.31}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "6"}], "}"}], ",", 
                   "21.31`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "25"}], "}"}], ",", 
                   "22.31`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 6}, 21.31}, " ~ ", {{2012, 9, 25}, 22.31}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{4.5, 22.53}, {5.5, 22.53}}]},
              
              ImageSizeCache->{{86.5857864376269, 
               102.4142135623731}, {-136.41421356237308`, \
-133.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 6}, 21.31}, " ~ ", {{2012, 9, 25}, 22.31}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 6}, 21.31}, \" ~ \", {{2012, 9, 25}, 22.31}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "6"}], "}"}], ",", 
                   "21.31`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "25"}], "}"}], ",", 
                   "22.31`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 6}, 21.31}, " ~ ", {{2012, 9, 25}, 22.31}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{5.5, 22.1}, {5.5, 22.53}}]},
              
              ImageSizeCache->{{99.5857864376269, 
               102.4142135623731}, {-137.4142135623731, -115.5857864376269}}],
             StatusArea[#, {{2012, 9, 26}, 22.1}]& ,
             TagBoxNote->"{{2012, 9, 26}, 22.1}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "26"}], "}"}], ",", 
                 "22.1`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 26}, 22.1}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{5.5, 22.1}, {6.5, 22.1}}]},
              
              ImageSizeCache->{{99.58578643762691, 
               115.41421356237309`}, {-118.41421356237309`, \
-115.58578643762691`}}],
             StatusArea[#, {{2012, 9, 26}, 22.1}]& ,
             TagBoxNote->"{{2012, 9, 26}, 22.1}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "26"}], "}"}], ",", 
                 "22.1`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 26}, 22.1}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{6.5, 22.1}, {6.5, 23.12}}]},
              
              ImageSizeCache->{{111.5857864376269, 
               114.4142135623731}, {-162.4142135623731, -115.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 27}, 22.73}, " ~ ", {{2012, 10, 8}, 22.92}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 27}, 22.73}, \" ~ \", {{2012, 10, 8}, \
22.92}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "27"}], "}"}], ",", 
                   "22.73`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "8"}], "}"}], ",", 
                   "22.92`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 27}, 22.73}, " ~ ", {{2012, 10, 8}, 22.92}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{6.5, 23.12}, {7.5, 23.12}}]},
              
              ImageSizeCache->{{111.5857864376269, 
               127.4142135623731}, {-161.41421356237308`, \
-158.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 27}, 22.73}, " ~ ", {{2012, 10, 8}, 22.92}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 27}, 22.73}, \" ~ \", {{2012, 10, 8}, \
22.92}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "27"}], "}"}], ",", 
                   "22.73`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "8"}], "}"}], ",", 
                   "22.92`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 27}, 22.73}, " ~ ", {{2012, 10, 8}, 22.92}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{7.5, 22.43}, {7.5, 23.12}}]},
              
              ImageSizeCache->{{124.5857864376269, 
               127.4142135623731}, {-162.41421356237308`, \
-129.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 10, 9}, 22.62}, " ~ ", {{2012, 10, 16}, 22.64}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 9}, 22.62}, \" ~ \", {{2012, 10, 16}, \
22.64}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "9"}], "}"}], ",", 
                   "22.62`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "16"}], "}"}], ",", 
                   "22.64`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 9}, 22.62}, " ~ ", {{2012, 10, 16}, 22.64}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{7.5, 22.43}, {8.5, 22.43}}]},
              
              ImageSizeCache->{{124.5857864376269, 
               140.4142135623731}, {-132.41421356237308`, \
-129.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 10, 9}, 22.62}, " ~ ", {{2012, 10, 16}, 22.64}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 9}, 22.62}, \" ~ \", {{2012, 10, 16}, \
22.64}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "9"}], "}"}], ",", 
                   "22.62`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "16"}], "}"}], ",", 
                   "22.64`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 9}, 22.62}, " ~ ", {{2012, 10, 16}, 22.64}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{8.5, 22.43}, {8.5, 22.91}}]},
              
              ImageSizeCache->{{136.5857864376269, 
               139.41421356237308`}, {-153.41421356237308`, \
-129.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 10, 17}, 22.91}, " ~ ", {{2012, 10, 18}, 22.81}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 17}, 22.91}, \" ~ \", {{2012, 10, 18}, \
22.81}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "17"}], "}"}], ",", 
                   "22.91`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "18"}], "}"}], ",", 
                   "22.81`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 17}, 22.91}, " ~ ", {{2012, 10, 18}, 22.81}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{8.5, 22.91}, {9.5, 22.91}}]},
              
              ImageSizeCache->{{136.5857864376269, 
               152.41421356237308`}, {-152.41421356237308`, \
-149.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 10, 17}, 22.91}, " ~ ", {{2012, 10, 18}, 22.81}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 17}, 22.91}, \" ~ \", {{2012, 10, 18}, \
22.81}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "17"}], "}"}], ",", 
                   "22.91`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "18"}], "}"}], ",", 
                   "22.81`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 17}, 22.91}, " ~ ", {{2012, 10, 18}, 22.81}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{9.5, 22.43}, {9.5, 22.91}}]},
              
              ImageSizeCache->{{149.5857864376269, 
               152.41421356237308`}, {-153.41421356237308`, \
-129.5857864376269}}],
             StatusArea[#, {{2012, 10, 19}, 22.03}]& ,
             TagBoxNote->"{{2012, 10, 19}, 22.03}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "19"}], "}"}], ",", 
                 "22.03`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 19}, 22.03}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{9.5, 21.06}, {9.5, 22.43}}]},
              
              ImageSizeCache->{{149.5857864376269, 
               152.41421356237308`}, {-133.4142135623731, -71.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 10, 19}, 22.03}, " ~ ", {{2012, 11, 5}, 21.41}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 19}, 22.03}, \" ~ \", {{2012, 11, 5}, \
21.41}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "19"}], "}"}], ",", 
                   "22.03`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "5"}], "}"}], ",", 
                   "21.41`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 19}, 22.03}, " ~ ", {{2012, 11, 5}, 21.41}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{9.5, 21.06}, {10.5, 21.06}}]},
              
              ImageSizeCache->{{149.5857864376269, 
               165.41421356237308`}, {-74.4142135623731, -71.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 10, 19}, 22.03}, " ~ ", {{2012, 11, 5}, 21.41}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 19}, 22.03}, \" ~ \", {{2012, 11, 5}, \
21.41}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "19"}], "}"}], ",", 
                   "22.03`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "5"}], "}"}], ",", 
                   "21.41`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 19}, 22.03}, " ~ ", {{2012, 11, 5}, 21.41}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{10.5, 21.06}, {10.5, 21.59}}]},
              
              ImageSizeCache->{{161.5857864376269, 
               164.41421356237308`}, {-97.41421356237312, -71.5857864376269}}],
             StatusArea[#, {{2012, 11, 6}, 21.59}]& ,
             TagBoxNote->"{{2012, 11, 6}, 21.59}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "11", ",", "6"}], "}"}], ",", 
                 "21.59`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 11, 6}, 21.59}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{10.5, 21.59}, {11.5, 21.59}}]},
              
              ImageSizeCache->{{161.5857864376269, 
               177.41421356237308`}, {-96.4142135623731, -93.5857864376269}}],
             StatusArea[#, {{2012, 11, 6}, 21.59}]& ,
             TagBoxNote->"{{2012, 11, 6}, 21.59}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "11", ",", "6"}], "}"}], ",", 
                 "21.59`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 11, 6}, 21.59}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{11.5, 20.01}, {11.5, 21.59}}]},
              
              ImageSizeCache->{{174.5857864376269, 
               177.41421356237308`}, {-97.4142135623731, \
-26.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 7}, 21.13}, " ~ ", {{2012, 11, 16}, 20.15}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 7}, 21.13}, \" ~ \", {{2012, 11, 16}, \
20.15}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "7"}], "}"}], ",", 
                   "21.13`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "16"}], "}"}], ",", 
                   "20.15`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 7}, 21.13}, " ~ ", {{2012, 11, 16}, 20.15}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{11.5, 20.01}, {12.5, 20.01}}]},
              
              ImageSizeCache->{{174.5857864376269, 
               190.41421356237308`}, {-29.414213562373103`, \
-26.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 7}, 21.13}, " ~ ", {{2012, 11, 16}, 20.15}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 7}, 21.13}, \" ~ \", {{2012, 11, 16}, \
20.15}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "7"}], "}"}], ",", 
                   "21.13`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "16"}], "}"}], ",", 
                   "20.15`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 7}, 21.13}, " ~ ", {{2012, 11, 16}, 20.15}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{12.5, 20.01}, {12.5, 21.59}}]},
              
              ImageSizeCache->{{186.5857864376269, 
               189.41421356237308`}, {-97.4142135623731, \
-26.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 19}, 20.66}, " ~ ", {{2012, 12, 12}, 21.78}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 19}, 20.66}, \" ~ \", {{2012, 12, 12}, \
21.78}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "19"}], "}"}], ",", 
                   "20.66`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "12"}], "}"}], ",", 
                   "21.78`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 19}, 20.66}, " ~ ", {{2012, 12, 12}, 21.78}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{12.5, 21.59}, {12.5, 21.93}}]},
              
              ImageSizeCache->{{186.5857864376269, 
               189.41421356237308`}, {-111.41421356237312`, \
-93.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 11, 19}, 20.66}, " ~ ", {{2012, 12, 18}, 21.69}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 19}, 20.66}, \" ~ \", {{2012, 12, 18}, \
21.69}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "19"}], "}"}], ",", 
                   "20.66`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "18"}], "}"}], ",", 
                   "21.69`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 19}, 20.66}, " ~ ", {{2012, 12, 18}, 21.69}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{12.5, 21.93}, {13.5, 21.93}}]},
              
              ImageSizeCache->{{186.5857864376269, 
               202.41421356237308`}, {-110.4142135623731, \
-107.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 11, 19}, 20.66}, " ~ ", {{2012, 12, 18}, 21.69}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 19}, 20.66}, \" ~ \", {{2012, 12, 18}, \
21.69}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "19"}], "}"}], ",", 
                   "20.66`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "18"}], "}"}], ",", 
                   "21.69`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 19}, 20.66}, " ~ ", {{2012, 12, 18}, 21.69}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{13.5, 20.44}, {13.5, 21.93}}]},
              ImageSizeCache->{{199.5857864376269, 
               202.41421356237308`}, {-111.4142135623731, \
-44.58578643762689}}],
             StatusArea[#, 
              Row[{{{2012, 12, 19}, 21.01}, " ~ ", {{2012, 12, 28}, 20.44}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 19}, 21.01}, \" ~ \", {{2012, 12, 28}, \
20.44}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "19"}], "}"}], ",", 
                   "21.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "28"}], "}"}], ",", 
                   "20.44`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 19}, 21.01}, " ~ ", {{2012, 12, 28}, 20.44}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{13.5, 20.44}, {14.5, 20.44}}]},
              
              ImageSizeCache->{{199.5857864376269, 
               215.41421356237308`}, {-47.414213562373114`, \
-44.58578643762689}}],
             StatusArea[#, 
              Row[{{{2012, 12, 19}, 21.01}, " ~ ", {{2012, 12, 28}, 20.44}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 19}, 21.01}, \" ~ \", {{2012, 12, 28}, \
20.44}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "19"}], "}"}], ",", 
                   "21.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "28"}], "}"}], ",", 
                   "20.44`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 19}, 21.01}, " ~ ", {{2012, 12, 28}, 20.44}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{14.5, 20.44}, {14.5, 21.34}}]},
              
              ImageSizeCache->{{211.5857864376269, 
               214.41421356237308`}, {-86.41421356237312, \
-44.58578643762689}}],
             StatusArea[#, 
              Row[{{{2012, 12, 31}, 20.99}, " ~ ", {{2013, 1, 7}, 21.13}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 31}, 20.99}, \" ~ \", {{2013, 1, 7}, \
21.13}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "31"}], "}"}], ",", 
                   "20.99`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "7"}], "}"}], ",", 
                   "21.13`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 31}, 20.99}, " ~ ", {{2013, 1, 7}, 21.13}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{14.5, 21.34}, {15.5, 21.34}}]},
              
              ImageSizeCache->{{211.5857864376269, 
               227.41421356237308`}, {-85.4142135623731, -82.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 12, 31}, 20.99}, " ~ ", {{2013, 1, 7}, 21.13}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 31}, 20.99}, \" ~ \", {{2013, 1, 7}, \
21.13}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "31"}], "}"}], ",", 
                   "20.99`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "7"}], "}"}], ",", 
                   "21.13`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 31}, 20.99}, " ~ ", {{2013, 1, 7}, 21.13}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{15.5, 20.9}, {15.5, 21.34}}]},
              
              ImageSizeCache->{{224.5857864376269, 
               227.41421356237308`}, {-86.41421356237312, -64.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 1, 8}, 20.9}, " ~ ", {{2013, 1, 16}, 21.12}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 8}, 20.9}, \" ~ \", {{2013, 1, 16}, 21.12}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "8"}], "}"}], ",", 
                   "20.9`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "16"}], "}"}], ",", 
                   "21.12`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 8}, 20.9}, " ~ ", {{2013, 1, 16}, 21.12}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{15.5, 20.9}, {16.5, 20.9}}]},
              
              ImageSizeCache->{{224.5857864376269, 
               240.41421356237308`}, {-67.4142135623731, -64.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 1, 8}, 20.9}, " ~ ", {{2013, 1, 16}, 21.12}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 8}, 20.9}, \" ~ \", {{2013, 1, 16}, 21.12}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "8"}], "}"}], ",", 
                   "20.9`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "16"}], "}"}], ",", 
                   "21.12`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 8}, 20.9}, " ~ ", {{2013, 1, 16}, 21.12}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{16.5, 20.9}, {16.5, 23.75}}]},
              
              ImageSizeCache->{{237.5857864376269, 
               240.41421356237308`}, {-188.4142135623731, -64.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 1, 17}, 21.3}, " ~ ", {{2013, 2, 20}, 23.41}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 17}, 21.3}, \" ~ \", {{2013, 2, 20}, 23.41}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "17"}], "}"}], ",", 
                   "21.3`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "20"}], "}"}], ",", 
                   "23.41`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 17}, 21.3}, " ~ ", {{2013, 2, 20}, 23.41}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{16.5, 23.75}, {17.5, 23.75}}]},
              
              ImageSizeCache->{{237.5857864376269, 
               253.41421356237308`}, {-188.41421356237308`, \
-185.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 1, 17}, 21.3}, " ~ ", {{2013, 2, 20}, 23.41}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 17}, 21.3}, \" ~ \", {{2013, 2, 20}, 23.41}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "17"}], "}"}], ",", 
                   "21.3`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "20"}], "}"}], ",", 
                   "23.41`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 17}, 21.3}, " ~ ", {{2013, 2, 20}, 23.41}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{17.5, 22.81}, {17.5, 23.75}}]},
              
              ImageSizeCache->{{249.5857864376269, 
               252.41421356237308`}, {-188.41421356237308`, \
-145.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 2, 21}, 23.26}, " ~ ", {{2013, 2, 26}, 23.05}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 21}, 23.26}, \" ~ \", {{2013, 2, 26}, \
23.05}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "21"}], "}"}], ",", 
                   "23.26`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "26"}], "}"}], ",", 
                   "23.05`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 21}, 23.26}, " ~ ", {{2013, 2, 26}, 23.05}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{17.5, 22.81}, {18.5, 22.81}}]},
              
              ImageSizeCache->{{249.5857864376269, 
               265.4142135623731}, {-148.41421356237308`, \
-145.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 2, 21}, 23.26}, " ~ ", {{2013, 2, 26}, 23.05}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 21}, 23.26}, \" ~ \", {{2013, 2, 26}, \
23.05}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "21"}], "}"}], ",", 
                   "23.26`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "26"}], "}"}], ",", 
                   "23.05`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 21}, 23.26}, " ~ ", {{2013, 2, 26}, 23.05}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{18.5, 22.81}, {18.5, 23.77}}]},
              
              ImageSizeCache->{{262.5857864376269, 
               265.4142135623731}, {-189.41421356237308`, \
-145.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 2, 27}, 23.37}, " ~ ", {{2013, 3, 15}, 23.44}}]]& ,
             TagBoxNote->
              "Row[{{{2013, 2, 27}, 23.37}, \" ~ \", {{2013, 3, 15}, \
23.44}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "27"}], "}"}], ",", 
                   "23.37`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "15"}], "}"}], ",", 
                   "23.44`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 27}, 23.37}, " ~ ", {{2013, 3, 15}, 23.44}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{18.5, 23.77}, {19.5, 23.77}}]},
              
              ImageSizeCache->{{262.5857864376269, 
               278.4142135623731}, {-189.41421356237308`, \
-186.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 2, 27}, 23.37}, " ~ ", {{2013, 3, 15}, 23.44}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 27}, 23.37}, \" ~ \", {{2013, 3, 15}, \
23.44}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "27"}], "}"}], ",", 
                   "23.37`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "15"}], "}"}], ",", 
                   "23.44`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 27}, 23.37}, " ~ ", {{2013, 3, 15}, 23.44}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{19.5, 22.93}, {19.5, 23.77}}]},
              
              ImageSizeCache->{{274.5857864376269, 
               277.4142135623731}, {-189.41421356237308`, \
-150.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 3, 18}, 23.25}, " ~ ", {{2013, 4, 9}, 23.06}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 18}, 23.25}, \" ~ \", {{2013, 4, 9}, 23.06}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "18"}], "}"}], ",", 
                   "23.25`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "9"}], "}"}], ",", 
                   "23.06`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 18}, 23.25}, " ~ ", {{2013, 4, 9}, 23.06}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{19.5, 22.93}, {20.5, 22.93}}]},
              
              ImageSizeCache->{{274.5857864376269, 
               290.4142135623731}, {-153.41421356237308`, \
-150.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 3, 18}, 23.25}, " ~ ", {{2013, 4, 9}, 23.06}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 18}, 23.25}, \" ~ \", {{2013, 4, 9}, 23.06}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "18"}], "}"}], ",", 
                   "23.25`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "9"}], "}"}], ",", 
                   "23.06`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 18}, 23.25}, " ~ ", {{2013, 4, 9}, 23.06}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{20.5, 22.93}, {20.5, 23.59}}]},
              ImageSizeCache->{{287.5857864376269, 
               290.4142135623731}, {-182.41421356237308`, \
-150.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 10}, 23.58}, " ~ ", {{2013, 4, 12}, 23.46}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 10}, 23.58}, \" ~ \", {{2013, 4, 12}, \
23.46}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "10"}], "}"}], ",", 
                   "23.58`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "12"}], "}"}], ",", 
                   "23.46`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 10}, 23.58}, " ~ ", {{2013, 4, 12}, 23.46}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{20.5, 23.59}, {21.5, 23.59}}]},
              
              ImageSizeCache->{{287.5857864376269, 
               303.4142135623731}, {-181.41421356237308`, \
-178.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 10}, 23.58}, " ~ ", {{2013, 4, 12}, 23.46}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 10}, 23.58}, \" ~ \", {{2013, 4, 12}, \
23.46}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "10"}], "}"}], ",", 
                   "23.58`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "12"}], "}"}], ",", 
                   "23.46`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 10}, 23.58}, " ~ ", {{2013, 4, 12}, 23.46}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{21.5, 22.93}, {21.5, 23.59}}]},
              
              ImageSizeCache->{{299.5857864376269, 
               302.4142135623731}, {-182.41421356237308`, \
-150.5857864376269}}],
             StatusArea[#, {{2013, 4, 15}, 22.81}]& ,
             TagBoxNote->"{{2013, 4, 15}, 22.81}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "15"}], "}"}], ",", 
                 "22.81`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 15}, 22.81}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{21.5, 21.35}, {21.5, 22.93}}]},
              
              ImageSizeCache->{{299.5857864376269, 
               302.4142135623731}, {-154.4142135623731, -83.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 15}, 22.81}, " ~ ", {{2013, 4, 23}, 21.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 15}, 22.81}, \" ~ \", {{2013, 4, 23}, 21.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "15"}], "}"}], ",", 
                   "22.81`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "23"}], "}"}], ",", 
                   "21.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 15}, 22.81}, " ~ ", {{2013, 4, 23}, 21.5}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{21.5, 21.35}, {22.5, 21.35}}]},
              
              ImageSizeCache->{{299.5857864376269, 
               315.4142135623731}, {-86.4142135623731, -83.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 15}, 22.81}, " ~ ", {{2013, 4, 23}, 21.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 15}, 22.81}, \" ~ \", {{2013, 4, 23}, 21.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "15"}], "}"}], ",", 
                   "22.81`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "23"}], "}"}], ",", 
                   "21.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 15}, 22.81}, " ~ ", {{2013, 4, 23}, 21.5}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{22.5, 21.35}, {22.5, 23.59}}]},
              
              ImageSizeCache->{{312.5857864376269, 
               315.4142135623731}, {-182.4142135623731, -83.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 24}, 21.96}, " ~ ", {{2013, 5, 21}, 23.66}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 24}, 21.96}, \" ~ \", {{2013, 5, 21}, \
23.66}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "24"}], "}"}], ",", 
                   "21.96`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "21"}], "}"}], ",", 
                   "23.66`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 24}, 21.96}, " ~ ", {{2013, 5, 21}, 23.66}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{22.5, 23.59}, {22.5, 23.86}}]},
              
              ImageSizeCache->{{312.5857864376269, 
               315.4142135623731}, {-193.41421356237308`, \
-178.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 24}, 21.96}, " ~ ", {{2013, 5, 30}, 23.6}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 24}, 21.96}, \" ~ \", {{2013, 5, 30}, 23.6}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "24"}], "}"}], ",", 
                   "21.96`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "30"}], "}"}], ",", 
                   "23.6`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 24}, 21.96}, " ~ ", {{2013, 5, 30}, 23.6}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{22.5, 23.86}, {23.5, 23.86}}]},
              
              ImageSizeCache->{{312.5857864376269, 
               328.4142135623731}, {-192.41421356237308`, \
-189.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 24}, 21.96}, " ~ ", {{2013, 5, 30}, 23.6}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 24}, 21.96}, \" ~ \", {{2013, 5, 30}, 23.6}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "24"}], "}"}], ",", 
                   "21.96`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "30"}], "}"}], ",", 
                   "23.6`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 24}, 21.96}, " ~ ", {{2013, 5, 30}, 23.6}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{23.5, 23.32}, {23.5, 23.86}}]},
              
              ImageSizeCache->{{324.5857864376269, 
               327.4142135623731}, {-192.41421356237308`, \
-166.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 31}, 23.32}, " ~ ", {{2013, 6, 6}, 23.38}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 31}, 23.32}, \" ~ \", {{2013, 6, 6}, 23.38}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "31"}], "}"}], ",", 
                   "23.32`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "6"}], "}"}], ",", 
                   "23.38`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 31}, 23.32}, " ~ ", {{2013, 6, 6}, 23.38}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{23.5, 23.32}, {24.5, 23.32}}]},
              
              ImageSizeCache->{{324.5857864376269, 
               340.4142135623731}, {-169.41421356237308`, \
-166.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 31}, 23.32}, " ~ ", {{2013, 6, 6}, 23.38}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 31}, 23.32}, \" ~ \", {{2013, 6, 6}, 23.38}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "31"}], "}"}], ",", 
                   "23.32`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "6"}], "}"}], ",", 
                   "23.38`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 31}, 23.32}, " ~ ", {{2013, 6, 6}, 23.38}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{24.5, 23.32}, {24.5, 24.33}}]},
              
              ImageSizeCache->{{337.5857864376269, 
               340.4142135623731}, {-212.41421356237308`, \
-166.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 7}, 23.86}, " ~ ", {{2013, 6, 19}, 23.98}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 7}, 23.86}, \" ~ \", {{2013, 6, 19}, 23.98}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "7"}], "}"}], ",", 
                   "23.86`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "19"}], "}"}], ",", 
                   "23.98`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 7}, 23.86}, " ~ ", {{2013, 6, 19}, 23.98}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{24.5, 24.33}, {25.5, 24.33}}]},
              
              ImageSizeCache->{{337.5857864376269, 
               353.4142135623731}, {-212.41421356237308`, \
-209.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 7}, 23.86}, " ~ ", {{2013, 6, 19}, 23.98}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 7}, 23.86}, \" ~ \", {{2013, 6, 19}, 23.98}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "7"}], "}"}], ",", 
                   "23.86`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "19"}], "}"}], ",", 
                   "23.98`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 7}, 23.86}, " ~ ", {{2013, 6, 19}, 23.98}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{25.5, 23.32}, {25.5, 24.33}}]},
              
              ImageSizeCache->{{349.5857864376269, 
               352.4142135623731}, {-212.41421356237308`, \
-166.5857864376269}}],
             StatusArea[#, {{2013, 6, 20}, 23.25}]& ,
             TagBoxNote->"{{2013, 6, 20}, 23.25}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "6", ",", "20"}], "}"}], ",", 
                 "23.25`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 6, 20}, 23.25}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{25.5, 22.93}, {25.5, 23.32}}]},
              
              ImageSizeCache->{{349.5857864376269, 
               352.4142135623731}, {-170.41421356237308`, \
-150.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 20}, 23.25}, " ~ ", {{2013, 6, 28}, 23.19}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 20}, 23.25}, \" ~ \", {{2013, 6, 28}, \
23.19}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "20"}], "}"}], ",", 
                   "23.25`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "28"}], "}"}], ",", 
                   "23.19`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 20}, 23.25}, " ~ ", {{2013, 6, 28}, 23.19}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{25.5, 22.93}, {26.5, 22.93}}]},
              
              ImageSizeCache->{{349.5857864376269, 
               365.4142135623731}, {-153.41421356237308`, \
-150.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 20}, 23.25}, " ~ ", {{2013, 6, 28}, 23.19}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 20}, 23.25}, \" ~ \", {{2013, 6, 28}, \
23.19}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "20"}], "}"}], ",", 
                   "23.25`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "28"}], "}"}], ",", 
                   "23.19`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 20}, 23.25}, " ~ ", {{2013, 6, 28}, 23.19}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{26.5, 22.93}, {26.5, 23.34}}]},
              
              ImageSizeCache->{{362.5857864376269, 
               365.4142135623731}, {-171.41421356237308`, \
-150.5857864376269}}],
             StatusArea[#, {{2013, 7, 1}, 23.34}]& ,
             TagBoxNote->"{{2013, 7, 1}, 23.34}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "1"}], "}"}], ",", 
                 "23.34`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 7, 1}, 23.34}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{26.5, 23.34}, {27.5, 23.34}}]},
              
              ImageSizeCache->{{362.5857864376269, 
               378.4142135623731}, {-170.41421356237308`, \
-167.5857864376269}}],
             StatusArea[#, {{2013, 7, 1}, 23.34}]& ,
             TagBoxNote->"{{2013, 7, 1}, 23.34}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "1"}], "}"}], ",", 
                 "23.34`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 7, 1}, 23.34}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{27.5, 22.9}, {27.5, 23.34}}]},
              
              ImageSizeCache->{{374.5857864376269, 
               377.4142135623731}, {-171.41421356237308`, \
-149.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 2}, 22.9}, " ~ ", {{2013, 7, 5}, 23.24}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 2}, 22.9}, \" ~ \", {{2013, 7, 5}, 23.24}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "2"}], "}"}], ",", 
                   "22.9`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "5"}], "}"}], ",", 
                   "23.24`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 2}, 22.9}, " ~ ", {{2013, 7, 5}, 23.24}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{27.5, 22.9}, {28.5, 22.9}}]},
              
              ImageSizeCache->{{374.5857864376269, 
               390.4142135623731}, {-152.41421356237308`, \
-149.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 2}, 22.9}, " ~ ", {{2013, 7, 5}, 23.24}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 2}, 22.9}, \" ~ \", {{2013, 7, 5}, 23.24}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "2"}], "}"}], ",", 
                   "22.9`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "5"}], "}"}], ",", 
                   "23.24`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 2}, 22.9}, " ~ ", {{2013, 7, 5}, 23.24}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{28.5, 22.9}, {28.5, 23.34}}]},
              
              ImageSizeCache->{{387.5857864376269, 
               390.4142135623731}, {-171.41421356237308`, \
-149.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 8}, 23.32}, " ~ ", {{2013, 7, 9}, 23.62}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 8}, 23.32}, \" ~ \", {{2013, 7, 9}, 23.62}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "8"}], "}"}], ",", 
                   "23.32`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "9"}], "}"}], ",", 
                   "23.62`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 8}, 23.32}, " ~ ", {{2013, 7, 9}, 23.62}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{28.5, 23.34}, {28.5, 23.94}}]},
              
              ImageSizeCache->{{387.5857864376269, 
               390.4142135623731}, {-196.41421356237308`, \
-167.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 8}, 23.32}, " ~ ", {{2013, 7, 15}, 23.63}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 8}, 23.32}, \" ~ \", {{2013, 7, 15}, 23.63}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "8"}], "}"}], ",", 
                   "23.32`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "15"}], "}"}], ",", 
                   "23.63`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 8}, 23.32}, " ~ ", {{2013, 7, 15}, 23.63}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{28.5, 23.94}, {29.5, 23.94}}]},
              
              ImageSizeCache->{{387.5857864376269, 
               403.4142135623731}, {-196.41421356237308`, \
-193.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 8}, 23.32}, " ~ ", {{2013, 7, 15}, 23.63}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 8}, 23.32}, \" ~ \", {{2013, 7, 15}, 23.63}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "8"}], "}"}], ",", 
                   "23.32`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "15"}], "}"}], ",", 
                   "23.63`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 8}, 23.32}, " ~ ", {{2013, 7, 15}, 23.63}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{29.5, 23.43}, {29.5, 23.94}}]},
              
              ImageSizeCache->{{399.5857864376269, 
               402.4142135623731}, {-196.41421356237308`, \
-171.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 16}, 23.43}, " ~ ", {{2013, 7, 18}, 23.63}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 16}, 23.43}, \" ~ \", {{2013, 7, 18}, \
23.63}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "16"}], "}"}], ",", 
                   "23.43`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "18"}], "}"}], ",", 
                   "23.63`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 16}, 23.43}, " ~ ", {{2013, 7, 18}, 23.63}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{29.5, 23.43}, {30.5, 23.43}}]},
              
              ImageSizeCache->{{399.5857864376269, 
               415.4142135623731}, {-174.41421356237308`, \
-171.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 16}, 23.43}, " ~ ", {{2013, 7, 18}, 23.63}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 16}, 23.43}, \" ~ \", {{2013, 7, 18}, \
23.63}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "16"}], "}"}], ",", 
                   "23.43`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "18"}], "}"}], ",", 
                   "23.63`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 16}, 23.43}, " ~ ", {{2013, 7, 18}, 23.63}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{30.5, 23.43}, {30.5, 24.86}}]},
              ImageSizeCache->{{412.5857864376269, 
               415.4142135623731}, {-235.41421356237308`, \
-171.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 19}, 24.72}, " ~ ", {{2013, 7, 25}, 24.69}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 19}, 24.72}, \" ~ \", {{2013, 7, 25}, \
24.69}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "24.72`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "25"}], "}"}], ",", 
                   "24.69`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 19}, 24.72}, " ~ ", {{2013, 7, 25}, 24.69}}], {
              GrayLevel[0]}], 
            "Tooltip"]& ]}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}}, 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 19.767500000000002`}, {31.5, 
             19.767500000000002`}}], {}}, {{
             LineBox[{{0.5, 19.767500000000002`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 
                19.767500000000002`}]}], 
             LineBox[{{31.5, 19.767500000000002`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {31.5, 
                19.767500000000002`}]}], {{}, {}, {
               LineBox[{{14.5, 19.767500000000002`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {14.5, 
                  19.767500000000002`}]}], 
               LineBox[{{14.5, 19.767500000000002`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {14.5, 
                  19.767500000000002`}]}]}}}, {
             InsetBox["\<\"2012\"\>", 
              Offset[{0., -2.}, {7.5, 19.767500000000002`}], {0, 1}, 
              Automatic, {1, 0}], 
             InsetBox["\<\"2013\"\>", 
              Offset[{0., -2.}, {23., 19.767500000000002`}], {0, 1}, 
              Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->True],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.4, Automatic},
       GridLines->
        FrontEndValueCache[{{{3.5, {}}, {6.5, {}}, {9.5, {}}, {12.5, {}}, {
           14.5, {}}, {16.5, {}}, {18.5, {}}, {19.5, {}}, {22.5, {}}, {
           23.5, {}}, {26.5, {}}, {14.5, 
            Directive[
             Dashing[{}]]}}, 
          FindDivisions[{#, #2}, 6]& }, {{{3.5, {}}, {6.5, {}}, {9.5, {}}, {
           12.5, {}}, {14.5, {}}, {16.5, {}}, {18.5, {}}, {19.5, {}}, {
           22.5, {}}, {23.5, {}}, {26.5, {}}, {14.5, 
            Directive[
             Dashing[{}]]}}, {19., 20., 21., 22., 23., 24., 25., 26.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "KagiChart", "\" of \"", "\"General Electric Company\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.1]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            Identity[#], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[19.767500000000002`]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{19., 
            FormBox["19.`", TraditionalForm]}, {20., 
            FormBox["20.`", TraditionalForm]}, {21., 
            FormBox["21.`", TraditionalForm]}, {22., 
            FormBox["22.`", TraditionalForm]}, {23., 
            FormBox["23.`", TraditionalForm]}, {24., 
            FormBox["24.`", TraditionalForm]}, {25., 
            FormBox["25.`", TraditionalForm]}, {26., 
            FormBox["26.`", TraditionalForm]}}}]], {576., -119.58957682310464`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{0.5, 20.56}, {1.5, 21.04}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{37.78823892179499, 
               51.66842807715066}, {-83.03191802020376, -61.41427777611921}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 8, 7}, 21.12}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 20.56}, \" ~ \", {{2012, 8, 7}, 21.12}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "20.56`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "7"}], "}"}], ",", 
                   "21.12`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 8, 7}, 21.12}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{1.5, 21.04}, {2.5, 21.52}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{51.66842807715066, 
               65.5486172325063}, {-104.6495582642882, -83.03191802020376}}],
             StatusArea[#, 
              Row[{{{2012, 8, 8}, 21.01}, " ~ ", {{2012, 9, 7}, 21.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 8}, 21.01}, \" ~ \", {{2012, 9, 7}, 21.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "8"}], "}"}], ",", 
                   "21.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "7"}], "}"}], ",", 
                   "21.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 8}, 21.01}, " ~ ", {{2012, 9, 7}, 21.59}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{2.5, 21.52}, {3.5, 22.}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{65.5486172325063, 
               79.42880638786198}, {-126.26719850837264`, \
-104.6495582642882}}],
             StatusArea[#, 
              Row[{{{2012, 9, 10}, 21.48}, " ~ ", {{2012, 9, 13}, 22.02}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 10}, 21.48}, \" ~ \", {{2012, 9, 13}, \
22.02}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "10"}], "}"}], ",", 
                   "21.48`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "13"}], "}"}], ",", 
                   "22.02`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 10}, 21.48}, " ~ ", {{2012, 9, 13}, 22.02}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{3.5, 22.}, {4.5, 22.48}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{79.42880638786198, 
               93.3089955432176}, {-147.88483875245709`, \
-126.26719850837264`}}],
             StatusArea[#, 
              Row[{{{2012, 9, 14}, 22.11}, " ~ ", {{2012, 9, 21}, 22.53}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 14}, 22.11}, \" ~ \", {{2012, 9, 21}, \
22.53}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "14"}], "}"}], ",", 
                   "22.11`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "21"}], "}"}], ",", 
                   "22.53`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 14}, 22.11}, " ~ ", {{2012, 9, 21}, 22.53}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{4.5, 22.48}, {5.5, 22.96}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{93.3089955432176, 
               107.18918469857329`}, {-169.50247899654153`, \
-147.88483875245709`}}],
             StatusArea[#, 
              Row[{{{2012, 9, 24}, 22.36}, " ~ ", {{2012, 10, 5}, 23.12}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 24}, 22.36}, \" ~ \", {{2012, 10, 5}, \
23.12}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "24"}], "}"}], ",", 
                   "22.36`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "5"}], "}"}], ",", 
                   "23.12`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 24}, 22.36}, " ~ ", {{2012, 10, 5}, 23.12}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{5.5, 22.}, {6.5, 22.48}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{107.18918469857329`, 
               121.06937385392894`}, {-147.88483875245709`, \
-126.26719850837264`}}],
             StatusArea[#, 
              Row[{{{2012, 10, 8}, 22.92}, " ~ ", {{2012, 10, 22}, 21.7}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 8}, 22.92}, \" ~ \", {{2012, 10, 22}, \
21.7}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "8"}], "}"}], ",", 
                   "22.92`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "22"}], "}"}], ",", 
                   "21.7`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 8}, 22.92}, " ~ ", {{2012, 10, 22}, 21.7}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{6.5, 21.52}, {7.5, 22.}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{121.06937385392894`, 
               134.94956300928462`}, {-126.26719850837264`, \
-104.6495582642882}}],
             StatusArea[#, {{2012, 10, 23}, 21.28}]& ,
             TagBoxNote->"{{2012, 10, 23}, 21.28}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "23"}], "}"}], ",", 
                 "21.28`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 23}, 21.28}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{7.5, 21.04}, {8.5, 21.52}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{134.94956300928462`, 
               148.82975216464027`}, {-104.6495582642882, \
-83.03191802020376}}],
             StatusArea[#, 
              Row[{{{2012, 10, 24}, 21.26}, " ~ ", {{2012, 11, 8}, 20.89}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 24}, 21.26}, \" ~ \", {{2012, 11, 8}, \
20.89}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "24"}], "}"}], ",", 
                   "21.26`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "8"}], "}"}], ",", 
                   "20.89`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 24}, 21.26}, " ~ ", {{2012, 11, 8}, 20.89}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{8.5, 20.56}, {9.5, 21.04}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{148.82975216464027`, 
               162.70994131999592`}, {-83.03191802020376, \
-61.41427777611921}}],
             StatusArea[#, 
              Row[{{{2012, 11, 9}, 21.}, " ~ ", {{2012, 11, 14}, 20.01}}]]& ,
             TagBoxNote->
              "Row[{{{2012, 11, 9}, 21.}, \" ~ \", {{2012, 11, 14}, 20.01}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "9"}], "}"}], ",", 
                   "21.`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "14"}], "}"}], ",", 
                   "20.01`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 9}, 21.}, " ~ ", {{2012, 11, 14}, 20.01}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{9.5, 20.08}, {10.5, 20.56}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{162.70994131999592`, 
               176.59013047535157`}, {-61.41427777611921, \
-39.796637532034765`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 9}, 21.}, " ~ ", {{2012, 11, 14}, 20.01}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 9}, 21.}, \" ~ \", {{2012, 11, 14}, 20.01}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "9"}], "}"}], ",", 
                   "21.`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "14"}], "}"}], ",", 
                   "20.01`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 9}, 21.}, " ~ ", {{2012, 11, 14}, 20.01}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{10.5, 20.56}, {11.5, 21.04}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{176.59013047535157`, 
               190.47031963070722`}, {-83.03191802020376, \
-61.41427777611921}}],
             StatusArea[#, 
              Row[{{{2012, 11, 15}, 20.06}, " ~ ", {{2012, 11, 23}, 21.04}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 15}, 20.06}, \" ~ \", {{2012, 11, 23}, \
21.04}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "15"}], "}"}], ",", 
                   "20.06`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "23"}], "}"}], ",", 
                   "21.04`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 15}, 20.06}, " ~ ", {{2012, 11, 23}, 21.04}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{11.5, 21.04}, {12.5, 21.52}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{190.47031963070722`, 
               204.35050878606287`}, {-104.6495582642882, \
-83.03191802020376}}],
             StatusArea[#, 
              Row[{{{2012, 11, 26}, 21.06}, " ~ ", {{2012, 12, 12}, 21.78}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 26}, 21.06}, \" ~ \", {{2012, 12, 12}, \
21.78}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "26"}], "}"}], ",", 
                   "21.06`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "12"}], "}"}], ",", 
                   "21.78`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 26}, 21.06}, " ~ ", {{2012, 12, 12}, 21.78}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{12.5, 20.56}, {13.5, 21.04}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{204.35050878606287`, 
               218.23069794141853`}, {-83.03191802020376, \
-61.41427777611921}}],
             StatusArea[#, 
              Row[{{{2012, 12, 13}, 21.62}, " ~ ", {{2012, 12, 28}, 20.44}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 13}, 21.62}, \" ~ \", {{2012, 12, 28}, \
20.44}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "13"}], "}"}], ",", 
                   "21.62`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "28"}], "}"}], ",", 
                   "20.44`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 13}, 21.62}, " ~ ", {{2012, 12, 28}, 20.44}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{13.5, 21.04}, {14.5, 21.52}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{218.23069794141853`, 
               232.11088709677423`}, {-104.6495582642882, \
-83.03191802020376}}],
             StatusArea[#, 
              Row[{{{2012, 12, 31}, 20.99}, " ~ ", {{2013, 1, 18}, 22.04}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 31}, 20.99}, \" ~ \", {{2013, 1, 18}, \
22.04}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "31"}], "}"}], ",", 
                   "20.99`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "18"}], "}"}], ",", 
                   "22.04`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 31}, 20.99}, " ~ ", {{2013, 1, 18}, 22.04}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{14.5, 21.52}, {15.5, 22.}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{232.11088709677423`, 
               245.9910762521299}, {-126.26719850837264`, \
-104.6495582642882}}],
             StatusArea[#, 
              Row[{{{2012, 12, 31}, 20.99}, " ~ ", {{2013, 1, 18}, 22.04}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 31}, 20.99}, \" ~ \", {{2013, 1, 18}, \
22.04}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "31"}], "}"}], ",", 
                   "20.99`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "18"}], "}"}], ",", 
                   "22.04`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 31}, 20.99}, " ~ ", {{2013, 1, 18}, 22.04}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{15.5, 22.}, {16.5, 22.48}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{245.9910762521299, 
               259.87126540748557`}, {-147.88483875245709`, \
-126.26719850837264`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 22}, 22.01}, " ~ ", {{2013, 1, 28}, 22.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 22}, 22.01}, \" ~ \", {{2013, 1, 28}, 22.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "22"}], "}"}], ",", 
                   "22.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "28"}], "}"}], ",", 
                   "22.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 22}, 22.01}, " ~ ", {{2013, 1, 28}, 22.5}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{16.5, 22.48}, {17.5, 22.96}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{259.87126540748557`, 
               273.7514545628412}, {-169.50247899654153`, \
-147.88483875245709`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 29}, 22.5}, " ~ ", {{2013, 2, 13}, 23.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 29}, 22.5}, \" ~ \", {{2013, 2, 13}, 23.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "29"}], "}"}], ",", 
                   "22.5`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "13"}], "}"}], ",", 
                   "23.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 29}, 22.5}, " ~ ", {{2013, 2, 13}, 23.39}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{17.5, 22.96}, {18.5, 23.44}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{273.7514545628412, 
               287.63164371819687`}, {-191.12011924062597`, \
-169.50247899654153`}}],
             StatusArea[#, 
              Row[{{{2013, 2, 14}, 23.41}, " ~ ", {{2013, 2, 19}, 23.75}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 14}, 23.41}, \" ~ \", {{2013, 2, 19}, \
23.75}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "14"}], "}"}], ",", 
                   "23.41`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "19"}], "}"}], ",", 
                   "23.75`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 14}, 23.41}, " ~ ", {{2013, 2, 19}, 23.75}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{18.5, 22.48}, {19.5, 22.96}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{287.63164371819687`, 
               301.5118328735525}, {-169.50247899654153`, \
-147.88483875245709`}}],
             StatusArea[#, 
              Row[{{{2013, 2, 20}, 23.41}, " ~ ", {{2013, 4, 19}, 21.75}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 20}, 23.41}, \" ~ \", {{2013, 4, 19}, \
21.75}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "20"}], "}"}], ",", 
                   "23.41`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "19"}], "}"}], ",", 
                   "21.75`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 20}, 23.41}, " ~ ", {{2013, 4, 19}, 21.75}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{19.5, 22.}, {20.5, 22.48}, "RoundingRadius" -> 
                0]},
              ImageSizeCache->{{301.5118328735525, 
               315.39202202890823`}, {-147.88483875245709`, \
-126.26719850837264`}}],
             StatusArea[#, 
              Row[{{{2013, 2, 20}, 23.41}, " ~ ", {{2013, 4, 19}, 21.75}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 20}, 23.41}, \" ~ \", {{2013, 4, 19}, \
21.75}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "20"}], "}"}], ",", 
                   "23.41`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "19"}], "}"}], ",", 
                   "21.75`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 20}, 23.41}, " ~ ", {{2013, 4, 19}, 21.75}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{20.5, 21.52}, {21.5, 22.}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{315.39202202890823`, 
               329.2722111842639}, {-126.26719850837264`, \
-104.6495582642882}}],
             StatusArea[#, {{2013, 4, 22}, 21.35}]& ,
             TagBoxNote->"{{2013, 4, 22}, 21.35}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "22"}], "}"}], ",", 
                 "21.35`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 22}, 21.35}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{21.5, 22.}, {22.5, 22.48}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{329.2722111842639, 
               343.15240033961953`}, {-147.88483875245709`, \
-126.26719850837264`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 23}, 21.5}, " ~ ", {{2013, 5, 3}, 22.57}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 23}, 21.5}, \" ~ \", {{2013, 5, 3}, 22.57}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "23"}], "}"}], ",", 
                   "21.5`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "3"}], "}"}], ",", 
                   "22.57`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 23}, 21.5}, " ~ ", {{2013, 5, 3}, 22.57}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{22.5, 22.48}, {23.5, 22.96}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{343.15240033961953`, 
               357.0325894949752}, {-169.50247899654153`, \
-147.88483875245709`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 6}, 22.58}, " ~ ", {{2013, 5, 8}, 23.01}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 6}, 22.58}, \" ~ \", {{2013, 5, 8}, 23.01}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "6"}], "}"}], ",", 
                   "22.58`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "8"}], "}"}], ",", 
                   "23.01`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 6}, 22.58}, " ~ ", {{2013, 5, 8}, 23.01}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{23.5, 22.96}, {24.5, 23.44}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{357.0325894949752, 
               370.91277865033084`}, {-191.12011924062597`, \
-169.50247899654153`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 9}, 22.78}, " ~ ", {{2013, 5, 17}, 23.46}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 9}, 22.78}, \" ~ \", {{2013, 5, 17}, 23.46}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "9"}], "}"}], ",", 
                   "22.78`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "17"}], "}"}], ",", 
                   "23.46`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 9}, 22.78}, " ~ ", {{2013, 5, 17}, 23.46}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{24.5, 23.44}, {25.5, 23.92}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{370.91277865033084`, 
               384.7929678056865}, {-212.7377594847104, \
-191.12011924062597`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 20}, 23.57}, " ~ ", {{2013, 6, 18}, 24.33}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 20}, 23.57}, \" ~ \", {{2013, 6, 18}, \
24.33}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "20"}], "}"}], ",", 
                   "23.57`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "18"}], "}"}], ",", 
                   "24.33`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 20}, 23.57}, " ~ ", {{2013, 6, 18}, 24.33}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{25.5, 22.96}, {26.5, 23.44}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{384.7929678056865, 
               398.67315696104214`}, {-191.12011924062597`, \
-169.50247899654153`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 19}, 23.98}, " ~ ", {{2013, 6, 24}, 22.93}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 19}, 23.98}, \" ~ \", {{2013, 6, 24}, \
22.93}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "19"}], "}"}], ",", 
                   "23.98`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "24"}], "}"}], ",", 
                   "22.93`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 19}, 23.98}, " ~ ", {{2013, 6, 24}, 22.93}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{26.5, 23.44}, {27.5, 23.92}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{398.67315696104214`, 
               412.5533461163978}, {-212.7377594847104, \
-191.12011924062597`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 25}, 23.11}, " ~ ", {{2013, 7, 11}, 23.94}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 25}, 23.11}, \" ~ \", {{2013, 7, 11}, \
23.94}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "25"}], "}"}], ",", 
                   "23.11`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "11"}], "}"}], ",", 
                   "23.94`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 25}, 23.11}, " ~ ", {{2013, 7, 11}, 23.94}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{27.5, 23.92}, {28.5, 24.400000000000002`}, 
                "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{412.5533461163978, 
               426.4335352717535}, {-234.35539972879508`, \
-212.7377594847104}}],
             StatusArea[#, 
              Row[{{{2013, 7, 12}, 23.76}, " ~ ", {{2013, 7, 19}, 24.72}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 12}, 23.76}, \" ~ \", {{2013, 7, 19}, \
24.72}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "12"}], "}"}], ",", 
                   "23.76`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "24.72`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 12}, 23.76}, " ~ ", {{2013, 7, 19}, 24.72}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], 
            "Tooltip"]& ]}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {}, 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 19.599999999999998`}, {28.5, 
             19.599999999999998`}}], {}}, {{
             LineBox[{{0.5, 19.599999999999998`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 
                19.599999999999998`}]}], 
             LineBox[{{28.5, 19.599999999999998`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {28.5, 
                19.599999999999998`}]}], {{}, {}, {
               LineBox[{{13.5, 19.599999999999998`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {13.5, 
                  19.599999999999998`}]}], 
               LineBox[{{13.5, 19.599999999999998`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {13.5, 
                  19.599999999999998`}]}]}}}, {
             InsetBox["\<\"2012\"\>", 
              Offset[{0., -2.}, {7., 19.599999999999998`}], {0, 1}, 
              Automatic, {1, 0}], 
             InsetBox["\<\"2013\"\>", 
              Offset[{0., -2.}, {21., 19.599999999999998`}], {0, 1}, 
              Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->True],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, Automatic},
       GridLines->
        FrontEndValueCache[{{{1.5, {}}, {4.5, {}}, {7.5, {}}, {11.5, {}}, {
           13.5, {}}, {16.5, {}}, {18.5, {}}, {21.5, {}}, {24.5, {}}, {
           26.5, {}}, {13.5, 
            Directive[
             Dashing[{}]]}}, 
          FindDivisions[{#, #2}, 6]& }, {{{1.5, {}}, {4.5, {}}, {7.5, {}}, {
           11.5, {}}, {13.5, {}}, {16.5, {}}, {18.5, {}}, {21.5, {}}, {
           24.5, {}}, {26.5, {}}, {13.5, 
            Directive[
             Dashing[{}]]}}, {19., 20., 21., 22., 23., 24., 25.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "RenkoChart", "\" of \"", "\"General Electric Company\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.1]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            Identity[#], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[19.599999999999998`]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{19., 
            FormBox["19.`", TraditionalForm]}, {20., 
            FormBox["20.`", TraditionalForm]}, {21., 
            FormBox["21.`", TraditionalForm]}, {22., 
            FormBox["22.`", TraditionalForm]}, {23., 
            FormBox["23.`", TraditionalForm]}, {24., 
            FormBox["24.`", TraditionalForm]}, {25., 
            FormBox["25.`", TraditionalForm]}}}]], {192., -358.76873046931394`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{0.5, 20.56}, {1.5, 20.92}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{37.78823892179503, 
               42.3073702747015}, {-71.45133410937865, -54.810951241079806`}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 8, 1}, 20.73}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 20.56}, \" ~ \", {{2012, 8, 1}, 20.73}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "20.56`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "1"}], "}"}], ",", 
                   "20.73`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 8, 1}, 20.73}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{1.5, 20.52}, {2.5, 20.56}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{42.3073702747015, 
               46.82650162760797}, {-54.810951241079806`, \
-52.962019811268874`}}],
             StatusArea[#, {{2012, 8, 2}, 20.52}]& ,
             TagBoxNote->"{{2012, 8, 2}, 20.52}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "2"}], "}"}], ",", 
                 "20.52`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 2}, 20.52}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{2.5, 20.56}, {3.5, 20.96}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{46.82650162760797, 
               51.34563298051455}, {-73.30026553918958, \
-54.810951241079806`}}],
             StatusArea[#, {{2012, 8, 3}, 20.96}]& ,
             TagBoxNote->"{{2012, 8, 3}, 20.96}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "3"}], "}"}], ",", 
                 "20.96`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 3}, 20.96}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{3.5, 20.96}, {4.5, 20.97}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{51.34563298051455, 
               55.86476433342102}, {-73.76249839664229, -73.30026553918958}}],
             StatusArea[#, {{2012, 8, 6}, 20.97}]& ,
             TagBoxNote->"{{2012, 8, 6}, 20.97}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "6"}], "}"}], ",", 
                 "20.97`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 6}, 20.97}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{4.5, 20.97}, {5.5, 21.12}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{55.86476433342102, 
               60.38389568632749}, {-80.69599125843342, -73.76249839664229}}],
             StatusArea[#, 
              Row[{{{2012, 8, 7}, 21.12}, " ~ ", {{2012, 8, 31}, 20.71}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 7}, 21.12}, \" ~ \", {{2012, 8, 31}, 20.71}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "7"}], "}"}], ",", 
                   "21.12`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "31"}], "}"}], ",", 
                   "20.71`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 7}, 21.12}, " ~ ", {{2012, 8, 31}, 20.71}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{5.5, 20.51}, {6.5, 20.97}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{60.38389568632749, 
               64.90302703923396}, {-73.76249839664229, -52.49978695381628}}],
             StatusArea[#, 
              Row[{{{2012, 9, 4}, 20.51}, " ~ ", {{2012, 9, 5}, 20.65}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 4}, 20.51}, \" ~ \", {{2012, 9, 5}, 20.65}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "4"}], "}"}], ",", 
                   "20.51`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "5"}], "}"}], ",", 
                   "20.65`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 4}, 20.51}, " ~ ", {{2012, 9, 5}, 20.65}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{6.5, 20.97}, {7.5, 21.31}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{64.90302703923396, 
               69.42215839214055}, {-89.47841555003549, -73.76249839664229}}],
             StatusArea[#, {{2012, 9, 6}, 21.31}]& ,
             TagBoxNote->"{{2012, 9, 6}, 21.31}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "6"}], "}"}], ",", 
                 "21.31`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 6}, 21.31}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{7.5, 21.31}, {8.5, 21.59}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{69.42215839214055, 
               73.94128974504702}, {-102.42093555871224`, \
-89.47841555003549}}],
             StatusArea[#, 
              Row[{{{2012, 9, 7}, 21.59}, " ~ ", {{2012, 9, 11}, 21.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 7}, 21.59}, \" ~ \", {{2012, 9, 11}, 21.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "7"}], "}"}], ",", 
                   "21.59`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "11"}], "}"}], ",", 
                   "21.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 7}, 21.59}, " ~ ", {{2012, 9, 11}, 21.59}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{8.5, 21.59}, {9.5, 21.89}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{73.94128974504702, 
               78.46042109795349}, {-116.28792128229452`, \
-102.42093555871224`}}],
             StatusArea[#, {{2012, 9, 12}, 21.89}]& ,
             TagBoxNote->"{{2012, 9, 12}, 21.89}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "12"}], "}"}], ",", 
                 "21.89`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 12}, 21.89}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{9.5, 21.89}, {10.5, 22.02}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{78.46042109795349, 
               82.97955245085996}, {-122.29694842918013`, \
-116.28792128229452`}}],
             StatusArea[#, {{2012, 9, 13}, 22.02}]& ,
             TagBoxNote->"{{2012, 9, 13}, 22.02}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "13"}], "}"}], ",", 
                 "22.02`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 13}, 22.02}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{10.5, 22.02}, {11.5, 22.11}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{82.97955245085996, 
               87.49868380376643}, {-126.45704414625482`, \
-122.29694842918013`}}],
             StatusArea[#, 
              Row[{{{2012, 9, 14}, 22.11}, " ~ ", {{2012, 9, 17}, 22.05}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 14}, 22.11}, \" ~ \", {{2012, 9, 17}, \
22.05}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "14"}], "}"}], ",", 
                   "22.11`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "17"}], "}"}], ",", 
                   "22.05`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 14}, 22.11}, " ~ ", {{2012, 9, 17}, 22.05}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{11.5, 22.11}, {12.5, 22.24}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{87.49868380376643, 
               92.01781515667301}, {-132.46607129314054`, \
-126.45704414625482`}}],
             StatusArea[#, {{2012, 9, 18}, 22.24}]& ,
             TagBoxNote->"{{2012, 9, 18}, 22.24}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "18"}], "}"}], ",", 
                 "22.24`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 18}, 22.24}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{12.5, 22.24}, {13.5, 22.43}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{92.01781515667301, 
               96.53694650957948}, {-141.2484955847425, \
-132.46607129314054`}}],
             StatusArea[#, 
              Row[{{{2012, 9, 19}, 22.43}, " ~ ", {{2012, 9, 20}, 22.43}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 19}, 22.43}, \" ~ \", {{2012, 9, 20}, \
22.43}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "19"}], "}"}], ",", 
                   "22.43`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "20"}], "}"}], ",", 
                   "22.43`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 19}, 22.43}, " ~ ", {{2012, 9, 20}, 22.43}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{13.5, 22.43}, {14.5, 22.53}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{96.53694650957948, 
               101.05607786248595`}, {-145.87082415927, -141.2484955847425}}],
             StatusArea[#, 
              Row[{{{2012, 9, 21}, 22.53}, " ~ ", {{2012, 9, 25}, 22.31}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 21}, 22.53}, \" ~ \", {{2012, 9, 25}, \
22.31}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "21"}], "}"}], ",", 
                   "22.53`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "25"}], "}"}], ",", 
                   "22.31`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 21}, 22.53}, " ~ ", {{2012, 9, 25}, 22.31}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{14.5, 22.1}, {15.5, 22.43}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{101.05607786248595`, 
               105.57520921539242`}, {-141.2484955847425, \
-125.99481128880223`}}],
             StatusArea[#, {{2012, 9, 26}, 22.1}]& ,
             TagBoxNote->"{{2012, 9, 26}, 22.1}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "26"}], "}"}], ",", 
                 "22.1`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 26}, 22.1}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{15.5, 22.43}, {16.5, 22.73}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{105.57520921539242`, 
               110.09434056829889`}, {-155.115481308325, -141.2484955847425}}],
             StatusArea[#, 
              Row[{{{2012, 9, 27}, 22.73}, " ~ ", {{2012, 9, 28}, 22.71}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 27}, 22.73}, \" ~ \", {{2012, 9, 28}, \
22.71}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "27"}], "}"}], ",", 
                   "22.73`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "28"}], "}"}], ",", 
                   "22.71`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 27}, 22.73}, " ~ ", {{2012, 9, 28}, 22.71}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{16.5, 22.73}, {17.5, 22.81}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{110.09434056829889`, 
               114.61347192120547`}, {-158.81334416794664`, \
-155.115481308325}}],
             StatusArea[#, 
              Row[{{{2012, 10, 1}, 22.81}, " ~ ", {{2012, 10, 2}, 22.79}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 1}, 22.81}, \" ~ \", {{2012, 10, 2}, \
22.79}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "1"}], "}"}], ",", 
                   "22.81`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "2"}], "}"}], ",", 
                   "22.79`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 1}, 22.81}, " ~ ", {{2012, 10, 2}, 22.79}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{17.5, 22.81}, {18.5, 22.91}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{114.61347192120547`, 
               119.13260327411194`}, {-163.43567274247414`, \
-158.81334416794664`}}],
             StatusArea[#, {{2012, 10, 3}, 22.91}]& ,
             TagBoxNote->"{{2012, 10, 3}, 22.91}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "3"}], "}"}], ",", 
                 "22.91`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 3}, 22.91}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{18.5, 22.91}, {19.5, 22.95}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{119.13260327411194`, 
               123.65173462701841`}, {-165.28460417228519`, \
-163.43567274247414`}}],
             StatusArea[#, {{2012, 10, 4}, 22.95}]& ,
             TagBoxNote->"{{2012, 10, 4}, 22.95}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "4"}], "}"}], ",", 
                 "22.95`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 4}, 22.95}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{19.5, 22.95}, {20.5, 23.12}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{123.65173462701841`, 
               128.17086597992488`}, {-173.14256274898196`, \
-165.28460417228519`}}],
             StatusArea[#, 
              Row[{{{2012, 10, 5}, 23.12}, " ~ ", {{2012, 10, 8}, 22.92}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 5}, 23.12}, \" ~ \", {{2012, 10, 8}, \
22.92}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "5"}], "}"}], ",", 
                   "23.12`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "8"}], "}"}], ",", 
                   "22.92`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 5}, 23.12}, " ~ ", {{2012, 10, 8}, 22.92}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{20.5, 22.62}, {21.5, 22.95}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{128.17086597992488`, 
               132.68999733283135`}, {-165.28460417228519`, \
-150.03091987634468`}}],
             StatusArea[#, {{2012, 10, 9}, 22.62}]& ,
             TagBoxNote->"{{2012, 10, 9}, 22.62}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "9"}], "}"}], ",", 
                 "22.62`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 9}, 22.62}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{21.5, 22.43}, {22.5, 22.62}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{132.68999733283135`, 
               137.20912868573794`}, {-150.03091987634468`, \
-141.2484955847425}}],
             StatusArea[#, 
              Row[{{{2012, 10, 10}, 22.43}, " ~ ", {{2012, 10, 18}, 22.81}}]]& ,
             TagBoxNote->
              "Row[{{{2012, 10, 10}, 22.43}, \" ~ \", {{2012, 10, 18}, \
22.81}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "10"}], "}"}], ",", 
                   "22.43`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "18"}], "}"}], ",", 
                   "22.81`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 10}, 22.43}, " ~ ", {{2012, 10, 18}, 22.81}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{22.5, 22.03}, {23.5, 22.43}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{137.20912868573794`, 
               141.7282600386444}, {-141.2484955847425, \
-122.75918128663295`}}],
             StatusArea[#, {{2012, 10, 19}, 22.03}]& ,
             TagBoxNote->"{{2012, 10, 19}, 22.03}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "19"}], "}"}], ",", 
                 "22.03`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 19}, 22.03}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{23.5, 21.7}, {24.5, 22.03}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{141.7282600386444, 
               146.24739139155088`}, {-122.75918128663295`, \
-107.50549699069245`}}],
             StatusArea[#, {{2012, 10, 22}, 21.7}]& ,
             TagBoxNote->"{{2012, 10, 22}, 21.7}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "22"}], "}"}], ",", 
                 "21.7`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 22}, 21.7}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{24.5, 21.28}, {25.5, 21.7}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{146.24739139155088`, 
               150.76652274445735`}, {-107.50549699069245`, \
-88.09171697767738}}],
             StatusArea[#, {{2012, 10, 23}, 21.28}]& ,
             TagBoxNote->"{{2012, 10, 23}, 21.28}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "23"}], "}"}], ",", 
                 "21.28`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 23}, 21.28}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{25.5, 21.26}, {26.5, 21.28}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{150.76652274445735`, 
               155.28565409736382`}, {-88.09171697767738, \
-87.16725126277186}}],
             StatusArea[#, 
              Row[{{{2012, 10, 24}, 21.26}, " ~ ", {{2012, 10, 25}, 21.26}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 24}, 21.26}, \" ~ \", {{2012, 10, 25}, \
21.26}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "24"}], "}"}], ",", 
                   "21.26`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "25"}], "}"}], ",", 
                   "21.26`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 24}, 21.26}, " ~ ", {{2012, 10, 25}, 21.26}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{26.5, 21.11}, {27.5, 21.26}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{155.28565409736382`, 
               159.8047854502704}, {-87.16725126277186, -80.2337584009806}}],
             StatusArea[#, {{2012, 10, 26}, 21.11}]& ,
             TagBoxNote->"{{2012, 10, 26}, 21.11}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "26"}], "}"}], ",", 
                 "21.11`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 26}, 21.11}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{27.5, 21.06}, {28.5, 21.11}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{159.8047854502704, 
               164.32391680317687`}, {-80.2337584009806, -77.92259411371697}}],
             StatusArea[#, {{2012, 10, 31}, 21.06}]& ,
             TagBoxNote->"{{2012, 10, 31}, 21.06}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "31"}], "}"}], ",", 
                 "21.06`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 31}, 21.06}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{28.5, 21.11}, {29.5, 21.34}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{164.32391680317687`, 
               168.84304815608334`}, {-90.86511412239372, -80.2337584009806}}],
             StatusArea[#, 
              Row[{{{2012, 11, 1}, 21.34}, " ~ ", {{2012, 11, 2}, 21.31}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 1}, 21.34}, \" ~ \", {{2012, 11, 2}, \
21.31}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "1"}], "}"}], ",", 
                   "21.34`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "2"}], "}"}], ",", 
                   "21.31`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 1}, 21.34}, " ~ ", {{2012, 11, 2}, 21.31}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{29.5, 21.34}, {30.5, 21.41}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{168.84304815608334`, 
               173.3621795089898}, {-94.100744124563, -90.86511412239372}}],
             StatusArea[#, {{2012, 11, 5}, 21.41}]& ,
             TagBoxNote->"{{2012, 11, 5}, 21.41}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "11", ",", "5"}], "}"}], ",", 
                 "21.41`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 11, 5}, 21.41}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{30.5, 21.41}, {31.5, 21.59}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{173.3621795089898, 
               177.88131086189628`}, {-102.42093555871224`, \
-94.100744124563}}],
             StatusArea[#, 
              Row[{{{2012, 11, 6}, 21.59}, " ~ ", {{2012, 11, 7}, 21.13}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 6}, 21.59}, \" ~ \", {{2012, 11, 7}, \
21.13}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "6"}], "}"}], ",", 
                   "21.59`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "7"}], "}"}], ",", 
                   "21.13`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 6}, 21.59}, " ~ ", {{2012, 11, 7}, 21.13}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{31.5, 20.89}, {32.5, 21.41}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{177.88131086189628`, 
               182.40044221480275`}, {-94.100744124563, -70.06463553702042}}],
             StatusArea[#, 
              Row[{{{2012, 11, 8}, 20.89}, " ~ ", {{2012, 11, 12}, 20.89}}]]& ,
             TagBoxNote->
              "Row[{{{2012, 11, 8}, 20.89}, \" ~ \", {{2012, 11, 12}, \
20.89}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "8"}], "}"}], ",", 
                   "20.89`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "12"}], "}"}], ",", 
                   "20.89`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 8}, 20.89}, " ~ ", {{2012, 11, 12}, 20.89}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{32.5, 20.68}, {33.5, 20.89}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{182.40044221480275`, 
               186.91957356770934`}, {-70.06463553702042, \
-60.357745530512716`}}],
             StatusArea[#, {{2012, 11, 13}, 20.68}]& ,
             TagBoxNote->"{{2012, 11, 13}, 20.68}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "11", ",", "13"}], "}"}], ",", 
                 "20.68`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 11, 13}, 20.68}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{33.5, 20.01}, {34.5, 20.68}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{186.91957356770934`, 
               191.4387049206158}, {-60.357745530512716`, \
-29.38814408117912}}],
             StatusArea[#, 
              Row[{{{2012, 11, 14}, 20.01}, " ~ ", {{2012, 12, 6}, 21.37}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 14}, 20.01}, \" ~ \", {{2012, 12, 6}, \
21.37}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "14"}], "}"}], ",", 
                   "20.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "6"}], "}"}], ",", 
                   "21.37`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 14}, 20.01}, " ~ ", {{2012, 12, 6}, 21.37}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{34.5, 20.68}, {35.5, 21.46}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{191.4387049206158, 
               195.95783627352228`}, {-96.41190841182674, \
-60.357745530512716`}}],
             StatusArea[#, 
              Row[{{{2012, 12, 7}, 21.46}, " ~ ", {{2012, 12, 10}, 21.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 7}, 21.46}, \" ~ \", {{2012, 12, 10}, \
21.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "7"}], "}"}], ",", 
                   "21.46`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "10"}], "}"}], ",", 
                   "21.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 7}, 21.46}, " ~ ", {{2012, 12, 10}, 21.39}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{35.5, 21.46}, {36.5, 21.51}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{195.95783627352228`, 
               200.47696762642886`}, {-98.72307269909038, \
-96.41190841182674}}],
             StatusArea[#, {{2012, 12, 11}, 21.51}]& ,
             TagBoxNote->"{{2012, 12, 11}, 21.51}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "11"}], "}"}], ",", 
                 "21.51`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 11}, 21.51}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{36.5, 21.51}, {37.5, 21.78}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{200.47696762642886`, 
               204.99609897933533`}, {-111.20335985031443`, \
-98.72307269909038}}],
             StatusArea[#, 
              Row[{{{2012, 12, 12}, 21.78}, " ~ ", {{2012, 12, 14}, 21.62}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 12}, 21.78}, \" ~ \", {{2012, 12, 14}, \
21.62}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "12"}], "}"}], ",", 
                   "21.78`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "14"}], "}"}], ",", 
                   "21.62`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 12}, 21.78}, " ~ ", {{2012, 12, 14}, 21.62}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{37.5, 21.78}, {38.5, 21.93}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{204.99609897933533`, 
               209.5152303322418}, {-118.13685271210545`, \
-111.20335985031443`}}],
             StatusArea[#, 
              Row[{{{2012, 12, 17}, 21.93}, " ~ ", {{2012, 12, 18}, 21.69}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 17}, 21.93}, \" ~ \", {{2012, 12, 18}, \
21.69}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "17"}], "}"}], ",", 
                   "21.93`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "18"}], "}"}], ",", 
                   "21.69`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 17}, 21.93}, " ~ ", {{2012, 12, 18}, 21.69}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{38.5, 21.01}, {39.5, 21.78}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{209.5152303322418, 
               214.03436168514827`}, {-111.20335985031443`, \
-75.61142982645333}}],
             StatusArea[#, 
              Row[{{{2012, 12, 19}, 21.01}, " ~ ", {{2012, 12, 20}, 21.05}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 19}, 21.01}, \" ~ \", {{2012, 12, 20}, \
21.05}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "19"}], "}"}], ",", 
                   "21.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "20"}], "}"}], ",", 
                   "21.05`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 19}, 21.01}, " ~ ", {{2012, 12, 20}, 21.05}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{39.5, 20.88}, {40.5, 21.01}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{214.03436168514827`, 
               218.55349303805474`}, {-75.61142982645333, -69.6024026795676}}],
             StatusArea[#, {{2012, 12, 21}, 20.88}]& ,
             TagBoxNote->"{{2012, 12, 21}, 20.88}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "21"}], "}"}], ",", 
                 "20.88`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 21}, 20.88}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{40.5, 20.82}, {41.5, 20.88}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{218.55349303805474`, 
               223.0726243909612}, {-69.6024026795676, -66.82900553485115}}],
             StatusArea[#, {{2012, 12, 24}, 20.82}]& ,
             TagBoxNote->"{{2012, 12, 24}, 20.82}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "24"}], "}"}], ",", 
                 "20.82`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 24}, 20.82}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{41.5, 20.77}, {42.5, 20.82}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{223.0726243909612, 
               227.5917557438678}, {-66.82900553485115, -64.5178412475874}}],
             StatusArea[#, {{2012, 12, 26}, 20.77}]& ,
             TagBoxNote->"{{2012, 12, 26}, 20.77}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "26"}], "}"}], ",", 
                 "20.77`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 26}, 20.77}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{42.5, 20.69}, {43.5, 20.77}, "RoundingRadius" -> 
                0]},
              ImageSizeCache->{{227.5917557438678, 
               232.11088709677426`}, {-64.5178412475874, \
-60.819978387965534`}}],
             StatusArea[#, {{2012, 12, 27}, 20.69}]& ,
             TagBoxNote->"{{2012, 12, 27}, 20.69}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "27"}], "}"}], ",", 
                 "20.69`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 27}, 20.69}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{43.5, 20.44}, {44.5, 20.69}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{232.11088709677426`, 
               236.63001844968073`}, {-60.819978387965534`, \
-49.26415695164701}}],
             StatusArea[#, {{2012, 12, 28}, 20.44}]& ,
             TagBoxNote->"{{2012, 12, 28}, 20.44}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "28"}], "}"}], ",", 
                 "20.44`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 28}, 20.44}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{44.5, 20.69}, {45.5, 20.99}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{236.63001844968073`, 
               241.1491498025872}, {-74.6869641115477, -60.819978387965534`}}],
             StatusArea[#, {{2012, 12, 31}, 20.99}]& ,
             TagBoxNote->"{{2012, 12, 31}, 20.99}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "31"}], "}"}], ",", 
                 "20.99`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 31}, 20.99}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{45.5, 20.99}, {46.5, 21.34}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{241.1491498025872, 
               245.6682811554938}, {-90.86511412239372, -74.6869641115477}}],
             StatusArea[#, 
              Row[{{{2013, 1, 2}, 21.34}, " ~ ", {{2013, 1, 17}, 21.3}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 2}, 21.34}, \" ~ \", {{2013, 1, 17}, 21.3}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "2"}], "}"}], ",", 
                   "21.34`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "17"}], "}"}], ",", 
                   "21.3`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 2}, 21.34}, " ~ ", {{2013, 1, 17}, 21.3}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{46.5, 21.34}, {47.5, 22.04}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{245.6682811554938, 
               250.18741250840026`}, {-123.22141414408566`, \
-90.86511412239372}}],
             StatusArea[#, 
              Row[{{{2013, 1, 18}, 22.04}, " ~ ", {{2013, 1, 23}, 21.94}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 18}, 22.04}, \" ~ \", {{2013, 1, 23}, \
21.94}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "18"}], "}"}], ",", 
                   "22.04`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "23"}], "}"}], ",", 
                   "21.94`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 18}, 22.04}, " ~ ", {{2013, 1, 23}, 21.94}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{47.5, 22.04}, {48.5, 22.05}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{250.18741250840026`, 
               254.70654386130673`}, {-123.68364700153847`, \
-123.22141414408566`}}],
             StatusArea[#, {{2013, 1, 24}, 22.05}]& ,
             TagBoxNote->"{{2013, 1, 24}, 22.05}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "1", ",", "24"}], "}"}], ",", 
                 "22.05`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 1, 24}, 22.05}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{48.5, 22.05}, {49.5, 22.29}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{254.70654386130673`, 
               259.2256752142132}, {-134.77723558040418`, \
-123.68364700153847`}}],
             StatusArea[#, {{2013, 1, 25}, 22.29}]& ,
             TagBoxNote->"{{2013, 1, 25}, 22.29}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "1", ",", "25"}], "}"}], ",", 
                 "22.29`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 1, 25}, 22.29}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{49.5, 22.29}, {50.5, 22.5}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{259.2256752142132, 
               263.74480656711967`}, {-144.48412558691177`, \
-134.77723558040418`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 28}, 22.5}, " ~ ", {{2013, 1, 31}, 22.28}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 28}, 22.5}, \" ~ \", {{2013, 1, 31}, 22.28}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "28"}], "}"}], ",", 
                   "22.5`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "31"}], "}"}], ",", 
                   "22.28`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 28}, 22.5}, " ~ ", {{2013, 1, 31}, 22.28}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{50.5, 22.5}, {51.5, 22.62}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{263.74480656711967`, 
               268.26393792002614`}, {-150.03091987634468`, \
-144.48412558691177`}}],
             StatusArea[#, 
              Row[{{{2013, 2, 1}, 22.62}, " ~ ", {{2013, 2, 12}, 22.58}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 1}, 22.62}, \" ~ \", {{2013, 2, 12}, 22.58}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "1"}], "}"}], ",", 
                   "22.62`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "12"}], "}"}], ",", 
                   "22.58`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 1}, 22.62}, " ~ ", {{2013, 2, 12}, 22.58}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{51.5, 22.62}, {52.5, 23.39}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{268.26393792002614`, 
               272.7830692729327}, {-185.62284990020578`, \
-150.03091987634468`}}],
             StatusArea[#, {{2013, 2, 13}, 23.39}]& ,
             TagBoxNote->"{{2013, 2, 13}, 23.39}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "2", ",", "13"}], "}"}], ",", 
                 "23.39`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 2, 13}, 23.39}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{52.5, 23.39}, {53.5, 23.41}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{272.7830692729327, 
               277.3022006258392}, {-186.54731561511142`, \
-185.62284990020578`}}],
             StatusArea[#, 
              Row[{{{2013, 2, 14}, 23.41}, " ~ ", {{2013, 2, 15}, 23.29}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 14}, 23.41}, \" ~ \", {{2013, 2, 15}, \
23.29}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "14"}], "}"}], ",", 
                   "23.41`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "15"}], "}"}], ",", 
                   "23.29`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 14}, 23.41}, " ~ ", {{2013, 2, 15}, 23.29}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{53.5, 23.41}, {54.5, 23.75}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{277.3022006258392, 
               281.82133197874566`}, {-202.2632327685045, \
-186.54731561511142`}}],
             StatusArea[#, 
              Row[{{{2013, 2, 19}, 23.75}, " ~ ", {{2013, 3, 7}, 23.68}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 19}, 23.75}, \" ~ \", {{2013, 3, 7}, 23.68}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "19"}], "}"}], ",", 
                   "23.75`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "7"}], "}"}], ",", 
                   "23.68`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 19}, 23.75}, " ~ ", {{2013, 3, 7}, 23.68}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{54.5, 23.75}, {55.5, 23.77}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{281.82133197874566`, 
               286.34046333165213`}, {-203.18769848340992`, \
-202.2632327685045}}],
             StatusArea[#, 
              Row[{{{2013, 3, 8}, 23.77}, " ~ ", {{2013, 3, 15}, 23.44}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 8}, 23.77}, \" ~ \", {{2013, 3, 15}, 23.44}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "8"}], "}"}], ",", 
                   "23.77`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "15"}], "}"}], ",", 
                   "23.44`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 8}, 23.77}, " ~ ", {{2013, 3, 15}, 23.44}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{55.5, 23.25}, {56.5, 23.75}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{286.34046333165213`, 
               290.8595946845587}, {-202.2632327685045, \
-179.15158989586746`}}],
             StatusArea[#, 
              Row[{{{2013, 3, 18}, 23.25}, " ~ ", {{2013, 3, 22}, 23.37}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 18}, 23.25}, \" ~ \", {{2013, 3, 22}, \
23.37}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "18"}], "}"}], ",", 
                   "23.25`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "22"}], "}"}], ",", 
                   "23.37`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 18}, 23.25}, " ~ ", {{2013, 3, 22}, 23.37}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{56.5, 23.24}, {57.5, 23.25}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{290.8595946845587, 
               295.3787260374652}, {-179.15158989586746`, \
-178.68935703841464`}}],
             StatusArea[#, {{2013, 3, 25}, 23.24}]& ,
             TagBoxNote->"{{2013, 3, 25}, 23.24}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "3", ",", "25"}], "}"}], ",", 
                 "23.24`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 3, 25}, 23.24}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{57.5, 23.12}, {58.5, 23.24}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{295.3787260374652, 
               299.89785739037166`}, {-178.68935703841464`, \
-173.14256274898196`}}],
             StatusArea[#, {{2013, 3, 26}, 23.12}]& ,
             TagBoxNote->"{{2013, 3, 26}, 23.12}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "3", ",", "26"}], "}"}], ",", 
                 "23.12`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 3, 26}, 23.12}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{58.5, 23.1}, {59.5, 23.12}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{299.89785739037166`, 
               304.4169887432781}, {-173.14256274898196`, \
-172.21809703407632`}}],
             StatusArea[#, 
              Row[{{{2013, 3, 27}, 23.1}, " ~ ", {{2013, 3, 28}, 23.12}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 27}, 23.1}, \" ~ \", {{2013, 3, 28}, 23.12}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "27"}], "}"}], ",", 
                   "23.1`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "28"}], "}"}], ",", 
                   "23.12`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 27}, 23.1}, " ~ ", {{2013, 3, 28}, 23.12}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{59.5, 23.08}, {60.5, 23.1}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{304.4169887432781, 
               308.9361200961846}, {-172.21809703407632`, \
-171.2936313191707}}],
             StatusArea[#, {{2013, 4, 1}, 23.08}]& ,
             TagBoxNote->"{{2013, 4, 1}, 23.08}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "1"}], "}"}], ",", 
                 "23.08`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 1}, 23.08}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{60.5, 23.1}, {61.5, 23.34}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{308.9361200961846, 
               313.45525144909107`}, {-183.31168561294214`, \
-172.21809703407632`}}],
             StatusArea[#, {{2013, 4, 2}, 23.34}]& ,
             TagBoxNote->"{{2013, 4, 2}, 23.34}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "2"}], "}"}], ",", 
                 "23.34`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 2}, 23.34}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{61.5, 23.}, {62.5, 23.1}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{313.45525144909107`, 
               317.97438280199754`}, {-172.21809703407632`, \
-167.59576845954882`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 3}, 23.}, " ~ ", {{2013, 4, 4}, 23.08}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 3}, 23.}, \" ~ \", {{2013, 4, 4}, 23.08}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "3"}], "}"}], ",", 
                   "23.`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "4"}], "}"}], ",", 
                   "23.08`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 3}, 23.}, " ~ ", {{2013, 4, 4}, 23.08}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{62.5, 22.93}, {63.5, 23.}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{317.97438280199754`, 
               322.4935141549041}, {-167.59576845954882`, \
-164.36013845737978`}}],
             StatusArea[#, {{2013, 4, 5}, 22.93}]& ,
             TagBoxNote->"{{2013, 4, 5}, 22.93}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "5"}], "}"}], ",", 
                 "22.93`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 5}, 22.93}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{63.5, 23.}, {64.5, 23.12}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{322.4935141549041, 
               327.0126455078106}, {-173.14256274898196`, \
-167.59576845954882`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 8}, 23.12}, " ~ ", {{2013, 4, 9}, 23.06}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 8}, 23.12}, \" ~ \", {{2013, 4, 9}, 23.06}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "8"}], "}"}], ",", 
                   "23.12`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "9"}], "}"}], ",", 
                   "23.06`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 8}, 23.12}, " ~ ", {{2013, 4, 9}, 23.06}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{64.5, 23.12}, {65.5, 23.58}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{327.0126455078106, 
               331.5317768607172}, {-194.40527419180796`, \
-173.14256274898196`}}],
             StatusArea[#, {{2013, 4, 10}, 23.58}]& ,
             TagBoxNote->"{{2013, 4, 10}, 23.58}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "10"}], "}"}], ",", 
                 "23.58`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 10}, 23.58}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{65.5, 23.58}, {66.5, 23.59}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{331.5317768607172, 
               336.05090821362364`}, {-194.86750704926055`, \
-194.40527419180796`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 11}, 23.59}, " ~ ", {{2013, 4, 12}, 23.46}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 11}, 23.59}, \" ~ \", {{2013, 4, 12}, \
23.46}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "11"}], "}"}], ",", 
                   "23.59`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "12"}], "}"}], ",", 
                   "23.46`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 11}, 23.59}, " ~ ", {{2013, 4, 12}, 23.46}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{66.5, 22.81}, {67.5, 23.58}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{336.05090821362364`, 
               340.5700395665301}, {-194.40527419180796`, \
-158.81334416794664`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 15}, 22.81}, " ~ ", {{2013, 4, 16}, 23.1}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 15}, 22.81}, \" ~ \", {{2013, 4, 16}, 23.1}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "15"}], "}"}], ",", 
                   "22.81`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "16"}], "}"}], ",", 
                   "23.1`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 15}, 22.81}, " ~ ", {{2013, 4, 16}, 23.1}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{67.5, 22.76}, {68.5, 22.81}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{340.5700395665301, 
               345.0891709194366}, {-158.81334416794664`, \
-156.50217988068323`}}],
             StatusArea[#, {{2013, 4, 17}, 22.76}]& ,
             TagBoxNote->"{{2013, 4, 17}, 22.76}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "17"}], "}"}], ",", 
                 "22.76`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 17}, 22.76}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{68.5, 22.67}, {69.5, 22.76}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{345.0891709194366, 
               349.60830227234305`}, {-156.50217988068323`, \
-152.34208416360855`}}],
             StatusArea[#, {{2013, 4, 18}, 22.67}]& ,
             TagBoxNote->"{{2013, 4, 18}, 22.67}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "18"}], "}"}], ",", 
                 "22.67`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 18}, 22.67}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{69.5, 21.75}, {70.5, 22.67}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{349.60830227234305`, 
               354.1274336252495}, {-152.34208416360855`, \
-109.8166612779562}}],
             StatusArea[#, {{2013, 4, 19}, 21.75}]& ,
             TagBoxNote->"{{2013, 4, 19}, 21.75}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "19"}], "}"}], ",", 
                 "21.75`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 19}, 21.75}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{70.5, 21.35}, {71.5, 21.75}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{354.1274336252495, 
               358.646564978156}, {-109.8166612779562, -91.32734697984654}}],
             StatusArea[#, 
              Row[{{{2013, 4, 22}, 21.35}, " ~ ", {{2013, 5, 7}, 22.68}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 22}, 21.35}, \" ~ \", {{2013, 5, 7}, 22.68}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "22"}], "}"}], ",", 
                   "21.35`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "7"}], "}"}], ",", 
                   "22.68`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 22}, 21.35}, " ~ ", {{2013, 5, 7}, 22.68}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{71.5, 21.75}, {72.5, 23.01}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{358.646564978156, 
               363.16569633106246`}, {-168.05800131700164`, \
-109.8166612779562}}],
             StatusArea[#, 
              Row[{{{2013, 5, 8}, 23.01}, " ~ ", {{2013, 5, 14}, 23.01}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 8}, 23.01}, \" ~ \", {{2013, 5, 14}, 23.01}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "8"}], "}"}], ",", 
                   "23.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "14"}], "}"}], ",", 
                   "23.01`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 8}, 23.01}, " ~ ", {{2013, 5, 14}, 23.01}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{72.5, 23.01}, {73.5, 23.24}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{363.16569633106246`, 
               367.68482768396905`}, {-178.68935703841464`, \
-168.05800131700164`}}],
             StatusArea[#, {{2013, 5, 15}, 23.24}]& ,
             TagBoxNote->"{{2013, 5, 15}, 23.24}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "15"}], "}"}], ",", 
                 "23.24`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 15}, 23.24}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{73.5, 23.24}, {74.5, 23.27}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{367.68482768396905`, 
               372.2039590368755}, {-180.07605561077287`, \
-178.68935703841464`}}],
             StatusArea[#, {{2013, 5, 16}, 23.27}]& ,
             TagBoxNote->"{{2013, 5, 16}, 23.27}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "16"}], "}"}], ",", 
                 "23.27`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 16}, 23.27}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{74.5, 23.27}, {75.5, 23.46}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{372.2039590368755, 
               376.7230903897821}, {-188.85847990237505`, \
-180.07605561077287`}}],
             StatusArea[#, {{2013, 5, 17}, 23.46}]& ,
             TagBoxNote->"{{2013, 5, 17}, 23.46}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "17"}], "}"}], ",", 
                 "23.46`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 17}, 23.46}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{75.5, 23.46}, {76.5, 23.57}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{376.7230903897821, 
               381.24222174268857`}, {-193.94304133435514`, \
-188.85847990237505`}}],
             StatusArea[#, {{2013, 5, 20}, 23.57}]& ,
             TagBoxNote->"{{2013, 5, 20}, 23.57}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "20"}], "}"}], ",", 
                 "23.57`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 20}, 23.57}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{76.5, 23.57}, {77.5, 23.66}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{381.24222174268857`, 
               385.76135309559504`}, {-198.10313705142983`, \
-193.94304133435514`}}],
             StatusArea[#, {{2013, 5, 21}, 23.66}]& ,
             TagBoxNote->"{{2013, 5, 21}, 23.66}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "21"}], "}"}], ",", 
                 "23.66`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 21}, 23.66}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{77.5, 23.66}, {78.5, 23.86}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{385.76135309559504`, 
               390.2804844485015}, {-207.3477942004846, \
-198.10313705142983`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 22}, 23.86}, " ~ ", {{2013, 5, 30}, 23.6}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 22}, 23.86}, \" ~ \", {{2013, 5, 30}, 23.6}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "22"}], "}"}], ",", 
                   "23.86`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "30"}], "}"}], ",", 
                   "23.6`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 22}, 23.86}, " ~ ", {{2013, 5, 30}, 23.6}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{78.5, 23.32}, {79.5, 23.66}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{390.2804844485015, 
               394.799615801408}, {-198.10313705142983`, \
-182.38721989803673`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 31}, 23.32}, " ~ ", {{2013, 6, 17}, 23.77}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 31}, 23.32}, \" ~ \", {{2013, 6, 17}, \
23.77}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "31"}], "}"}], ",", 
                   "23.32`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "17"}], "}"}], ",", 
                   "23.77`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 31}, 23.32}, " ~ ", {{2013, 6, 17}, 23.77}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{79.5, 23.66}, {80.5, 24.33}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{394.799615801408, 
               399.31874715431445`}, {-229.07273850076342`, \
-198.10313705142983`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 18}, 24.33}, " ~ ", {{2013, 6, 19}, 23.98}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 18}, 24.33}, \" ~ \", {{2013, 6, 19}, \
23.98}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "18"}], "}"}], ",", 
                   "24.33`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "19"}], "}"}], ",", 
                   "23.98`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 18}, 24.33}, " ~ ", {{2013, 6, 19}, 23.98}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{80.5, 23.25}, {81.5, 23.66}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{399.31874715431445`, 
               403.8378785072209}, {-198.10313705142983`, \
-179.15158989586746`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 20}, 23.25}, " ~ ", {{2013, 6, 21}, 23.36}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 20}, 23.25}, \" ~ \", {{2013, 6, 21}, \
23.36}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "20"}], "}"}], ",", 
                   "23.25`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "21"}], "}"}], ",", 
                   "23.36`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 20}, 23.25}, " ~ ", {{2013, 6, 21}, 23.36}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{81.5, 22.93}, {82.5, 23.25}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{403.8378785072209, 
               408.3570098601275}, {-179.15158989586746`, \
-164.36013845737978`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 24}, 22.93}, " ~ ", {{2013, 7, 1}, 23.34}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 24}, 22.93}, \" ~ \", {{2013, 7, 1}, 23.34}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "24"}], "}"}], ",", 
                   "22.93`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "1"}], "}"}], ",", 
                   "23.34`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 24}, 22.93}, " ~ ", {{2013, 7, 1}, 23.34}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{82.5, 22.9}, {83.5, 22.93}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{408.3570098601275, 
               412.876141213034}, {-164.36013845737978`, \
-162.97343988502132`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 2}, 22.9}, " ~ ", {{2013, 7, 10}, 23.54}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 2}, 22.9}, \" ~ \", {{2013, 7, 10}, 23.54}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "2"}], "}"}], ",", 
                   "22.9`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "10"}], "}"}], ",", 
                   "23.54`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 2}, 22.9}, " ~ ", {{2013, 7, 10}, 23.54}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{83.5, 22.93}, {84.5, 23.94}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{412.876141213034, 
               417.39527256594045`}, {-211.0456570601067, \
-164.36013845737978`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 11}, 23.94}, " ~ ", {{2013, 7, 18}, 23.63}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 11}, 23.94}, \" ~ \", {{2013, 7, 18}, \
23.63}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "11"}], "}"}], ",", 
                   "23.94`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "18"}], "}"}], ",", 
                   "23.63`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 11}, 23.94}, " ~ ", {{2013, 7, 18}, 23.63}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{84.5, 23.94}, {85.5, 24.72}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{417.39527256594045`, 
               421.91440391884703`}, {-247.09981994142038`, \
-211.0456570601067}}],
             StatusArea[#, {{2013, 7, 19}, 24.72}]& ,
             TagBoxNote->"{{2013, 7, 19}, 24.72}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                 "24.72`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 7, 19}, 24.72}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{85.5, 24.72}, {86.5, 24.86}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{421.91440391884703`, 
               426.4335352717535}, {-253.57107994575892`, \
-247.09981994142038`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 22}, 24.86}, " ~ ", {{2013, 7, 25}, 24.69}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 22}, 24.86}, \" ~ \", {{2013, 7, 25}, \
24.69}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "22"}], "}"}], ",", 
                   "24.86`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "25"}], "}"}], ",", 
                   "24.69`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 22}, 24.86}, " ~ ", {{2013, 7, 25}, 24.69}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], 
            "Tooltip"]& ]}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {}, 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 19.767500000000002`}, {86.5, 
             19.767500000000002`}}], {}}, {{
             LineBox[{{0.5, 19.767500000000002`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 
                19.767500000000002`}]}], 
             LineBox[{{86.5, 19.767500000000002`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {86.5, 
                19.767500000000002`}]}], {{}, {}, {
               LineBox[{{45.5, 19.767500000000002`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {45.5, 
                  19.767500000000002`}]}], 
               LineBox[{{45.5, 19.767500000000002`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {45.5, 
                  19.767500000000002`}]}]}}}, {
             InsetBox["\<\"2012\"\>", 
              Offset[{0., -2.}, {23., 19.767500000000002`}], {0, 1}, 
              Automatic, {1, 0}], 
             InsetBox["\<\"2013\"\>", 
              Offset[{0., -2.}, {66., 19.767500000000002`}], {0, 1}, 
              Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->True],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, Automatic},
       GridLines->
        FrontEndValueCache[{{{5.5, {}}, {16.5, {}}, {28.5, {}}, {33.5, {}}, {
           45.5, {}}, {50.5, {}}, {53.5, {}}, {59.5, {}}, {70.5, {}}, {
           78.5, {}}, {81.5, {}}, {45.5, 
            Directive[
             Dashing[{}]]}}, 
          FindDivisions[{#, #2}, 6]& }, {{{5.5, {}}, {16.5, {}}, {28.5, {}}, {
           33.5, {}}, {45.5, {}}, {50.5, {}}, {53.5, {}}, {59.5, {}}, {
           70.5, {}}, {78.5, {}}, {81.5, {}}, {45.5, 
            Directive[
             Dashing[{}]]}}, {19., 20., 21., 22., 23., 24., 25.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "LineBreakChart", "\" of \"", "\"General Electric Company\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.02]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            Identity[#], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[19.767500000000002`]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{19., 
            FormBox["19.`", TraditionalForm]}, {20., 
            FormBox["20.`", TraditionalForm]}, {21., 
            FormBox["21.`", TraditionalForm]}, {22., 
            FormBox["22.`", TraditionalForm]}, {23., 
            FormBox["23.`", TraditionalForm]}, {24., 
            FormBox["24.`", TraditionalForm]}, {25., 
            FormBox["25.`", TraditionalForm]}}}]], {576., -358.76873046931394`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{0.525, 20.55}, {1.475, 23.1}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{38.53563372246784, 
               66.93663614804174}, {-175.10705239315627`, \
-53.84446435731519}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 10, 9}, 22.62}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 20.56}, \" ~ \", {{2012, 10, 9}, \
22.62}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "20.56`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "9"}], "}"}], ",", 
                   "22.62`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 20.56}, " ~ ", {{2012, 10, 9}, 22.62}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{1.525, 20.1}, {2.475, 22.95}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{68.43142574938773, 
               96.83242817496162}, {-167.97395897928305`, \
-32.445184115696236`}}],
             StatusArea[#, 
              Row[{{{2012, 10, 10}, 22.43}, " ~ ", {{2012, 11, 21}, 20.68}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 10}, 22.43}, \" ~ \", {{2012, 11, 21}, \
20.68}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "10"}], "}"}], ",", 
                   "22.43`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "21"}], "}"}], ",", 
                   "20.68`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 10}, 22.43}, " ~ ", {{2012, 11, 21}, 20.68}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{2.525, 20.25}, {3.475, 21.9}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{98.3272177763076, 
               126.72822020188153`}, {-118.04230508217216`, \
-39.57827752956922}}],
             StatusArea[#, 
              Row[{{{2012, 11, 23}, 21.04}, " ~ ", {{2012, 12, 18}, 21.69}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 23}, 21.04}, \" ~ \", {{2012, 12, 18}, \
21.69}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "23"}], "}"}], ",", 
                   "21.04`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "18"}], "}"}], ",", 
                   "21.69`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 23}, 21.04}, " ~ ", {{2012, 12, 18}, 21.69}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{3.525, 20.55}, {4.475, 21.75}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{128.22300980322754`, 
               156.6240122288014}, {-110.90921166829918`, \
-53.84446435731519}}],
             StatusArea[#, 
              Row[{{{2012, 12, 19}, 21.01}, " ~ ", {{2012, 12, 31}, 20.99}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 19}, 21.01}, \" ~ \", {{2012, 12, 31}, \
20.99}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "19"}], "}"}], ",", 
                   "21.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "31"}], "}"}], ",", 
                   "20.99`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 19}, 21.01}, " ~ ", {{2012, 12, 31}, 20.99}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{4.525, 20.7}, {5.475, 23.7}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{158.11880183014742`, 
               186.5198042557213}, {-203.6394260486482, \
-60.977557771188174`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 2}, 21.34}, " ~ ", {{2013, 2, 22}, 23.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 2}, 21.34}, \" ~ \", {{2013, 2, 22}, 23.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "2"}], "}"}], ",", 
                   "21.34`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "22"}], "}"}], ",", 
                   "23.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 2}, 21.34}, " ~ ", {{2013, 2, 22}, 23.39}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{5.525, 22.95}, {6.475, 23.55}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{188.01459385706733`, 
               216.4155962826412}, {-196.50633263477522`, \
-167.97395897928305`}}],
             StatusArea[#, 
              Row[{{{2013, 2, 25}, 22.81}, " ~ ", {{2013, 3, 4}, 23.27}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 25}, 22.81}, \" ~ \", {{2013, 3, 4}, 23.27}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "25"}], "}"}], ",", 
                   "22.81`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "4"}], "}"}], ",", 
                   "23.27`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 25}, 22.81}, " ~ ", {{2013, 3, 4}, 23.27}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{6.525, 23.1}, {7.475, 23.7}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{217.91038588398723`, 
               246.31138830956112`}, {-203.6394260486482, \
-175.10705239315627`}}],
             StatusArea[#, 
              Row[{{{2013, 3, 5}, 23.59}, " ~ ", {{2013, 3, 26}, 23.12}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 5}, 23.59}, \" ~ \", {{2013, 3, 26}, 23.12}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "5"}], "}"}], ",", 
                   "23.59`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "26"}], "}"}], ",", 
                   "23.12`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 5}, 23.59}, " ~ ", {{2013, 3, 26}, 23.12}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{7.525, 22.95}, {8.475, 23.55}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{247.8061779109071, 
               276.20718033648103`}, {-196.50633263477522`, \
-167.97395897928305`}}],
             StatusArea[#, 
              Row[{{{2013, 3, 27}, 23.1}, " ~ ", {{2013, 4, 9}, 23.06}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 27}, 23.1}, \" ~ \", {{2013, 4, 9}, 23.06}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "27"}], "}"}], ",", 
                   "23.1`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "9"}], "}"}], ",", 
                   "23.06`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 27}, 23.1}, " ~ ", {{2013, 4, 9}, 23.06}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{8.525, 23.1}, {9.475, 23.55}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{277.701969937827, 
               306.1029723634009}, {-196.50633263477522`, \
-175.10705239315627`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 10}, 23.58}, " ~ ", {{2013, 4, 12}, 23.46}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 10}, 23.58}, \" ~ \", {{2013, 4, 12}, \
23.46}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "10"}], "}"}], ",", 
                   "23.58`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "12"}], "}"}], ",", 
                   "23.46`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 10}, 23.58}, " ~ ", {{2013, 4, 12}, 23.46}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{9.525, 21.45}, {10.475, 23.4}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{307.59776196474695`, 
               335.99876439032084`}, {-189.373239220902, -96.64302484055321}}],
             StatusArea[#, 
              Row[{{{2013, 4, 15}, 22.81}, " ~ ", {{2013, 4, 25}, 21.95}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 15}, 22.81}, \" ~ \", {{2013, 4, 25}, \
21.95}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "15"}], "}"}], ",", 
                   "22.81`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "25"}], "}"}], ",", 
                   "21.95`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 15}, 22.81}, " ~ ", {{2013, 4, 25}, 21.95}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{10.525, 21.6}, {11.475, 24.3}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{337.4935539916669, 
               365.89455641724066`}, {-232.17179970414014`, \
-103.7761182544262}}],
             StatusArea[#, 
              Row[{{{2013, 4, 26}, 22.21}, " ~ ", {{2013, 6, 19}, 23.98}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 26}, 22.21}, \" ~ \", {{2013, 6, 19}, \
23.98}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "26"}], "}"}], ",", 
                   "22.21`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "19"}], "}"}], ",", 
                   "23.98`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 26}, 22.21}, " ~ ", {{2013, 6, 19}, 23.98}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{11.525, 22.95}, {12.475, 24.15}, 
                "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{367.3893460185867, 
               395.7903484441606}, {-225.03870629026716`, \
-167.97395897928305`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 20}, 23.25}, " ~ ", {{2013, 7, 8}, 23.32}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 20}, 23.25}, \" ~ \", {{2013, 7, 8}, 23.32}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "20"}], "}"}], ",", 
                   "23.25`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "8"}], "}"}], ",", 
                   "23.32`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 20}, 23.25}, " ~ ", {{2013, 7, 8}, 23.32}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{12.525, 23.1}, {13.475, 24.75}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{397.28513804550664`, 
               425.68614047108053`}, {-253.5710799457591, \
-175.10705239315627`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 9}, 23.62}, " ~ ", {{2013, 7, 25}, 24.69}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 9}, 23.62}, \" ~ \", {{2013, 7, 25}, 24.69}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "9"}], "}"}], ",", 
                   "23.62`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "25"}], "}"}], ",", 
                   "24.69`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 9}, 23.62}, " ~ ", {{2013, 7, 25}, 24.69}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], 
            "Tooltip"]& ]}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}, 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 19.8}, {13.5, 19.8}}], {}}, {{
             LineBox[{{0.5, 19.8}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 19.8}]}], 
             LineBox[{{13.5, 19.8}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {13.5, 
                19.8}]}], {{}, {}, {
               LineBox[{{4.5, 19.8}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {4.5, 19.8}]}], 
               LineBox[{{4.5, 19.8}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {4.5, 19.8}]}]}}}, {
             InsetBox["\<\"2012\"\>", Offset[{0., -2.}, {2.5, 19.8}], {0, 1}, 
              Automatic, {1, 0}], 
             InsetBox["\<\"2013\"\>", Offset[{0., -2.}, {9., 19.8}], {0, 1}, 
              Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->True],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, Automatic},
       GridLines->
        FrontEndValueCache[{{{1.5, {}}, {2.5, {}}, {4.5, {}}, {5.5, {}}, {
           7.5, {}}, {10.5, {}}, {11.5, {}}, {4.5, 
            Directive[
             Dashing[{}]]}}, 
          FindDivisions[{#, #2}, 6]& }, {{{1.5, {}}, {2.5, {}}, {4.5, {}}, {
           5.5, {}}, {7.5, {}}, {10.5, {}}, {11.5, {}}, {4.5, 
            Directive[
             Dashing[{}]]}}, {19., 20., 21., 22., 23., 24., 25.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "PointFigureChart", "\" of \"", "\"General Electric Company\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.02]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            N[
             Identity[#]], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[19.8]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{19., 
            FormBox["19.`", TraditionalForm]}, {20., 
            FormBox["20.`", TraditionalForm]}, {21., 
            FormBox["21.`", TraditionalForm]}, {22., 
            FormBox["22.`", TraditionalForm]}, {23., 
            FormBox["23.`", TraditionalForm]}, {24., 
            FormBox["24.`", TraditionalForm]}, {25., 
            FormBox["25.`", TraditionalForm]}}}]], {192., -597.9478841155233},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499622}], 
     TagBox[InsetBox["", {576., -597.9478841155233}, {Center, Center}, {360., 222.4922359499622}],
      "InsetString"]}}, {}},
  ContentSelectable->True,
  ImageSize->{740., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.583806516841095*^9, 3.5838066287564964`*^9, {3.5838066793233886`*^9, 
   3.58380671361535*^9}}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comany: Microsoft", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, {
  3.583806852738307*^9, 3.583806881441949*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"SameQ", "[", 
          RowBox[{"fChart", ",", "CandlestickChart"}], "]"}], ",", 
         RowBox[{"fChart", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", 
             RowBox[{"DatePlus", "[", 
              RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"fChart", ",", "\"\< of \>\"", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MatchQ", "[", 
                  RowBox[{
                   RowBox[{"FinancialData", "[", 
                    RowBox[{"\"\<MSFT\>\"", ",", "\"\<Name\>\""}], "]"}], ",", 
                   RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], 
                  "]"}], ",", "\"\<MSFT\>\"", ",", 
                 RowBox[{"FinancialData", "[", 
                  RowBox[{"\"\<MSFT\>\"", ",", "\"\<Name\>\""}], "]"}]}], 
                "]"}], ",", " ", "\"\< for last \>\"", ",", "365", ",", 
               "\"\< days\>\""}], " ", "}"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"fChart", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", 
             RowBox[{"DatePlus", "[", 
              RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
           RowBox[{"Switch", "[", 
            RowBox[{
            "fChart", ",", "KagiChart", ",", "0.02", ",", "RenkoChart", ",", 
             "0.1", ",", "LineBreakChart", ",", "3", ",", "PointFigureChart", 
             ",", "0.03", ",", "CandlestickChart", ",", "0.02"}], "]"}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"fChart", ",", "\"\< of \>\"", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MatchQ", "[", 
                  RowBox[{
                   RowBox[{"FinancialData", "[", 
                    RowBox[{"\"\<MSFT\>\"", ",", "\"\<Name\>\""}], "]"}], ",", 
                   RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], 
                  "]"}], ",", "\"\<MSFT\>\"", ",", 
                 RowBox[{"FinancialData", "[", 
                  RowBox[{"\"\<MSFT\>\"", ",", "\"\<Name\>\""}], "]"}]}], 
                "]"}], ",", " ", "\"\< for last \>\"", ",", "365", ",", 
               "\"\< days\>\""}], " ", "}"}], "]"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"fChart", ",", 
         RowBox[{"{", 
          RowBox[{
          "CandlestickChart", ",", "KagiChart", ",", "RenkoChart", ",", 
           "LineBreakChart", ",", "PointFigureChart"}], "}"}]}], "}"}]}], 
      "]"}], ",", "2", ",", "2", ",", "1", ",", 
     RowBox[{"{", "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"730", ",", "700"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5838061314880543`*^9, 3.583806196384766*^9}, 
   3.583806313122443*^9, {3.58380634593832*^9, 3.583806363509325*^9}, {
   3.5838064848982677`*^9, 3.5838064920106745`*^9}, {3.583806608773353*^9, 
   3.5838066183078985`*^9}, {3.5838066706608934`*^9, 
   3.5838067433320494`*^9}, {3.5838069097505684`*^9, 3.583806918280056*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        DynamicModuleBox[{System`CandlestickChartDump`$indicatorpos$203157 = 
         Clip[
          Ceiling[-0.5 + True], {1, 250}], 
         System`CandlestickChartDump`$closevalue$203157 = Dynamic[
          FEPrivate`Part[
          System`CandlestickChartDump`pp$203157, 
           System`CandlestickChartDump`$indicatorpos$203157]], 
         System`CandlestickChartDump`$timestampQ$203157 = True, 
         System`CandlestickChartDump`$textstyle$203157 = {}, 
         System`CandlestickChartDump`$timestampdepth$203157 = "Full", 
         System`CandlestickChartDump`pp$203157 = CompressedData["
1:eJxdVG9klWEUv+vLuGLSEsmyYtYfV0yq58/7nmdkqTSbkbiipsSyLTNlKVkm
ElefUhKr9CUm+jKpaNOnlombFRkTiU1Gltmn7vP+fs/7WC/XcZ9zzu+c8zt/
ms8NdJ+vKxQKa7Xfp5nad8LIwkjjRMeCkemV1nJlysjDB/4zUpx7OmjvGPHa
kR4jO8YWuybnjVSmaoYNFv/PWPHqxn5LPyv+uWnMivUA16O+4L+bVrpr2sVN
Cd5LiRz1CdQn4sMVtyaIV7WIUyHuNyvXvGLNypKHX7Ry2QdYZh6PrZS9w/YE
7y9tLqFP4K8S1LmBcRqTPB8vug4lzDvKv56WYdr30G6S8mr0D/HwbukX6mU9
swb6VYM69lriWtmdFWDJg837kPl1GvDUYcgv+1I1OW7m/8sg3mdDvjRwTmu5
kH0afRBNPjR51pwDjfhzEQc8x3yzOBeNPPNmuxi3lfb3NPo6odh3Bb7bFfrQ
pFivYl2Kc6ZYH/NaU4j3Qkmb//5EO/SJ9vX8v3oYvBz5D7+BdrcV+aG+StxX
irwo9k+xLvL1M+SvEb/I9+f0H1KS7dFd4rTEujJ9W+BTQZ5iHceiPfYw5pvV
3afAwwj1Mwr9GVfr8Woym9O3zH+/xtwdoBzWnGPmcZ/96Y/1ZPWNavKpuRe0
+82+zTN+s0acwYiftf+R5p7FONjbMA+ader1c1KKMvgHPNwjzf6T9xbO3Q/m
scz5nY1xsJ+co9fRDnyFvup8PzCXYX+Y50aD+lZ0LjH/Jp//IMOeZnmXDefJ
8N4x397wHu8f+mbIl2GfuN8feJfHoz7cw3DPgJtwL1LWnZLflPMg8BsQ+CUC
vCtCfMr3Qhz+P0u7g8I7IcxfEHdawNMS/YqOcRxxHPSXHPpy0qGPmx36upNy
1HGeHHBv0W7Ige+PDnnfoL7XcS8c+vLFgfc3tO9z5J3vZeK1xXfwTPvjxH8n
yOeJwO+7EJ917mN9nY53hnWVHO8PeatjftvIwx6X++MO0/5rzD+TW9rJSzv3
jXaTjrynxBfe5ZRzmZKXVP4Bk11ajw==
         "], System`CandlestickChartDump`$ohlclabel$203157 = Grid[{{
            Style[
            "O: ", 12, {}, FontFamily -> "Times", LineBreakWithin -> False], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$opens$203157, 
               System`CandlestickChartDump`$indicatorpos$203157]], 12, {}, 
             FontFamily -> "Times"], 
            Style[
            "H: ", 12, {}, FontFamily -> "Times", LineBreakWithin -> False], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$highs$203157, 
               System`CandlestickChartDump`$indicatorpos$203157]], 12, {}, 
             FontFamily -> "Times"], 
            Style[
            "L: ", 12, {}, FontFamily -> "Times", LineBreakWithin -> False], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$lows$203157, 
               System`CandlestickChartDump`$indicatorpos$203157]], 12, {}, 
             FontFamily -> "Times"], 
            Style[
            "C: ", 12, {}, FontFamily -> "Times", LineBreakWithin -> False], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$closes$203157, 
               System`CandlestickChartDump`$indicatorpos$203157]], 12, {}, 
             FontFamily -> "Times"], 
            Style[
             Dynamic[
              Part[
              System`CandlestickChartDump`$dates$203157, 
               System`CandlestickChartDump`$indicatorpos$203157]], 12, {}, 
             FontFamily -> "Times", LineBreakWithin -> False]}}, ItemSize -> 
          Automatic, Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
          False], System`CandlestickChartDump`$highlightstyle$203157 = 
         Directive[
          AbsolutePointSize[5], 
          GrayLevel[0]], 
         System`CandlestickChartDump`$axishighlightmin$203157 = 
         25.337956692913384`, 
         System`CandlestickChartDump`$closemarkerQ$203157 = False, 
         System`CandlestickChartDump`$timestampstyle$203157 = Directive[
          GrayLevel[0.75], 
          Opacity[0.25]], System`CandlestickChartDump`$bouncingballQ$203157 = 
         True, System`CandlestickChartDump`$tooltipstyle$203157 = {
         FrameStyle -> GrayLevel[0.7], Background -> RGBColor[1, 1, 0.7], 
          ContentPadding -> False}, System`CandlestickChartDump`$xmin$203157 =
          0.5, System`CandlestickChartDump`$xmax$203157 = 250.5, 
         System`CandlestickChartDump`$fastpos$203157 = True, 
         System`CandlestickChartDump`$mouseQ$203157 = False, 
         System`CandlestickChartDump`$tooltipvalue$203157 = Dynamic[
          FEPrivate`Part[
          System`CandlestickChartDump`$tpp$203157, 
           System`CandlestickChartDump`$indicatorpos$203157]], 
         System`CandlestickChartDump`$tpp$203157 = CompressedData["
1:eJxdVG9klWEUv+vLuGLSEsmyYtYfV0yq58/7nmdkqTSbkbiipsSyLTNlKVkm
ElefUhKr9CUm+jKpaNOnlombFRkTiU1Gltmn7vP+fs/7WC/XcZ9zzu+c8zt/
ms8NdJ+vKxQKa7Xfp5nad8LIwkjjRMeCkemV1nJlysjDB/4zUpx7OmjvGPHa
kR4jO8YWuybnjVSmaoYNFv/PWPHqxn5LPyv+uWnMivUA16O+4L+bVrpr2sVN
Cd5LiRz1CdQn4sMVtyaIV7WIUyHuNyvXvGLNypKHX7Ry2QdYZh6PrZS9w/YE
7y9tLqFP4K8S1LmBcRqTPB8vug4lzDvKv56WYdr30G6S8mr0D/HwbukX6mU9
swb6VYM69lriWtmdFWDJg837kPl1GvDUYcgv+1I1OW7m/8sg3mdDvjRwTmu5
kH0afRBNPjR51pwDjfhzEQc8x3yzOBeNPPNmuxi3lfb3NPo6odh3Bb7bFfrQ
pFivYl2Kc6ZYH/NaU4j3Qkmb//5EO/SJ9vX8v3oYvBz5D7+BdrcV+aG+StxX
irwo9k+xLvL1M+SvEb/I9+f0H1KS7dFd4rTEujJ9W+BTQZ5iHceiPfYw5pvV
3afAwwj1Mwr9GVfr8Woym9O3zH+/xtwdoBzWnGPmcZ/96Y/1ZPWNavKpuRe0
+82+zTN+s0acwYiftf+R5p7FONjbMA+ader1c1KKMvgHPNwjzf6T9xbO3Q/m
scz5nY1xsJ+co9fRDnyFvup8PzCXYX+Y50aD+lZ0LjH/Jp//IMOeZnmXDefJ
8N4x397wHu8f+mbIl2GfuN8feJfHoz7cw3DPgJtwL1LWnZLflPMg8BsQ+CUC
vCtCfMr3Qhz+P0u7g8I7IcxfEHdawNMS/YqOcRxxHPSXHPpy0qGPmx36upNy
1HGeHHBv0W7Ige+PDnnfoL7XcS8c+vLFgfc3tO9z5J3vZeK1xXfwTPvjxH8n
yOeJwO+7EJ917mN9nY53hnWVHO8PeatjftvIwx6X++MO0/5rzD+TW9rJSzv3
jXaTjrynxBfe5ZRzmZKXVP4Bk11ajw==
         "], System`CandlestickChartDump`$opens$203157 = CompressedData["
1:eJxFVAs4ltkWlmpqMDITlZBbTQ0J5ZK99/d5v7+LpptbhSnKJZHkMiHX81fj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         "], System`CandlestickChartDump`$highs$203157 = CompressedData["
1:eJxdVAs4VekaFpVph2ooHRkpIk4Thspe/1rLuzhdjNu4hkxNnVwel0qNcRQS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         "], System`CandlestickChartDump`$lows$203157 = CompressedData["
1:eJxFVAk4llkblphkLaFGQ6iRpVANcc77ft/9MaoJY7ls1VjKhCzDRJn0d4XJ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         "], System`CandlestickChartDump`$closes$203157 = CompressedData["
1:eJxdVG9klWEUv+vLuGLSEsmyYtYfV0yq58/7nmdkqTSbkbiipsSyLTNlKVkm
ElefUhKr9CUm+jKpaNOnlombFRkTiU1Gltmn7vP+fs/7WC/XcZ9zzu+c8zt/
ms8NdJ+vKxQKa7Xfp5nad8LIwkjjRMeCkemV1nJlysjDB/4zUpx7OmjvGPHa
kR4jO8YWuybnjVSmaoYNFv/PWPHqxn5LPyv+uWnMivUA16O+4L+bVrpr2sVN
Cd5LiRz1CdQn4sMVtyaIV7WIUyHuNyvXvGLNypKHX7Ry2QdYZh6PrZS9w/YE
7y9tLqFP4K8S1LmBcRqTPB8vug4lzDvKv56WYdr30G6S8mr0D/HwbukX6mU9
swb6VYM69lriWtmdFWDJg837kPl1GvDUYcgv+1I1OW7m/8sg3mdDvjRwTmu5
kH0afRBNPjR51pwDjfhzEQc8x3yzOBeNPPNmuxi3lfb3NPo6odh3Bb7bFfrQ
pFivYl2Kc6ZYH/NaU4j3Qkmb//5EO/SJ9vX8v3oYvBz5D7+BdrcV+aG+StxX
irwo9k+xLvL1M+SvEb/I9+f0H1KS7dFd4rTEujJ9W+BTQZ5iHceiPfYw5pvV
3afAwwj1Mwr9GVfr8Woym9O3zH+/xtwdoBzWnGPmcZ/96Y/1ZPWNavKpuRe0
+82+zTN+s0acwYiftf+R5p7FONjbMA+ader1c1KKMvgHPNwjzf6T9xbO3Q/m
scz5nY1xsJ+co9fRDnyFvup8PzCXYX+Y50aD+lZ0LjH/Jp//IMOeZnmXDefJ
8N4x397wHu8f+mbIl2GfuN8feJfHoz7cw3DPgJtwL1LWnZLflPMg8BsQ+CUC
vCtCfMr3Qhz+P0u7g8I7IcxfEHdawNMS/YqOcRxxHPSXHPpy0qGPmx36upNy
1HGeHHBv0W7Ige+PDnnfoL7XcS8c+vLFgfc3tO9z5J3vZeK1xXfwTPvjxH8n
yOeJwO+7EJ917mN9nY53hnWVHO8PeatjftvIwx6X++MO0/5rzD+TW9rJSzv3
jXaTjrynxBfe5ZRzmZKXVP4Bk11ajw==
         "], System`CandlestickChartDump`$dates$203157 = {
         "Thu. Jul 26, 2012", "Fri. Jul 27, 2012", "Mon. Jul 30, 2012", 
          "Tue. Jul 31, 2012", "Wed. Aug 01, 2012", "Thu. Aug 02, 2012", 
          "Fri. Aug 03, 2012", "Mon. Aug 06, 2012", "Tue. Aug 07, 2012", 
          "Wed. Aug 08, 2012", "Thu. Aug 09, 2012", "Fri. Aug 10, 2012", 
          "Mon. Aug 13, 2012", "Tue. Aug 14, 2012", "Wed. Aug 15, 2012", 
          "Thu. Aug 16, 2012", "Fri. Aug 17, 2012", "Mon. Aug 20, 2012", 
          "Tue. Aug 21, 2012", "Wed. Aug 22, 2012", "Thu. Aug 23, 2012", 
          "Fri. Aug 24, 2012", "Mon. Aug 27, 2012", "Tue. Aug 28, 2012", 
          "Wed. Aug 29, 2012", "Thu. Aug 30, 2012", "Fri. Aug 31, 2012", 
          "Tue. Sep 04, 2012", "Wed. Sep 05, 2012", "Thu. Sep 06, 2012", 
          "Fri. Sep 07, 2012", "Mon. Sep 10, 2012", "Tue. Sep 11, 2012", 
          "Wed. Sep 12, 2012", "Thu. Sep 13, 2012", "Fri. Sep 14, 2012", 
          "Mon. Sep 17, 2012", "Tue. Sep 18, 2012", "Wed. Sep 19, 2012", 
          "Thu. Sep 20, 2012", "Fri. Sep 21, 2012", "Mon. Sep 24, 2012", 
          "Tue. Sep 25, 2012", "Wed. Sep 26, 2012", "Thu. Sep 27, 2012", 
          "Fri. Sep 28, 2012", "Mon. Oct 01, 2012", "Tue. Oct 02, 2012", 
          "Wed. Oct 03, 2012", "Thu. Oct 04, 2012", "Fri. Oct 05, 2012", 
          "Mon. Oct 08, 2012", "Tue. Oct 09, 2012", "Wed. Oct 10, 2012", 
          "Thu. Oct 11, 2012", "Fri. Oct 12, 2012", "Mon. Oct 15, 2012", 
          "Tue. Oct 16, 2012", "Wed. Oct 17, 2012", "Thu. Oct 18, 2012", 
          "Fri. Oct 19, 2012", "Mon. Oct 22, 2012", "Tue. Oct 23, 2012", 
          "Wed. Oct 24, 2012", "Thu. Oct 25, 2012", "Fri. Oct 26, 2012", 
          "Wed. Oct 31, 2012", "Thu. Nov 01, 2012", "Fri. Nov 02, 2012", 
          "Mon. Nov 05, 2012", "Tue. Nov 06, 2012", "Wed. Nov 07, 2012", 
          "Thu. Nov 08, 2012", "Fri. Nov 09, 2012", "Mon. Nov 12, 2012", 
          "Tue. Nov 13, 2012", "Wed. Nov 14, 2012", "Thu. Nov 15, 2012", 
          "Fri. Nov 16, 2012", "Mon. Nov 19, 2012", "Tue. Nov 20, 2012", 
          "Wed. Nov 21, 2012", "Fri. Nov 23, 2012", "Mon. Nov 26, 2012", 
          "Tue. Nov 27, 2012", "Wed. Nov 28, 2012", "Thu. Nov 29, 2012", 
          "Fri. Nov 30, 2012", "Mon. Dec 03, 2012", "Tue. Dec 04, 2012", 
          "Wed. Dec 05, 2012", "Thu. Dec 06, 2012", "Fri. Dec 07, 2012", 
          "Mon. Dec 10, 2012", "Tue. Dec 11, 2012", "Wed. Dec 12, 2012", 
          "Thu. Dec 13, 2012", "Fri. Dec 14, 2012", "Mon. Dec 17, 2012", 
          "Tue. Dec 18, 2012", "Wed. Dec 19, 2012", "Thu. Dec 20, 2012", 
          "Fri. Dec 21, 2012", "Mon. Dec 24, 2012", "Wed. Dec 26, 2012", 
          "Thu. Dec 27, 2012", "Fri. Dec 28, 2012", "Mon. Dec 31, 2012", 
          "Wed. Jan 02, 2013", "Thu. Jan 03, 2013", "Fri. Jan 04, 2013", 
          "Mon. Jan 07, 2013", "Tue. Jan 08, 2013", "Wed. Jan 09, 2013", 
          "Thu. Jan 10, 2013", "Fri. Jan 11, 2013", "Mon. Jan 14, 2013", 
          "Tue. Jan 15, 2013", "Wed. Jan 16, 2013", "Thu. Jan 17, 2013", 
          "Fri. Jan 18, 2013", "Tue. Jan 22, 2013", "Wed. Jan 23, 2013", 
          "Thu. Jan 24, 2013", "Fri. Jan 25, 2013", "Mon. Jan 28, 2013", 
          "Tue. Jan 29, 2013", "Wed. Jan 30, 2013", "Thu. Jan 31, 2013", 
          "Fri. Feb 01, 2013", "Mon. Feb 04, 2013", "Tue. Feb 05, 2013", 
          "Wed. Feb 06, 2013", "Thu. Feb 07, 2013", "Fri. Feb 08, 2013", 
          "Mon. Feb 11, 2013", "Tue. Feb 12, 2013", "Wed. Feb 13, 2013", 
          "Thu. Feb 14, 2013", "Fri. Feb 15, 2013", "Tue. Feb 19, 2013", 
          "Wed. Feb 20, 2013", "Thu. Feb 21, 2013", "Fri. Feb 22, 2013", 
          "Mon. Feb 25, 2013", "Tue. Feb 26, 2013", "Wed. Feb 27, 2013", 
          "Thu. Feb 28, 2013", "Fri. Mar 01, 2013", "Mon. Mar 04, 2013", 
          "Tue. Mar 05, 2013", "Wed. Mar 06, 2013", "Thu. Mar 07, 2013", 
          "Fri. Mar 08, 2013", "Mon. Mar 11, 2013", "Tue. Mar 12, 2013", 
          "Wed. Mar 13, 2013", "Thu. Mar 14, 2013", "Fri. Mar 15, 2013", 
          "Mon. Mar 18, 2013", "Tue. Mar 19, 2013", "Wed. Mar 20, 2013", 
          "Thu. Mar 21, 2013", "Fri. Mar 22, 2013", "Mon. Mar 25, 2013", 
          "Tue. Mar 26, 2013", "Wed. Mar 27, 2013", "Thu. Mar 28, 2013", 
          "Mon. Apr 01, 2013", "Tue. Apr 02, 2013", "Wed. Apr 03, 2013", 
          "Thu. Apr 04, 2013", "Fri. Apr 05, 2013", "Mon. Apr 08, 2013", 
          "Tue. Apr 09, 2013", "Wed. Apr 10, 2013", "Thu. Apr 11, 2013", 
          "Fri. Apr 12, 2013", "Mon. Apr 15, 2013", "Tue. Apr 16, 2013", 
          "Wed. Apr 17, 2013", "Thu. Apr 18, 2013", "Fri. Apr 19, 2013", 
          "Mon. Apr 22, 2013", "Tue. Apr 23, 2013", "Wed. Apr 24, 2013", 
          "Thu. Apr 25, 2013", "Fri. Apr 26, 2013", "Mon. Apr 29, 2013", 
          "Tue. Apr 30, 2013", "Wed. May 01, 2013", "Thu. May 02, 2013", 
          "Fri. May 03, 2013", "Mon. May 06, 2013", "Tue. May 07, 2013", 
          "Wed. May 08, 2013", "Thu. May 09, 2013", "Fri. May 10, 2013", 
          "Mon. May 13, 2013", "Tue. May 14, 2013", "Wed. May 15, 2013", 
          "Thu. May 16, 2013", "Fri. May 17, 2013", "Mon. May 20, 2013", 
          "Tue. May 21, 2013", "Wed. May 22, 2013", "Thu. May 23, 2013", 
          "Fri. May 24, 2013", "Tue. May 28, 2013", "Wed. May 29, 2013", 
          "Thu. May 30, 2013", "Fri. May 31, 2013", "Mon. Jun 03, 2013", 
          "Tue. Jun 04, 2013", "Wed. Jun 05, 2013", "Thu. Jun 06, 2013", 
          "Fri. Jun 07, 2013", "Mon. Jun 10, 2013", "Tue. Jun 11, 2013", 
          "Wed. Jun 12, 2013", "Thu. Jun 13, 2013", "Fri. Jun 14, 2013", 
          "Mon. Jun 17, 2013", "Tue. Jun 18, 2013", "Wed. Jun 19, 2013", 
          "Thu. Jun 20, 2013", "Fri. Jun 21, 2013", "Mon. Jun 24, 2013", 
          "Tue. Jun 25, 2013", "Wed. Jun 26, 2013", "Thu. Jun 27, 2013", 
          "Fri. Jun 28, 2013", "Mon. Jul 01, 2013", "Tue. Jul 02, 2013", 
          "Wed. Jul 03, 2013", "Fri. Jul 05, 2013", "Mon. Jul 08, 2013", 
          "Tue. Jul 09, 2013", "Wed. Jul 10, 2013", "Thu. Jul 11, 2013", 
          "Fri. Jul 12, 2013", "Mon. Jul 15, 2013", "Tue. Jul 16, 2013", 
          "Wed. Jul 17, 2013", "Thu. Jul 18, 2013", "Fri. Jul 19, 2013", 
          "Mon. Jul 22, 2013", "Tue. Jul 23, 2013", "Wed. Jul 24, 2013", 
          "Thu. Jul 25, 2013"}, System`CandlestickChartDump`$OHLCQ$203157 = 
         False}, {
          
          DynamicBox[Typeset`ToBoxes[
           System`CandlestickChartDump`$fastpos$203157 = First[
               MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
            System`CandlestickChartDump`$indicatorpos$203157 = 
             If[System`CandlestickChartDump`$fastpos$203157 =!= False, 
               Clip[
                Ceiling[System`CandlestickChartDump`$fastpos$203157 - 0.5], {
                 Ceiling[System`CandlestickChartDump`$xmin$203157], 
                 Floor[System`CandlestickChartDump`$xmax$203157]}], 
               System`CandlestickChartDump`$indicatorpos$203157]; 
            System`CandlestickChartDump`$mouseQ$203157 = Not[
               TrueQ[System`CandlestickChartDump`$fastpos$203157]]; 
            System`CandlestickChartDump`$ohlclabel$203157 = Grid[{{
                 Style[
                 "O: ", 12, System`CandlestickChartDump`$textstyle$203157, 
                  FontFamily -> "Times", LineBreakWithin -> False], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$opens$203157, 
                    System`CandlestickChartDump`$indicatorpos$203157]], 12, 
                  System`CandlestickChartDump`$textstyle$203157, FontFamily -> 
                  "Times"], 
                 Style[
                 "H: ", 12, System`CandlestickChartDump`$textstyle$203157, 
                  FontFamily -> "Times", LineBreakWithin -> False], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$highs$203157, 
                    System`CandlestickChartDump`$indicatorpos$203157]], 12, 
                  System`CandlestickChartDump`$textstyle$203157, FontFamily -> 
                  "Times"], 
                 Style[
                 "L: ", 12, System`CandlestickChartDump`$textstyle$203157, 
                  FontFamily -> "Times", LineBreakWithin -> False], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$lows$203157, 
                    System`CandlestickChartDump`$indicatorpos$203157]], 12, 
                  System`CandlestickChartDump`$textstyle$203157, FontFamily -> 
                  "Times"], 
                 Style[
                 "C: ", 12, System`CandlestickChartDump`$textstyle$203157, 
                  FontFamily -> "Times", LineBreakWithin -> False], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$closes$203157, 
                    System`CandlestickChartDump`$indicatorpos$203157]], 12, 
                  System`CandlestickChartDump`$textstyle$203157, FontFamily -> 
                  "Times"], 
                 Style[
                  Dynamic[
                   Part[
                   System`CandlestickChartDump`$dates$203157, 
                    System`CandlestickChartDump`$indicatorpos$203157]], 12, 
                  System`CandlestickChartDump`$textstyle$203157, FontFamily -> 
                  "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic,
                Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
               False]; If[System`CandlestickChartDump`$mouseQ$203157, 
              If[
              System`CandlestickChartDump`$timestampQ$203157, {
               System`CandlestickChartDump`$timestampstyle$203157, 
                Dynamic[
                 Deploy[
                  
                  Rectangle[{
                   System`CandlestickChartDump`$indicatorpos$203157 - 0.5, 
                    System`CandlestickChartDump`$axishighlightmin$203157}, 
                   If[
                   System`CandlestickChartDump`$timestampdepth$203157 === 
                    "Full", 
                    
                    Scaled[{0, 1}, {
                    System`CandlestickChartDump`$indicatorpos$203157 + 0.5, 
                    System`CandlestickChartDump`$axishighlightmin$203157}], 
                    Offset[{
                    0, System`CandlestickChartDump`$timestampdepth$203157}, {
                    System`CandlestickChartDump`$indicatorpos$203157 + 0.5, 
                    System`CandlestickChartDump`$axishighlightmin$203157}]]]]]\
}, {}], 
              If[System`CandlestickChartDump`$timestampQ$203157, {
                Opacity[0], 
                
                Rectangle[{
                 System`CandlestickChartDump`$xmin$203157, 
                  System`CandlestickChartDump`$axishighlightmin$203157}, 
                 If[
                 System`CandlestickChartDump`$timestampdepth$203157 === 
                  "Full", 
                  
                  Scaled[{0, 1}, {
                   System`CandlestickChartDump`$xmin$203157 + 1, 
                    System`CandlestickChartDump`$axishighlightmin$203157}], 
                  
                  Offset[{
                   0, System`CandlestickChartDump`$timestampdepth$203157}, {
                   System`CandlestickChartDump`$xmin$203157 + 1, 
                    System`CandlestickChartDump`$axishighlightmin$203157}]]]},\
 {}]], StandardForm, Graphics],
           
           ImageSizeCache->{{37.78823892179496, 
            39.31862655880769}, {-255.37499999999994`, -18.91710609087295}}], \
{{}, 
           StyleBox[{
             {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1], 
              LineBox[CompressedData["
1:eJxlmgtcj+f7xyNbDokp/ORUIcmhckrnO2EhOipppcO3vt/6VsKIsIVpDtGo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               "]]}, 
             {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1], 
              LineBox[CompressedData["
1:eJyNmglYjmnUx5ssY5K1sku2bElp0d4tkvZdi9KmRW8LsnwYvJiECUOILGPN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               "]]}},
            Antialiasing->True], {}, {}}, {}, {}, 
          DynamicBox[Typeset`ToBoxes[
            If[System`CandlestickChartDump`$mouseQ$203157, {
              Dynamic[
               If[
               System`CandlestickChartDump`$bouncingballQ$203157, {
                System`CandlestickChartDump`$highlightstyle$203157, 
                 Deploy[
                  Point[{
                    Dynamic[System`CandlestickChartDump`$indicatorpos$203157],
                     System`CandlestickChartDump`$tooltipvalue$203157 = 
                    Dynamic[
                    FEPrivate`Part[
                    System`CandlestickChartDump`$tpp$203157, 
                    System`CandlestickChartDump`$indicatorpos$203157]]; 
                    System`CandlestickChartDump`$closevalue$203157 = Dynamic[
                    FEPrivate`Part[
                    System`CandlestickChartDump`pp$203157, 
                    System`CandlestickChartDump`$indicatorpos$203157]]}]]}, 
                System`CandlestickChartDump`$tooltipvalue$203157 = Dynamic[
                   FEPrivate`Part[
                   System`CandlestickChartDump`$tpp$203157, 
                    System`CandlestickChartDump`$indicatorpos$203157]]; 
                System`CandlestickChartDump`$closevalue$203157 = Dynamic[
                   FEPrivate`Part[
                   System`CandlestickChartDump`pp$203157, 
                    System`CandlestickChartDump`$indicatorpos$203157]]; {}]], 
              Dynamic[
               If[System`CandlestickChartDump`$closemarkerQ$203157, {
                 Inset[
                  Framed[
                   Style[
                   System`CandlestickChartDump`$tooltipvalue$203157, 10, 
                    FontFamily -> "Helvetica"], 
                   System`CandlestickChartDump`$tooltipstyle$203157], 
                  Offset[{
                    Dynamic[
                    FEPrivate`If[
                    FEPrivate`Greater[
                    System`CandlestickChartDump`$indicatorpos$203157 + 
                    0.5, (System`CandlestickChartDump`$xmax$203157 + 
                    System`CandlestickChartDump`$xmin$203157)/2], -5, 
                    5]], -5}, {
                   System`CandlestickChartDump`$indicatorpos$203157, 
                    System`CandlestickChartDump`$closevalue$203157}], {
                   Dynamic[
                    FEPrivate`If[
                    FEPrivate`Greater[
                    System`CandlestickChartDump`$indicatorpos$203157, (
                    System`CandlestickChartDump`$xmax$203157 + 
                    System`CandlestickChartDump`$xmin$203157)/2], 1, -1]], 
                   1}]}, {}]]}, {}], StandardForm, Graphics],
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}},
           TrackedSymbols:>{System`CandlestickChartDump`$mouseQ$203157}], {}},
         DynamicModuleValues:>{}], 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 25.337956692913384`}, {250.5, 
             25.337956692913384`}}], {}}, {{
             LineBox[{{0.5, 25.337956692913384`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 
                25.337956692913384`}]}], 
             LineBox[{{250.5, 25.337956692913384`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {250.5, 
                25.337956692913384`}]}], {{}, {}, {
               LineBox[{{108.5, 25.337956692913384`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {108.5, 
                  25.337956692913384`}]}], 
               LineBox[{{108.5, 25.337956692913384`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {108.5, 
                  25.337956692913384`}]}]}}}, {
             InsetBox["\<\"`12\"\>", 
              Offset[{0., -2.}, {54.5, 25.337956692913384`}], {0, 1}, 
              Automatic, {1, 0}], 
             InsetBox["\<\"`13\"\>", 
              Offset[{0., -2.}, {179.5, 25.337956692913384`}], {0, 1}, 
              Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->False],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, Automatic},
       Frame->{{False, False}, {False, False}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->
        FrontEndValueCache[{{{4.5, {}}, {27.5, {}}, {46.5, {}}, {67.5, {}}, {
           88.5, {}}, {108.5, {}}, {129.5, {}}, {148.5, {}}, {168.5, {}}, {
           190.5, {}}, {212.5, {}}, {232.5, {}}, {108.5, 
            Directive[
             Opacity[0.4], 
             Dashing[{}]]}}, 
          FindDivisions[{25.337956692913384`, #2}, 6]& }, {{{4.5, {}}, {
           27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
           129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
           232.5, {}}, {108.5, 
            Directive[
             Opacity[0.4], 
             Dashing[{}]]}}, {24., 26., 28., 30., 32., 34., 36., 38.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "CandlestickChart", "\" of \"", "\"Microsoft Corporation\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.02]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            Identity[#], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[25.337956692913384`]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{24., 
            FormBox["24.`", TraditionalForm]}, {26., 
            FormBox["26.`", TraditionalForm]}, {28., 
            FormBox["28.`", TraditionalForm]}, {30., 
            FormBox["30.`", TraditionalForm]}, {32., 
            FormBox["32.`", TraditionalForm]}, {34., 
            FormBox["34.`", TraditionalForm]}, {36., 
            FormBox["36.`", TraditionalForm]}, {38., 
            FormBox["38.`", TraditionalForm]}}}]], {192., -119.58957682310464`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{0.5, 29.16}, {0.5, 30.9}}]},
              
              ImageSizeCache->{{36.58578643762691, 
               39.4142135623731}, {-123.4142135623731, -84.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 8, 22}, 30.54}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 29.16}, \" ~ \", {{2012, 8, 22}, \
30.54}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "29.16`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "22"}], "}"}], ",", 
                   "30.54`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 8, 22}, 30.54}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{0.5, 30.9}, {1.5, 30.9}}]},
              
              ImageSizeCache->{{36.58578643762691, 
               50.4142135623731}, {-122.41421356237309`, \
-119.58578643762691`}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 8, 22}, 30.54}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 29.16}, \" ~ \", {{2012, 8, 22}, \
30.54}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "29.16`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "22"}], "}"}], ",", 
                   "30.54`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 8, 22}, 30.54}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{1.5, 30.26}, {1.5, 30.9}}]},
              
              ImageSizeCache->{{46.58578643762691, 
               49.4142135623731}, {-123.4142135623731, -106.58578643762691`}}],
             StatusArea[#, 
              Row[{{{2012, 8, 23}, 30.26}, " ~ ", {{2012, 9, 5}, 30.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 23}, 30.26}, \" ~ \", {{2012, 9, 5}, 30.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "23"}], "}"}], ",", 
                   "30.26`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "5"}], "}"}], ",", 
                   "30.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 23}, 30.26}, " ~ ", {{2012, 9, 5}, 30.39}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{1.5, 30.26}, {2.5, 30.26}}]},
              
              ImageSizeCache->{{46.58578643762691, 
               60.4142135623731}, {-109.41421356237309`, \
-106.58578643762691`}}],
             StatusArea[#, 
              Row[{{{2012, 8, 23}, 30.26}, " ~ ", {{2012, 9, 5}, 30.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 23}, 30.26}, \" ~ \", {{2012, 9, 5}, 30.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "23"}], "}"}], ",", 
                   "30.26`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "5"}], "}"}], ",", 
                   "30.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 23}, 30.26}, " ~ ", {{2012, 9, 5}, 30.39}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{2.5, 30.26}, {2.5, 31.35}}]},
              
              ImageSizeCache->{{56.58578643762689, 
               59.414213562373114`}, {-132.4142135623731, \
-106.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 6}, 31.35}, " ~ ", {{2012, 9, 7}, 30.95}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 6}, 31.35}, \" ~ \", {{2012, 9, 7}, 30.95}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "6"}], "}"}], ",", 
                   "31.35`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "7"}], "}"}], ",", 
                   "30.95`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 6}, 31.35}, " ~ ", {{2012, 9, 7}, 30.95}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{2.5, 31.35}, {3.5, 31.35}}]},
              
              ImageSizeCache->{{56.58578643762689, 
               70.4142135623731}, {-132.41421356237308`, -129.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 6}, 31.35}, " ~ ", {{2012, 9, 7}, 30.95}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 6}, 31.35}, \" ~ \", {{2012, 9, 7}, 30.95}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "6"}], "}"}], ",", 
                   "31.35`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "7"}], "}"}], ",", 
                   "30.95`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 6}, 31.35}, " ~ ", {{2012, 9, 7}, 30.95}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{3.5, 30.72}, {3.5, 31.35}}]},
              
              ImageSizeCache->{{66.5857864376269, 
               69.4142135623731}, {-132.4142135623731, -116.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 10}, 30.72}, " ~ ", {{2012, 9, 19}, 31.05}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 10}, 30.72}, \" ~ \", {{2012, 9, 19}, \
31.05}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "10"}], "}"}], ",", 
                   "30.72`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "19"}], "}"}], ",", 
                   "31.05`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 10}, 30.72}, " ~ ", {{2012, 9, 19}, 31.05}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{3.5, 30.72}, {4.5, 30.72}}]},
              
              ImageSizeCache->{{66.58578643762691, 
               80.41421356237309}, {-119.41421356237309`, \
-116.58578643762691`}}],
             StatusArea[#, 
              Row[{{{2012, 9, 10}, 30.72}, " ~ ", {{2012, 9, 19}, 31.05}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 10}, 30.72}, \" ~ \", {{2012, 9, 19}, \
31.05}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "10"}], "}"}], ",", 
                   "30.72`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "19"}], "}"}], ",", 
                   "31.05`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 10}, 30.72}, " ~ ", {{2012, 9, 19}, 31.05}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{4.5, 30.72}, {4.5, 31.45}}]},
              
              ImageSizeCache->{{76.5857864376269, 
               79.4142135623731}, {-134.4142135623731, -116.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 20}, 31.45}, " ~ ", {{2012, 9, 21}, 31.19}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 20}, 31.45}, \" ~ \", {{2012, 9, 21}, \
31.19}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "20"}], "}"}], ",", 
                   "31.45`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "21"}], "}"}], ",", 
                   "31.19`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 20}, 31.45}, " ~ ", {{2012, 9, 21}, 31.19}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{4.5, 31.45}, {5.5, 31.45}}]},
              
              ImageSizeCache->{{76.5857864376269, 
               90.4142135623731}, {-134.41421356237308`, -131.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 20}, 31.45}, " ~ ", {{2012, 9, 21}, 31.19}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 20}, 31.45}, \" ~ \", {{2012, 9, 21}, \
31.19}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "20"}], "}"}], ",", 
                   "31.45`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "21"}], "}"}], ",", 
                   "31.19`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 20}, 31.45}, " ~ ", {{2012, 9, 21}, 31.19}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{5.5, 30.72}, {5.5, 31.45}}]},
              
              ImageSizeCache->{{86.5857864376269, 
               89.4142135623731}, {-134.4142135623731, -116.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 9, 24}, 30.78}, " ~ ", {{2012, 9, 25}, 30.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 24}, 30.78}, \" ~ \", {{2012, 9, 25}, \
30.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "24"}], "}"}], ",", 
                   "30.78`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "25"}], "}"}], ",", 
                   "30.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 24}, 30.78}, " ~ ", {{2012, 9, 25}, 30.39}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{5.5, 28.95}, {5.5, 30.72}}]},
              
              ImageSizeCache->{{86.58578643762691, 
               89.41421356237309}, {-119.4142135623731, -79.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 9, 24}, 30.78}, " ~ ", {{2012, 10, 16}, 29.49}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 24}, 30.78}, \" ~ \", {{2012, 10, 16}, \
29.49}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "24"}], "}"}], ",", 
                   "30.78`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "16"}], "}"}], ",", 
                   "29.49`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 24}, 30.78}, " ~ ", {{2012, 10, 16}, 29.49}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{5.5, 28.95}, {6.5, 28.95}}]},
              
              ImageSizeCache->{{86.58578643762691, 
               100.41421356237309`}, {-82.41421356237309, \
-79.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 9, 24}, 30.78}, " ~ ", {{2012, 10, 16}, 29.49}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 24}, 30.78}, \" ~ \", {{2012, 10, 16}, \
29.49}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "24"}], "}"}], ",", 
                   "30.78`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "16"}], "}"}], ",", 
                   "29.49`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 24}, 30.78}, " ~ ", {{2012, 10, 16}, 29.49}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{6.5, 28.95}, {6.5, 29.59}}]},
              
              ImageSizeCache->{{96.58578643762691, 
               99.41421356237309}, {-96.4142135623731, -79.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 10, 17}, 29.59}, " ~ ", {{2012, 10, 18}, 29.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 17}, 29.59}, \" ~ \", {{2012, 10, 18}, \
29.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "17"}], "}"}], ",", 
                   "29.59`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "18"}], "}"}], ",", 
                   "29.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 17}, 29.59}, " ~ ", {{2012, 10, 18}, 29.5}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{6.5, 29.59}, {7.5, 29.59}}]},
              
              ImageSizeCache->{{96.58578643762691, 
               110.41421356237309`}, {-95.41421356237309, \
-92.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 10, 17}, 29.59}, " ~ ", {{2012, 10, 18}, 29.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 17}, 29.59}, \" ~ \", {{2012, 10, 18}, \
29.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "17"}], "}"}], ",", 
                   "29.59`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "18"}], "}"}], ",", 
                   "29.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 17}, 29.59}, " ~ ", {{2012, 10, 18}, 29.5}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{7.5, 27.88}, {7.5, 29.59}}]},
              
              ImageSizeCache->{{106.58578643762691`, 
               109.41421356237309`}, {-96.4142135623731, -57.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 10, 19}, 28.64}, " ~ ", {{2012, 10, 26}, 28.21}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 19}, 28.64}, \" ~ \", {{2012, 10, 26}, \
28.21}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "19"}], "}"}], ",", 
                   "28.64`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "26"}], "}"}], ",", 
                   "28.21`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 19}, 28.64}, " ~ ", {{2012, 10, 26}, 28.21}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{7.5, 27.88}, {8.5, 27.88}}]},
              
              ImageSizeCache->{{106.58578643762691`, 
               120.41421356237309`}, {-60.4142135623731, -57.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 10, 19}, 28.64}, " ~ ", {{2012, 10, 26}, 28.21}}]]& ,
             TagBoxNote->
              "Row[{{{2012, 10, 19}, 28.64}, \" ~ \", {{2012, 10, 26}, \
28.21}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "19"}], "}"}], ",", 
                   "28.64`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "26"}], "}"}], ",", 
                   "28.21`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 19}, 28.64}, " ~ ", {{2012, 10, 26}, 28.21}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{8.5, 27.88}, {8.5, 29.59}}]},
              
              ImageSizeCache->{{116.58578643762691`, 
               119.41421356237309`}, {-96.4142135623731, -57.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 10, 31}, 28.54}, " ~ ", {{2012, 11, 5}, 29.63}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 31}, 28.54}, \" ~ \", {{2012, 11, 5}, \
29.63}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "31"}], "}"}], ",", 
                   "28.54`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "5"}], "}"}], ",", 
                   "29.63`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 31}, 28.54}, " ~ ", {{2012, 11, 5}, 29.63}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{8.5, 29.59}, {8.5, 29.86}}]},
              
              ImageSizeCache->{{116.58578643762691`, 
               119.41421356237309`}, {-101.41421356237309`, \
-92.58578643762691}}],
             StatusArea[#, 
              Row[{{{2012, 10, 31}, 28.54}, " ~ ", {{2012, 11, 6}, 29.86}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 31}, 28.54}, \" ~ \", {{2012, 11, 6}, \
29.86}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "31"}], "}"}], ",", 
                   "28.54`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "6"}], "}"}], ",", 
                   "29.86`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 31}, 28.54}, " ~ ", {{2012, 11, 6}, 29.86}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{8.5, 29.86}, {9.5, 29.86}}]},
              
              ImageSizeCache->{{116.5857864376269, 
               130.4142135623731}, {-101.4142135623731, -98.5857864376269}}],
             StatusArea[#, 
              Row[{{{2012, 10, 31}, 28.54}, " ~ ", {{2012, 11, 6}, 29.86}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 31}, 28.54}, \" ~ \", {{2012, 11, 6}, \
29.86}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "31"}], "}"}], ",", 
                   "28.54`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "6"}], "}"}], ",", 
                   "29.86`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 31}, 28.54}, " ~ ", {{2012, 11, 6}, 29.86}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{9.5, 27.88}, {9.5, 29.86}}]},
              
              ImageSizeCache->{{126.5857864376269, 
               129.4142135623731}, {-101.41421356237312`, \
-57.58578643762689}}],
             StatusArea[#, 
              Row[{{{2012, 11, 7}, 29.08}, " ~ ", {{2012, 11, 13}, 27.09}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 7}, 29.08}, \" ~ \", {{2012, 11, 13}, \
27.09}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "7"}], "}"}], ",", 
                   "29.08`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "13"}], "}"}], ",", 
                   "27.09`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 7}, 29.08}, " ~ ", {{2012, 11, 13}, 27.09}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{9.5, 26.52}, {9.5, 27.88}}]},
              
              ImageSizeCache->{{126.5857864376269, 
               129.4142135623731}, {-61.41421356237311, \
-30.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 7}, 29.08}, " ~ ", {{2012, 11, 21}, 26.95}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 7}, 29.08}, \" ~ \", {{2012, 11, 21}, \
26.95}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "7"}], "}"}], ",", 
                   "29.08`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "21"}], "}"}], ",", 
                   "26.95`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 7}, 29.08}, " ~ ", {{2012, 11, 21}, 26.95}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{9.5, 26.52}, {10.5, 26.52}}]},
              
              ImageSizeCache->{{126.5857864376269, 
               140.4142135623731}, {-33.41421356237311, \
-30.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 7}, 29.08}, " ~ ", {{2012, 11, 21}, 26.95}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 7}, 29.08}, \" ~ \", {{2012, 11, 21}, \
26.95}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "7"}], "}"}], ",", 
                   "29.08`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "21"}], "}"}], ",", 
                   "26.95`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 7}, 29.08}, " ~ ", {{2012, 11, 21}, 26.95}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{10.5, 26.52}, {10.5, 27.7}}]},
              
              ImageSizeCache->{{136.5857864376269, 
               139.41421356237308`}, {-58.41421356237311, \
-30.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 23}, 27.7}, " ~ ", {{2012, 11, 26}, 27.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 23}, 27.7}, \" ~ \", {{2012, 11, 26}, \
27.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "23"}], "}"}], ",", 
                   "27.7`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "26"}], "}"}], ",", 
                   "27.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 23}, 27.7}, " ~ ", {{2012, 11, 26}, 27.39}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{10.5, 27.7}, {11.5, 27.7}}]},
              
              ImageSizeCache->{{136.5857864376269, 
               150.41421356237308`}, {-57.414213562373114`, \
-54.58578643762689}}],
             StatusArea[#, 
              Row[{{{2012, 11, 23}, 27.7}, " ~ ", {{2012, 11, 26}, 27.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 23}, 27.7}, \" ~ \", {{2012, 11, 26}, \
27.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "23"}], "}"}], ",", 
                   "27.7`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "26"}], "}"}], ",", 
                   "27.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 23}, 27.7}, " ~ ", {{2012, 11, 26}, 27.39}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{11.5, 26.37}, {11.5, 27.7}}]},
              ImageSizeCache->{{147.5857864376269, 
               150.41421356237308`}, {-58.41421356237311, \
-27.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 27}, 27.08}, " ~ ", {{2012, 12, 10}, 26.94}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 27}, 27.08}, \" ~ \", {{2012, 12, 10}, \
26.94}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "27"}], "}"}], ",", 
                   "27.08`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "10"}], "}"}], ",", 
                   "26.94`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 27}, 27.08}, " ~ ", {{2012, 12, 10}, 26.94}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{11.5, 26.37}, {12.5, 26.37}}]},
              
              ImageSizeCache->{{147.5857864376269, 
               161.41421356237308`}, {-30.414213562373103`, \
-27.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 27}, 27.08}, " ~ ", {{2012, 12, 10}, 26.94}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 27}, 27.08}, \" ~ \", {{2012, 12, 10}, \
26.94}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "27"}], "}"}], ",", 
                   "27.08`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "10"}], "}"}], ",", 
                   "26.94`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 27}, 27.08}, " ~ ", {{2012, 12, 10}, 26.94}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{12.5, 26.37}, {12.5, 27.68}}]},
              
              ImageSizeCache->{{157.5857864376269, 
               160.41421356237308`}, {-57.41421356237311, \
-27.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 12, 11}, 27.32}, " ~ ", {{2012, 12, 21}, 27.45}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 11}, 27.32}, \" ~ \", {{2012, 12, 21}, \
27.45}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "11"}], "}"}], ",", 
                   "27.32`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "21"}], "}"}], ",", 
                   "27.45`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 11}, 27.32}, " ~ ", {{2012, 12, 21}, 27.45}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{12.5, 27.68}, {13.5, 27.68}}]},
              
              ImageSizeCache->{{157.5857864376269, 
               171.41421356237308`}, {-56.414213562373114`, \
-53.58578643762689}}],
             StatusArea[#, 
              Row[{{{2012, 12, 11}, 27.32}, " ~ ", {{2012, 12, 21}, 27.45}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 11}, 27.32}, \" ~ \", {{2012, 12, 21}, \
27.45}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "11"}], "}"}], ",", 
                   "27.32`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "21"}], "}"}], ",", 
                   "27.45`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 11}, 27.32}, " ~ ", {{2012, 12, 21}, 27.45}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{13.5, 26.55}, {13.5, 27.68}}]},
              
              ImageSizeCache->{{167.5857864376269, 
               170.41421356237308`}, {-57.41421356237311, \
-30.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 12, 24}, 27.06}, " ~ ", {{2012, 12, 31}, 26.71}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 24}, 27.06}, \" ~ \", {{2012, 12, 31}, \
26.71}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "24"}], "}"}], ",", 
                   "27.06`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "31"}], "}"}], ",", 
                   "26.71`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 24}, 27.06}, " ~ ", {{2012, 12, 31}, 26.71}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{13.5, 26.55}, {14.5, 26.55}}]},
              
              ImageSizeCache->{{167.5857864376269, 
               
               181.41421356237308`}, {-33.41421356237311, \
-30.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2012, 12, 24}, 27.06}, " ~ ", {{2012, 12, 31}, 26.71}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 24}, 27.06}, \" ~ \", {{2012, 12, 31}, \
26.71}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "24"}], "}"}], ",", 
                   "27.06`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "31"}], "}"}], ",", 
                   "26.71`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 24}, 27.06}, " ~ ", {{2012, 12, 31}, 26.71}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{14.5, 26.55}, {14.5, 27.62}}]},
              
              ImageSizeCache->{{177.5857864376269, 
               180.41421356237308`}, {-55.41421356237311, \
-30.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 2}, 27.62}, " ~ ", {{2013, 1, 3}, 27.25}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 2}, 27.62}, \" ~ \", {{2013, 1, 3}, 27.25}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "2"}], "}"}], ",", 
                   "27.62`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "3"}], "}"}], ",", 
                   "27.25`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 2}, 27.62}, " ~ ", {{2013, 1, 3}, 27.25}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{14.5, 27.62}, {15.5, 27.62}}]},
              
              ImageSizeCache->{{177.5857864376269, 
               191.41421356237308`}, {-55.414213562373114`, \
-52.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 1, 2}, 27.62}, " ~ ", {{2013, 1, 3}, 27.25}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 2}, 27.62}, \" ~ \", {{2013, 1, 3}, 27.25}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "2"}], "}"}], ",", 
                   "27.62`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "3"}], "}"}], ",", 
                   "27.25`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 2}, 27.62}, " ~ ", {{2013, 1, 3}, 27.25}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{15.5, 26.46}, {15.5, 27.62}}]},
              
              ImageSizeCache->{{187.5857864376269, 
               190.41421356237308`}, {-55.41421356237311, \
-28.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 4}, 26.74}, " ~ ", {{2013, 1, 14}, 26.89}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 4}, 26.74}, \" ~ \", {{2013, 1, 14}, 26.89}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "4"}], "}"}], ",", 
                   "26.74`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "14"}], "}"}], ",", 
                   "26.89`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 4}, 26.74}, " ~ ", {{2013, 1, 14}, 26.89}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{15.5, 26.46}, {16.5, 26.46}}]},
              
              ImageSizeCache->{{187.5857864376269, 
               201.41421356237308`}, {-31.414213562373103`, \
-28.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 4}, 26.74}, " ~ ", {{2013, 1, 14}, 26.89}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 4}, 26.74}, \" ~ \", {{2013, 1, 14}, 26.89}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "4"}], "}"}], ",", 
                   "26.74`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "14"}], "}"}], ",", 
                   "26.89`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 4}, 26.74}, " ~ ", {{2013, 1, 14}, 26.89}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{16.5, 26.46}, {16.5, 27.62}}]},
              
              ImageSizeCache->{{197.5857864376269, 
               200.41421356237308`}, {-55.41421356237311, \
-28.585786437626894`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 15}, 27.21}, " ~ ", {{2013, 1, 24}, 27.63}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 15}, 27.21}, \" ~ \", {{2013, 1, 24}, \
27.63}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "15"}], "}"}], ",", 
                   "27.21`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "24"}], "}"}], ",", 
                   "27.63`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 15}, 27.21}, " ~ ", {{2013, 1, 24}, 27.63}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{16.5, 27.62}, {16.5, 28.01}}]},
              
              ImageSizeCache->{{197.5857864376269, 
               200.41421356237308`}, {-63.414213562373114`, \
-52.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 1, 15}, 27.21}, " ~ ", {{2013, 2, 5}, 27.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 15}, 27.21}, \" ~ \", {{2013, 2, 5}, 27.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "15"}], "}"}], ",", 
                   "27.21`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "5"}], "}"}], ",", 
                   "27.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 15}, 27.21}, " ~ ", {{2013, 2, 5}, 27.5}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{16.5, 28.01}, {17.5, 28.01}}]},
              
              ImageSizeCache->{{197.5857864376269, 
               211.41421356237308`}, {-63.414213562373114`, \
-60.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 1, 15}, 27.21}, " ~ ", {{2013, 2, 5}, 27.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 15}, 27.21}, \" ~ \", {{2013, 2, 5}, 27.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "15"}], "}"}], ",", 
                   "27.21`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "5"}], "}"}], ",", 
                   "27.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 15}, 27.21}, " ~ ", {{2013, 2, 5}, 27.5}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{17.5, 27.28}, {17.5, 28.01}}]},
              
              ImageSizeCache->{{207.5857864376269, 
               210.41421356237308`}, {-63.414213562373114`, \
-45.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 2, 6}, 27.34}, " ~ ", {{2013, 2, 11}, 27.86}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 6}, 27.34}, \" ~ \", {{2013, 2, 11}, 27.86}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "6"}], "}"}], ",", 
                   "27.34`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "11"}], "}"}], ",", 
                   "27.86`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 6}, 27.34}, " ~ ", {{2013, 2, 11}, 27.86}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{17.5, 27.28}, {18.5, 27.28}}]},
              
              ImageSizeCache->{{207.5857864376269, 
               221.41421356237308`}, {-48.414213562373114`, \
-45.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 2, 6}, 27.34}, " ~ ", {{2013, 2, 11}, 27.86}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 6}, 27.34}, \" ~ \", {{2013, 2, 11}, 27.86}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "6"}], "}"}], ",", 
                   "27.34`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "11"}], "}"}], ",", 
                   "27.86`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 6}, 27.34}, " ~ ", {{2013, 2, 11}, 27.86}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{18.5, 27.28}, {18.5, 28.05}}]},
              
              ImageSizeCache->{{217.5857864376269, 
               220.41421356237308`}, {-64.41421356237312, \
-45.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 2, 12}, 27.88}, " ~ ", {{2013, 2, 22}, 27.76}}]]& ,
             
             TagBoxNote->
              
              "Row[{{{2013, 2, 12}, 27.88}, \" ~ \", {{2013, 2, 22}, \
27.76}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "12"}], "}"}], ",", 
                   "27.88`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "22"}], "}"}], ",", 
                   "27.76`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 12}, 27.88}, " ~ ", {{2013, 2, 22}, 27.76}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{18.5, 28.05}, {19.5, 28.05}}]},
              
              ImageSizeCache->{{217.5857864376269, 
               231.41421356237308`}, {-64.4142135623731, -61.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 2, 12}, 27.88}, " ~ ", {{2013, 2, 22}, 27.76}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 12}, 27.88}, \" ~ \", {{2013, 2, 22}, \
27.76}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "12"}], "}"}], ",", 
                   "27.88`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "22"}], "}"}], ",", 
                   "27.76`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 12}, 27.88}, " ~ ", {{2013, 2, 22}, 27.76}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{19.5, 27.37}, {19.5, 28.05}}]},
              
              ImageSizeCache->{{227.5857864376269, 
               230.41421356237308`}, {-64.41421356237312, \
-47.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 2, 25}, 27.37}, " ~ ", {{2013, 3, 1}, 27.95}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 25}, 27.37}, \" ~ \", {{2013, 3, 1}, 27.95}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "25"}], "}"}], ",", 
                   "27.37`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "1"}], "}"}], ",", 
                   "27.95`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 25}, 27.37}, " ~ ", {{2013, 3, 1}, 27.95}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{19.5, 27.37}, {20.5, 27.37}}]},
              
              ImageSizeCache->{{227.5857864376269, 
               241.41421356237308`}, {-50.414213562373114`, \
-47.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 2, 25}, 27.37}, " ~ ", {{2013, 3, 1}, 27.95}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 25}, 27.37}, \" ~ \", {{2013, 3, 1}, 27.95}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "25"}], "}"}], ",", 
                   "27.37`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "1"}], "}"}], ",", 
                   "27.95`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 25}, 27.37}, " ~ ", {{2013, 3, 1}, 27.95}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{20.5, 27.37}, {20.5, 30.28}}]},
              ImageSizeCache->{{237.5857864376269, 
               240.41421356237308`}, {-110.41421356237312`, \
-47.58578643762689}}],
             StatusArea[#, 
              Row[{{{2013, 3, 4}, 28.15}, " ~ ", {{2013, 4, 10}, 30.28}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 4}, 28.15}, \" ~ \", {{2013, 4, 10}, 30.28}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "4"}], "}"}], ",", 
                   "28.15`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "10"}], "}"}], ",", 
                   "30.28`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 4}, 28.15}, " ~ ", {{2013, 4, 10}, 30.28}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{20.5, 30.28}, {21.5, 30.28}}]},
              
              ImageSizeCache->{{237.5857864376269, 
               251.41421356237308`}, {-110.4142135623731, \
-107.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 3, 4}, 28.15}, " ~ ", {{2013, 4, 10}, 30.28}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 4}, 28.15}, \" ~ \", {{2013, 4, 10}, 30.28}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "4"}], "}"}], ",", 
                   "28.15`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "10"}], "}"}], ",", 
                   "30.28`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 4}, 28.15}, " ~ ", {{2013, 4, 10}, 30.28}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{21.5, 28.69}, {21.5, 30.28}}]},
              
              ImageSizeCache->{{247.5857864376269, 
               250.41421356237308`}, {-110.41421356237312`, \
-74.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 11}, 28.94}, " ~ ", {{2013, 4, 18}, 28.79}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 11}, 28.94}, \" ~ \", {{2013, 4, 18}, \
28.79}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "11"}], "}"}], ",", 
                   "28.94`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "18"}], "}"}], ",", 
                   "28.79`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 11}, 28.94}, " ~ ", {{2013, 4, 18}, 28.79}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{21.5, 28.69}, {22.5, 28.69}}]},
              
              ImageSizeCache->{{247.5857864376269, 
               261.4142135623731}, {-77.4142135623731, -74.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 11}, 28.94}, " ~ ", {{2013, 4, 18}, 28.79}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 11}, 28.94}, \" ~ \", {{2013, 4, 18}, \
28.79}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "11"}], "}"}], ",", 
                   "28.94`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "18"}], "}"}], ",", 
                   "28.79`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 11}, 28.94}, " ~ ", {{2013, 4, 18}, 28.79}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{22.5, 28.69}, {22.5, 33.75}}]},
              
              ImageSizeCache->{{257.5857864376269, 
               260.4142135623731}, {-181.4142135623731, -74.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 19}, 29.77}, " ~ ", {{2013, 5, 7}, 33.31}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 19}, 29.77}, \" ~ \", {{2013, 5, 7}, 33.31}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "19"}], "}"}], ",", 
                   "29.77`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "7"}], "}"}], ",", 
                   "33.31`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 19}, 29.77}, " ~ ", {{2013, 5, 7}, 33.31}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{22.5, 33.75}, {23.5, 33.75}}]},
              
              ImageSizeCache->{{257.5857864376269, 
               271.4142135623731}, {-181.41421356237308`, \
-178.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 4, 19}, 29.77}, " ~ ", {{2013, 5, 7}, 33.31}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 19}, 29.77}, \" ~ \", {{2013, 5, 7}, 33.31}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "19"}], "}"}], ",", 
                   "29.77`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "7"}], "}"}], ",", 
                   "33.31`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 19}, 29.77}, " ~ ", {{2013, 5, 7}, 33.31}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{23.5, 32.66}, {23.5, 33.75}}]},
              
              ImageSizeCache->{{267.5857864376269, 
               270.4142135623731}, {-181.41421356237308`, \
-155.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 8}, 32.99}, " ~ ", {{2013, 5, 13}, 33.03}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 8}, 32.99}, \" ~ \", {{2013, 5, 13}, 33.03}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "8"}], "}"}], ",", 
                   "32.99`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "13"}], "}"}], ",", 
                   "33.03`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 8}, 32.99}, " ~ ", {{2013, 5, 13}, 33.03}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{23.5, 32.66}, {24.5, 32.66}}]},
              
              ImageSizeCache->{{267.5857864376269, 
               281.4142135623731}, {-158.41421356237308`, \
-155.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 8}, 32.99}, " ~ ", {{2013, 5, 13}, 33.03}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 8}, 32.99}, \" ~ \", {{2013, 5, 13}, 33.03}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "8"}], "}"}], ",", 
                   "32.99`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "13"}], "}"}], ",", 
                   "33.03`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 8}, 32.99}, " ~ ", {{2013, 5, 13}, 33.03}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{24.5, 32.66}, {24.5, 35.08}}]},
              
              ImageSizeCache->{{277.5857864376269, 
               280.4142135623731}, {-208.41421356237308`, \
-155.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 14}, 33.53}, " ~ ", {{2013, 5, 22}, 34.61}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 14}, 33.53}, \" ~ \", {{2013, 5, 22}, \
34.61}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "14"}], "}"}], ",", 
                   "33.53`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "22"}], "}"}], ",", 
                   "34.61`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 14}, 33.53}, " ~ ", {{2013, 5, 22}, 34.61}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{24.5, 35.08}, {25.5, 35.08}}]},
              
              ImageSizeCache->{{277.5857864376269, 
               291.4142135623731}, {-208.41421356237308`, \
-205.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 14}, 33.53}, " ~ ", {{2013, 5, 22}, 34.61}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 14}, 33.53}, \" ~ \", {{2013, 5, 22}, \
34.61}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "14"}], "}"}], ",", 
                   "33.53`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "22"}], "}"}], ",", 
                   "34.61`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 14}, 33.53}, " ~ ", {{2013, 5, 22}, 34.61}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{25.5, 34.15}, {25.5, 35.08}}]},
              
              ImageSizeCache->{{288.5857864376269, 
               291.4142135623731}, {-209.41421356237308`, \
-186.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 23}, 34.15}, " ~ ", {{2013, 5, 24}, 34.27}}]]& ,
             TagBoxNote->
              "Row[{{{2013, 5, 23}, 34.15}, \" ~ \", {{2013, 5, 24}, \
34.27}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "23"}], "}"}], ",", 
                   "34.15`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "24"}], "}"}], ",", 
                   "34.27`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 23}, 34.15}, " ~ ", {{2013, 5, 24}, 34.27}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{25.5, 34.15}, {26.5, 34.15}}]},
              
              ImageSizeCache->{{288.5857864376269, 
               302.4142135623731}, {-189.41421356237308`, \
-186.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 23}, 34.15}, " ~ ", {{2013, 5, 24}, 34.27}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 23}, 34.15}, \" ~ \", {{2013, 5, 24}, \
34.27}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "23"}], "}"}], ",", 
                   "34.15`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "24"}], "}"}], ",", 
                   "34.27`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 23}, 34.15}, " ~ ", {{2013, 5, 24}, 34.27}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{26.5, 34.15}, {26.5, 35.59}}]},
              
              ImageSizeCache->{{298.5857864376269, 
               301.4142135623731}, {-219.41421356237308`, \
-186.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 28}, 35.02}, " ~ ", {{2013, 6, 3}, 35.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 28}, 35.02}, \" ~ \", {{2013, 6, 3}, 35.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "28"}], "}"}], ",", 
                   "35.02`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "3"}], "}"}], ",", 
                   "35.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 28}, 35.02}, " ~ ", {{2013, 6, 3}, 35.59}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{26.5, 35.59}, {27.5, 35.59}}]},
              
              ImageSizeCache->{{298.5857864376269, 
               312.4142135623731}, {-218.41421356237308`, \
-215.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 5, 28}, 35.02}, " ~ ", {{2013, 6, 3}, 35.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 28}, 35.02}, \" ~ \", {{2013, 6, 3}, 35.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "28"}], "}"}], ",", 
                   "35.02`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "3"}], "}"}], ",", 
                   "35.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 28}, 35.02}, " ~ ", {{2013, 6, 3}, 35.59}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{27.5, 34.78}, {27.5, 35.59}}]},
              ImageSizeCache->{{308.5857864376269, 
               311.4142135623731}, {-219.41421356237308`, \
-199.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 4}, 34.99}, " ~ ", {{2013, 6, 6}, 34.96}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 4}, 34.99}, \" ~ \", {{2013, 6, 6}, 34.96}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "4"}], "}"}], ",", 
                   "34.99`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "6"}], "}"}], ",", 
                   "34.96`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 4}, 34.99}, " ~ ", {{2013, 6, 6}, 34.96}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{27.5, 34.78}, {28.5, 34.78}}]},
              
              ImageSizeCache->{{308.5857864376269, 
               322.4142135623731}, {-202.41421356237308`, \
-199.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 4}, 34.99}, " ~ ", {{2013, 6, 6}, 34.96}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 4}, 34.99}, \" ~ \", {{2013, 6, 6}, 34.96}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "4"}], "}"}], ",", 
                   "34.99`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "6"}], "}"}], ",", 
                   "34.96`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 4}, 34.99}, " ~ ", {{2013, 6, 6}, 34.96}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{28.5, 34.78}, {28.5, 35.67}}]},
              
              ImageSizeCache->{{318.5857864376269, 
               321.4142135623731}, {-221.41421356237308`, \
-199.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 7}, 35.67}, " ~ ", {{2013, 6, 10}, 35.47}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 7}, 35.67}, \" ~ \", {{2013, 6, 10}, 35.47}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "7"}], "}"}], ",", 
                   "35.67`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "10"}], "}"}], ",", 
                   "35.47`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 7}, 35.67}, " ~ ", {{2013, 6, 10}, 35.47}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{28.5, 35.67}, {29.5, 35.67}}]},
              
              ImageSizeCache->{{318.5857864376269, 
               332.4142135623731}, {-220.41421356237308`, \
-217.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 7}, 35.67}, " ~ ", {{2013, 6, 10}, 35.47}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 7}, 35.67}, \" ~ \", {{2013, 6, 10}, 35.47}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "7"}], "}"}], ",", 
                   "35.67`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "10"}], "}"}], ",", 
                   "35.47`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 7}, 35.67}, " ~ ", {{2013, 6, 10}, 35.47}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{29.5, 34.78}, {29.5, 35.67}}]},
              
              ImageSizeCache->{{328.5857864376269, 
               331.4142135623731}, {-221.41421356237308`, \
-199.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 11}, 34.84}, " ~ ", {{2013, 6, 13}, 34.72}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 11}, 34.84}, \" ~ \", {{2013, 6, 13}, \
34.72}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "11"}], "}"}], ",", 
                   "34.84`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "13"}], "}"}], ",", 
                   "34.72`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 11}, 34.84}, " ~ ", {{2013, 6, 13}, 34.72}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{29.5, 34.4}, {29.5, 34.78}}]},
              
              ImageSizeCache->{{328.5857864376269, 
               331.4142135623731}, {-202.41421356237308`, \
-191.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 11}, 34.84}, " ~ ", {{2013, 6, 14}, 34.4}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 11}, 34.84}, \" ~ \", {{2013, 6, 14}, 34.4}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "11"}], "}"}], ",", 
                   "34.84`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "14"}], "}"}], ",", 
                   "34.4`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 11}, 34.84}, " ~ ", {{2013, 6, 14}, 34.4}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{29.5, 34.4}, {30.5, 34.4}}]},
              
              ImageSizeCache->{{328.5857864376269, 
               342.4142135623731}, {-194.41421356237308`, \
-191.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 11}, 34.84}, " ~ ", {{2013, 6, 14}, 34.4}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 11}, 34.84}, \" ~ \", {{2013, 6, 14}, 34.4}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "11"}], "}"}], ",", 
                   "34.84`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "14"}], "}"}], ",", 
                   "34.4`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 11}, 34.84}, " ~ ", {{2013, 6, 14}, 34.4}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{30.5, 34.4}, {30.5, 35.}}]},
              
              ImageSizeCache->{{338.5857864376269, 
               341.4142135623731}, {-207.41421356237308`, \
-191.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 17}, 35.}, " ~ ", {{2013, 6, 19}, 34.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 17}, 35.}, \" ~ \", {{2013, 6, 19}, 34.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "17"}], "}"}], ",", 
                   "35.`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "19"}], "}"}], ",", 
                   "34.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 17}, 35.}, " ~ ", {{2013, 6, 19}, 34.59}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{30.5, 35.}, {31.5, 35.}}]},
              
              ImageSizeCache->{{338.5857864376269, 
               352.4142135623731}, {-206.41421356237308`, \
-203.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 17}, 35.}, " ~ ", {{2013, 6, 19}, 34.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 17}, 35.}, \" ~ \", {{2013, 6, 19}, 34.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "17"}], "}"}], ",", 
                   "35.`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "19"}], "}"}], ",", 
                   "34.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 17}, 35.}, " ~ ", {{2013, 6, 19}, 34.59}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{31.5, 33.27}, {31.5, 35.}}]},
              
              ImageSizeCache->{{348.5857864376269, 
               351.4142135623731}, {-207.41421356237308`, \
-168.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 20}, 33.49}, " ~ ", {{2013, 6, 25}, 33.67}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 20}, 33.49}, \" ~ \", {{2013, 6, 25}, \
33.67}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "20"}], "}"}], ",", 
                   "33.49`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "25"}], "}"}], ",", 
                   "33.67`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 20}, 33.49}, " ~ ", {{2013, 6, 25}, 33.67}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{31.5, 33.27}, {32.5, 33.27}}]},
              
              ImageSizeCache->{{348.5857864376269, 
               362.4142135623731}, {-171.41421356237308`, \
-168.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 20}, 33.49}, " ~ ", {{2013, 6, 25}, 33.67}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 20}, 33.49}, \" ~ \", {{2013, 6, 25}, \
33.67}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "20"}], "}"}], ",", 
                   "33.49`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "25"}], "}"}], ",", 
                   "33.67`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 20}, 33.49}, " ~ ", {{2013, 6, 25}, 33.67}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{32.5, 33.27}, {32.5, 34.62}}]},
              
              ImageSizeCache->{{358.5857864376269, 
               361.4142135623731}, {-199.41421356237308`, \
-168.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 26}, 34.35}, " ~ ", {{2013, 7, 1}, 34.36}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 26}, 34.35}, \" ~ \", {{2013, 7, 1}, 34.36}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "26"}], "}"}], ",", 
                   "34.35`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "1"}], "}"}], ",", 
                   "34.36`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 26}, 34.35}, " ~ ", {{2013, 7, 1}, 34.36}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{32.5, 34.62}, {33.5, 34.62}}]},
              
              ImageSizeCache->{{358.5857864376269, 
               372.4142135623731}, {-198.41421356237308`, \
-195.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 6, 26}, 34.35}, " ~ ", {{2013, 7, 1}, 34.36}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 26}, 34.35}, \" ~ \", {{2013, 7, 1}, 34.36}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "26"}], "}"}], ",", 
                   "34.35`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "1"}], "}"}], ",", 
                   "34.36`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 26}, 34.35}, " ~ ", {{2013, 7, 1}, 34.36}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{33.5, 33.94}, {33.5, 34.62}}]},
              
              ImageSizeCache->{{368.5857864376269, 
               371.4142135623731}, {-199.41421356237308`, \
-182.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 2}, 33.94}, " ~ ", {{2013, 7, 9}, 34.35}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 2}, 33.94}, \" ~ \", {{2013, 7, 9}, 34.35}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "2"}], "}"}], ",", 
                   "33.94`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "9"}], "}"}], ",", 
                   "34.35`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 2}, 33.94}, " ~ ", {{2013, 7, 9}, 34.35}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{33.5, 33.94}, {34.5, 33.94}}]},
              
              ImageSizeCache->{{368.5857864376269, 
               
               382.4142135623731}, {-185.41421356237308`, \
-182.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 2}, 33.94}, " ~ ", {{2013, 7, 9}, 34.35}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 2}, 33.94}, \" ~ \", {{2013, 7, 9}, 34.35}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "2"}], "}"}], ",", 
                   "33.94`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "9"}], "}"}], ",", 
                   "34.35`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 2}, 33.94}, " ~ ", {{2013, 7, 9}, 34.35}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{34.5, 33.94}, {34.5, 34.62}}]},
              
              ImageSizeCache->{{378.5857864376269, 
               381.4142135623731}, {-199.41421356237308`, \
-182.5857864376269}}],
             StatusArea[#, {{2013, 7, 10}, 34.7}]& ,
             TagBoxNote->"{{2013, 7, 10}, 34.7}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "10"}], "}"}], ",", 
                 "34.7`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 7, 10}, 34.7}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{34.5, 34.62}, {34.5, 36.27}}]},
              
              ImageSizeCache->{{378.5857864376269, 
               381.4142135623731}, {-232.41421356237308`, \
-195.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 10}, 34.7}, " ~ ", {{2013, 7, 17}, 35.74}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 10}, 34.7}, \" ~ \", {{2013, 7, 17}, 35.74}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "10"}], "}"}], ",", 
                   "34.7`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "17"}], "}"}], ",", 
                   "35.74`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 10}, 34.7}, " ~ ", {{2013, 7, 17}, 35.74}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{34.5, 36.27}, {35.5, 36.27}}]},
              
              ImageSizeCache->{{378.5857864376269, 
               392.4142135623731}, {-232.41421356237308`, \
-229.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 10}, 34.7}, " ~ ", {{2013, 7, 17}, 35.74}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 10}, 34.7}, \" ~ \", {{2013, 7, 17}, 35.74}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "10"}], "}"}], ",", 
                   "34.7`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "17"}], "}"}], ",", 
                   "35.74`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 10}, 34.7}, " ~ ", {{2013, 7, 17}, 35.74}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.5, 0.7, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{35.5, 33.94}, {35.5, 36.27}}]},
              
              ImageSizeCache->{{388.5857864376269, 
               391.4142135623731}, {-233.41421356237308`, \
-182.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 18}, 35.44}, " ~ ", {{2013, 7, 19}, 31.4}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 18}, 35.44}, \" ~ \", {{2013, 7, 19}, 31.4}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "18"}], "}"}], ",", 
                   "35.44`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "31.4`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 18}, 35.44}, " ~ ", {{2013, 7, 19}, 31.4}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{35.5, 31.4}, {35.5, 33.94}}]},
              
              ImageSizeCache->{{388.5857864376269, 
               391.4142135623731}, {-186.41421356237308`, \
-130.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 18}, 35.44}, " ~ ", {{2013, 7, 19}, 31.4}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 18}, 35.44}, \" ~ \", {{2013, 7, 19}, 31.4}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "18"}], "}"}], ",", 
                   "35.44`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "31.4`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 18}, 35.44}, " ~ ", {{2013, 7, 19}, 31.4}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{35.5, 31.4}, {36.5, 31.4}}]},
              
              ImageSizeCache->{{388.5857864376269, 
               402.4142135623731}, {-133.41421356237308`, \
-130.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 18}, 35.44}, " ~ ", {{2013, 7, 19}, 31.4}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 18}, 35.44}, \" ~ \", {{2013, 7, 19}, 31.4}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "18"}], "}"}], ",", 
                   "35.44`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "31.4`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 18}, 35.44}, " ~ ", {{2013, 7, 19}, 31.4}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{36.5, 31.4}, {36.5, 32.01}}]},
              
              ImageSizeCache->{{398.5857864376269, 
               401.4142135623731}, {-146.41421356237308`, \
-130.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 22}, 32.01}, " ~ ", {{2013, 7, 24}, 31.96}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 22}, 32.01}, \" ~ \", {{2013, 7, 24}, \
31.96}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "22"}], "}"}], ",", 
                   "32.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "24"}], "}"}], ",", 
                   "31.96`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 22}, 32.01}, " ~ ", {{2013, 7, 24}, 31.96}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{36.5, 32.01}, {37.5, 32.01}}]},
              
              ImageSizeCache->{{398.5857864376269, 
               412.4142135623731}, {-145.41421356237308`, \
-142.5857864376269}}],
             StatusArea[#, 
              Row[{{{2013, 7, 22}, 32.01}, " ~ ", {{2013, 7, 24}, 31.96}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 22}, 32.01}, \" ~ \", {{2013, 7, 24}, \
31.96}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "22"}], "}"}], ",", 
                   "32.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "24"}], "}"}], ",", 
                   "31.96`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 22}, 32.01}, " ~ ", {{2013, 7, 24}, 31.96}}], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{37.5, 31.39}, {37.5, 32.01}}]},
              
              ImageSizeCache->{{408.5857864376269, 
               411.4142135623731}, {-145.41421356237308`, \
-129.5857864376269}}],
             StatusArea[#, {{2013, 7, 25}, 31.39}]& ,
             TagBoxNote->"{{2013, 7, 25}, 31.39}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "25"}], "}"}], ",", 
                 "31.39`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 7, 25}, 31.39}, {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.1, 0], AbsoluteThickness[1.5], CapForm["Round"], 
          EdgeForm[Opacity[0.7]], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               LineBox[{{37.5, 31.39}, {37.5, 32.01}}]},
              
              ImageSizeCache->{{408.5857864376269, 
               411.4142135623731}, {-145.41421356237308`, \
-129.5857864376269}}],
             StatusArea[#, {{2013, 7, 25}, 31.39}]& ,
             TagBoxNote->"{{2013, 7, 25}, 31.39}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "25"}], "}"}], ",", 
                 "31.39`"}], "}"}], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 7, 25}, 31.39}, {
              GrayLevel[0]}], 
            "Tooltip"]& ]}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 25.875}, {38.5, 25.875}}], {}}, {{
             LineBox[{{0.5, 25.875}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 25.875}]}], 
             LineBox[{{38.5, 25.875}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {38.5, 
                25.875}]}], {{}, {}, {
               LineBox[{{14.5, 25.875}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {14.5, 25.875}]}], 
               LineBox[{{14.5, 25.875}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {14.5, 
                  25.875}]}]}}}, {
             InsetBox["\<\"2012\"\>", Offset[{0., -2.}, {7.5, 25.875}], {0, 1},
               Automatic, {1, 0}], 
             InsetBox["\<\"2013\"\>", Offset[{0., -2.}, {26.5, 25.875}], {0, 1},
               Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->True],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.4, Automatic},
       GridLines->
        FrontEndValueCache[{{{1.5, {}}, {5.5, {}}, {8.5, {}}, {11.5, {}}, {
           14.5, {}}, {16.5, {}}, {19.5, {}}, {20.5, {}}, {22.5, {}}, {
           26.5, {}}, {32.5, {}}, {14.5, 
            Directive[
             Dashing[{}]]}}, 
          FindDivisions[{#, #2}, 6]& }, {{{1.5, {}}, {5.5, {}}, {8.5, {}}, {
           11.5, {}}, {14.5, {}}, {16.5, {}}, {19.5, {}}, {20.5, {}}, {
           22.5, {}}, {26.5, {}}, {32.5, {}}, {14.5, 
            Directive[
             Dashing[{}]]}}, {24., 26., 28., 30., 32., 34., 36., 38.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "KagiChart", "\" of \"", "\"Microsoft Corporation\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.1]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            Identity[#], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[25.875]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{24., 
            FormBox["24.`", TraditionalForm]}, {26., 
            FormBox["26.`", TraditionalForm]}, {28., 
            FormBox["28.`", TraditionalForm]}, {30., 
            FormBox["30.`", TraditionalForm]}, {32., 
            FormBox["32.`", TraditionalForm]}, {34., 
            FormBox["34.`", TraditionalForm]}, {36., 
            FormBox["36.`", TraditionalForm]}, {38., 
            FormBox["38.`", TraditionalForm]}}}]], {576., -119.58957682310464`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{0.5, 29.16}, {1.5, 30.15}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{37.78823892179494, 
               61.70054575011896}, {-104.04194789815858`, \
-82.76073744633709}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 8, 7}, 30.26}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 29.16}, \" ~ \", {{2012, 8, 7}, 30.26}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "29.16`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "7"}], "}"}], ",", 
                   "30.26`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 8, 7}, 30.26}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{1.5, 30.15}, {2.5, 31.139999999999997`}, 
                "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{61.70054575011896, 
               85.61285257844298}, {-125.32315834997996`, \
-104.04194789815858`}}],
             StatusArea[#, 
              Row[{{{2012, 8, 8}, 30.33}, " ~ ", {{2012, 9, 6}, 31.35}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 8}, 30.33}, \" ~ \", {{2012, 9, 6}, 31.35}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "8"}], "}"}], ",", 
                   "30.33`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "6"}], "}"}], ",", 
                   "31.35`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 8}, 30.33}, " ~ ", {{2012, 9, 6}, 31.35}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{2.5, 29.16}, {3.5, 30.15}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{85.61285257844298, 
               109.52515940676699`}, {-104.04194789815858`, \
-82.76073744633709}}],
             StatusArea[#, 
              Row[{{{2012, 9, 7}, 30.95}, " ~ ", {{2012, 10, 10}, 28.98}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 7}, 30.95}, \" ~ \", {{2012, 10, 10}, \
28.98}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "7"}], "}"}], ",", 
                   "30.95`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "10"}], "}"}], ",", 
                   "28.98`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 7}, 30.95}, " ~ ", {{2012, 10, 10}, 28.98}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{3.5, 28.17}, {4.5, 29.16}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{109.52515940676699`, 
               133.437466235091}, {-82.76073744633709, -61.47952699451571}}],
             StatusArea[#, 
              Row[{{{2012, 10, 11}, 28.95}, " ~ ", {{2012, 10, 22}, 28.}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 11}, 28.95}, \" ~ \", {{2012, 10, 22}, \
28.}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "11"}], "}"}], ",", 
                   "28.95`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "22"}], "}"}], ",", 
                   "28.`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 11}, 28.95}, " ~ ", {{2012, 10, 22}, 28.}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{4.5, 27.180000000000003`}, {5.5, 28.17}, 
                "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{133.437466235091, 
               157.34977306341503`}, {-61.47952699451571, \
-40.19831654269433}}],
             StatusArea[#, 
              Row[{{{2012, 10, 23}, 28.05}, " ~ ", {{2012, 11, 13}, 27.09}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 23}, 28.05}, \" ~ \", {{2012, 11, 13}, \
27.09}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "23"}], "}"}], ",", 
                   "28.05`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "13"}], "}"}], ",", 
                   "27.09`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 23}, 28.05}, " ~ ", {{2012, 11, 13}, 27.09}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{5.5, 28.17}, {6.5, 29.16}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{157.34977306341503`, 
               181.26207989173903`}, {-82.76073744633709, \
-61.47952699451571}}],
             StatusArea[#, 
              Row[{{{2012, 11, 14}, 26.84}, " ~ ", {{2013, 4, 9}, 29.61}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 14}, 26.84}, \" ~ \", {{2013, 4, 9}, \
29.61}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "14"}], "}"}], ",", 
                   "26.84`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "9"}], "}"}], ",", 
                   "29.61`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 14}, 26.84}, " ~ ", {{2013, 4, 9}, 29.61}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{6.5, 29.16}, {7.5, 30.15}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{181.26207989173903`, 
               205.17438672006307`}, {-104.04194789815858`, \
-82.76073744633709}}],
             StatusArea[#, {{2013, 4, 10}, 30.28}]& ,
             TagBoxNote->"{{2013, 4, 10}, 30.28}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "10"}], "}"}], ",", 
                 "30.28`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 10}, 30.28}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{7.5, 30.15}, {8.5, 31.139999999999997`}, 
                "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{205.17438672006307`, 
               229.08669354838707`}, {-125.32315834997996`, \
-104.04194789815858`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 11}, 28.94}, " ~ ", {{2013, 4, 24}, 31.76}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 11}, 28.94}, \" ~ \", {{2013, 4, 24}, \
31.76}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "11"}], "}"}], ",", 
                   "28.94`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "24"}], "}"}], ",", 
                   "31.76`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 11}, 28.94}, " ~ ", {{2013, 4, 24}, 31.76}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{8.5, 31.139999999999997`}, {9.5, 
                32.129999999999995`}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{229.08669354838707`, 
               252.99900037671108`}, {-146.60436880180134`, \
-125.32315834997996`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 25}, 31.94}, " ~ ", {{2013, 4, 29}, 32.61}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 25}, 31.94}, \" ~ \", {{2013, 4, 29}, \
32.61}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "25"}], "}"}], ",", 
                   "31.94`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "29"}], "}"}], ",", 
                   "32.61`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 25}, 31.94}, " ~ ", {{2013, 4, 29}, 32.61}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{9.5, 32.129999999999995`}, {10.5, 33.12}, 
                "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{252.99900037671108`, 
               276.91130720503514`}, {-167.88557925362284`, \
-146.60436880180134`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 30}, 33.1}, " ~ ", {{2013, 5, 2}, 33.16}}]]& ,
             TagBoxNote->
              "Row[{{{2013, 4, 30}, 33.1}, \" ~ \", {{2013, 5, 2}, 33.16}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "30"}], "}"}], ",", 
                   "33.1`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "2"}], "}"}], ",", 
                   "33.16`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 30}, 33.1}, " ~ ", {{2013, 5, 2}, 33.16}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{10.5, 33.12}, {11.5, 34.11}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{276.91130720503514`, 
               300.82361403335915`}, {-189.16678970544433`, \
-167.88557925362284`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 3}, 33.49}, " ~ ", {{2013, 5, 17}, 34.87}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 3}, 33.49}, \" ~ \", {{2013, 5, 17}, 34.87}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "3"}], "}"}], ",", 
                   "33.49`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "17"}], "}"}], ",", 
                   "34.87`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 3}, 33.49}, " ~ ", {{2013, 5, 17}, 34.87}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{11.5, 34.11}, {12.5, 35.1}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{300.82361403335915`, 
               324.73592086168316`}, {-210.44800015726582`, \
-189.16678970544433`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 20}, 35.08}, " ~ ", {{2013, 6, 3}, 35.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 20}, 35.08}, \" ~ \", {{2013, 6, 3}, 35.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "20"}], "}"}], ",", 
                   "35.08`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "3"}], "}"}], ",", 
                   "35.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 20}, 35.08}, " ~ ", {{2013, 6, 3}, 35.59}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{12.5, 35.1}, {13.5, 36.09}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{324.73592086168316`, 
               348.64822769000716`}, {-231.7292106090872, \
-210.44800015726582`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 4}, 34.99}, " ~ ", {{2013, 7, 15}, 36.17}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 4}, 34.99}, \" ~ \", {{2013, 7, 15}, 36.17}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "4"}], "}"}], ",", 
                   "34.99`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "15"}], "}"}], ",", 
                   "36.17`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 4}, 34.99}, " ~ ", {{2013, 7, 15}, 36.17}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{13.5, 34.11}, {14.5, 35.1}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{348.64822769000716`, 
               372.56053451833117`}, {-210.44800015726582`, \
-189.16678970544433`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 16}, 36.27}, " ~ ", {{2013, 7, 19}, 31.4}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 16}, 36.27}, \" ~ \", {{2013, 7, 19}, 31.4}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "16"}], "}"}], ",", 
                   "36.27`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "31.4`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 16}, 36.27}, " ~ ", {{2013, 7, 19}, 31.4}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{14.5, 33.12}, {15.5, 34.11}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{372.56053451833117`, 
               396.4728413466552}, {-189.16678970544433`, \
-167.88557925362284`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 16}, 36.27}, " ~ ", {{2013, 7, 19}, 31.4}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 16}, 36.27}, \" ~ \", {{2013, 7, 19}, 31.4}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "16"}], "}"}], ",", 
                   "36.27`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "31.4`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 16}, 36.27}, " ~ ", {{2013, 7, 19}, 31.4}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{15.5, 32.129999999999995`}, {16.5, 33.12}, 
                "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{396.4728413466552, 
               420.38514817497924`}, {-167.88557925362284`, \
-146.60436880180134`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 16}, 36.27}, " ~ ", {{2013, 7, 19}, 31.4}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 16}, 36.27}, \" ~ \", {{2013, 7, 19}, 31.4}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "16"}], "}"}], ",", 
                   "36.27`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "31.4`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 16}, 36.27}, " ~ ", {{2013, 7, 19}, 31.4}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], 
            "Tooltip"]& ]}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}, {}, 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 26.190000000000005`}, {16.5, 
             26.190000000000005`}}], {}}, {{
             LineBox[{{0.5, 26.190000000000005`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 
                26.190000000000005`}]}], 
             LineBox[{{16.5, 26.190000000000005`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {16.5, 
                26.190000000000005`}]}], {{}, {}, {
               LineBox[{{5.5, 26.190000000000005`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {5.5, 
                  26.190000000000005`}]}], 
               LineBox[{{5.5, 26.190000000000005`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {5.5, 
                  26.190000000000005`}]}]}}}, {
             InsetBox["\<\"2012\"\>", 
              Offset[{0., -2.}, {3., 26.190000000000005`}], {0, 1}, 
              Automatic, {1, 0}], 
             InsetBox["\<\"2013\"\>", 
              Offset[{0., -2.}, {11., 26.190000000000005`}], {0, 1}, 
              Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->True],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, Automatic},
       GridLines->
        FrontEndValueCache[{{{1.5, {}}, {2.5, {}}, {4.5, {}}, {5.5, {}}, {
           9.5, {}}, {11.5, {}}, {12.5, {}}, {5.5, 
            Directive[
             Dashing[{}]]}}, 
          FindDivisions[{#, #2}, 6]& }, {{{1.5, {}}, {2.5, {}}, {4.5, {}}, {
           5.5, {}}, {9.5, {}}, {11.5, {}}, {12.5, {}}, {5.5, 
            Directive[
             Dashing[{}]]}}, {26., 28., 30., 32., 34., 36., 38.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "RenkoChart", "\" of \"", "\"Microsoft Corporation\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.1]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            Identity[#], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[26.190000000000005`]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{26., 
            FormBox["26.`", TraditionalForm]}, {28., 
            FormBox["28.`", TraditionalForm]}, {30., 
            FormBox["30.`", TraditionalForm]}, {32., 
            FormBox["32.`", TraditionalForm]}, {34., 
            FormBox["34.`", TraditionalForm]}, {36., 
            FormBox["36.`", TraditionalForm]}, {38., 
            FormBox["38.`", TraditionalForm]}}}]], {192., -358.76873046931394`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{0.5, 29.16}, {1.5, 29.76}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{37.78823892179497, 
               41.81557480867065}, {-105.5227953145594, -92.14739929545726}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 8, 3}, 29.75}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 29.16}, \" ~ \", {{2012, 8, 3}, 29.75}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "29.16`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "3"}], "}"}], ",", 
                   "29.75`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 8, 3}, 29.75}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{1.5, 29.76}, {2.5, 29.95}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{41.81557480867065, 
               45.84291069554621}, {-109.75833738727499`, \
-105.5227953145594}}],
             StatusArea[#, {{2012, 8, 6}, 29.95}]& ,
             TagBoxNote->"{{2012, 8, 6}, 29.95}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "6"}], "}"}], ",", 
                 "29.95`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 6}, 29.95}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{2.5, 29.95}, {3.5, 30.26}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{45.84291069554621, 
               49.870246582421885`}, {-116.66895866381117`, \
-109.75833738727499`}}],
             StatusArea[#, {{2012, 8, 7}, 30.26}]& ,
             TagBoxNote->"{{2012, 8, 7}, 30.26}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "7"}], "}"}], ",", 
                 "30.26`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 7}, 30.26}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{3.5, 30.26}, {4.5, 30.33}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{49.870246582421885`, 
               53.89758246929745}, {-118.22942153270628`, \
-116.66895866381117`}}],
             StatusArea[#, {{2012, 8, 8}, 30.33}]& ,
             TagBoxNote->"{{2012, 8, 8}, 30.33}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "8"}], "}"}], ",", 
                 "30.33`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 8}, 30.33}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{4.5, 30.33}, {5.5, 30.5}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{53.89758246929745, 
               57.92491835617312}, {-122.019117071452, -118.22942153270628`}}],
             StatusArea[#, 
              Row[{{{2012, 8, 9}, 30.5}, " ~ ", {{2012, 8, 15}, 30.2}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 9}, 30.5}, \" ~ \", {{2012, 8, 15}, 30.2}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "9"}], "}"}], ",", 
                   "30.5`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "15"}], "}"}], ",", 
                   "30.2`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 9}, 30.5}, " ~ ", {{2012, 8, 15}, 30.2}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{5.5, 30.5}, {6.5, 30.78}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{57.92491835617312, 
               61.9522542430488}, {-128.26096854703303`, -122.019117071452}}],
             StatusArea[#, {{2012, 8, 16}, 30.78}]& ,
             TagBoxNote->"{{2012, 8, 16}, 30.78}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "8", ",", "16"}], "}"}], ",", 
                 "30.78`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 8, 16}, 30.78}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{6.5, 30.78}, {7.5, 30.9}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{61.9522542430488, 
               65.97959012992436}, {-130.9360477508534, \
-128.26096854703303`}}],
             StatusArea[#, 
              Row[{{{2012, 8, 17}, 30.9}, " ~ ", {{2012, 8, 22}, 30.54}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 17}, 30.9}, \" ~ \", {{2012, 8, 22}, 30.54}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "17"}], "}"}], ",", 
                   "30.9`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "22"}], "}"}], ",", 
                   "30.54`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 17}, 30.9}, " ~ ", {{2012, 8, 22}, 30.54}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{7.5, 30.26}, {8.5, 30.78}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{65.97959012992436, 
               70.00692601680004}, {-128.26096854703303`, \
-116.66895866381117`}}],
             StatusArea[#, 
              Row[{{{2012, 8, 23}, 30.26}, " ~ ", {{2012, 9, 5}, 30.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 8, 23}, 30.26}, \" ~ \", {{2012, 9, 5}, 30.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "8", ",", "23"}], "}"}], ",", 
                   "30.26`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "5"}], "}"}], ",", 
                   "30.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 8, 23}, 30.26}, " ~ ", {{2012, 9, 5}, 30.39}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{8.5, 30.78}, {9.5, 31.35}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{70.00692601680004, 
               74.0342619036756}, {-140.96759476518002`, \
-128.26096854703303`}}],
             StatusArea[#, 
              Row[{{{2012, 9, 6}, 31.35}, " ~ ", {{2012, 9, 19}, 31.05}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 6}, 31.35}, \" ~ \", {{2012, 9, 19}, 31.05}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "6"}], "}"}], ",", 
                   "31.35`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "19"}], "}"}], ",", 
                   "31.05`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 6}, 31.35}, " ~ ", {{2012, 9, 19}, 31.05}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{9.5, 31.35}, {10.5, 31.45}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{74.0342619036756, 
               78.06159779055128}, {-143.1968274350303, \
-140.96759476518002`}}],
             StatusArea[#, 
              Row[{{{2012, 9, 20}, 31.45}, " ~ ", {{2012, 9, 24}, 30.78}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 20}, 31.45}, \" ~ \", {{2012, 9, 24}, \
30.78}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "20"}], "}"}], ",", 
                   "31.45`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "24"}], "}"}], ",", 
                   "30.78`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 20}, 31.45}, " ~ ", {{2012, 9, 24}, 30.78}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{10.5, 30.39}, {11.5, 31.35}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{78.06159779055128, 
               82.08893367742684}, {-140.96759476518002`, \
-119.56696113461658`}}],
             StatusArea[#, {{2012, 9, 25}, 30.39}]& ,
             TagBoxNote->"{{2012, 9, 25}, 30.39}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "25"}], "}"}], ",", 
                 "30.39`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 25}, 30.39}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{11.5, 30.17}, {12.5, 30.39}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{82.08893367742684, 
               86.11626956430251}, {-119.56696113461658`, \
-114.66264926094584`}}],
             StatusArea[#, {{2012, 9, 26}, 30.17}]& ,
             TagBoxNote->"{{2012, 9, 26}, 30.17}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "26"}], "}"}], ",", 
                 "30.17`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 26}, 30.17}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{12.5, 30.16}, {13.5, 30.17}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{86.11626956430251, 
               90.14360545117808}, {-114.66264926094584`, \
-114.43972599396079`}}],
             StatusArea[#, {{2012, 9, 27}, 30.16}]& ,
             TagBoxNote->"{{2012, 9, 27}, 30.16}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "27"}], "}"}], ",", 
                 "30.16`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 27}, 30.16}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{13.5, 29.76}, {14.5, 30.16}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{90.14360545117808, 
               94.17094133805375}, {-114.43972599396079`, \
-105.5227953145594}}],
             StatusArea[#, {{2012, 9, 28}, 29.76}]& ,
             TagBoxNote->"{{2012, 9, 28}, 29.76}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "9", ",", "28"}], "}"}], ",", 
                 "29.76`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 9, 28}, 29.76}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{14.5, 29.49}, {15.5, 29.76}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{94.17094133805375, 
               98.19827722492931}, {-105.5227953145594, -99.50386710596331}}],
             StatusArea[#, 
              Row[{{{2012, 10, 1}, 29.49}, " ~ ", {{2012, 10, 8}, 29.78}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 1}, 29.49}, \" ~ \", {{2012, 10, 8}, \
29.78}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "1"}], "}"}], ",", 
                   "29.49`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "8"}], "}"}], ",", 
                   "29.78`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 1}, 29.49}, " ~ ", {{2012, 10, 8}, 29.78}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{15.5, 29.28}, {16.5, 29.49}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{98.19827722492931, 
               102.22561311180499`}, {-99.50386710596331, \
-94.82247849927762}}],
             StatusArea[#, {{2012, 10, 9}, 29.28}]& ,
             TagBoxNote->"{{2012, 10, 9}, 29.28}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "9"}], "}"}], ",", 
                 "29.28`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 9}, 29.28}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{16.5, 28.98}, {17.5, 29.28}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{102.22561311180499`, 
               106.25294899868067`}, {-94.82247849927762, \
-88.13478048972661}}],
             StatusArea[#, {{2012, 10, 10}, 28.98}]& ,
             TagBoxNote->"{{2012, 10, 10}, 28.98}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "10"}], "}"}], ",", 
                 "28.98`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 10}, 28.98}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{17.5, 28.95}, {18.5, 28.98}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{106.25294899868067`, 
               110.28028488555623`}, {-88.13478048972661, \
-87.46601068877146}}],
             StatusArea[#, 
              Row[{{{2012, 10, 11}, 28.95}, " ~ ", {{2012, 10, 12}, 29.2}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 11}, 28.95}, \" ~ \", {{2012, 10, 12}, \
29.2}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "11"}], "}"}], ",", 
                   "28.95`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "12"}], "}"}], ",", 
                   "29.2`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 11}, 28.95}, " ~ ", {{2012, 10, 12}, 29.2}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{18.5, 28.98}, {19.5, 29.51}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{110.28028488555623`, 
               114.3076207724319}, {-99.94971363993352, -88.13478048972661}}],
             StatusArea[#, 
              Row[{{{2012, 10, 15}, 29.51}, " ~ ", {{2012, 10, 16}, 29.49}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 15}, 29.51}, \" ~ \", {{2012, 10, 16}, \
29.49}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "15"}], "}"}], ",", 
                   "29.51`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "16"}], "}"}], ",", 
                   "29.49`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 15}, 29.51}, " ~ ", {{2012, 10, 16}, 29.49}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{19.5, 29.51}, {20.5, 29.59}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{114.3076207724319, 
               118.33495665930747`}, {-101.7330997758138, \
-99.94971363993352}}],
             StatusArea[#, 
              Row[{{{2012, 10, 17}, 29.59}, " ~ ", {{2012, 10, 18}, 29.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 17}, 29.59}, \" ~ \", {{2012, 10, 18}, \
29.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "17"}], "}"}], ",", 
                   "29.59`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "18"}], "}"}], ",", 
                   "29.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 17}, 29.59}, " ~ ", {{2012, 10, 18}, 29.5}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{20.5, 28.64}, {21.5, 29.51}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{118.33495665930747`, 
               122.36229254618314`}, {-99.94971363993352, -80.5553894122354}}],
             StatusArea[#, {{2012, 10, 19}, 28.64}]& ,
             TagBoxNote->"{{2012, 10, 19}, 28.64}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "19"}], "}"}], ",", 
                 "28.64`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 19}, 28.64}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{21.5, 28.}, {22.5, 28.64}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{122.36229254618314`, 
               126.3896284330587}, {-80.5553894122354, -66.28830032519306}}],
             StatusArea[#, 
              Row[{{{2012, 10, 22}, 28.}, " ~ ", {{2012, 10, 23}, 28.05}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 22}, 28.}, \" ~ \", {{2012, 10, 23}, \
28.05}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "22"}], "}"}], ",", 
                   "28.`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "23"}], "}"}], ",", 
                   "28.05`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 22}, 28.}, " ~ ", {{2012, 10, 23}, 28.05}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{22.5, 27.9}, {23.5, 28.}, "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{126.3896284330587, 
               130.41696431993438`}, {-66.28830032519306, \
-64.05906765534269}}],
             StatusArea[#, {{2012, 10, 24}, 27.9}]& ,
             TagBoxNote->"{{2012, 10, 24}, 27.9}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "10", ",", "24"}], "}"}], ",", 
                 "27.9`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 10, 24}, 27.9}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{23.5, 27.88}, {24.5, 27.9}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{130.41696431993438`, 
               134.44430020680994`}, {-64.05906765534269, -63.6132211213727}}],
             StatusArea[#, 
              Row[{{{2012, 10, 25}, 27.88}, " ~ ", {{2012, 10, 31}, 28.54}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 10, 25}, 27.88}, \" ~ \", {{2012, 10, 31}, \
28.54}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "25"}], "}"}], ",", 
                   "27.88`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "31"}], "}"}], ",", 
                   "28.54`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 10, 25}, 27.88}, " ~ ", {{2012, 10, 31}, 28.54}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{24.5, 27.9}, {25.5, 29.52}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{134.44430020680994`, 
               138.47163609368562`}, {-100.17263690691846`, \
-64.05906765534269}}],
             StatusArea[#, 
              Row[{{{2012, 11, 1}, 29.52}, " ~ ", {{2012, 11, 2}, 29.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 1}, 29.52}, \" ~ \", {{2012, 11, 2}, 29.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "1"}], "}"}], ",", 
                   "29.52`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "2"}], "}"}], ",", 
                   "29.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 1}, 29.52}, " ~ ", {{2012, 11, 2}, 29.5}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{25.5, 29.52}, {26.5, 29.63}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{138.47163609368562`, 
               142.49897198056118`}, {-102.62479284375388`, \
-100.17263690691846`}}],
             StatusArea[#, {{2012, 11, 5}, 29.63}]& ,
             TagBoxNote->"{{2012, 11, 5}, 29.63}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "11", ",", "5"}], "}"}], ",", 
                 "29.63`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 11, 5}, 29.63}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{26.5, 29.63}, {27.5, 29.86}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{142.49897198056118`, 
               146.52630786743686`}, {-107.75202798440966`, \
-102.62479284375388`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 6}, 29.86}, " ~ ", {{2012, 11, 12}, 28.22}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 6}, 29.86}, \" ~ \", {{2012, 11, 12}, \
28.22}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "6"}], "}"}], ",", 
                   "29.86`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "12"}], "}"}], ",", 
                   "28.22`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 6}, 29.86}, " ~ ", {{2012, 11, 12}, 28.22}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{27.5, 27.09}, {28.5, 29.63}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{146.52630786743686`, 
               150.55364375431253`}, {-102.62479284375388`, \
-46.00228302955486}}],
             StatusArea[#, {{2012, 11, 13}, 27.09}]& ,
             TagBoxNote->"{{2012, 11, 13}, 27.09}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "11", ",", "13"}], "}"}], ",", 
                 "27.09`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 11, 13}, 27.09}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{28.5, 26.84}, {29.5, 27.09}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{150.55364375431253`, 
               154.5809796411881}, {-46.00228302955486, -40.42920135492898}}],
             StatusArea[#, {{2012, 11, 14}, 26.84}]& ,
             TagBoxNote->"{{2012, 11, 14}, 26.84}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "11", ",", "14"}], "}"}], ",", 
                 "26.84`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 11, 14}, 26.84}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{29.5, 26.66}, {30.5, 26.84}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{154.5809796411881, 
               158.60831552806377`}, {-40.42920135492898, \
-36.416582549198324`}}],
             StatusArea[#, {{2012, 11, 15}, 26.66}]& ,
             TagBoxNote->"{{2012, 11, 15}, 26.66}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "11", ",", "15"}], "}"}], ",", 
                 "26.66`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 11, 15}, 26.66}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{30.5, 26.52}, {31.5, 26.66}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{158.60831552806377`, 
               162.63565141493933`}, {-36.416582549198324`, \
-33.295656811407866`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 16}, 26.52}, " ~ ", {{2012, 11, 21}, 26.95}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 16}, 26.52}, \" ~ \", {{2012, 11, 21}, \
26.95}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "16"}], "}"}], ",", 
                   "26.52`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "21"}], "}"}], ",", 
                   "26.95`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 16}, 26.52}, " ~ ", {{2012, 11, 21}, 26.95}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{31.5, 26.66}, {32.5, 27.7}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{162.63565141493933`, 
               166.662987301815}, {-59.60060231564205, -36.416582549198324`}}],
             StatusArea[#, 
              Row[{{{2012, 11, 23}, 27.7}, " ~ ", {{2012, 11, 30}, 26.62}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 23}, 27.7}, \" ~ \", {{2012, 11, 30}, \
26.62}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "23"}], "}"}], ",", 
                   "27.7`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "30"}], "}"}], ",", 
                   "26.62`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 23}, 27.7}, " ~ ", {{2012, 11, 30}, 26.62}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{32.5, 26.43}, {33.5, 26.66}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{166.662987301815, 
               170.69032318869057`}, {-36.416582549198324`, \
-31.28934740854254}}],
             StatusArea[#, {{2012, 12, 3}, 26.43}]& ,
             TagBoxNote->"{{2012, 12, 3}, 26.43}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "3"}], "}"}], ",", 
                 "26.43`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 3}, 26.43}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{33.5, 26.37}, {34.5, 26.43}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{170.69032318869057`, 
               174.71765907556625`}, {-31.28934740854254, \
-29.95180780663236}}],
             StatusArea[#, {{2012, 12, 4}, 26.37}]& ,
             TagBoxNote->"{{2012, 12, 4}, 26.37}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "4"}], "}"}], ",", 
                 "26.37`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 4}, 26.37}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{34.5, 26.43}, {35.5, 26.67}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{174.71765907556625`, 
               178.74499496244192`}, {-36.63950581618337, \
-31.28934740854254}}],
             StatusArea[#, {{2012, 12, 5}, 26.67}]& ,
             TagBoxNote->"{{2012, 12, 5}, 26.67}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "5"}], "}"}], ",", 
                 "26.67`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 5}, 26.67}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{35.5, 26.67}, {36.5, 26.73}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{178.74499496244192`, 
               182.77233084931748`}, {-37.97704541809367, \
-36.63950581618337}}],
             StatusArea[#, 
              Row[{{{2012, 12, 6}, 26.73}, " ~ ", {{2012, 12, 7}, 26.46}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 6}, 26.73}, \" ~ \", {{2012, 12, 7}, \
26.46}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "6"}], "}"}], ",", 
                   "26.73`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "7"}], "}"}], ",", 
                   "26.46`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 6}, 26.73}, " ~ ", {{2012, 12, 7}, 26.46}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{36.5, 26.73}, {37.5, 26.94}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{182.77233084931748`, 
               186.79966673619305`}, {-42.65843402477935, \
-37.97704541809367}}],
             StatusArea[#, {{2012, 12, 10}, 26.94}]& ,
             TagBoxNote->"{{2012, 12, 10}, 26.94}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2012", ",", "12", ",", "10"}], "}"}], ",", 
                 "26.94`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2012, 12, 10}, 26.94}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{37.5, 26.94}, {38.5, 27.32}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{186.79966673619305`, 
               190.82700262306872`}, {-51.129518170210645`, \
-42.65843402477935}}],
             StatusArea[#, 
              Row[{{{2012, 12, 11}, 27.32}, " ~ ", {{2012, 12, 17}, 27.1}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 11}, 27.32}, \" ~ \", {{2012, 12, 17}, \
27.1}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "11"}], "}"}], ",", 
                   "27.32`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "17"}], "}"}], ",", 
                   "27.1`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 11}, 27.32}, " ~ ", {{2012, 12, 17}, 27.1}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{38.5, 27.32}, {39.5, 27.56}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{190.82700262306872`, 
               194.8543385099444}, {-56.47967657785148, \
-51.129518170210645`}}],
             StatusArea[#, 
              Row[{{{2012, 12, 18}, 27.56}, " ~ ", {{2012, 12, 19}, 27.31}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 18}, 27.56}, \" ~ \", {{2012, 12, 19}, \
27.31}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "18"}], "}"}], ",", 
                   "27.56`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "19"}], "}"}], ",", 
                   "27.31`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 18}, 27.56}, " ~ ", {{2012, 12, 19}, 27.31}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{39.5, 27.56}, {40.5, 27.68}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{194.8543385099444, 
               198.88167439681996`}, {-59.15475578167195, \
-56.47967657785148}}],
             StatusArea[#, 
              Row[{{{2012, 12, 20}, 27.68}, " ~ ", {{2012, 12, 24}, 27.06}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 20}, 27.68}, \" ~ \", {{2012, 12, 24}, \
27.06}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "20"}], "}"}], ",", 
                   "27.68`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "24"}], "}"}], ",", 
                   "27.06`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 20}, 27.68}, " ~ ", {{2012, 12, 24}, 27.06}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{40.5, 26.86}, {41.5, 27.56}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{198.88167439681996`, 
               202.90901028369564`}, {-56.47967657785148, \
-40.875047888899076`}}],
             StatusArea[#, 
              Row[{{{2012, 12, 26}, 26.86}, " ~ ", {{2012, 12, 27}, 26.96}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 26}, 26.86}, \" ~ \", {{2012, 12, 27}, \
26.96}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "26"}], "}"}], ",", 
                   "26.86`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "27"}], "}"}], ",", 
                   "26.96`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 26}, 26.86}, " ~ ", {{2012, 12, 27}, 26.96}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{41.5, 26.55}, {42.5, 26.86}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{202.90901028369564`, 
               206.9363461705712}, {-40.875047888899076`, \
-33.96442661236301}}],
             StatusArea[#, 
              Row[{{{2012, 12, 28}, 26.55}, " ~ ", {{2012, 12, 31}, 26.71}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 28}, 26.55}, \" ~ \", {{2012, 12, 31}, \
26.71}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "28"}], "}"}], ",", 
                   "26.55`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "31"}], "}"}], ",", 
                   "26.71`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 28}, 26.55}, " ~ ", {{2012, 12, 31}, 26.71}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{42.5, 26.86}, {43.5, 27.62}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{206.9363461705712, 
               210.96368205744687`}, {-57.81721617976177, \
-40.875047888899076`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 2}, 27.62}, " ~ ", {{2013, 1, 9}, 26.7}}]]& ,
             TagBoxNote->
              "Row[{{{2013, 1, 2}, 27.62}, \" ~ \", {{2013, 1, 9}, 26.7}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "2"}], "}"}], ",", 
                   "27.62`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "9"}], "}"}], ",", 
                   "26.7`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 2}, 27.62}, " ~ ", {{2013, 1, 9}, 26.7}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{43.5, 26.46}, {44.5, 26.86}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{210.96368205744687`, 
               214.99101794432244`}, {-40.875047888899076`, \
-31.958117209497686`}}],
             StatusArea[#, 
              Row[{{{2013, 1, 10}, 26.46}, " ~ ", {{2013, 1, 23}, 27.61}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 10}, 26.46}, \" ~ \", {{2013, 1, 23}, \
27.61}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "10"}], "}"}], ",", 
                   "26.46`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "23"}], "}"}], ",", 
                   "27.61`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 10}, 26.46}, " ~ ", {{2013, 1, 23}, 27.61}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{44.5, 26.86}, {45.5, 27.63}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{214.99101794432244`, 
               219.0183538311981}, {-58.04013944674682, \
-40.875047888899076`}}],
             StatusArea[#, {{2013, 1, 24}, 27.63}]& ,
             TagBoxNote->"{{2013, 1, 24}, 27.63}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "1", ",", "24"}], "}"}], ",", 
                 "27.63`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 1, 24}, 27.63}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{45.5, 27.63}, {46.5, 27.88}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{219.0183538311981, 
               223.0456897180738}, {-63.6132211213727, -58.04013944674682}}],
             StatusArea[#, {{2013, 1, 25}, 27.88}]& ,
             TagBoxNote->"{{2013, 1, 25}, 27.88}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "1", ",", "25"}], "}"}], ",", 
                 "27.88`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 1, 25}, 27.88}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{46.5, 27.88}, {47.5, 27.91}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{223.0456897180738, 
               227.07302560494935`}, {-64.28199092232774, -63.6132211213727}}],
             StatusArea[#, {{2013, 1, 28}, 27.91}]& ,
             TagBoxNote->"{{2013, 1, 28}, 27.91}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "1", ",", "28"}], "}"}], ",", 
                 "27.91`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 1, 28}, 27.91}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{47.5, 27.91}, {48.5, 28.01}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{227.07302560494935`, 
               231.1003614918249}, {-66.51122359217823, -64.28199092232774}}],
             StatusArea[#, 
              Row[{{{2013, 1, 29}, 28.01}, " ~ ", {{2013, 1, 30}, 27.85}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 29}, 28.01}, \" ~ \", {{2013, 1, 30}, \
27.85}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "29"}], "}"}], ",", 
                   "28.01`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "30"}], "}"}], ",", 
                   "27.85`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 29}, 28.01}, " ~ ", {{2013, 1, 30}, 27.85}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{48.5, 27.45}, {49.5, 27.91}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{231.1003614918249, 
               235.1276973787006}, {-64.28199092232774, -54.02752064101617}}],
             StatusArea[#, 
              Row[{{{2013, 1, 31}, 27.45}, " ~ ", {{2013, 2, 1}, 27.93}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 1, 31}, 27.45}, \" ~ \", {{2013, 2, 1}, 27.93}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "1", ",", "31"}], "}"}], ",", 
                   "27.45`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "1"}], "}"}], ",", 
                   "27.93`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 1, 31}, 27.45}, " ~ ", {{2013, 2, 1}, 27.93}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{49.5, 27.44}, {50.5, 27.45}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{235.1276973787006, 
               239.15503326557626`}, {-54.02752064101617, \
-53.80459737403112}}],
             StatusArea[#, 
              Row[{{{2013, 2, 4}, 27.44}, " ~ ", {{2013, 2, 5}, 27.5}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 4}, 27.44}, \" ~ \", {{2013, 2, 5}, 27.5}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "4"}], "}"}], ",", 
                   "27.44`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "5"}], "}"}], ",", 
                   "27.5`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 4}, 27.44}, " ~ ", {{2013, 2, 5}, 27.5}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{50.5, 27.34}, {51.5, 27.44}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{239.15503326557626`, 
               243.18236915245183`}, {-53.80459737403112, \
-51.57536470418074}}],
             StatusArea[#, {{2013, 2, 6}, 27.34}]& ,
             TagBoxNote->"{{2013, 2, 6}, 27.34}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "2", ",", "6"}], "}"}], ",", 
                 "27.34`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 2, 6}, 27.34}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{51.5, 27.28}, {52.5, 27.34}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{243.18236915245183`, 
               247.2097050393275}, {-51.57536470418074, -50.23782510227056}}],
             StatusArea[#, {{2013, 2, 7}, 27.28}]& ,
             TagBoxNote->"{{2013, 2, 7}, 27.28}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "2", ",", "7"}], "}"}], ",", 
                 "27.28`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 2, 7}, 27.28}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{52.5, 27.34}, {53.5, 27.55}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{247.2097050393275, 
               251.23704092620306`}, {-56.25675331086654, \
-51.57536470418074}}],
             StatusArea[#, {{2013, 2, 8}, 27.55}]& ,
             TagBoxNote->"{{2013, 2, 8}, 27.55}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "2", ",", "8"}], "}"}], ",", 
                 "27.55`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 2, 8}, 27.55}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{53.5, 27.55}, {54.5, 27.86}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{251.23704092620306`, 
               255.26437681307874`}, {-63.167374587402605`, \
-56.25675331086654}}],
             StatusArea[#, {{2013, 2, 11}, 27.86}]& ,
             TagBoxNote->"{{2013, 2, 11}, 27.86}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "2", ",", "11"}], "}"}], ",", 
                 "27.86`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 2, 11}, 27.86}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{54.5, 27.86}, {55.5, 27.88}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{255.26437681307874`, 
               259.2917126999543}, {-63.6132211213727, -63.167374587402605`}}],
             StatusArea[#, {{2013, 2, 12}, 27.88}]& ,
             TagBoxNote->"{{2013, 2, 12}, 27.88}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "2", ",", "12"}], "}"}], ",", 
                 "27.88`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 2, 12}, 27.88}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{55.5, 27.88}, {56.5, 28.03}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{259.2917126999543, 
               263.31904858683}, {-66.95707012614821, -63.6132211213727}}],
             StatusArea[#, {{2013, 2, 13}, 28.03}]& ,
             TagBoxNote->"{{2013, 2, 13}, 28.03}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "2", ",", "13"}], "}"}], ",", 
                 "28.03`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 2, 13}, 28.03}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{56.5, 28.03}, {57.5, 28.04}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{263.31904858683, 
               267.34638447370565`}, {-67.17999339313326, \
-66.95707012614821}}],
             StatusArea[#, 
              Row[{{{2013, 2, 14}, 28.04}, " ~ ", {{2013, 2, 15}, 28.01}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 14}, 28.04}, \" ~ \", {{2013, 2, 15}, \
28.01}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "14"}], "}"}], ",", 
                   "28.04`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "15"}], "}"}], ",", 
                   "28.01`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 14}, 28.04}, " ~ ", {{2013, 2, 15}, 28.01}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{57.5, 28.04}, {58.5, 28.05}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{267.34638447370565`, 
               271.3737203605812}, {-67.40291666011831, -67.17999339313326}}],
             StatusArea[#, {{2013, 2, 19}, 28.05}]& ,
             TagBoxNote->"{{2013, 2, 19}, 28.05}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "2", ",", "19"}], "}"}], ",", 
                 "28.05`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 2, 19}, 28.05}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{58.5, 27.87}, {59.5, 28.04}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{271.3737203605812, 
               275.4010562474568}, {-67.17999339313326, \
-63.390297854387654`}}],
             StatusArea[#, {{2013, 2, 20}, 27.87}]& ,
             TagBoxNote->"{{2013, 2, 20}, 27.87}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "2", ",", "20"}], "}"}], ",", 
                 "27.87`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 2, 20}, 27.87}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{59.5, 27.49}, {60.5, 27.87}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{275.4010562474568, 
               279.42839213433246`}, {-63.390297854387654`, \
-54.91921370895625}}],
             StatusArea[#, 
              Row[{{{2013, 2, 21}, 27.49}, " ~ ", {{2013, 2, 22}, 27.76}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 21}, 27.49}, \" ~ \", {{2013, 2, 22}, \
27.76}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "21"}], "}"}], ",", 
                   "27.49`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "22"}], "}"}], ",", 
                   "27.76`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 21}, 27.49}, " ~ ", {{2013, 2, 22}, 27.76}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{60.5, 27.37}, {61.5, 27.49}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{279.42839213433246`, 
               283.45572802120813`}, {-54.91921370895625, \
-52.24413450513589}}],
             StatusArea[#, 
              Row[{{{2013, 2, 25}, 27.37}, " ~ ", {{2013, 3, 1}, 27.95}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 2, 25}, 27.37}, \" ~ \", {{2013, 3, 1}, 27.95}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "2", ",", "25"}], "}"}], ",", 
                   "27.37`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "1"}], "}"}], ",", 
                   "27.95`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 2, 25}, 27.37}, " ~ ", {{2013, 3, 1}, 27.95}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{61.5, 27.49}, {62.5, 28.15}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{283.45572802120813`, 
               287.4830639080837}, {-69.63214932996857, -54.91921370895625}}],
             StatusArea[#, {{2013, 3, 4}, 28.15}]& ,
             TagBoxNote->"{{2013, 3, 4}, 28.15}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "3", ",", "4"}], "}"}], ",", 
                 "28.15`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 3, 4}, 28.15}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{62.5, 28.15}, {63.5, 28.35}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{287.4830639080837, 
               291.51039979495937`}, {-74.09061466966943, \
-69.63214932996857}}],
             StatusArea[#, 
              Row[{{{2013, 3, 5}, 28.35}, " ~ ", {{2013, 3, 26}, 28.16}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 5}, 28.35}, \" ~ \", {{2013, 3, 26}, 28.16}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "5"}], "}"}], ",", 
                   "28.35`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "26"}], "}"}], ",", 
                   "28.16`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 5}, 28.35}, " ~ ", {{2013, 3, 26}, 28.16}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{63.5, 28.35}, {64.5, 28.37}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{291.51039979495937`, 
               295.53773568183504`}, {-74.53646120363942, \
-74.09061466966943}}],
             StatusArea[#, {{2013, 3, 27}, 28.37}]& ,
             TagBoxNote->"{{2013, 3, 27}, 28.37}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "3", ",", "27"}], "}"}], ",", 
                 "28.37`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 3, 27}, 28.37}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{64.5, 28.37}, {65.5, 28.61}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{295.53773568183504`, 
               299.5650715687106}, {-79.88661961128025, -74.53646120363942}}],
             StatusArea[#, 
              Row[{{{2013, 3, 28}, 28.61}, " ~ ", {{2013, 4, 1}, 28.61}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 3, 28}, 28.61}, \" ~ \", {{2013, 4, 1}, 28.61}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "3", ",", "28"}], "}"}], ",", 
                   "28.61`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "1"}], "}"}], ",", 
                   "28.61`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 3, 28}, 28.61}, " ~ ", {{2013, 4, 1}, 28.61}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{65.5, 28.61}, {66.5, 28.8}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{299.5650715687106, 
               303.59240745558617`}, {-84.12216168399596, \
-79.88661961128025}}],
             StatusArea[#, 
              Row[{{{2013, 4, 2}, 28.8}, " ~ ", {{2013, 4, 8}, 28.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 2}, 28.8}, \" ~ \", {{2013, 4, 8}, 28.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "2"}], "}"}], ",", 
                   "28.8`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "8"}], "}"}], ",", 
                   "28.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 2}, 28.8}, " ~ ", {{2013, 4, 8}, 28.59}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               RectangleBox[{66.5, 28.8}, {67.5, 29.61}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{303.59240745558617`, 
               307.61974334246185`}, {-102.17894630978378`, \
-84.12216168399596}}],
             StatusArea[#, {{2013, 4, 9}, 29.61}]& ,
             TagBoxNote->"{{2013, 4, 9}, 29.61}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "9"}], "}"}], ",", 
                 "29.61`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 9}, 29.61}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{67.5, 29.61}, {68.5, 30.28}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{307.61974334246185`, 
               311.6470792293375}, {-117.11480519778127`, \
-102.17894630978378`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 10}, 30.28}, " ~ ", {{2013, 4, 19}, 29.77}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 10}, 30.28}, \" ~ \", {{2013, 4, 19}, \
29.77}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "10"}], "}"}], ",", 
                   "30.28`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "19"}], "}"}], ",", 
                   "29.77`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 10}, 30.28}, " ~ ", {{2013, 4, 19}, 29.77}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{68.5, 30.28}, {69.5, 30.83}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{311.6470792293375, 
               315.6744151162131}, {-129.37558488195816`, \
-117.11480519778127`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 22}, 30.83}, " ~ ", {{2013, 4, 23}, 30.6}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 22}, 30.83}, \" ~ \", {{2013, 4, 23}, 30.6}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "22"}], "}"}], ",", 
                   "30.83`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "23"}], "}"}], ",", 
                   "30.6`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 22}, 30.83}, " ~ ", {{2013, 4, 23}, 30.6}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{69.5, 30.83}, {70.5, 31.76}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{315.6744151162131, 
               319.70175100308865`}, {-150.10744871156646`, \
-129.37558488195816`}}],
             StatusArea[#, {{2013, 4, 24}, 31.76}]& ,
             TagBoxNote->"{{2013, 4, 24}, 31.76}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "24"}], "}"}], ",", 
                 "31.76`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 24}, 31.76}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{70.5, 31.76}, {71.5, 31.94}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{319.70175100308865`, 
               323.7290868899643}, {-154.12006751729712`, \
-150.10744871156646`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 25}, 31.94}, " ~ ", {{2013, 4, 26}, 31.79}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 25}, 31.94}, \" ~ \", {{2013, 4, 26}, \
31.79}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "25"}], "}"}], ",", 
                   "31.94`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "26"}], "}"}], ",", 
                   "31.79`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 25}, 31.94}, " ~ ", {{2013, 4, 26}, 31.79}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{71.5, 31.94}, {72.5, 32.61}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{323.7290868899643, 
               327.75642277684}, {-169.05592640529449`, \
-154.12006751729712`}}],
             StatusArea[#, {{2013, 4, 29}, 32.61}]& ,
             TagBoxNote->"{{2013, 4, 29}, 32.61}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "4", ",", "29"}], "}"}], ",", 
                 "32.61`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 4, 29}, 32.61}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{72.5, 32.61}, {73.5, 33.1}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{327.75642277684, 
               331.78375866371556`}, {-179.9791664875612, \
-169.05592640529449`}}],
             StatusArea[#, 
              Row[{{{2013, 4, 30}, 33.1}, " ~ ", {{2013, 5, 1}, 32.72}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 30}, 33.1}, \" ~ \", {{2013, 5, 1}, 32.72}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "30"}], "}"}], ",", 
                   "33.1`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "1"}], "}"}], ",", 
                   "32.72`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 30}, 33.1}, " ~ ", {{2013, 5, 1}, 32.72}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{73.5, 33.1}, {74.5, 33.16}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{331.78375866371556`, 
               335.8110945505911}, {-181.31670608947138`, \
-179.9791664875612}}],
             StatusArea[#, {{2013, 5, 2}, 33.16}]& ,
             TagBoxNote->"{{2013, 5, 2}, 33.16}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "2"}], "}"}], ",", 
                 "33.16`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 2}, 33.16}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{74.5, 33.16}, {75.5, 33.49}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{335.8110945505911, 
               339.8384304374669}, {-188.67317389997766`, \
-181.31670608947138`}}],
             StatusArea[#, {{2013, 5, 3}, 33.49}]& ,
             TagBoxNote->"{{2013, 5, 3}, 33.49}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "3"}], "}"}], ",", 
                 "33.49`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 3}, 33.49}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{75.5, 33.49}, {76.5, 33.75}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{339.8384304374669, 
               343.8657663243425}, {-194.46917884158847`, \
-188.67317389997766`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 6}, 33.75}, " ~ ", {{2013, 5, 7}, 33.31}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 6}, 33.75}, \" ~ \", {{2013, 5, 7}, 33.31}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "6"}], "}"}], ",", 
                   "33.75`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "7"}], "}"}], ",", 
                   "33.31`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 6}, 33.75}, " ~ ", {{2013, 5, 7}, 33.31}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{76.5, 32.99}, {77.5, 33.49}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{343.8657663243425, 
               347.89310221121804`}, {-188.67317389997766`, \
-177.5270105507259}}],
             StatusArea[#, {{2013, 5, 8}, 32.99}]& ,
             TagBoxNote->"{{2013, 5, 8}, 32.99}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "8"}], "}"}], ",", 
                 "32.99`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 8}, 32.99}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{77.5, 32.66}, {78.5, 32.99}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{347.89310221121804`, 
               351.9204380980937}, {-177.5270105507259, \
-170.17054274021962`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 9}, 32.66}, " ~ ", {{2013, 5, 13}, 33.03}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 9}, 32.66}, \" ~ \", {{2013, 5, 13}, 33.03}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "9"}], "}"}], ",", 
                   "32.66`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "13"}], "}"}], ",", 
                   "33.03`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 9}, 32.66}, " ~ ", {{2013, 5, 13}, 33.03}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{78.5, 32.99}, {79.5, 33.53}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{351.9204380980937, 
               355.9477739849694}, {-189.56486696791774`, \
-177.5270105507259}}],
             StatusArea[#, {{2013, 5, 14}, 33.53}]& ,
             TagBoxNote->"{{2013, 5, 14}, 33.53}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "14"}], "}"}], ",", 
                 "33.53`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 14}, 33.53}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{79.5, 33.53}, {80.5, 33.85}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{355.9477739849694, 
               359.97510987184495`}, {-196.69841151143885`, \
-189.56486696791774`}}],
             StatusArea[#, {{2013, 5, 15}, 33.85}]& ,
             TagBoxNote->"{{2013, 5, 15}, 33.85}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "15"}], "}"}], ",", 
                 "33.85`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 15}, 33.85}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{80.5, 33.85}, {81.5, 34.08}, "RoundingRadius" -> 
                0]},
              ImageSizeCache->{{359.97510987184495`, 
               364.0024457587205}, {-201.82564665209463`, \
-196.69841151143885`}}],
             StatusArea[#, {{2013, 5, 16}, 34.08}]& ,
             TagBoxNote->"{{2013, 5, 16}, 34.08}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "16"}], "}"}], ",", 
                 "34.08`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 16}, 34.08}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{81.5, 34.08}, {82.5, 34.87}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{364.0024457587205, 
               368.0297816455962}, {-219.43658474391248`, \
-201.82564665209463`}}],
             StatusArea[#, {{2013, 5, 17}, 34.87}]& ,
             TagBoxNote->"{{2013, 5, 17}, 34.87}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "5", ",", "17"}], "}"}], ",", 
                 "34.87`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 5, 17}, 34.87}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{82.5, 34.87}, {83.5, 35.08}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{368.0297816455962, 
               372.05711753247186`}, {-224.11797335059816`, \
-219.43658474391248`}}],
             StatusArea[#, 
              Row[{{{2013, 5, 20}, 35.08}, " ~ ", {{2013, 5, 31}, 34.9}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 5, 20}, 35.08}, \" ~ \", {{2013, 5, 31}, 34.9}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "20"}], "}"}], ",", 
                   "35.08`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "5", ",", "31"}], "}"}], ",", 
                   "34.9`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 5, 20}, 35.08}, " ~ ", {{2013, 5, 31}, 34.9}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{83.5, 35.08}, {84.5, 35.59}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{372.05711753247186`, 
               376.0844534193474}, {-235.4870599668351, \
-224.11797335059816`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 3}, 35.59}, " ~ ", {{2013, 6, 6}, 34.96}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 3}, 35.59}, \" ~ \", {{2013, 6, 6}, 34.96}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "3"}], "}"}], ",", 
                   "35.59`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "6"}], "}"}], ",", 
                   "34.96`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 3}, 35.59}, " ~ ", {{2013, 6, 6}, 34.96}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{84.5, 35.59}, {85.5, 35.67}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{376.0844534193474, 
               380.1117893062231}, {-237.27044610271537`, \
-235.4870599668351}}],
             StatusArea[#, 
              Row[{{{2013, 6, 7}, 35.67}, " ~ ", {{2013, 6, 10}, 35.47}}]]& ,
             TagBoxNote->
              "Row[{{{2013, 6, 7}, 35.67}, \" ~ \", {{2013, 6, 10}, 35.47}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "7"}], "}"}], ",", 
                   "35.67`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "10"}], "}"}], ",", 
                   "35.47`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 7}, 35.67}, " ~ ", {{2013, 6, 10}, 35.47}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{85.5, 34.84}, {86.5, 35.59}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{380.1117893062231, 
               384.1391251930988}, {-235.4870599668351, \
-218.76781494295744`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 11}, 34.84}, " ~ ", {{2013, 6, 12}, 35.}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 11}, 34.84}, \" ~ \", {{2013, 6, 12}, 35.}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "11"}], "}"}], ",", 
                   "34.84`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "12"}], "}"}], ",", 
                   "35.`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 11}, 34.84}, " ~ ", {{2013, 6, 12}, 35.}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{86.5, 34.72}, {87.5, 34.84}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{384.1391251930988, 
               388.16646107997434`}, {-218.76781494295744`, \
-216.09273573913697`}}],
             StatusArea[#, {{2013, 6, 13}, 34.72}]& ,
             TagBoxNote->"{{2013, 6, 13}, 34.72}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "6", ",", "13"}], "}"}], ",", 
                 "34.72`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 6, 13}, 34.72}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{87.5, 34.4}, {88.5, 34.72}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{388.16646107997434`, 
               392.1937969668499}, {-216.09273573913697`, \
-208.95919119561574`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 14}, 34.4}, " ~ ", {{2013, 6, 19}, 34.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 14}, 34.4}, \" ~ \", {{2013, 6, 19}, 34.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "14"}], "}"}], ",", 
                   "34.4`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "19"}], "}"}], ",", 
                   "34.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 14}, 34.4}, " ~ ", {{2013, 6, 19}, 34.59}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{88.5, 33.49}, {89.5, 34.4}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{392.1937969668499, 
               
               396.2211328537256}, {-208.95919119561574`, \
-188.67317389997766`}}],
             StatusArea[#, {{2013, 6, 20}, 33.49}]& ,
             TagBoxNote->"{{2013, 6, 20}, 33.49}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "6", ",", "20"}], "}"}], ",", 
                 "33.49`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 6, 20}, 33.49}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{89.5, 33.27}, {90.5, 33.49}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{396.2211328537256, 
               400.24846874060125`}, {-188.67317389997766`, \
-183.76886202630692`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 21}, 33.27}, " ~ ", {{2013, 7, 10}, 34.7}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 21}, 33.27}, \" ~ \", {{2013, 7, 10}, 34.7}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "21"}], "}"}], ",", 
                   "33.27`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "10"}], "}"}], ",", 
                   "34.7`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 21}, 33.27}, " ~ ", {{2013, 7, 10}, 34.7}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{90.5, 33.49}, {91.5, 35.69}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{400.24846874060125`, 
               404.2758046274768}, {-237.71629263668535`, \
-188.67317389997766`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 11}, 35.69}, " ~ ", {{2013, 7, 12}, 35.67}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 11}, 35.69}, \" ~ \", {{2013, 7, 12}, \
35.67}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "11"}], "}"}], ",", 
                   "35.69`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "12"}], "}"}], ",", 
                   "35.67`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 11}, 35.69}, " ~ ", {{2013, 7, 12}, 35.67}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{91.5, 35.69}, {92.5, 36.17}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{404.2758046274768, 
               408.3031405143524}, {-248.41660945196713`, \
-237.71629263668535`}}],
             StatusArea[#, {{2013, 7, 15}, 36.17}]& ,
             TagBoxNote->"{{2013, 7, 15}, 36.17}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "15"}], "}"}], ",", 
                 "36.17`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 7, 15}, 36.17}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{92.5, 36.17}, {93.5, 36.27}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{408.3031405143524, 
               412.33047640122805`}, {-250.6458421218175, \
-248.41660945196713`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 16}, 36.27}, " ~ ", {{2013, 7, 18}, 35.44}}]]& ,
             TagBoxNote->
              "Row[{{{2013, 7, 16}, 36.27}, \" ~ \", {{2013, 7, 18}, \
35.44}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "16"}], "}"}], ",", 
                   "36.27`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "18"}], "}"}], ",", 
                   "35.44`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 16}, 36.27}, " ~ ", {{2013, 7, 18}, 35.44}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{93.5, 31.4}, {94.5, 36.17}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{412.33047640122805`, 
               416.35781228810373`}, {-248.41660945196713`, \
-142.08221110010516`}}],
             StatusArea[#, 
              Row[{{{2013, 7, 19}, 31.4}, " ~ ", {{2013, 7, 24}, 31.96}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 19}, 31.4}, \" ~ \", {{2013, 7, 24}, 31.96}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "31.4`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "24"}], "}"}], ",", 
                   "31.96`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 19}, 31.4}, " ~ ", {{2013, 7, 24}, 31.96}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{94.5, 31.39}, {95.5, 31.4}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{416.35781228810373`, 
               420.3851481749793}, {-142.08221110010516`, \
-141.8592878331201}}],
             StatusArea[#, {{2013, 7, 25}, 31.39}]& ,
             TagBoxNote->"{{2013, 7, 25}, 31.39}"],
            StyleBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "25"}], "}"}], ",", 
                 "31.39`"}], "}"}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[{{2013, 7, 25}, 31.39}, {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], 
            "Tooltip"]& ]}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}}, {}, 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 25.875}, {95.5, 25.875}}], {}}, {{
             LineBox[{{0.5, 25.875}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 25.875}]}], 
             LineBox[{{95.5, 25.875}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {95.5, 
                25.875}]}], {{}, {}, {
               LineBox[{{42.5, 25.875}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {42.5, 25.875}]}], 
               LineBox[{{42.5, 25.875}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {42.5, 
                  25.875}]}]}}}, {
             InsetBox["\<\"2012\"\>", Offset[{0., -2.}, {21.5, 25.875}], {0, 1},
               Automatic, {1, 0}], 
             InsetBox["\<\"2013\"\>", Offset[{0., -2.}, {69., 25.875}], {0, 1},
               Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->True],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, Automatic},
       GridLines->
        FrontEndValueCache[{{{7.5, {}}, {14.5, {}}, {24.5, {}}, {32.5, {}}, {
           42.5, {}}, {48.5, {}}, {60.5, {}}, {64.5, {}}, {72.5, {}}, {
           83.5, {}}, {89.5, {}}, {42.5, 
            Directive[
             Dashing[{}]]}}, 
          FindDivisions[{#, #2}, 6]& }, {{{7.5, {}}, {14.5, {}}, {24.5, {}}, {
           32.5, {}}, {42.5, {}}, {48.5, {}}, {60.5, {}}, {64.5, {}}, {
           72.5, {}}, {83.5, {}}, {89.5, {}}, {42.5, 
            Directive[
             Dashing[{}]]}}, {24., 26., 28., 30., 32., 34., 36., 38.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "LineBreakChart", "\" of \"", "\"Microsoft Corporation\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.02]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            Identity[#], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[25.875]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{24., 
            FormBox["24.`", TraditionalForm]}, {26., 
            FormBox["26.`", TraditionalForm]}, {28., 
            FormBox["28.`", TraditionalForm]}, {30., 
            FormBox["30.`", TraditionalForm]}, {32., 
            FormBox["32.`", TraditionalForm]}, {34., 
            FormBox["34.`", TraditionalForm]}, {36., 
            FormBox["36.`", TraditionalForm]}, {38., 
            FormBox["38.`", TraditionalForm]}}}]], {576., -358.76873046931394`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{0.525, 29.099999999999998`}, {1.475, 31.2}, 
                "RoundingRadius" -> 0]},
              
              ImageSizeCache->{{40.50732571541457, 
               76.51745625638421}, {-140.46099110158718`, \
-93.19392470853165}}],
             StatusArea[#, 
              Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 9, 27}, 30.16}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 7, 26}, 29.16}, \" ~ \", {{2012, 9, 27}, \
30.16}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "7", ",", "26"}], "}"}], ",", 
                   "29.16`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "27"}], "}"}], ",", 
                   "30.16`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 7, 26}, 29.16}, " ~ ", {{2012, 9, 27}, 30.16}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{1.525, 27.9}, {2.475, 30.9}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{78.41272628485628, 
               114.42285682582593`}, {-133.70855304543647`, \
-66.18417248392848}}],
             StatusArea[#, 
              Row[{{{2012, 9, 28}, 29.76}, " ~ ", {{2012, 10, 31}, 28.54}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 9, 28}, 29.76}, \" ~ \", {{2012, 10, 31}, \
28.54}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "9", ",", "28"}], "}"}], ",", 
                   "29.76`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "10", ",", "31"}], "}"}], ",", 
                   "28.54`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 9, 28}, 29.76}, " ~ ", {{2012, 10, 31}, 28.54}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{2.525, 28.2}, {3.475, 29.7}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{116.31812685429799`, 
               152.32825739526766`}, {-106.6988008208333, -72.9366105400793}}],
             StatusArea[#, 
              Row[{{{2012, 11, 1}, 29.52}, " ~ ", {{2012, 11, 9}, 28.83}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 1}, 29.52}, \" ~ \", {{2012, 11, 9}, \
28.83}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "1"}], "}"}], ",", 
                   "29.52`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "9"}], "}"}], ",", 
                   "28.83`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 1}, 29.52}, " ~ ", {{2012, 11, 9}, 28.83}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{3.525, 26.4}, {4.475, 29.4}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{154.2235274237397, 
               190.23365796470932`}, {-99.94636276468248, \
-32.42198220317448}}],
             StatusArea[#, 
              Row[{{{2012, 11, 12}, 28.22}, " ~ ", {{2012, 12, 19}, 27.31}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 11, 12}, 28.22}, \" ~ \", {{2012, 12, 19}, \
27.31}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "11", ",", "12"}], "}"}], ",", 
                   "28.22`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "19"}], "}"}], ",", 
                   "27.31`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 11, 12}, 28.22}, " ~ ", {{2012, 12, 19}, 27.31}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{4.525, 26.7}, {5.475, 30.}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{192.12892799318143`, 
               228.13905853415105`}, {-113.45123887698412`, \
-39.1744202593253}}],
             StatusArea[#, 
              Row[{{{2012, 12, 20}, 27.68}, " ~ ", {{2013, 4, 11}, 28.94}}]]& ,
             
             TagBoxNote->
              "Row[{{{2012, 12, 20}, 27.68}, \" ~ \", {{2013, 4, 11}, \
28.94}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2012", ",", "12", ",", "20"}], "}"}], ",", 
                   "27.68`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "11"}], "}"}], ",", 
                   "28.94`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2012, 12, 20}, 27.68}, " ~ ", {{2013, 4, 11}, 28.94}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{5.525, 28.8}, {6.475, 29.7}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{230.03432856262316`, 
               266.04445910359277`}, {-106.6988008208333, \
-86.44148665238095}}],
             StatusArea[#, 
              Row[{{{2013, 4, 12}, 28.79}, " ~ ", {{2013, 4, 19}, 29.77}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 12}, 28.79}, \" ~ \", {{2013, 4, 19}, \
29.77}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "12"}], "}"}], ",", 
                   "28.79`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "19"}], "}"}], ",", 
                   "29.77`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 12}, 28.79}, " ~ ", {{2013, 4, 19}, 29.77}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{6.525, 29.1}, {7.475, 35.4}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{267.9397291320649, 
               303.9498596730345}, {-234.99512388769836`, \
-93.19392470853177}}],
             StatusArea[#, 
              Row[{{{2013, 4, 22}, 30.83}, " ~ ", {{2013, 6, 19}, 34.59}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 4, 22}, 30.83}, \" ~ \", {{2013, 6, 19}, \
34.59}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "4", ",", "22"}], "}"}], ",", 
                   "30.83`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "19"}], "}"}], ",", 
                   "34.59`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 4, 22}, 30.83}, " ~ ", {{2013, 6, 19}, 34.59}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{7.525, 33.3}, {8.475, 35.1}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{305.8451297015066, 
               341.8552602424762}, {-228.24268583154765`, \
-187.7280574946427}}],
             StatusArea[#, 
              Row[{{{2013, 6, 20}, 33.49}, " ~ ", {{2013, 6, 26}, 34.35}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 20}, 33.49}, \" ~ \", {{2013, 6, 26}, \
34.35}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "20"}], "}"}], ",", 
                   "33.49`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "26"}], "}"}], ",", 
                   "34.35`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 20}, 33.49}, " ~ ", {{2013, 6, 26}, 34.35}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.7, 0.8, 0.3], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{8.525, 33.6}, {9.475, 36.}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{343.75053027094833`, 
               379.76066081191794`}, {-248.5, -194.48049555079365`}}],
             StatusArea[#, 
              Row[{{{2013, 6, 27}, 34.62}, " ~ ", {{2013, 7, 18}, 35.44}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 6, 27}, 34.62}, \" ~ \", {{2013, 7, 18}, \
35.44}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "6", ",", "27"}], "}"}], ",", 
                   "34.62`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "18"}], "}"}], ",", 
                   "35.44`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 6, 27}, 34.62}, " ~ ", {{2013, 7, 18}, 35.44}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], "Tooltip"]& ]}, 
         {RGBColor[0.8, 0.2, 0.2], 
          TagBox[
           TooltipBox[
            TagBox[
             DynamicBox[{
               FEPrivate`If[
                CurrentValue["MouseOver"], 
                EdgeForm[{
                  GrayLevel[0.5], 
                  AbsoluteThickness[1.5], 
                  Opacity[0.66]}], {}, {}], 
               
               RectangleBox[{9.525, 31.5}, {10.475, 35.7}, "RoundingRadius" -> 
                0]},
              
              ImageSizeCache->{{381.65593084039006`, 
               417.66606138135967`}, {-241.7475619438493, -147.213429157738}}],
             StatusArea[#, 
              Row[{{{2013, 7, 19}, 31.4}, " ~ ", {{2013, 7, 25}, 31.39}}]]& ,
             
             TagBoxNote->
              "Row[{{{2013, 7, 19}, 31.4}, \" ~ \", {{2013, 7, 25}, 31.39}}]"],
            StyleBox[
             TemplateBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "19"}], "}"}], ",", 
                   "31.4`"}], "}"}], "\" ~ \"", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"{", 
                    RowBox[{"2013", ",", "7", ",", "25"}], "}"}], ",", 
                   "31.39`"}], "}"}]}, "RowDefault"], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Row[{{{2013, 7, 19}, 31.4}, " ~ ", {{2013, 7, 25}, 31.39}}], {
              GrayLevel[0], 
              Directive[], 
              Directive[]}], 
            "Tooltip"]& ]}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, 
        TagBox[
         StyleBox[{{{}, 
            LineBox[{{0.5, 25.799999999999997`}, {10.5, 
             25.799999999999997`}}], {}}, {{
             LineBox[{{0.5, 25.799999999999997`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {0.5, 
                25.799999999999997`}]}], 
             LineBox[{{10.5, 25.799999999999997`}, 
               Offset[{-1.4695761589768238`*^-15, -8.}, {10.5, 
                25.799999999999997`}]}], {{}, {}, {
               LineBox[{{4.5, 25.799999999999997`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {4.5, 
                  25.799999999999997`}]}], 
               LineBox[{{4.5, 25.799999999999997`}, 
                 Offset[{-7.347880794884119*^-16, -4.}, {4.5, 
                  25.799999999999997`}]}]}}}, {
             InsetBox["\<\"2012\"\>", 
              Offset[{0., -2.}, {2.5, 25.799999999999997`}], {0, 1}, 
              Automatic, {1, 0}], 
             InsetBox["\<\"2013\"\>", 
              Offset[{0., -2.}, {7.5, 25.799999999999997`}], {0, 1}, 
              Automatic, {1, 0}]}}}, "GraphicsAxes",
          StripOnInput->False,
          Antialiasing->True],
         Deploy,
         DefaultBaseStyle->"Deploy"]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, True},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, Automatic},
       GridLines->
        FrontEndValueCache[{{{1.5, {}}, {2.5, {}}, {3.5, {}}, {4.5, {}}, {
           6.5, {}}, {8.5, {}}, {4.5, 
            Directive[
             Dashing[{}]]}}, 
          FindDivisions[{#, #2}, 6]& }, {{{1.5, {}}, {2.5, {}}, {3.5, {}}, {
           4.5, {}}, {6.5, {}}, {8.5, {}}, {4.5, 
            Directive[
             Dashing[{}]]}}, {24., 26., 28., 30., 32., 34., 36., 38.}}],
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[1], 
         GrayLevel[0.5]],
       PlotLabel->FormBox[
         TemplateBox[{
          "PointFigureChart", "\" of \"", "\"Microsoft Corporation\"", 
           "\" for last \"", "365", "\" days\""}, "RowDefault"], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangePadding->{{None, None}, {None, 
          Scaled[0.02]}},
       Ticks->FrontEndValueCache[{Automatic, Map[{
            N[
             Identity[#]], 
            N[#]}& , 
           DeleteCases[
            FindDivisions[{
              If[Identity === Identity, #, 
               Identity[25.799999999999997`]], 
              Identity[#2]}, 6], 0]]& }, {Automatic, {{24., 
            FormBox["24.`", TraditionalForm]}, {26., 
            FormBox["26.`", TraditionalForm]}, {28., 
            FormBox["28.`", TraditionalForm]}, {30., 
            FormBox["30.`", TraditionalForm]}, {32., 
            FormBox["32.`", TraditionalForm]}, {34., 
            FormBox["34.`", TraditionalForm]}, {36., 
            FormBox["36.`", TraditionalForm]}, {38., 
            FormBox["38.`", TraditionalForm]}}}]], {192., -597.9478841155233},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499622}], 
     TagBox[InsetBox["", {576., -597.9478841155233}, {Center, Center}, {360., 222.4922359499622}],
      "InsetString"]}}, {}},
  ContentSelectable->True,
  ImageSize->{730, 700},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.583806516841095*^9, 3.5838066287564964`*^9, {3.5838066793233886`*^9, 
   3.58380671361535*^9}, 3.583806932757884*^9}]
}, {2}]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 5: \[Delta] - \[Gamma] Hedges for a list of securities\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}, {3.583805545995566*^9, 
  3.583805546363587*^9}, {3.5838068151691585`*^9, 3.583806822049552*^9}, {
  3.5838069601934533`*^9, 3.583806960626478*^9}, {3.58380760213317*^9, 
  3.583807631092827*^9}, {3.5838116233511705`*^9, 3.583811629062497*^9}}],

Cell["\<\
1)  Added Value: The evaluation of a range of powerful derivative products \
which can be used to replicate the behavior of an underlying stock that we \
wish to hedge against in the market.

2)  Caption: In order to minimize the risk associated with a particular stock \
it is often necessary to hedge against the variability in that stock by \
trying to statically replicate its behavior using a range of derivative \
products. The following table provides graphs and tables which show how \
successfully different options can replicate any given stock.

3)  Why we are better: We are able to combine graphs and tables with the \
computation of complex financial derivatives to show which instruments would \
best be used in an immunised portfolio to hedge against the risky behavior of \
any given stock. Very few other financial programs have such a range of \
capability for both computation and graphics.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}, {
   3.5841523050128965`*^9, 3.584152336611704*^9}, {3.5841524176203375`*^9, 
   3.584152584884905*^9}, {3.5841526407420993`*^9, 3.584152706260847*^9}, {
   3.5841527365015764`*^9, 3.584153095111088*^9}}],

Cell[CellGroupData[{

Cell["\<\
Various \[Delta] - \[Gamma] Hedges designed to replicate underlying securities\
\>", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9, 
   3.5838068609627776`*^9, {3.583811423989768*^9, 3.5838114473181024`*^9}, {
   3.5838116356548743`*^9, 3.5838116388550577`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Comany:  \[Delta] - \[Gamma] Hedges for General Electric\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"price", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<GE\>\"", ",", "\"\<Close\>\""}], "]"}]}], ",", "\n", 
     RowBox[{"div", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<GE\>\"", ",", "\"\<DividendYield\>\""}], "]"}]}], ",", 
     "\n", 
     RowBox[{"vol", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<GE\>\"", ",", "\"\<Volatility50Day\>\""}], "]"}]}]}], 
    "}"}], ",", 
   RowBox[{"Column", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"DeltaGammaHedge", "[", 
       RowBox[{"#", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", 
           RowBox[{"Switch", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"-", "1"}], "]"}], "]"}], ",", "\"\<Put\>\"", ",", 
             RowBox[{"1.1", "*", "price"}], ",", "\"\<Call\>\"", ",", 
             RowBox[{"0.9", "*", "price"}]}], "]"}]}], ",", " ", 
          RowBox[{"\"\<Expiration\>\"", "\[Rule]", "1"}]}], "}"}], ",", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<InterestRate\>\"", "\[Rule]", " ", "0.002"}], ",", 
          RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", " ", "price"}], ",", " ", 
          RowBox[{"\"\<Dividend\>\"", "\[Rule]", "div"}], ",", " ", 
          RowBox[{"\"\<Volatility\>\"", "\[Rule]", "vol"}]}], "}"}]}], "]"}], 
      "&"}], " ", "/@", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Call\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Put\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Put\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Put\>\""}], 
        "}"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4952132473995705`*^9, 3.4952132521652565`*^9}, {
   3.495213350994646*^9, 3.4952133583228655`*^9}, {3.495213543793989*^9, 
   3.4952136202637177`*^9}, {3.495213665498672*^9, 3.495213671217495*^9}, {
   3.4952138342352066`*^9, 3.49521388523586*^9}, {3.495214258316529*^9, 
   3.495214258785261*^9}, {3.4952142910183983`*^9, 3.4952142992055836`*^9}, {
   3.4952144392314568`*^9, 3.4952144771206264`*^9}, {3.495214566712267*^9, 
   3.495214641117564*^9}, {3.4952147925062513`*^9, 3.495214857458545*^9}, 
   3.4952157716963673`*^9, 3.495217663645976*^9, {3.495217869427843*^9, 
   3.4952178964276705`*^9}, {3.495217986192721*^9, 3.4952179896926985`*^9}, {
   3.4952180212862463`*^9, 3.495218065551588*^9}, {3.495218096770138*^9, 
   3.495218188113773*^9}, 3.495218579474202*^9, 3.4952187111469197`*^9, {
   3.495218744162756*^9, 3.4952187494596653`*^9}, {3.4952188203038683`*^9, 
   3.4952188234288883`*^9}, {3.4952188554603434`*^9, 3.495218855882221*^9}, 
   3.4952193374946785`*^9, {3.495219376463678*^9, 3.4952193790886946`*^9}, {
   3.4952200570149083`*^9, 3.4952200623743176`*^9}, {3.495284465908083*^9, 
   3.4952844775800323`*^9}, 3.4952845197053022`*^9, 3.4952845616586957`*^9, {
   3.4952849458174047`*^9, 3.495285022739772*^9}, 3.4952862327631407`*^9, {
   3.495286510280542*^9, 3.4952865144524436`*^9}, {3.4952868488452086`*^9, 
   3.4952868826422997`*^9}, {3.4952869897992353`*^9, 3.49528709048738*^9}, 
   3.495289290188958*^9, {3.5074663423934727`*^9, 3.5074663636966915`*^9}, {
   3.5074664743380194`*^9, 3.5074664747750444`*^9}, {3.507466817002334*^9, 
   3.507466827797553*^9}, {3.5074673499480743`*^9, 3.507467356656086*^9}, {
   3.5206175359046288`*^9, 3.5206175365956974`*^9}, {3.5206177430003357`*^9, 
   3.520617743762412*^9}, {3.520618657824809*^9, 3.52061867133616*^9}, {
   3.520620080156826*^9, 3.520620080416696*^9}, {3.5206205246678495`*^9, 
   3.5206205380078497`*^9}, {3.521404919171875*^9, 3.521404928890625*^9}, 
   3.5214224365625*^9, {3.583807556758575*^9, 3.5838075621658845`*^9}, {
   3.5838078753357964`*^9, 3.583807875783822*^9}, {3.583810013153073*^9, 
   3.5838100155212083`*^9}, {3.583810051865287*^9, 3.583810120946238*^9}, {
   3.583810170594078*^9, 3.5838102168347225`*^9}, {3.583810322754781*^9, 
   3.583810342531912*^9}, {3.583810413027944*^9, 3.5838104695401764`*^9}, {
   3.5838105125326357`*^9, 3.5838105444364605`*^9}, 3.5838106047409096`*^9, {
   3.583810677430067*^9, 3.583810679156166*^9}, {3.583810755253518*^9, 
   3.583810820584255*^9}, 3.583810851176005*^9, {3.58381092189705*^9, 
   3.583811064615213*^9}, {3.5838115190182033`*^9, 3.5838115191772127`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         TemplateBox[{GraphicsBox[{{}, {{}, {}, {
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               LineBox[CompressedData["
1:eJwVxXk0FHgAB3Dkmsy4UhjHYF9yxHszDDPM+H0jSy1eFKVFXrGGZLRR0YHF
qohc1bLMi6VNT5lFpVMGm/Rk1QxSUm1DJS3KMTl294/P+1juFgZFqygpKQX9
5//lKdXMc1lO+ItoGuXk9xLNmh2MG3VOiG4RBh806SN2vTTaYK8TRlrCU3dL
nhC/r22K+RknrLu5V4/kSInQ+vAY3cwZnpezdBZj+klhoIPM3csZ5pS7Wpk/
DJLGo68lYbHOaH6/jogzh4j04jnxsQJn2G584RPZ+oLM9vmJKpud4WOzc6he
e4QYLymfvjfkjF3LLdHN/q8Iz/Z66ogyG48c6ZSqitckYlu8QNmGDW+KwZvu
pTckPc0yxCqADfPtFnuy9r8lVXUyL68kNgZVtezWzMhJuzSXGVXGxtB9/c0P
8saIXGkDI7uVDUNW1GI/+z3RXD9DrZWzoeHE+TNt8gOx235Z0Ul1QeRvhRaT
9z4S/58ix0ZZLnD8cZPGjgufiLB+tUwz1AVTv/bkfnz4DykceCixTXPB7O3Z
0e6eSdK4Il28ucYF+dmbj297PkWkjmzR3m4X2AzSugqmp8ls6Pu8vEkX0P3s
E7MMvhB6tii13tAVoUeLm9hkhvAatgl6+K4wbhwWVB+YJRFDlJBPe1zBqO1u
7xbPkXT1e166p1yxWJ9U+/v8PKliJjGZDa64NJ7YwfruK2kPs2UEyVzxCysw
cFftApHnDFMPLLhi2Pr595ZaS0SzsVhRbMVBUJvCKC5lmdgP+441+XJAOe/b
U3xYCf6UJak0gYNxoaTgG64yhM6NkpkSDmSePsLQJWUU7hKIDW9xkHtjn5Ld
AxU0njITcV5xYPXpysSJsysga+7LC9XgYlxtYFEQq4q5kZzUVAcuvlywKr4N
NdCpfEH5Vi7UN4mNk03VwXOdCr6dwkXDkUd3MhfUEbH7otcLERe5Z/cuD4xo
IP10GHOpgwv5smwuqksTVTf0GIxxLkQR8YWG1yhof9NJhb4behLp4SO1KzGq
fVQRyXHDg4FLPVfKtUBxY45lRLhhIGN/3/4SKuyj5dKqLDe8owU7GRXS4H+m
XCKpc4PeH6o3Cwu1Iby1Rfx3rxvWHSuyfVyqgyK5mkht1g25ftPDLwN00aR3
K8/azB268cu0i091IeMlpvp4uWNCa3KQFaaHuZi1AkGsOzyv1rEy3uqBXvws
+GSBO3rtavJLEvXBu1vgVdfsDlaFzmD4oj4i3m1kdg+5o4kWd70hdxXSDRTm
48o8bL1WlZBsYoAqcpVKs+FBlOzQplNvgI64KIVDAA+NPO0M1Q2rMVpqPBaQ
xMNOzcEYZv9qUO73SIVlPFh96HzZm7AG9uOZkjOtPORUML0dNQwRYMgVi+U8
ZG7Nrh4UGSLRc6Kyj8pHRn7Q6EGOEYr2VedNs/h4TL9j+aXXCE3nd6QahPJB
M70anBBrDJmEJmCn8dEuS1OaVKZjbqItOKSGj4ojgU8OldFBpx/2OtTNx4z1
iUcLLBPwvB2Y5yf5kNlqv03rNkFE4mvzFkMPPAz1nleJMkV6+TnqM74HPLpk
135eMEV1p59CsccD9ckhtStLzdAxqTxmcsoDsuKTcfkO5hg1vS7lNXjApC5g
lX6nOVb6xkvCZR74ttfmfmkEA+sPWIqPL3hg6sLnFONZBgIqZZUiK4LGtaSs
x8cCiV25ea2+BPEp/cm6JRYo+ozUVwkE/l+btgSNWKCJMROjUkpAeSq3L1lv
iX8BmoxNVw==
                "]]}, {
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               LineBox[CompressedData["
1:eJwVzGs0lAkAh3GDNGoUIgxj4pxViWqai7m//0y7yYlCxFZTK2oS0Uk3226z
FSKS5KR0TLkkWmVcVp3Ui1GRrmomsZXUzlC2kNAUbfvhOc+3n1tkfHC0qYmJ
SfD3/r9+bxHr5CE2zppuZfREfiapJeHMK+VscA7t8+OdHiU9H1pZPXvIxt1J
R3ekP/pELv/SZPw8wkZUqqrgBXWYjPfY00tncDBAVbcuwhCZHeStE8k4OJze
NJyye4Cs3tejWbuFA7HjBeKvdf+S2tKT6t+yOIh1bsuV3+0jR9uXqwpqOTjj
+v6dhUhPOk1QMskuDlrcbHwvl/WQ4rl1Sd0ULhqWKRZeXviClK+KVVDmcDFr
5aW/v1k9JZX73cLcA7kY+LPX5pzuAVlYrpPJErmovJoY45vdSDZrj7CiTnOh
ZFs4uq4/TepNFjOTG757EfqWT0O1BNVrhHZe/92bZTjyTNpKeK6+aLxF46Ey
rcLJpekxEXBgQ69hEQ+HD26Oa3vTScRX2OuoETycuHFsw3WzV0R2xx3N3P08
RF2Lm2Kf+4aoNlOq/Ut44F/xr4n16CW087mqrW08UGtny5vr3hGjEW8zMgZ5
6FSbU12WfSDoyaqkCgcf/PJ0oEMQN0iIK1cp7kt8cCf0ZcU/3I+EvMsy7MNG
H7Cf3DuQPTFMKC1ImXW6D/KD61dLbo8QhaxEFqvSB+aPyr36ssaI5rVzmcE6
H8StOEXJDTcS+tQXtB1ffaC9l6qD21eCWp1jzHHnQ7p818X+vnFi3gu/3ho/
PqruRCnzqr4RAZYTWu02Po4Wl3kWXjdBPKdaM3KCj6bXs+zHzlGQvV6hdrjG
x4h73reAFFNUpzNU/Fd8eEZOf1sUYwZdbXtGxGQBos+lPPkcaI6x7tSkJG8B
TnWP31jBngQ6TaLIDxHgPnNnWYmDBcQ+Q6H1ewUwXd+f8+WLBeSRpbLnKgF4
BRt/D+qeDGXmWtbETQFinncqSpupKLxiw2T2C6ByCQ4Zv2CJ5te3aLAV4vGa
VklI5hQYpu0zbuALMS0fc8q2T4WlkNX7h1wI384622+hNMyL1msLDwmxy2nB
+CqhFQKO5Ws05UKUh583lLtOQ/y1leo3D4V4eZLRbmI2Hcf1k1STRoVwenqi
PswwHTU21zI8GCLMnpoSoou2hk6ckLRUJkJjeaMfpcMaY5t/UCi2iLDGf1zi
5W8Dek5naFqWCJ/6+OzV9TYQ38iSldeKkJWWOOfAfFvI+5aw2rpE8Jxbyag4
awulndG1nyJGc8s72w7bGSgkLtOs5oghV8ymmiXPwM2YKKN3oBhfJm8c9x6d
AUOuU29gohi5pQVD4VvsYNl4Xxt/WoyFSzsNB7vsMK//oOZYgxh39PbPLwXY
I9BBoFbrxdiUEtT+jLRHgu/7gnaaBBSPzNvmi2bieFxRxsdFEuTfbKlfUDwT
NXnhSXYREnCjzat+nukAncZKwd0vwUNzlCYfdsDY+6bQsBIJYop/PVNpdACd
vke2u00C8yV12V2xjhD/6M3KG5Sg4PVQisVLR8gTelyvOkjBPzh/HyvICcr8
k7ROiRTt7jHb12qcUHRrudG4UYqEppJNqVw6bg5Sep3TpZgS+WpNVSkdBpc6
rbhSimIKI+i5kzOm+MVq1umkWHwu/CdqhjO8dripf/8qRRdOiNgTzggs0BWo
3Ans7H6wUJ7ggoTWIxkNfgSmK6d6pPW44Pgwkl5tI1DGXOpcs4qBGubIZtNc
AkvIA9YvbzHwH0lKT/E=
                "]]}, {
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               LineBox[CompressedData["
1:eJwVi31YDHYAx+9yKF2opLperpKXVLPTXffSXb8vN8Ryz0jSsySFrpxKmnFC
RUNC9IborJjJLKcXbUXldFu1p1V2R2WU6Trp6UX0crXM/vg8n38+H+fw2I07
jSgUysZP/G/dwUJW7nEvJEUvu9psqCLGN7YwK4q8wHvHCrRZ9IgsbTYza2v2
gvRaC7PEQk38Jx4Zxke8QKnZ/zNP3EBiFx3QMxzYMN7gTL11v4mc3+Cp9RGz
8dMtvalRRQspSXylColi42SEeNzV+y+iuZmrPHyODZr2mp9IqyWjrf6K/DI2
2FSqYd3FNmI7RT1T3cGGTXeEmSTxORG63Zd3UjmoSq5PWZ3ykoRukkmpSziQ
v7XxZAR2kaSjzptdJBzExzfVmxpekYIirVicwMGDwFTrseLX5LHmNGvHZQ62
ZYvmv9yvIzrKCmZqDQchrNG6GomeGHuM0H/QcXDb7d6iq9xesjTotkFN98bG
IzG8BFYfWZ8Spu9Z7o3wZR4Tq4T9JPaOldY42Bsh+d9wTTwGyflnDSq3o95Y
/kRTL1s5REqmJSnX3fAGp7y8dP32d0TzGUexu/HTv8Zm7PbJYTIa3JuePuSN
qu8MmScq3hNGqkJ+x5oLv4StJzsHPxDh3U3SJhEX43NWaMpZoyS0w2TzQAQX
muAb8lmHxkjSjGrx3DQunm9IO9DxxzgpYCWwWHe5mDM20OS2eII8DnFjbtRy
EeOvPfzh1CTRnXhB3zfJxahElOr74V9iXJJpyHTh4c5H125a1Efi/sJPX+rH
w5fFasn1eArWm0xpNDE8tHJ8ntI4VMSyS1QjWTzEWA6aXp+g4vw2qdK6kgcn
v+6+ZLURStIcFLwuHnqeMOT52dOgLWtND57JR0N5Rsm4lIaxzhNyuScfDwZX
X8rEdDDoImleAB/qZJG7zH4GhNx3gVUH+eiOSog6NjkDoeE3xX8r+LC99Tag
rXMmks6EsKbq+Agnhb176o1RUGHOZPbxofLI81xRboLH/6jpsBCAt/eJfcDN
WeiZnWgI4wnQSPevKLxiChMBS58cKoDsI43ilUOH+06dpuC4AC5rp4YpWWZY
n5GnUhUJ0P+Gm2WWMxuxlV8pXzcL0NKl7NxyZQ4u6KYrpo8KILUpl+0NmItS
88r0RQ4+iNvtVa1pnwutME6+RuwDam9zZPAOc4xFLpRKo3zgmHV21+SAORiZ
7YGnzvmgLkpW+fCwBYQPz4mLynwwFh2965qZJULffMFq7PBBee7JyO8Vlkia
Z3DsowoxNaB+WOs1DwWkmG62RIiWfQtl1IZ5qIveYfCUCOG14HpsWLgVerJt
9ZIEIeymVta/mLSCSW2TJvayEBk0o4OJl+bDve+YKqNGiLPeXUf4PGtIrPlK
pe5Tn9XZbtVmjbiV/fmtdBE+d6CcMU+0wYU9henDy0X4s4VkezjbovTiFvm8
YBEMSsXwrt9toVWZSTlHRSh+wPyxZi8DY/2PAjffEGHgffU9voMdGIwD4m8b
Rfg1KMmytcEOwlWerItDIszRhTWcktsjNO6V4y/WvhhUbH8a5uGApLxcervI
F1+npgiCOh1QqPY3GCJ8EZSjGpblOKJuiKq3S/PFs1bXaQUSJnrs72uEd30R
7xDAPkRzwiw/mWqr1hfoWWBRFu4Ej33OyiOTvmhR0/Kmap0gydfmK1wIFld9
aApycUZc/en0Gj8C8W8jd2qOOePCe8i7Yghc9TN5fJ0zSpkjkUbZBI2Obntq
17rgP/4WSlY=
                "]]}}, {}}, AspectRatio -> 
            NCache[GoldenRatio^(-1), 0.6180339887498948], 
            AxesOrigin -> {19.517932035838292`, 0}, Frame -> True, 
            FrameLabel -> {{
               FormBox["\"value\"", TraditionalForm], None}, {
               FormBox["\"underlying price\"", TraditionalForm], None}}, 
            ImageSize -> {530, 370}, 
            LabelStyle -> {FontFamily -> "Verdana", FontSize -> 10}, 
            Method -> {}, PlotLabel -> 
            FormBox["\"AmericanCall \[Delta]-\[Gamma] Hedge\"", 
              TraditionalForm], 
            PlotRange -> {{19.517932035838292`, 
             31.58206796416171}, {-1.5866414212361306`, 9.144053851384703}}, 
            PlotRangeClipping -> True, 
            PlotRangePadding -> {{0.24128271856646835`, 
             0.24128271856646835`}, {0.21461390545241668`, 
             0.21461390545241668`}}],
           TemplateBox[{"\"Value\"", "\"Delta\"", "\"Delta-Gamma\""}, 
            "LineLegend", DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
              False]& ), Editable -> True, 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"20.19\"\>",
               20.18816180963404,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-50.05%\"\>", 
             "0.4980802323078235`", "\<\"-4.20%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.08\"\>",
               21.081801508028366`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-34.79%\"\>", 
             "0.5398285474784692`", "\<\"-2.95%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.98\"\>",
               21.975441206422694`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-22.13%\"\>", 
             "0.581576862649115`", "\<\"-1.75%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.87\"\>",
               22.86908090481702,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-12.29%\"\>", 
             "0.6233251778197608`", "\<\"-0.83%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"23.76\"\>",
               23.762720603211346`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-5.36%\"\>", 
             "0.6650734929904064`", "\<\"-0.27%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.66\"\>",
               24.656360301605673`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-1.31%\"\>", 
             "0.7068218081610521`", "\<\"-0.04%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"25.55\"\>",
               25.55,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\" 0.00%\"\>", 
             "0.7485701233316979`", "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"26.44\"\>",
               26.44363969839433,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-1.24%\"\>", 
             "0.7903184385023437`", "\<\"+0.04%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.34\"\>",
               27.337279396788656`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-4.79%\"\>", 
             "0.8320667536729894`", "\<\"+0.31%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"28.23\"\>",
               28.230919095182983`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-10.42%\"\>", 
             "0.8738150688436352`", "\<\"+1.04%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.12\"\>",
               29.124558793577307`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-17.93%\"\>", 
             "0.9155633840142808`", "\<\"+2.46%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.02\"\>",
               30.01819849197164,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-25.60%\"\>", 
             "0.9573116991849268`", "\<\"+6.25%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.91\"\>",
               30.911838190365962`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7485701233316979`", "\<\"-33.27%\"\>", 
             "0.9990600143555723`", "\<\"+12.59%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         TemplateBox[{GraphicsBox[{{}, {{}, {}, {
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               LineBox[CompressedData["
1:eJwVyWk41AkAx/FxTYgk1wxyS9Y6ZoaZMYf/r6cMFg+LpBxTykMrtpAjK9qK
MniworVCooPatCiK1lVLK4XowNpR7hxpipTa9sX3+bz4Ggb/6BUiTSKRvL72
vzXvtg1EWtKx2jLqy+o1wbDAf0g+gI574uQiv3gTkM8eGi1Lp6Ol6+fXOXom
sJlKm+Q10LFg2NMw1m6MXZziuYEJOnaneMb5hhvjhKhWclCTAd208YJxVWNc
G3qwoujIwDf98Vln643w1FJMqohmIFdh9mGk0AhSyUtkooyBoLbNneFkI1g8
VlZ+/piB/POqb3OuGcLH0EQt+gsDfygeV3jlY4ijURyqspUt/nqfPRP6yQCX
2zz1LwXYgvptU6BpuQF61UNNt4hs0dTtZWHiZoCPIUkWgw22uCjHIZ5N6sP0
1i+0w5O2ED97uFaRow8P+UqWipYdQoVLXrMiPcTvbOZfcbRDhNitKuefjSir
HNi6NcYOxpf2VZHpG9H18bXLcJkdWpefTPmn6uK9m4xnXI8dkvRsV0sHdaBf
TPVVJTGRvZvy0xhNBy7z1gFVVkyYraGssk9rIxqCYMdAJo7s6tSsElNRlBMQ
NiJior2sVejKpeL+aFRkwu2vX6cn0jyfggXG6Ri1KSaynNca+S5qQftkyZFr
WixYUuj0cQ8tbBuoS3ESsCBqZ6rO/66JCLOuVHEMC4NpirRUFU0UxI9mJF5g
wbWoWKblkAZaOpdzNXpZWMd7tVLbr45pbZVfr5PYCDzfdSqOqw71A6YlLtZs
7Ca76OtdUINDE7fiZSAbHhXf2dxVUkPYOq+qpAw2/OtbLSPiNyBXGHZD6w4b
dQllpzGuijvVR2/dmGLjjPFgnbuvKsakzjS5UuxhuhBoUtmxHireVW1jAnsU
UXWdwvnrwS5v6Uw+bI+dtcoG7vtVEPzu6SNquT2smg2YowHrkCGY66/ptce5
rGN51duVcbNAdshdioMX9AOiNm8l/DupPTphzYHgst6fpjvWQoFDmzwWxAF/
eqBPLFQEQ+Q0p5PJgYakN0I6UgEBQ4GSujsc2LR40nKPySPVMmbFY5qDUbes
1t8K16D6aDppmsJFZm7nPfMGMl48KiWfcOJClIkRwbAcZA1vKenFcsGyp9Ws
kuVgGfVwQ305F5Ls52N+TFnsaHtJ8erjYkN2nM7ecBmkqK/ovZbi4QPNZXnT
RWlUhqw3TbXhYeVQhsH1cSk8ubnJwkDIQ5xrMptsKYXPa/i025k8mChOcegJ
JGze6c3yaeRBbbq/APlfCK/K/fy5aR7g+qL8B8fPROLH5K2nqHz4ms2EXv3y
iahwy3cxcubjboT61UftH4nuc1c9GmP5WFUO5hXnrRDLc63bfSv4OLk08lIc
+YEwwnP/hT4+eqmFEfu8lwm3nPk96dIO2LOvqHx+yxIROyoXZkJzwJX7i97u
nPdECUM38q7QAeY2VwROvHdE5wl6jF+WA3yy/3a65CQhFvudjyw2OqByIMSI
FfCW0DUTpmTMOKBo8fj55oRFQhB/OHWTNoGqPlq2cukb4mCnKKPZmYCmdVfN
RPcCUahdlrsrjoBRtSZXi7xAtIfXn5VUEPBwjQ5vS58jZhu7i7OeEBjpMZui
UGcJpbQorzwpYP9F+ZyGmzNE6fWk7WIKUJjYJ2uzd5qwe3bKz8oGGJQRjJP1
pogHpDz/RCeg7c3Gpx3jE4TQvCSoIwgYXqIkkJrGCcn3lXs0YoHaDkkEu3SM
+A9e4Dqd
                "]]}, {
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               LineBox[CompressedData["
1:eJwVxX040wkAB/B5WypijDFv47zVysvGbLPt9+3k7eqOVHqxKL1xFY55ifNS
VypTz8MVXV2tc9YLV+mICo1U8v5Wea1DdV7ydtIUd7q7Pz7PxzI0MmCPKolE
CvjP/xd/WPMiYhUL2eqdJqGBVnjpFdSnKWaBIRHRvfWtQD733WBeBgtFr+VG
K1st4TRyfFhwjwXRBm0a5ZQltvEvTbwYYqHxocRA6WuJo9KSmShDNoJYffq9
ZEvc6KufW+LJxrtfPPSqahjoXDVAksewcYhSqCtPY0AldZZM5LGx6LCeToaQ
AWartnZ3KxsrB97TX81YYKOltX7MZza+qnpIuxZhgZRovrG2gwv2ybKo0cPm
uFbjb3FV7IKjKTsoglBztFP32ayWuuDydsdl5D4zzO9JZvbec0GVYGFJ6yYz
2JT96Bw77II+k6ZF51tM4adZ4KZDc8Xc3AX13b6mSNhaJbzu6Qrjnm9VHGpM
kFfwwsND4grOPd7CrMAEjfNjvi/zXBFwTnO+upQO5To1//g2V0TGd85Kneiw
uGQcSCFxcDrwysymAmP4TjqKCx04KHSN/cvC2hgx8Ar13M7BU+qaiZGLRvg5
Sxz2h5SDofd674ppRngyGB1x6D4H6h0DQ8lZNEyxT0r0Rzhg/F70xnspDfRj
ssQbNDcIs1IHKMcMsebFnTRvLzdsi/rmVe+CAQ7aNaYPSNxwyM+sV55ggNyE
wcykX92Q4zDWGTlNRXXdx2yDdjcUa5c/4x2gYpSu89MtEhftYyfb1P7UB/WA
jczXkYvJhi3NTSH6EFW6y19v50Kr0K4ht1sPYcsCCpMzubDPUNbu3KCH7JCw
27RyLjzDHz9iNlFQXpRSdnuEi90+Z6o/eFHwVuVs5VojHg7b7XqgqNKFzobC
mrdePFwis8pP8nXBza+uS43lIbFBJepqmA5CP3S2GOfzUHJSFu4uXoZMr4nn
xe08jHsLd7X4aaM0V73vaxU+bMm94l0eWugfpg8OOfKx41FC4CxnKRbznYcP
B/MhO2LoL12xBGyp94TJKT66UOJrYb4Y4r7tM3fK+aB9Xu9RTNFE+irJnN8o
H/6VkwJvjUUoSskgjRq5IyPpFKf3owZ6Wi6Tj3q7o4bHdIocU4e6ZZmWeZw7
/p59ulytXw2ropv07ua7Q1C694vcDlVsrnltFNDhDolE3YxZq4I06pz5mIoA
Jaw8Q8V9Egr26NqkOwnQM5DKuCL+TDwrtWUyQgRYF1yu3+zxD7GwSOh8/5QA
VT1KsnLFPGG/dYPbxgoBWJtZc2Z6n4iAgnDhxKgA+R0Hxz0/KYmk+VSPE8ZC
WPlf7z/YP0PI1+X4WvkIkdP4puNs7TTRfPE3v4o4Iai+jNrKm1PEx4mHmwLl
QmhJyyQNzHHCCt1BUx1CTP3gEGQyN0ysy5rcmaEqQtf38tX7n74h4gY1wqyd
RaiINbUvz+knZGzTiAchIkS9tDUzrO8i6o6yJFtOi8BtoY7e2dtKTD/3SZyu
EGHHEY2IQnIVYWoXkpb5TgQSOtRkqgkKr4TYdFs6gajSL4Ofp1crouqkmVU+
BMLC2YP1tm2K8/S87G3xBK7FexowM7oVj/bfPTcjJzD2kJn/WNmvGK9ovnT6
GYGZupLKWPu3Cq3j0QFnVADrNmGnzbYRxeVbyZsGjACtridTz6XjCteuE1sc
nICcSTuNmldTinrSmaAkb8AqZoxyYXZaEbJcFvw0GLipLDKP0f2gmFlfsNMg
DhAlxjLXLp9V/AvoxUDI
                "]]}, {
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               LineBox[CompressedData["
1:eJwVx3k4FHgAh/EZVxG5ryFXaFv3jHEMM79v60prt3KtXLMsS0+lMI5lHXmE
zbFLF2VjRW2Ox1FSjq3U5khJrnW0GrlG02iL8lB22z/e530++qFHPcPFKBSK
56f+/7UV55EoMzoG83dNNRw3xjPXgMnNgXS85KIwW8YYUsXR0xUn6QgsLThU
c9oIloLsBcdbdOg5mUZp6xnBn3VRNDJPB8tbs2S81hCZudeXj6kxUNPvI5xl
GaJusndNxoUBXjM/gtO7HaNmfEpVLAO/SHZsmfHfDmraeylSwYD4nfnREaEB
TJ7IyY09YeDRTEifWroBvPUNlWP/ZUAUayK4pGKA1BiWppy5NcKOOJunVuvj
93v7dK8EWsNioPZC1S59PFWJMNqVa439ZWFWtHE9rIenmEzcssbD0UNLE7F6
MGo5ZRW3YI2SpM7hxa162Lu52lZenYkf5Qe68311kXjgDvuqCxO8jTab54U6
qKgecXLiMaHW6bLS178NfetC92cVTHznHyXhrbAN7zzE9yUMMBHUxQyL89KG
7kVNX0WKDaSkS1WsSrTgvmQRWGNugwO6v6lm82mIhWuoS9Any7hEJJjSUFoY
GDmVa4NNvdnSYkmaeDAdE/VDqw24wQc/GPdq4DXjJ56ywAahXQIyp60B2omy
pDp1WyhJSg+RGHU4jzSnu7na4qh6101GrxqO7OjL4vNskbyxXXTXUA3nEqfz
ki/ZwrJVl7d4XBV3e1aLVJ/aomhP6546vgoWafIl9RQ7XKp/Gy3jrAKVw0Zl
7hZ2CBI8FFCvKoPT4VD1IsgO999/0XRKQRmRWz1rUvLsMDLu9/B2khKKuJGN
6m12OFMkx8yaV0RbQ2pLo8AO4rohS3O+ipilnun4UsMeWulea/xuBch71dyb
dbXH8+YZnwS2Auwq7/akxdmjKn2nxNcH5RG6MtqvWWmPKU7XR37gVuS5ioav
PbVH9OWK4mofOdw4JzH5FZWFgJa2oStesni+QJuet2ChLFqpacx3C6RZVgvH
g1nA8GVLcGXAyHUTaeWzwJxO3DdxWBqBk0HLzW0sZBfnKNakbUaWGW9t7yIL
pqvDsfXnNqEh9SRlUcMBptSQhIXrUhjvL5fKdHNAxrWd2r6jkpDQb5HViXcA
Xd4ydHVDAmYxj5RuVjoAKjz3fhMJfHPvhYbnoAPKO1cGxoPEka6ypiOkOoJL
a16nnRFDdbiCUZalI6K1mh78PEDF0A1jEz2uIyb/FNLtlanY2MS2as13RLlm
ONT9KfjsgJetd7sjEs1s/vby+Jd4Vh9kixYdEZq0LXVa9JEkr6c55WiyIUFL
/3b8wgdS5XHW3WA3G56ywSccvNbJ419r97bHs+G7v0UoqbpGVkWdPr5VbEgK
cs/a81eJAcYCXg+yET44kTHS8p54FC6FnBTjIFHhSuNk8TsSPy0ZaWjFAav8
lYFH5gopY2hH/cHl4HpG/Yhh0jLpyaTz/Ao4GG8R9n2f9Ja8Gd6d9Kadgxuk
SlLpxBuivYObnveSA9DG0o3P/0NcE+OyjGkEiW45nMpbr8mxnty8O7sJugvC
U9S6lsh5WkWRfwLBB0ajWIuFiNw/dLN4uYrgfOpb2c/rhORV++OLBUOfHGVa
epS8JLLZMZ6nqcA78cCG7DkBKa9P8eFrAH2cDPeYigXC/CvHz9wSEOqURVjE
zpNeyumAZDcgvrJJ5rbfHOHuLAvuDgbC+tvp+l6zZHl/dYhqPFBb1jHlEzpD
/gMDjTvt
                "]]}}, {}}, AspectRatio -> 
            NCache[GoldenRatio^(-1), 0.6180339887498948], 
            AxesOrigin -> {18.177472488246803`, 0}, Frame -> True, 
            FrameLabel -> {{
               FormBox["\"value\"", TraditionalForm], None}, {
               FormBox["\"underlying price\"", TraditionalForm], None}}, 
            ImageSize -> {530, 370}, 
            LabelStyle -> {FontFamily -> "Verdana", FontSize -> 10}, 
            Method -> {}, PlotLabel -> 
            FormBox["\"AmericanPut \[Delta]-\[Gamma] Hedge\"", 
              TraditionalForm], 
            PlotRange -> {{18.177472488246803`, 
             32.9225275117532}, {-1.447581453095736, 11.253302551986883`}}, 
            PlotRangeClipping -> True, 
            PlotRangePadding -> {{0.294901100470128, 0.294901100470128}, {
             0.2540176801016524, 0.2540176801016524}}],
           TemplateBox[{"\"Value\"", "\"Delta\"", "\"Delta-Gamma\""}, 
            "LineLegend", DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
              False]& ), Editable -> True, 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"20.19\"\>",
               20.18816180963404,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-19.79%\"\>", 
             RowBox[{"-", "0.9256271171756643`"}], "\<\"+8.77%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.08\"\>",
               21.081801508028366`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-14.68%\"\>", 
             RowBox[{"-", "0.8913543383161627`"}], "\<\"+5.15%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.98\"\>",
               21.975441206422694`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-10.03%\"\>", 
             RowBox[{"-", "0.8570815594566612`"}], "\<\"+2.67%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.87\"\>",
               22.86908090481702,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-6.01%\"\>", 
             RowBox[{"-", "0.8228087805971597`"}], "\<\"+1.13%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"23.76\"\>",
               23.762720603211346`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-2.84%\"\>", 
             RowBox[{"-", "0.7885360017376583`"}], "\<\"+0.33%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.66\"\>",
               24.656360301605673`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-0.75%\"\>", 
             RowBox[{"-", "0.7542632228781567`"}], "\<\"+0.04%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"25.55\"\>",
               25.55,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\" 0.00%\"\>", 
             RowBox[{"-", "0.7199904440186552`"}], "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"26.44\"\>",
               26.44363969839433,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-0.80%\"\>", 
             RowBox[{"-", "0.6857176651591537`"}], "\<\"-0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.34\"\>",
               27.337279396788656`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-3.26%\"\>", 
             RowBox[{"-", "0.6514448862996521`"}], "\<\"-0.08%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"28.23\"\>",
               28.230919095182983`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-7.42%\"\>", 
             RowBox[{"-", "0.6171721074401506`"}], "\<\"-0.28%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.12\"\>",
               29.124558793577307`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-13.34%\"\>", 
             RowBox[{"-", "0.5828993285806492`"}], "\<\"-0.64%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.02\"\>",
               30.01819849197164,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-20.91%\"\>", 
             RowBox[{"-", "0.5486265497211475`"}], "\<\"-1.07%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.91\"\>",
               30.911838190365962`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.7199904440186552`"}], "\<\"-29.97%\"\>", 
             RowBox[{"-", "0.5143537708616461`"}], "\<\"-1.41%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         TemplateBox[{GraphicsBox[{{}, {{}, {}, {
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               LineBox[CompressedData["
1:eJwVx3k4FHgAh3FHiho3YTQGz2qT1E7mPvy+NW0r4SmlbXqsitIoId2eNmyo
REhFbDO76NJ6ckZSqcFudFiema3UROw4GhZZNKRt/3ifz/O6hEYH7jTQ09ML
/NL/ao4WMnKSvNCUPjlNd1YR4yub6TXFXjC5Hdu4y+IFWdxqavqy1QuNYbkv
rOiviN/UI93HcS+ore8XDfu9JtELj/RRaUw02G/Z15inJlnrPVUCMRNue7Tt
RUmdpOLYO0VwBBO3eV455590EeW1nLIfM5jITK3dnejWTSba/OSyKiZMm321
FRk9xGFGP/1BBxMck6Q7e+dpiNC9Oq5Tn4UQPm1Vf24vCdkYKdVfxEJemlOp
hNtPEuJdNrkGsPD1OqO6gf4BUlCsEosPsDDsc7O8vkRLGpRnGDvyWGj1qwmf
PDFENHor6Mn1LHQqbuRvYA8T4yXjlKsaFuomX58d9Bohi7+/qWuisGFefX37
U/4o8f9pW1/vcjauaLqej/p+INEltipjCRsblq8337JjjGS9aFa4x7Mxa4mR
ZirlX1JhmFDme4WNI6FvFE/Lx4lyKUu+p4WNwMhZbx/2TpAJyUBa2ggbtQzT
Db+7fSTUZHlciR0HsU3hK5sjdURYulH6TMRB1PDLjxV1UySkw2TTP2Ec/PFB
YbvH9hNJmP1AbJHKgaNEcb390AwpYBxgMEo5kFmnhz3v/Ewagt3pgSoODgb+
qZbd0IPmpJqyf5qD2Qg0nwnXh3FFti7blYtliZ8N9y8ygIfap6/Sh4u5HRL5
wKAB/E1mlMooLp44/aRbV22IaGaFYvw8Fw02PUezkmYha6u0zO7ul4+/3HUx
yAgVqTQ5t4uLR6OnI9Yung1VVVuaZA4PP/uqW3MN5mCy82RcnCcP7vexT6qe
AypFJM3fwMNfmX7rC+8ZQ8gZDao7yoPryVj28l9MEBJ6TfxGzkPYavfbn5Ln
IiE9mDHTyIOsPnT1UNQ8FNRY0ulaHmoqRf7aLRQ0dDdRYMVHDU27rHONKXrN
jum2cflguj3eVi4wgwmf0ZcYwkf487zItd+Yw2OnRlmQxEdKxnHDZmsL+Gfm
KxTFfBgP6lJrMy0QfXddWU8rH12Vm9XvzSxxTmMkN5rg4/KKqvLAs5aotLyb
tpAmAOcW+bvbzAoqYUzcd2IBFjoFx5/PtMLkLjepNEKA1qHttRJra1CzXwWd
zhDA68aEgXuONYT3M8TFVQIcvWQ+PeFog5D+VYyWDgGCD55KrPvVBgk2Oiet
vhCNlw4WRy6yRQG5RTFdJERJkVXLzC1bNO7eofMMEIIWFH4ogjsfvRcc+gIO
CFFfmxtf+HA+TB4+U0bnCbG5TW+qcK0dPLQnFJn1Qmy9M+gdqrJDgB2vrEwj
xMDVZT3K7faIWTkka6OIUKXa0TQ+aI9zewvTPiwXYftps1n34hxQmbs5zkYi
QunS2BlnYypUClMpK16EvLu+EseLVEwOPQradEWEYNsAXdFXjqBSj4gPt4iQ
uzXVuLrCEcJvPRm5IyJYvpa99xUvQEjMO6c7dt4Q97f7bmlfgIT8HMorkTcK
TtlS3obRUNjkp9OFeeNiaXtg+xgNjSP6fY6p3riZ3HKckeKE3gXVSmGpN+xj
6haP2dEx1ydS8YPKG24v53nML6ZjyX6XsuPT3sh28Fy9xskZATKVTO5KsKfb
aE35LmfEPD6TVu9D8FtL2CtxmTPOjSGuK4pAID7cOqVzRiV9fJfBBQJqSAr1
xSoX/Aez606c
                "]]}, {
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               LineBox[CompressedData["
1:eJwVjH040wkAx0dv000JGWN2XPVEdM/Y+37b71vrOl3Su960ahXrleQulrKu
1MV6FKc3V7tI7qgQKi/dT00qLifXdqEXxbFKu8gNK7ruj8/zeT7/fHxU0Ys2
2tNotEWf+N+dCTncEweCYdOe9J9/tI+i5y7nXM8PRnhSM+9qTS/l3+jo2NwY
jKt7WCR78C0V+v6WbdAajEkDV9PpqyxU9JR4M4vNw+99ojyT4RV1bGGgSarg
4YeeisrzAV1USeILQ8QmHmZZiMbYzHbKmHeieE8aDzTTnnv7Pjyj+ptC9WfL
eIj/Y18vu+ER5TFsd4Rq5eHt3WTPCv0DivC7pmmz4yPmgMvhiy9qKOWSrWq7
qXxon2zbmsHMp7RJPuG+YXxUh8fOTV1VSGbnmxSKuE+d/VCbH1xL1hhTuRtO
82FeFskUhzSRnbQZnOTqTz+lyvLTd80kPcDKuNDJR2JQoUq7qI30X1Zgq2UI
UM0PDLvysp2c9/1ac1eQAF7iAnGHtouMvjTRRF8hwFrCb7Kb+2vy2KM6g1+S
AOfJPKeQQgtZMkJb/E2uAHHnnIeJL3pI43S+fku9AG45D94ZLb1k/4pXOl2P
ANfPH325vaKPZCXrNZeYQkRemP9szEErSRQtUTfIhKD/Ms7488IBUtnqEP7P
eiHyf71fJ2bbSO1oSuGUIsTcAl11k/k9mc2N43KLhHhzce7VLaVDZE2EH2eR
SYi0y2MvjtR+JDsPPWXs/CCE+6OOxoZcGuglGbYMXxFeLa+Zm5Vqh2lPQ8yl
ISLcbM6pjdphj3kOw0bjdhHSV+6fwVs2AtG8EoP1RxFUraoqmmwkjq1RFzMr
ReBFzBTe9x2FkhS2XvRchJFPfK6coo+GqaxJt2KMGI9X2wVGWkZjoO2QRhMo
xsWnbXlBD8eAxZCpsxaLsXdNte/HcjoIYe/SqgQx5rfpz9TrHaBU5Sme6MXg
rEtyP5k8FtojEdzh22K8fa7M2LDlM2Rfn8DhdItxSyUfx13IQE17LQPOEqS3
sw8PCRzRNS7RtlYkweYNQyPqvMbBQcI171NKIPn78d7j9uMxbWOnMfuABIzI
qkGVeTzmHc0yGPIl2P5uXgUzygnRlQuKOxol+KvkRv9QsxPSO0fpR/VLMDMu
kN8ROgGlEyp1U9hSFPDOxNZRE2AiYjRfK6Rw+ZdRVBTkjIGoyWr1JikSyxLf
HM91BiujZenhNCk6vu323+PuAuK3NEV+mRShggj1+lQXKF/O4ta3SlFmrc+d
M+wCravNu9uOgPc1afuXO1yRTRYyHKcSOLir4HO3Dlfc3rzBFhhGoFfoqfwQ
PhFdmR7msDgCKwdSsl7cmwiHmw3G6NMEbl23PbpLuGFa937D0WoC0xI2uxUW
uiGMKS4u7iRwXNyyONOXiZiZlrNNDBk+Ds45tjuTifRtObp3QTKoK8ob1tHd
UXpyucZ1hQyNGj9GyG53mAyOan6SDCLpqTnTLe4YsNxaGp4rw7n39EOu6zzA
YsUrdtXLMLYqvsb2pweIrwK5J3tkiE002z2fzYIy5oV3OVOOFmI5eaecBW3W
CUaLTA7F0J3ESwGeyKkNtdnWy3H5hrAiQ++J2z12Zs8UOZh78/oTnL3Q5XXN
SBTJoZUz+WuTvTA2ZKthtUmO18MHY2cPeCFgp0/x3g9yLKGshQFb2Ag7azqr
9yVRlRT5xvkpGzH3UnXVISQmweQ/uMAb6X3QPN9OQkebrX5m8EYpxxpln0nC
Wl2We1vAwX8ASFgi
                "]]}, {
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               LineBox[CompressedData["
1:eJwViX1YDHYAx69ILy7S63W9XJeNkszVvXRv/b517VmMpsgcOeb1WHSm0Uoc
8lbXk4RU41otWVjXcyEroUtPhCeqW+oZlVzn1pDocqXN/vg8n+fzfJjrkuI2
WlMolLhP/G/DT6Ws/IxQUKY0Couy9t60K1vBqKkIBeStZv/rZWROq6Pjk9ZP
fzj5g9m2hiwaa7B8GAnFkonkvrr7DSRpVoqR7sNGyoWZSVnNd0lubLBeKGGj
X7j+kTatlWj39OkStrAx7+rv9RfmtpOO8vyq9Bw2aJLkfZ+Z/yTmx4vU566w
cb5P6zK7u5t4Tlhl3+xmo/PktjRN5zMiCryW2mPFwYtLS1b1mHuJbFmi3CqA
g+Iz5X1BTv1EuY+53D+Gg0vZtW0CjoGUVOglkmQOpqpU8xw3G0ljRxZrQyEH
tXn04ZIyEzFQIhiHbn3qXzcyx98MEru5I9TzBg6m3dx2nbbgNZnz7UVLE5WL
FTsKVo/r35DFB9YaB0K46D6y0uXh9Lck6bKb3k7KxYS/Jd3qm2GS23lPF7iP
i3uRKWdPn3xHtJOUVQvLuAgfaN+R3fOedMzjqL9v4SLByWnsRYiZmKUmlWqI
C2Z9IL84a5TQD6lTL3vwUPCGObfO9IGINMvkD8U8aMpH2/hLxois23756/U8
KJ5fnu9ZN06UU25KnDJ56CyNiFw5b4KUsJJZLA0PL41au4/n/yWNCYGMOD0P
sVLrBkoeBYYjT6k7x3k4QKF3aeOtYKfNs+T5h8HeVHw/38saQU+jjdXRYTC6
5Rdc6rfGYvuJjo7tYXDPGMdbzSQksbW6kZNhOMN+1CBXTkbuGnmVR20YFLPd
GE5LbaDN9FGH9YahMKE53hgwBforj1VSWz782k2bhqxsMdpzJDU1mI932Xvi
gp7agk4Vy4uW8uGTmU47fcMOIt7b+Lqf+Chs/qeGVWwP2bpyyV9qPrYueBA6
ccgByuwE1sQdPnKo3sfGtk9FSc0MBmOQDwfnrprAVVQ0Pm+iwlkAvdRWd3Sh
Iwam7bGsDROA0l9aThNPg72AZdwvE2CXpnLTk5DpCNpo6CjJEOCXNW7KF25O
WHy8SKerEGD+UYc/RvKckFS7pKq/VQBTLO+7YpcZOGGwUduYBXhUV/Rj38kZ
qJ5Rq5rlI0RPM89c5+EMvUiR+pVECNquqYYvfnbG6ObP5fItQqQ1ukcK/V1A
z+uKP5YjhG21dOqz31wgqs+RVFwRoj6qPcIr1BWyl1Gslm4h1LsOv3h9wxVK
V4vvoJUIFxcoRhIWuqGEVFIdA0TouZGbvK7TDXe2brAEx4ggaTOtocjdMXDK
0xiTLMKDY2k13A/usL/9sCOpUARlr2SvjcoDQYMHdcdviSDrklQl+tEQ48Gv
qjKIsDU5LTbxKg2KyFfnHlPFOFtpkk2O8cSJbaWq4RAxLFm5T9gDnqg+syLV
VSqG0l5x++N+OvQ6RzlnnxisgMPua3y9MPqqIX55mRhUY1vnijov0Okpkt0t
YjgvkNr9vcoboi+DWWeGxIj42r3M7aM3ZIo+3+se4Sh85VDZqfaBsiif2iUO
h28obxY7yhelTYsslvXhaKUVOQSYfHFnyMrolRmOC2puQnUuAwPe1zpEmnDo
n2dkJ/r4wSE6UbdaH47t0ZkzW37ww9ydzKq94+EoSA96877ZDzHn9OfU/gQr
D8qHBxlMKO5mqW5FE1RKI4I1u5k48Q6pvdsJCihXz5JWJqoZI5utTxHQU5qi
igL98R8WNUf+
                "]]}}, {}}, AspectRatio -> 
            NCache[GoldenRatio^(-1), 0.6180339887498948], 
            AxesOrigin -> {19.517932035838292`, 0}, Frame -> True, 
            FrameLabel -> {{
               FormBox["\"value\"", TraditionalForm], None}, {
               FormBox["\"underlying price\"", TraditionalForm], None}}, 
            ImageSize -> {530, 370}, 
            LabelStyle -> {FontFamily -> "Verdana", FontSize -> 10}, 
            Method -> {}, PlotLabel -> 
            FormBox["\"FutureEuropeanCall \[Delta]-\[Gamma] Hedge\"", 
              TraditionalForm], 
            PlotRange -> {{19.517932035838292`, 
             31.58206796416171}, {-1.2852317489524112`, 9.081262730815116}}, 
            PlotRangeClipping -> True, 
            PlotRangePadding -> {{0.24128271856646835`, 
             0.24128271856646835`}, {0.20732988959535054`, 
             0.20732988959535054`}}],
           TemplateBox[{"\"Value\"", "\"Delta\"", "\"Delta-Gamma\""}, 
            "LineLegend", DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
              False]& ), Editable -> True, 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"20.19\"\>",
               20.18816180963404,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-39.19%\"\>", 
             "0.5650733058239013`", "\<\"-8.21%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.08\"\>",
               21.081801508028366`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-26.68%\"\>", 
             "0.5964555632735081`", "\<\"-5.17%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.98\"\>",
               21.975441206422694`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-16.59%\"\>", 
             "0.627837820723115`", "\<\"-2.83%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.87\"\>",
               22.86908090481702,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-9.00%\"\>", 
             "0.6592200781727219`", "\<\"-1.25%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"23.76\"\>",
               23.762720603211346`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-3.83%\"\>", 
             "0.6906023356223286`", "\<\"-0.38%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.66\"\>",
               24.656360301605673`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-0.91%\"\>", 
             "0.7219845930719355`", "\<\"-0.05%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"25.55\"\>",
               25.55,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\" 0.00%\"\>", 
             "0.7533668505215424`", "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"26.44\"\>",
               26.44363969839433,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-0.81%\"\>", 
             "0.7847491079711493`", "\<\"+0.05%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.34\"\>",
               27.337279396788656`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-3.05%\"\>", 
             "0.8161313654207561`", "\<\"+0.39%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"28.23\"\>",
               28.230919095182983`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-6.43%\"\>", 
             "0.847513622870363`", "\<\"+1.32%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.12\"\>",
               29.124558793577307`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-10.71%\"\>", 
             "0.8788958803199698`", "\<\"+3.06%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.02\"\>",
               30.01819849197164,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-15.67%\"\>", 
             "0.9102781377695768`", "\<\"+5.84%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.91\"\>",
               30.911838190365962`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.7533668505215424`", "\<\"-21.14%\"\>", 
             "0.9416603952191835`", "\<\"+9.84%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         TemplateBox[{GraphicsBox[{{}, {{}, {}, {
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               LineBox[CompressedData["
1:eJwVxXk0FHgAB/AhZ5HbGIRx93LOYMaYmd93H5FHRgphEJtdHSh3l6NnaZG2
0qasSFRUG1ln2li2VkqRY0WbIzkbEWWx2d0/Pu9DD43yChOnUChe//n/qkWn
3khzBkzNUguHug3w2jlgUEbIQGs2b+p2ogGk8g6PFGcy0Kw1l5SvbQCryYwJ
bj0DAfWlv1c06cOfc0XUO85Akwk/Y26vPtKyflk4pM4EzfvGbKisPu4MPlle
v5UJ6cqvz6z/mY4+82FKaQwTFm2hQpEXHWLJn6VIMRMmbrR7qkt62PJCXr7/
BRMHyp97phXoYRfdUCVmjYmmVV2hk6MekqI5NHkLG6TZcCvrunRxs8VT94bQ
Bu8Fgh03dXXRpfqt0VdZNkiorVMMj9DBStiJLQP1NjATnVSSbdwEo9rz1nET
NohgmakWbNgEgUw5S4Fqi9w9zfvthNpI9GvilW21xfxa8tT4HS0Ul/c6Osba
4qCG5mArRQtPV2ZcXxfbYoNz/dTQLk18cl/nmdBpC6eAUSXPchp0r9B8lCh2
2JsflmksRoPrrKXwloUdohIiaxL9NBAD59CtgXboHlyTC6ii4qezwvA3WXYQ
1I5JjGyk4tFIdOSRBjt4Ogau0Q+q4wPz+1iVSTuo21xmWLarQfO7wqN3qCys
pvjkbjJTg1NvdYqLMws5i3mtlDOqiDB5mj4cy8KDwNdL0x9VcDFxJPvYNRZM
Ix+Pz/mroLlt6ZxaFwuJwoxqw1ZlTGkqXLpLYSMmR3X4gqUyVA8aFbpasjH7
JpjhU6AE/gOH0tFANpx68svi5JUQvtHr1olsNr5cr45al6KIc8HhldT7bJhK
mv+gNaWA+xVJtZWTbLT5pko79W/EmNiFB24a9ojrq5jOeyYPhZ23Wsac7WE8
7frS6rEc2CXNbclx9tCOMLDRe7QBoYt9z2kl9pCp3ed95Ml6ZDuLeqq67LH3
Xp2Te7csai5KDG4X48DxMb/j+qgMhiY0R8YtOWiw/Cshd0kashzridQgDkLc
uck6KtJgZrmItE5zQDUse+XGlIJwMHCh+j4HXdtbuXQ/SaSbxy4LpjjIoTVp
Xk2TQEVSJmVKwwEhC7rV7dXr8Op5kVSaiwNyq9v1C2fEIUGvldOJd8DnZo8g
6mZxmEc/U64rcUDEQ6q3xQEx+LaMani9dADlXdbSwD0KUlSXdWbEuBB0PvRU
p1BQHqZolG7FRYW6B/1a6RfSXWO8RS+YC++r6r4Un3/IF2medcNpLtqz7PuM
lFaJqd9O1q5GLkST/crzvcvEq3wfTzTFBan3OIUbf5NjK8mOp2g8sHxrFyZT
l0ip+4+u+tt4SCsJSm/95jPpKLgtaIznQelFvkKJ9yeyJPrN26eUB+rAqL2/
xyLRR3/Ah5c8FLm11NV4LhD3s7MhmeJ8eLGPH88QfiTxI5LhhtZ8OD+UfZt3
eJ4UMrUjfw3mI1dSIKo+M0fa0hixu3P4cBXn7b9Z84HM92w7Ot/IxxuJZLfo
p7NE2yQ4JXuaj8Hl03Z7uCLinBiXbqxJkNFx3qGscYYcasvKbtpGQAnkSA24
T5PLmsXn/BMIxnoUL52cmSStB+ryFkoJZCf+uWyWP0HeN3ZcyekmWNDvKwrb
PU7kMqK9csWAzqNiMQ0G70jR3RPewxrA/nkpQd3qW2L756ndFlZA1Yqq0fuR
UfKEkhtwzAWwZAR1jveMkODNhUF/BAG55/fsYPcMk4Ud5SFq8cAzH+pi1NAQ
+RfW9j0N
                "]]}, {
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               LineBox[CompressedData["
1:eJwVynk41Akcx/Fxl3KfM25CkXMcYxi/T9GgFEuiclRPFh1iHNmkbKupkF1R
qS1aDBp3chTtkNi0QnIkPK6KrJVlSJTd2T++z+d5P6+vzpFTXsHCJBLJS3D/
b9Wic1+4iSUUzLv4ky3aGGYeHFrnbwkRlqf8Glsb4lmR47nJluBXdZkpumrD
/OOlKYdHlni36LnbaL02DtCzZ/smLVF0Krc3MVMLSSkP+RHKVFxeyJUtVdZC
6dCLFckdVBw7nbdrIEsT/SZjJE4UFTtX89hiapoQOv9ZnMilwuh8fpPFXQ0Y
d0lJDXRRISnC+RqgpYG9OpsUov6lYobNsU3+TR3nWHSylKkV2iULWDV66ihq
9tQq9LdCSVpB6ThHDd2KIfrbUqyQKl84Jb1ZDavBCcaDj6wQfqNQz55LgX5t
hkXMlBX2UIoCQ7ZS4LGOayujYg3T7KJbGWVkxO1vZNzfYQ053fs9PHMycrl9
Tk7R1pjj3JeZeaCK9tUZt+Fca3Rt4e5UtVbFkruI5+lX1qgo5V50rlWBVjZ5
nxzJBhkWxY0Rdipw+2TmX2xqg6jq4tU79cqIAvPIjgAbeNuV2LQxlHEn3T90
JMUGNk9KIhd5SmgdZ4X/8NgGSttKS3S2K2GOeiVa4aMNFp+VTu5+pgjKxZwz
pSq26HUt0z3DVIRzX3WiC9MW1e1lAQXPFXDSsJ09Fm2LLM/yrO6dCrgZN54a
n2eLuJ7y12vt8mhqW76m1G0LP78KaWMPeUxTZG6Vk2igD1W4+b6Sg+IJ/Rw3
MxoohyqTfvKWg+MTe85EAA0rE5W88l5ZhEp7FSek0vA25MHKoK8srgWFVqrU
0xDVH3xc9qEM6ivO1VZ+pIE28v1YaJ003gtdf7JL1Q7LH0J8mxqkIONd3Pye
aYe62dCX5KaNoOU3tZ2PsUPCUpgTq2UDjiz2d5Lz7cBYO/boRZskUpmzvVXd
dvgmdsJMr2M9am6KDu0WoqNB6iQnvnsdRqco45NmdJxVClfr6ZPAerrF1I+B
dGzXOJW+dVAc1BSXWbWrdAjpR0hcHBGD/1AAv7qejtatkQnDE6Jgm0SveEzT
wbZiLVhPiaDiXDJpWtUeTIeosLQZYbztvCee5GIPcefokQ9zQhDVqd2oGWuP
1l0xPsQiCSasl/J1+fZQKpy5YbbwL+HbPKHq9doe12tmL4yufiMSFVc0Z4Qc
oNU6F54u+pXgBsvqs80dkNM7f2C71ArRU2NgrB0k8Pd85oLSMrEmwbB4fNUB
2fwly3zNJWLzfm/bvQ0O0BT9ouljyCe8uGGM2WmBK6xKipvPE/Gr550ukxnY
rPdtqYY2R3Dcb7jpujLgGbzW0nlhhui4W+LREMvA0SThbIvMKWJ59qnPPo6g
88RjMzjvCF0MHJx7zcChp5J7FmtGCff0T4eThR3R+FTDveyXASJ2XCx0k4Wg
SQZfI6teETlU9fDfgxzRleDvd7ykmWhLsoz2S3NEYkdI8/Wfc4j5Xtcz8w2C
fwWxzg3ptTx1w6DE1L8cMSrFurR24U8eMy6GbUAhMPe8IqM+u5cX0ZaS2uhK
YDm5aOJz/DDvNiX32oHTBM4adJFvl4zznh2vy+JzBC3Rvo326wfe3w0d2Wk9
BI5O/RHWd2Wat/ESyytTCDjb1pweHTfLu1ee4DOmChj1jvhfof7Ds35z2c/U
HOC2DEe8MVrgvSBlHox3EXjNYJKh7iIvaEtO4PNAgRcMZMWSP/P433EPK8UK
/GZ/SYvsF95/xWBUJA==
                "]]}, {
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               LineBox[CompressedData["
1:eJwVx3k4FHgAh/EZChVRyBlmQsm6ZsxhML9vi8FDSJIy8aRYJRJCKLRyDbWp
VbtPUjblfOQpkWvLtfGQqBSp1lWusHJF2N0/3ufzvDSfk66+YhQKxfW//vfB
rHVXkAEDFwQPuy/RdfBe4NkrJWQgU6bxvFGxNiSun+rPSWXArUNUpW+mDeOR
pGGLxwzUXJZKSGjahoO8mxNdnxnodDLvNdu3DQmihzPBW5jIkNJucBiio7i3
ZXG9DRPUP+vMK8PpeGPQR8kNZUIlRMnqwjo6qLHzEiSHiQ80ek9RFg36L2Rk
ul8w4fS8n2LCpMGNpi0fuspEYMSB8k0tWjgXwlORMTQFa2vispOPFvLqXTTv
CU2xN7bjbse8JjoVftLZJTLF1RqxkFoDTSz5ntV/99gUJrPZwqN+GtApv2Jy
etgUdN18v/rbW+EsVcCRVWLhuIvGL+8+qiPywBPLfBsW5MJW3xZpqSOnoMvK
KowFycuOuzhH1dC6NG7/PocFj3trm6MKVDHnKO4S0cECtXxncMRXFWjeVHHf
RGFj7ZMqtgFRgf2kkbDQkA2vugr1G+nKCIXAx+YQG7K1NHrDByXcuCz0/yhi
Q+3BnCCXoYSm/pCgM5VsRN/miEjKFkwxU8LkR9hgpgxOZPQrQvVCdlSxEgdW
x5dPZfMVYd1VFmcr4KDI+ryCb5YCAre3JvaFcRCsHNo1sCKPa5H9adF/cJA8
1F6udkQeT5sXMhQ7OfhWeL1CumUzRlVlfyuhcFEf0Pb2EXMzFE7oZNsbcTGo
HaSsemsT+DXmuQOHuBC+iYpgy26C/0bXwrNpXPzw89fZDfFyyPD2L1Wq4iLP
5f521pgsqu6fKy8d4aI4fU9OQ/dGDFF/rXFQNoNXTYtnU5sMZPcW1g8JzFD7
Uc2N95c0uHeeNseeNsPLGWuRVtMG+My+aVe5Y4Yr322oZ1rWI00w8fpBpxnE
5zUeWb1ah0fX1vTupvJAH2zPjxuQwt/Dqv2fjXiYrvfoNVqQxDqeyXC8Fw8R
mY9379ksCabIdkItnYe7ntPLgyYSEPYemimr4iFVXvzLqPtaJBqELTqP8qBS
O6Z6JH4N7p9LpYwqm+OAZ1HS7lJx9LTfkkiwNYfdmDWz4JMY1tDKpTXCzTEc
WLb1DE0MBiFtmyvumIM3sCyoPEzF/voBZdeX/72DRkngPQriFBY1xqkW6HYw
KNIdWiUFvnI6icYWuPapLcI9cYW8eqSrr+VtgTI/jafHGctkRdLSpDLdAoxW
jeQjI0tkx4G9HLdqC8gptbeicJG4FhyznBi1gJOt0SWxyG8keinWKlnFEtNC
0p7nvEByHTPt6XaWmNq/msZkzJPnWUXO1eGWcOWefJajOUcWJur2uedaQnbl
Yvyc0iyho9tz6qUlduZ7VRiqzRDHy5OHU8X4yDP7cMJB7ysJ71/rr23CR0KJ
TLbjj9Mkm6keVOvNR+P6L04Mv39IcwIjzOMiHz4OMTHfr06R6dd2UdPVfNT1
hzu7Z00S9e3ecWljfMR8c7sdoztBBJGnE3VVCeZ6MiYCGsdJcLMo7YkdwY4k
Y4521Bj5XTUn42AEgdaKQXSu9ShpCKi4PpNL0ENElZPaI+RL9fObF18ReDja
zYqpDRPppBDXq1QgdZuv/kfdz+RWydl9fcpAYmOfMMHuE2G9TfYwNAb4jNqU
6dgh0kK56hltCzw8tliq1zZIvPWyvZ55AeMBma/1jAfJzJ6Cw4rhwCA3Y2Y6
b4D8CwSeP2A=
                "]]}}, {}}, AspectRatio -> 
            NCache[GoldenRatio^(-1), 0.6180339887498948], 
            AxesOrigin -> {18.177472488246803`, 0}, Frame -> True, 
            FrameLabel -> {{
               FormBox["\"value\"", TraditionalForm], None}, {
               FormBox["\"underlying price\"", TraditionalForm], None}}, 
            ImageSize -> {530, 370}, 
            LabelStyle -> {FontFamily -> "Verdana", FontSize -> 10}, 
            Method -> {}, PlotLabel -> 
            FormBox["\"FutureEuropeanPut \[Delta]-\[Gamma] Hedge\"", 
              TraditionalForm], 
            PlotRange -> {{18.177472488246803`, 
             32.9225275117532}, {-1.5665947677275178`, 10.567503741508753`}}, 
            PlotRangeClipping -> True, 
            PlotRangePadding -> {{0.294901100470128, 0.294901100470128}, {
             0.24268197018472543`, 0.24268197018472543`}}],
           TemplateBox[{"\"Value\"", "\"Delta\"", "\"Delta-Gamma\""}, 
            "LineLegend", DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
              False]& ), Editable -> True, 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"20.19\"\>",
               20.18816180963404,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-26.94%\"\>", 
             RowBox[{"-", "0.8901592957668352`"}], "\<\"+6.89%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.08\"\>",
               21.081801508028366`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-19.70%\"\>", 
             RowBox[{"-", "0.8543018765411663`"}], "\<\"+3.79%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.98\"\>",
               21.975441206422694`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-13.22%\"\>", 
             RowBox[{"-", "0.8184444573154973`"}], "\<\"+1.82%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.87\"\>",
               22.86908090481702,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-7.75%\"\>", 
             RowBox[{"-", "0.7825870380898284`"}], "\<\"+0.70%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"23.76\"\>",
               23.762720603211346`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-3.57%\"\>", 
             RowBox[{"-", "0.7467296188641597`"}], "\<\"+0.19%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.66\"\>",
               24.656360301605673`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-0.92%\"\>", 
             RowBox[{"-", "0.7108721996384907`"}], "\<\"+0.02%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"25.55\"\>",
               25.55,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\" 0.00%\"\>", 
             RowBox[{"-", "0.6750147804128218`"}], "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"26.44\"\>",
               26.44363969839433,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-0.95%\"\>", 
             RowBox[{"-", "0.6391573611871529`"}], "\<\"-0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.34\"\>",
               27.337279396788656`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-3.85%\"\>", 
             RowBox[{"-", "0.603299941961484`"}], "\<\"-0.09%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"28.23\"\>",
               28.230919095182983`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-8.69%\"\>", 
             RowBox[{"-", "0.5674425227358151`"}], "\<\"-0.23%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.12\"\>",
               29.124558793577307`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-15.40%\"\>", 
             RowBox[{"-", "0.5315851035101463`"}], "\<\"-0.36%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.02\"\>",
               30.01819849197164,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-23.86%\"\>", 
             RowBox[{"-", "0.4957276842844772`"}], "\<\"-0.37%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.91\"\>",
               30.911838190365962`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.6750147804128218`"}], "\<\"-33.91%\"\>", 
             RowBox[{"-", "0.45987026505880846`"}], "\<\"-0.08%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         TemplateBox[{GraphicsBox[{{}, {{}, {}, {
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               LineBox[CompressedData["
1:eJwVxXs8FAYAB3Bvd5zyPo5zWCuP+Ozi3g+/nI1PoUhkq8vocSmPjSV6INTS
9UFIy3LDTNPKXedWKJHXikn63OmlIh3K2qcXOrLHH9/P1y0+JXK7gZ6eXuR/
/l+bWUuvyPeDmkAZeOFkAELdJtqVBj8kfMU983uuAbwGLSzuD/qBcam84O2k
AULnb+g+zPhh9Oe172sjDJGyfN8kheqPxm/uht1qNURJhI+GJ/LHH3s+vpGs
MILywFjn5l3+UOx6F3y4zAjq+grFwSJ/zLsENDoYGmN2KFRWpfLHjvyOQt80
Yzgu6p+4/tAf9d5tvJ5xY/A9L2c91Wfgdumw+1iMCcRReyT6HgxkZlj9lN9v
gpxst2j3cAYI9kPW8kBT1DRoRKJ0Bnoznt3f0WKKLvVx+rYzDAReSN9w3o8A
rd5qWkE7A0+ITiPZFwkgrJwh/aJloC/27l2tFxFeMed1PSQmttkYlo2dIyLs
cNzkxComPPMzM7/zMEPKBTsNIZaJdR9Sn1T/aoaSe7c6PbOZcB4vck1caQ6l
YY5iTR0T5rqpU4Nyc6h9GbLdfUyMr9f/cZhJwmzsC6n0NRPde3u/z20jgVIg
y7pAZiHmSJVqMNgCfHmUZEDAginry6zeIQuIHxKj/05goWEKvpKtS5Bjcl1k
WchChILkofprCWro6XS6nIWjm6avyQ8uRddmT1qkhoU8+o2ai6aW0B59TEpb
YEHPZO6YOMISBGWprtSdjVTXUeFUpSW8H4dMNoWwkRaa93LdhCXCiItqdTIb
1cuqm0v9rJDir+ycKWPD6XjLkCrHCiVbJQpyKxvprhZxlwesoCykytijbDg0
lxX+QLWGRjUkjTXlwPuO+f4tSdaYe3o0K8uHg5eLL2ON2qxBIQkklRs4OJeQ
vK5oqQ34rDcbr2ZysNpJmvfP1zYQx9eLRmQccBsWqdEqG+Sc2Exf7OZgXyK+
KCPaouaKFY02zYFsRvpJq9gWXc96SLDmglo2+qivyRYTSw7o4thcPK/8eLrX
3A5ELn0yV8zFyGj8ocYEO3hv16pr8rkgO0Ur86/aIay4srOzgYvuwCdbQuzt
kdK6XjE+yMXMx5u186n2OKk1lhnPcuG2WNcg67dHk1WrdDmVh8PxvRUMTzI0
/NSsYBEPcQ7BxW1HyJjb+alEsosHB65hM+85GZTSBxuPFfHgnCRjXgxyAL+t
SNSg4mFYWOBDrnOAeCqI3veQhwM54x0ZJo7IsdW5TOvz0VutJN+ROKImoJFk
4cGH0kweuazfEd2J23Q+4Xx4p4tPffsZBRPljpPh6Xw0B5ibXCungNgxoE45
w0fAwK0uowUKvKfzOovb+ahXZ75fk+CEcDJHodDyoVJdaynuc0Jq4KuqIZIA
/X1GrGF/Z5xMqpW+XSXA8+4jUprMGU2nN2XZxgqQ/y5oJNGMCk2nhYSRLcBQ
pdnalr1UzL26sTG6ToB7oqTZJeNUUCj7RBl9Ajww/dMwMdIF/M996KdfC9A3
HlXS3+ECceqYSzNZCCPT+XbWKhpyKitIDwRCEMm5yt9qaajtCdXpEoS4HdgS
ZG/uiu7X+pNOhUIk766gPwpyxYTzZTVfLsSOmUS5R7YrzEL2dG7RCJHm4Rux
0OyKlWluikMLQhxsa6+Nee+K8CpNlcw9AJesplg8uhtSbx6XtocEYAUv6mx9
khtOvkPWaHIA2KxTCWcb3NBEm9lpUB6A/QQvCnXSDf8CG1ox3A==
                "]]}, {
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               LineBox[CompressedData["
1:eJwVxX80FAYAB3BHfhxHfpzOHefQZn6k7bif7te3rsYaWvIjJUU1WnTnMZWn
uRaruPKrpljOYxRNMZSyFzk08crzuqvxUqRzNVPiSZfY9sfnfdwTZOH7jI2M
jML/8/+6I9XM0pwA/NpKeJia+l5iUbON0VYfgDMTStLAbYPEZ9Da+q/BABx2
cNroSVqUhHzoMryfD0DC+uqjipiPEpnnYT2NzkJE6trrw7VLkqItflqBlAVx
5c1p1tyypDlrXB27n4WziVUldyuNoLlU2nS0gAXi8uS19CAC3g2FqCpaWfjh
Z78B92kCqEuE0x0jLMz6penvnzWG0PtG5jMCG8k9bSuyBCaIi0hOInixMRa7
5OY9bgJFtnuURxgbUXNSkfbkClTVa6XSdDb680/FHP/cFN2afObeMjaw+sH3
X2hNoTNax8jtZKP1Frn4SZYZLNbMk2p1bPiEb7+at9ocPtFXDL0kDipequ5x
75kj9Mfd+kl/DpyOvdBNyC0ga3DUWsRwoHTyNSmmEFH0+J7aO5sD40Y5Q3Kb
iGYTRdOmGg4ygq4LpvZaQrOWrTrQz8HU6IfoC1ZWeBfzSqmc4WB3xrr0L3+3
Ai1XldlA4WLY+kTh7DYShI0RSfdFXITVDPxWuUxC3Agx6vUeLrqF9n2htdZQ
mHVIbfO44D2MfmEIsUEVM53JbOTi6oGLhMuzNuiO9WaEa7nwMHlOjyxbCd2J
UVLaIhchoWT6MTdbWDSXGEo8eDCjcq88SrOF72iwviWYB/VEDH/tXVuEEpc0
moM8HG3MuptDs4OM1ayeP8sDL0sVOZJih6JdSU2Udh7eBnU9Z96xQ3MeXcUb
46HB4UXqSbI9tK1DyhhzPvY/NTd6mmiPhWcnMjP9+Pjkis8Zdrs9aCRRUvlW
PkYzQl2UNg4Qct9G/nGEjwvr5fXj8Q6IS7gkfaLiY6tNCY/f6gDF6VjmUg8f
NsOtvQUWZFS12TEYU3z8WfM4QreDjO7nvSTYB+J46odx4TUyJm2yDLt5gZCI
XFNLjB1BDGTqj8UFwmCxbvllpCN89+k0VTmBaHm45zTqHBFaWK5W1wdCVvmT
c+miI2Tt3zRNDAbCO7mu7p/Nq1CsM1WZvguEjjvA3VC9Ci127UpPugCVJq97
yuZXQSuUZwZJBdjxwC5i5isKFhI/TUraL4BjOWs86CIFtJLhyFMFAgx+Gy2v
eEOB8HaBtL5VgDz/zKU5qRPiXm5g9o8IsHHpF+XXpU5QkA2uUwQhlvs6aFWv
nFAluUay9hLi1rnxywsiKnq+22vwCxMiI96Uu7mIislzVH1YuhBMP6+emgkq
iHfua2RlQvy9sGnrIpcG36nj6sJOIWq7U8bC82kIo/CbmnRCJBQWyupGaZCv
n64YIolAj23+uMx0RnFKtXLWX4RHn2nzo3Kd0XJ+WyY5RoTi2QVqw2NnaNXW
SexsEUI6nC+brHHBwnRXZFSNCGb5Ys72bBfQaIelh/pFuBMV39045ALhRj/m
+RkRsjxyws096YiTj7vepIjBma59tvMIHYryUtKwSIw3N/sOtgzQUd0bYjDs
EaMhd2rR0s0VPTMEvXOeGElbVubHp7li0uWGRtgohgfdn9rW6wrL4GT1Tq0Y
T/URl2xoDKxJc2/6YVGMCy2H2PtSGAir0FaoPCSIUJSp2zsZkPflKzuDJTCv
HfUiWrqheA6ZYwclmLB6I2sJcEMLYz7R+JwEXamEG7t2uuFff3U2pQ==
                "]]}, {
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               LineBox[CompressedData["
1:eJwVkH041AcAx707HHl/Oc45rXJJ7bhXfsdX14snuUoRS1KoKxUbW7qn5sjL
E8d5SRJzG7OWJu5Bse5JdWjNsrJcXlqJhdFTj7zu1sPsj8/z+ePz34d+JDE0
Xk9HRyd0hf89draGWZbpA/dN2uXvpXog1UbQWut8MMnI+rD6lR7WPzE3H3ji
gyqxaCApQB87/32g/WfeB8RUWHPed/pIXJs6QaGy8FBZcSHF0ABFe7w0fkIW
fFW07Z4JBmg6N6KOOs7CFdORpYZeA/RdK1Oel7PwunKkTo8wxELvTkVVCwt2
yfTg1dcM4bSkm98+xIJPftUrK1sjEIzbkmFdNgKmIsU9GUaI3ndSrOvBXul7
30TMGEGaRg93F7FhlZwXrow3RnWdRihMYWOwUlf1fMAYHX15zLirbBSY3rL7
bRcJYzqBtKx7bHipfowteEgCacM8+YcxNm4pB2pdA02wfv8NbReZA8ZU0Itz
KhOEZMRMjHtzIBPPG13nmyKx3k5DiuTgGWNkTU2rKYr6f1Uz0jgw2UTmJ/DN
0KQvVe6o5WBdagp0VWbo28hWJHRz4G3oTMSDjIXISZlsmoM1mmXPsi4yKFkK
Sb0DF6Qpd8sykTmIxn3iHgEXT4WZE3H95ogeMgl/H8tF9vDqFp04C0iN2oWW
uVx8cl/3qxPTFqhmpjCZjVw0vKF6VktXoSOKQQvVcGG1jpj8g2SJsZyX5OSP
XASeJ7UJQi1BairRlrjzcHRuJr2g0hKeL4MmmoN4yJAvbekat0SIyVJf32ke
ioM99N74WCGR1aSev8RDGePztkmpFYoOiZUOd3goYgyceN5jhaZcqoL3mof0
4Bj7G1RraFp6ZZHGfIjlRqr4U9ZYHM6RSLz4EM51HzC+aw0KWSCu2MuH9fnG
OfkqGxDcD2Gqs3z0r22+uHzYBtFHrgn/VPBR/EHjEN5iA2l+FHOpk4/Nw47f
lpjYorrVikZ7y8f4+7PurdG26BhdmWjtiwy6tkrdbItxi3PaGJ4vbL4st7tl
ZgcTX+ZEerQvyif3Z8tj7eAZP9ZXnbnSM9jTu1R2CCmsUKvrfJHp5x2+YGeP
xDu7lX898cWEvaglK8kexWOGCsMFX2yzvWjxb7c9mq3uyNZS/VDqM3p4v4cD
NESSZLvQD0MpUQ1XsxyweGyNWHzcD/b9s/Mdow6glAyGXZT7YdvBn3iazY4g
7sqFdS1+SDC4kNJT7Yjov7cwu4f8kP04ta5e3wlSW63rW10Cl1vzB5PjnVAd
0EA29yBQ2XnfgP6LEzpPxGm9RATKZ20ZLZ4UjJc6TYhSCORuzdn+aSEFJvd7
+hKvEkhsdYwpnqPA8+0FdeE9AjtCHn0xdMAZIge+UjlGwMWgPM1M7Yykze+q
eskCjL7IyXb3dEHxqRrZjLcA3zwvzXG75ILmKxES20gBRLMPMgyXXKBRm4vZ
aQLMeK9KfSqmYvHdg7DwWgEKSiTHMp9RQaGkCs90C0CzN9zjGugKYqsX88q0
ALU/32QpbroiOmnEtc3BH27pZ6yNqTRIK8rIgwJ/yI8fmgyT0VDTtVOrjfXH
YvJRVd5HGjqndSecc/2xfve2Lc84bhh3ud1HNPojdEG8TpPoBtOgk+qDGn+c
2VSRE3zdDRuS6cqvP/rj0uKLONaoG0RVmiqFewDqQze2F1LpSHqUJ7sXFIB2
gfxyTAQdxbOQvD4dgMdty5M1JXQ00+aP6ZUGQNOVpvrsdzr+A4XSK4o=
                "]]}}, {}}, AspectRatio -> 
            NCache[GoldenRatio^(-1), 0.6180339887498948], 
            AxesOrigin -> {19.517932035838292`, 0}, Frame -> True, 
            FrameLabel -> {{
               FormBox["\"value\"", TraditionalForm], None}, {
               FormBox["\"underlying price\"", TraditionalForm], None}}, 
            ImageSize -> {530, 370}, 
            LabelStyle -> {FontFamily -> "Verdana", FontSize -> 10}, 
            Method -> {}, PlotLabel -> 
            FormBox["\"PerpetualAmericanCall \[Delta]-\[Gamma] Hedge\"", 
              TraditionalForm], 
            PlotRange -> {{19.517932035838292`, 31.58206796416171}, {
              0, 8.953347032195088}}, PlotRangeClipping -> True, 
            PlotRangePadding -> {{0.24128271856646835`, 
             0.24128271856646835`}, {0.17906694064390177`, 
             0.17906694064390177`}}],
           TemplateBox[{"\"Value\"", "\"Delta\"", "\"Delta-Gamma\""}, 
            "LineLegend", DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
              False]& ), Editable -> True, 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"20.19\"\>",
               20.18816180963404,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-10.98%\"\>", 
             "0.4399419702298354`", "\<\"+0.71%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.08\"\>",
               21.081801508028366`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-7.71%\"\>", 
             "0.457689541820952`", "\<\"+0.41%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.98\"\>",
               21.975441206422694`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-4.98%\"\>", 
             "0.4754371134120686`", "\<\"+0.21%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.87\"\>",
               22.86908090481702,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-2.83%\"\>", 
             "0.4931846850031852`", "\<\"+0.09%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"23.76\"\>",
               23.762720603211346`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-1.27%\"\>", 
             "0.5109322565943017`", "\<\"+0.03%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.66\"\>",
               24.656360301605673`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-0.32%\"\>", 
             "0.5286798281854183`", "\<\"+0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"25.55\"\>",
               25.55,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\" 0.00%\"\>", 
             "0.5464273997765349`", "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"26.44\"\>",
               26.44363969839433,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-0.33%\"\>", 
             "0.5641749713676515`", "\<\"-0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.34\"\>",
               27.337279396788656`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-1.32%\"\>", 
             "0.581922542958768`", "\<\"-0.03%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"28.23\"\>",
               28.230919095182983`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-3.01%\"\>", 
             "0.5996701145498846`", "\<\"-0.09%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.12\"\>",
               29.124558793577307`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-5.40%\"\>", 
             "0.6174176861410011`", "\<\"-0.21%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.02\"\>",
               30.01819849197164,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-8.52%\"\>", 
             "0.6351652577321178`", "\<\"-0.40%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.91\"\>",
               30.911838190365962`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.5464273997765349`", "\<\"-12.38%\"\>", 
             "0.6529128293232344`", "\<\"-0.70%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         TemplateBox[{GraphicsBox[{{}, {{}, {}, {
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               LineBox[CompressedData["
1:eJwVxX04FAYcB/BTJkK2yGtTEmnyco77nTt3921eLqUXhyJvj4ooZByRODVD
3jZN0gtKrEIvpkhohac60StKVHMehepSY3lote2Pz/Mx2bJLHDqLwWCI//P/
dZMuvdFWdvDP609RaSU8c/MfUA2wA7tUFIc/CCrFP8jLs+1wx6KzaV8zwXY0
c8Sp0Q55z8eZHY2EzdxSRe8rOwxp+dYaNBDScy5NxOiyUNdQpxtziXBuoGN6
risLNppNwq5awmOrQUZlHAsehYvVmRcIStKPKsJyFmSVWb7HagiW9zU1++6z
oBKepqpRRfA2Waod94UFqV38p/2nCamxXANNa3vM31ijy6gknGnbsOh0gD3y
XXjcH8sJD3W2m63MsYdkPmONxgnCTGiKZX+jPfTWHbU6VkIwa/iVGT9ij6PL
tt2yOUZYr1pFWnoOyBze+VlWTEj0u84/6+oA7fKoxogiQnlVr7OzxAEr13a9
mFdI6Jx54/6s3AFR47/4NRYQ/vaYvWH3AwcM2fhrRfxMWFRqsPEbBhuRc8LG
vs0juL+zCai2ZmP4Wkr342xCHNy2uAayoabzqaEoi3C8ICD8RQ4bb4vapJsz
CDflsdFJV9koYfP0TNMJ46wDEu1RNkpn3HeM7yMY/lS255weYZ5CHNoqJbj0
Xk4TuREizJiTxSmEqGWdGYMSgvwLa44kmXA4UZ6bfIqQKTU64JVEuCGbOrjg
IUFyRyeCdhPGDLWOXGBwsOlR/aFF8QSdSLMydxsOZNpf/lGPIwhaeJVDgRxM
Jq0r+BRDCJ8nrk7J5cA0NEz4PppwMDi8Vq+Jg/720KnRSELTxdSG2lEO1olv
1rzcQRhWOtSyRt8Rz4f81r4KJ2h5VbcNuzmiqE9053UYgVNxQyaNd0TGybn6
E9sIWyYf3zOocMS0OMqMsZWQ66boqXvoiPzgA8NaIYT6w8oDa5W4sPRrX20a
TPhzxFD+yoYL884uETeQoMZljuwL4iJzRck9b38CK0ekMMrjoqVnV0+sHyFg
IHDichMXygtveRRuImRYSabXj3Hxe3TY8kYfwsXUbMaYPg+ybM/gQS/C03sn
VNJFPGi3dMg1xARlkwYN4wQeRCzPM7wNBKvYrvlXKnhI9C+riFpH2NQ2pC9+
xEOQ59nOcg9Cms608RslJ3T7HlvQv5pQFfq1WYatE3RDn0h03Qnd9eaWi4Od
IKiZeuEtInyew2dezXPCXrfbHkWuBAs/L/JudkLlE9fap84EcVUEXzHmhJPu
J2cv+Z6QPCN1zjLgY/V+LjcShEqPIvclq/iIpBNrGgWEuyU165sT+AhpybdW
4xOmFK0+Gyv5MBxW9PnzCEvQ5z/+iA8debdLrSPBo+BdSPYsAT5ypGFqHEKC
/KvwpUwBjtf7sLexCWWshdHXggVg7BqpvmFPkKXbSXzzBdBuV1wzYRE+9Kza
86FZAEWc2/Z0JmHhsuC03NcCuJ7/cHzUhuCWGJ9hbihEq62Rr6c1IUaWk3t9
lRDGO9QLmlYQjhqWH9y8W4jzp5iwsCS077xSPFEpxHdM46DDywlvm++W5ncL
kfrb/iFVC4JGZqy4UAmI0mbK9poTTlxI8RnUBx64GKn+tZTg8CTL19oWcFYX
H9lpSuhgFPoniwDNTOWElyaE4OVlQbeDAOMk6eGtiwkTnlUhCxKA98UrPsqN
Cf8C1fciiQ==
                "]]}, {
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               LineBox[CompressedData["
1:eJwVknk0FAgcx4ct1You5VhJcrVyzRi/MWPG17qLJ0S5mvKyKSXnsOSotVMY
tUiyuZJ5QpI3lUgeqd7qWcrVRaGsq/BKalPt2j++7/vX95/P97Mx6IhnsDyD
wfBcyP8t+2DfF2bMhCBpLmKVjDDg6N+/NICJD5Fvk9fXEhTORQyXpjNRvf91
5uYagtn4iTHreiaCA56fZ1cT/LhFU32jTGh6dFXYVhFSM67Nhq9jocehrc6t
glDd/+Dz9w4sSLjN93zLCY+NhxjSKBbsTOu6g6UEueSPCjalLMxvujIUcZFg
9FBJ6elDFmRq0unEC4QdG3XXRP3LwkGlgq9pxYSkSK66kokFdORzFM8WEi61
bt9QHmCBZ3Np6qXnCV0q+/VsMyyQNZlicCWfMB+caPS83gIug7HshjyCXl2O
ecyYBeR6w+zu5xLcl1bSClU2brYFe3TlEOJ8m/kVDmyENwUIX2QRSiv77Oyi
2TCUeR2eOE1on3/jMlDKxsvyrQlzmYQ51++2xz5iI6/ANk1eQthQpO6zimEJ
9yxOnnI6wWXaNKDKxBIKYlOpxklCFByDHAIt0RSvL9MXEwqyAkJeZlhCdGR9
CzOVcH84MuyXBksY71PpFBwnzLDSoteMW2Jkl+LA1hSCxm/F8dWqhEI3+Umf
JIJ93/UUJ8cFTj/98ynoKOGwQbt4KJqwnGYUjsQT8uKGJQkLXO8ajaokxBFa
2j5lr+0iJGi/0DkhIkxorMivYXDAWttrlrOwUzmkV+xiysHksnZBcSRBcJsn
fRXIQem3O65V4YQQZc+qRAkHfu/r/erCCNnCkFrVWxysHrsa0nqIcOtqUl3t
OAdt/eWizoOEEbnc29vUrHDsUVHq8xDCCq+q1hFHK3Du52aP/kzglLW0JcdY
YaZBUvJ+HyHow+NO9TIrXKr59cq/QQSJ41SvrMsKwrL4RsW9hBt5i/rd5LhQ
zY94oCokDI5pDI+actGZGfJkUyBhGdd87NhuLsTHhX+b+hNYGU5TP2RyIYj1
meX5EgL6A2ev3+JiLtRN3nknQWwc/dl9govqPfYrd3gTrialMybUeAj25mnt
8SI86yxRSHXiYf1W5pZDHoRFG+uWa4l46BFs5sa5E4wj/1p9s4wHCUvbOdWN
sLP1lZpnNw/2hqo+v28jpKh81nojZ415TeV9BS6EyuCVemIza8hWLY685ETo
uaFvpC20RqjCl+RrDoRvS/jmDZnW0Jl/l9lsRzD09aIdjdZ4Nj1+vt2W4Fl5
gD81YY3s14MVT2wWfpxPtjupzofL08d1r/kEqetZFx1nPuQ6Ou7N8AgdhZfd
G0V81N+51/3FivBp6o63j5SP8LrGoaUcgg6e+s9082F4WTatYklwzZremy4v
wGBJ5VdtC4JoeHGIrrkAebkXFI2ZhGKWZliTUAD39HPqVmaEtlRm9K5TAixJ
Pm3gYEJ41+sc/65RgKYoMdtjC0HTQJgimRRAFJJoF/gjwTEuRqyvYQOTwGiP
A4aE8LYMSbOzDUY8QoUx+oQ/NEqz/WJtUOgYdPiY7oK3oTfPzUpt4M3zTcjU
Ibxt7Cg61WOD5Wbb0/K1Fzw/Eel5Rg64q+uUJ9UilNQkeg+pAUfVBdJaTQL7
ycldJmYAS5ktu61BeMA445/gBEzKb2lpUyMINxfv/nM3cPGjTmfvOsKsR+Xe
tSLA7436wJAK4T+CZCn+
                "]]}, {
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               LineBox[CompressedData["
1:eJwVkGk4FAgch2dUksi2KUc9iULSuMb4j7n8yjGUjR0pcsWmbCG5j3V1TEIH
leig1LRiPURMoo3sFj2FXG2lR3Q4KlpJVqu2/fA+76f3y6sbsFsSqMBgMCTf
+N+VH+26Q1kW2PskL5xxi/DMwatHydsCjp+0U2LqCIq5e/oL0y3QU8AVj9UQ
zIYODgpqLMDvHLsbJids4eWPdA9YYMcJJ4UP1wj7M66Nhy1iY+tzwURsBaG0
596Usj0b+tfvX1QoJzxi9TFkEWxULf5H+VgpgZn8SdGmkA31ubeNdUsIxm2q
qo/b2BBJDRWriwgbdVcsiPjKhuVho9MbLhOSwnlaqiaW+KTTNDB8kVDU6Krz
q7clDopmjKZfILSr79Bfk2GJ/sEnZSYFhM+BicZPaywxV8dlVfdZgr78uHnU
oCUYfX6+qacJLkrFpKbBQb2JqrNZLiHWs154xZ6DDUqbP/SfJBQWd9vaRnJQ
FCLcmHeccP/zW6dnhRy0+NaHumURJpxnuMY85KDhae/a+UcJOvlam+YzrJD6
8kxbeybBadTUu8TECipx4xq56YQIOATY+1hhW96Qpn8a4WyWd1BvhhUO2Sd0
sKSEO/3hoXE3rBCXeEX8ZR/hPftQ5IIhK9CayKj2VIL2gYL4Ug1Cw7Gn3sXJ
BLvuqhSxA2FRcO/0gURCiOF9aV8kwboj2SMwgXAqtj8z4dsnozt1wY5x37rm
yeyF7YSXdjk80xjCsLZaXhmDi2AXldtaUQT1YP0CJ1Mu6l8tnaEUQRDd5Mte
+HDxfHbL9D9hhKB5kpLETC5aqrQqRkMJ2X5BVzVquUgbZS4bCibUlifJrw5x
oVolFb/eSXjFPHlzvaY1tioWrRwIIqi5lTS+crBG0ovAxjfbCdxLDc3JUdbY
6VyvMb6NEPDxUavWJWvorZHrM34iZDqMdFW2W0PWsO6dmj+h+tTMnh+YPEw8
iA9d7kd4PqjdP2DKw4Lt4is8H8Icnvlgqi8P/x4qP+fuRWBniEcWH+ahwrp6
faQnwbvHZ7yqlgfLKI/KnM0EKStyymWYh72CU5117oTypHTGsCYf+UfDy167
EZ60nlfcL+ZDGjpsqy4hzNSVqyyN5sP68Zcse1cCK/zB99cv8VHTWpYXv4Gw
ufGFpqSDD0XJ9JZKZ0KK+tTSt0wBdLYOdI2uIxQHfqcvNRNg1lSIspkTobPa
wHiZnwBynazJCDHhy2yh+Y3DAnAeup6vtSes9HSjjXUCpMwrZc62I0iKfxaO
DAuQ+0i2ZNNaQsLnZNs0LSESVvP/LgJB5pzjpOcohLFqSPJXEaHl3G8uddFC
FMXx73oKCZMjt903yYR4v+dyk5xP0MNjr/cdQihOlO7T4hGcs0b90xVEGJwl
mUziEqL7ZwWtMBch50K2waAVoYC9JPR3PxHmN++e584hNO+3iPQ4IoLHL0Nl
f7IJY12O8WN1Iuyq/arMsyAsMfRLyXwjwnpphU6FGcEhNkpqoG2DyR7mCMuU
ENackVnvaIOwW++iSlmE09qF2VtibFDNipabrSb8set67rjMBk2GZyrkqwjv
6lryj3TaQFbqvWOtEUHlYLjkBBNwvXWjq82QcL4s0b1PE7jrXTUdYEDg/JXm
YWIGzJE6906uINxjnPBKEAPa/JT47OUEP6MC3yZfYCLBtdVUjzD+Y7H/wmgg
3/Hms7ZlhP8A1wcvUw==
                "]]}}, {}}, AspectRatio -> 
            NCache[GoldenRatio^(-1), 0.6180339887498948], 
            AxesOrigin -> {18.177472488246803`, 0}, Frame -> True, 
            FrameLabel -> {{
               FormBox["\"value\"", TraditionalForm], None}, {
               FormBox["\"underlying price\"", TraditionalForm], None}}, 
            ImageSize -> {530, 370}, 
            LabelStyle -> {FontFamily -> "Verdana", FontSize -> 10}, 
            Method -> {}, PlotLabel -> 
            FormBox["\"PerpetualAmericanPut \[Delta]-\[Gamma] Hedge\"", 
              TraditionalForm], 
            PlotRange -> {{18.177472488246803`, 32.9225275117532}, {
              0, 23.757911554433445`}}, PlotRangeClipping -> True, 
            PlotRangePadding -> {{0.294901100470128, 0.294901100470128}, {
             0.4751582310886689, 0.4751582310886689}}],
           TemplateBox[{"\"Value\"", "\"Delta\"", "\"Delta-Gamma\""}, 
            "LineLegend", DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
              False]& ), Editable -> True, 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
          "Legended",
          DisplayFunction->(GridBox[{{
              TagBox[
               ItemBox[
                PaneBox[
                 TagBox[#, "SkipImageSizeLevel"], 
                 Alignment -> {Center, Baseline}, BaselinePosition -> 
                 Baseline], DefaultBaseStyle -> "Labeled"], 
               "SkipImageSizeLevel"], 
              ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
            GridBoxAlignment -> {
             "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
            False, GridBoxItemSize -> Automatic, 
            BaselinePosition -> {1, 1}]& ),
          Editable->True,
          InterpretationFunction->(RowBox[{"Legended", "[", 
             RowBox[{#, ",", 
               RowBox[{"Placed", "[", 
                 RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"20.19\"\>",
               20.18816180963404,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.12%\"\>", 
             RowBox[{"-", "0.04650495370162375`"}], "\<\"-0.02%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.08\"\>",
               21.081801508028366`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.08%\"\>", 
             RowBox[{"-", "0.04573854348071494`"}], "\<\"-0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"21.98\"\>",
               21.975441206422694`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.05%\"\>", 
             RowBox[{"-", "0.04497213325980613`"}], "\<\"-0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.87\"\>",
               22.86908090481702,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.03%\"\>", 
             RowBox[{"-", "0.04420572303889732`"}], "\<\"-0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"23.76\"\>",
               23.762720603211346`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.01%\"\>", 
             RowBox[{"-", "0.04343931281798852`"}], "\<\"-0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.66\"\>",
               24.656360301605673`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.00%\"\>", 
             RowBox[{"-", "0.042672902597079704`"}], "\<\"-0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"25.55\"\>",
               25.55,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\" 0.00%\"\>", 
             RowBox[{"-", "0.0419064923761709`"}], "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"26.44\"\>",
               26.44363969839433,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.00%\"\>", 
             RowBox[{"-", "0.04114008215526209`"}], "\<\"+0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.34\"\>",
               27.337279396788656`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.01%\"\>", 
             RowBox[{"-", "0.040373671934353275`"}], "\<\"+0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"28.23\"\>",
               28.230919095182983`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.02%\"\>", 
             RowBox[{"-", "0.03960726171344447`"}], "\<\"+0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.12\"\>",
               29.124558793577307`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.04%\"\>", 
             RowBox[{"-", "0.03884085149253566`"}], "\<\"+0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.02\"\>",
               30.01819849197164,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.07%\"\>", 
             RowBox[{"-", "0.03807444127162685`"}], "\<\"+0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"30.91\"\>",
               30.911838190365962`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.0419064923761709`"}], "\<\"-0.09%\"\>", 
             RowBox[{"-", "0.037308031050718046`"}], "\<\"+0.01%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.583810654597761*^9, 3.583810685556532*^9, 
  3.583811082473234*^9, 3.591408337443405*^9, 3.5914084479237986`*^9, 
  3.5914087861947927`*^9}]
}, {2}]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Comany:  \[Delta] - \[Gamma] Hedges for Microsoft\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.5838114878464203`*^9, 3.583811490725585*^9}, {
   3.5838115727742777`*^9, 3.583811587884142*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"price", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<MSFT\>\"", ",", "\"\<Close\>\""}], "]"}]}], ",", "\n", 
     RowBox[{"div", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<MSFT\>\"", ",", "\"\<DividendYield\>\""}], "]"}]}], ",", 
     "\n", 
     RowBox[{"vol", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<MSFT\>\"", ",", "\"\<Volatility50Day\>\""}], "]"}]}]}], 
    "}"}], ",", 
   RowBox[{"Column", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"DeltaGammaHedge", "[", 
       RowBox[{"#", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", 
           RowBox[{"Switch", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"-", "1"}], "]"}], "]"}], ",", "\"\<Put\>\"", ",", 
             RowBox[{"1.1", "*", "price"}], ",", "\"\<Call\>\"", ",", 
             RowBox[{"0.9", "*", "price"}]}], "]"}]}], ",", " ", 
          RowBox[{"\"\<Expiration\>\"", "\[Rule]", "1"}]}], "}"}], ",", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<InterestRate\>\"", "\[Rule]", " ", "0.002"}], ",", 
          RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", " ", "price"}], ",", " ", 
          RowBox[{"\"\<Dividend\>\"", "\[Rule]", "div"}], ",", " ", 
          RowBox[{"\"\<Volatility\>\"", "\[Rule]", "vol"}]}], "}"}]}], "]"}], 
      "&"}], " ", "/@", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Call\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Put\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Put\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Put\>\""}], 
        "}"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4952132473995705`*^9, 3.4952132521652565`*^9}, {
   3.495213350994646*^9, 3.4952133583228655`*^9}, {3.495213543793989*^9, 
   3.4952136202637177`*^9}, {3.495213665498672*^9, 3.495213671217495*^9}, {
   3.4952138342352066`*^9, 3.49521388523586*^9}, {3.495214258316529*^9, 
   3.495214258785261*^9}, {3.4952142910183983`*^9, 3.4952142992055836`*^9}, {
   3.4952144392314568`*^9, 3.4952144771206264`*^9}, {3.495214566712267*^9, 
   3.495214641117564*^9}, {3.4952147925062513`*^9, 3.495214857458545*^9}, 
   3.4952157716963673`*^9, 3.495217663645976*^9, {3.495217869427843*^9, 
   3.4952178964276705`*^9}, {3.495217986192721*^9, 3.4952179896926985`*^9}, {
   3.4952180212862463`*^9, 3.495218065551588*^9}, {3.495218096770138*^9, 
   3.495218188113773*^9}, 3.495218579474202*^9, 3.4952187111469197`*^9, {
   3.495218744162756*^9, 3.4952187494596653`*^9}, {3.4952188203038683`*^9, 
   3.4952188234288883`*^9}, {3.4952188554603434`*^9, 3.495218855882221*^9}, 
   3.4952193374946785`*^9, {3.495219376463678*^9, 3.4952193790886946`*^9}, {
   3.4952200570149083`*^9, 3.4952200623743176`*^9}, {3.495284465908083*^9, 
   3.4952844775800323`*^9}, 3.4952845197053022`*^9, 3.4952845616586957`*^9, {
   3.4952849458174047`*^9, 3.495285022739772*^9}, 3.4952862327631407`*^9, {
   3.495286510280542*^9, 3.4952865144524436`*^9}, {3.4952868488452086`*^9, 
   3.4952868826422997`*^9}, {3.4952869897992353`*^9, 3.49528709048738*^9}, 
   3.495289290188958*^9, {3.5074663423934727`*^9, 3.5074663636966915`*^9}, {
   3.5074664743380194`*^9, 3.5074664747750444`*^9}, {3.507466817002334*^9, 
   3.507466827797553*^9}, {3.5074673499480743`*^9, 3.507467356656086*^9}, {
   3.5206175359046288`*^9, 3.5206175365956974`*^9}, {3.5206177430003357`*^9, 
   3.520617743762412*^9}, {3.520618657824809*^9, 3.52061867133616*^9}, {
   3.520620080156826*^9, 3.520620080416696*^9}, {3.5206205246678495`*^9, 
   3.5206205380078497`*^9}, {3.521404919171875*^9, 3.521404928890625*^9}, 
   3.5214224365625*^9, {3.583807556758575*^9, 3.5838075621658845`*^9}, {
   3.5838078753357964`*^9, 3.583807875783822*^9}, {3.583810013153073*^9, 
   3.5838100155212083`*^9}, {3.583810051865287*^9, 3.583810120946238*^9}, {
   3.583810170594078*^9, 3.5838102168347225`*^9}, {3.583810322754781*^9, 
   3.583810342531912*^9}, {3.583810413027944*^9, 3.5838104695401764`*^9}, {
   3.5838105125326357`*^9, 3.5838105444364605`*^9}, 3.5838106047409096`*^9, {
   3.583810677430067*^9, 3.583810679156166*^9}, {3.583810755253518*^9, 
   3.583810820584255*^9}, 3.583810851176005*^9, {3.58381092189705*^9, 
   3.583811064615213*^9}, {3.5838114982660165`*^9, 3.5838115276416965`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         GraphicsBox[{InsetBox[
            GraphicsBox[{{}, {{}, {}, 
               {RGBColor[0.24720000000000014`, 0.24, 0.6], 
                LineBox[CompressedData["
1:eJwVkWk41AkAh6fBuMtNQ+47yW3GMf+fmTFCm1II5VpHrRy15Sg3kbIVNk9U
urBEpfTQJskoV+QqWSIp5c6iRDWt/fB73g/v++2nFhDhGkQmkUiuq/ufW729
cvbOG+HA+0RK1JcmQmxSg1X2izF6Cz9PBz9sI9pjZhYWS43xG2mm+Mz8c+KU
YE0R+E1QtdQ9NdXZTTjnJbll+ZpAVGykJjLoBSGq5UTpf2CC8eaYDiXbV8Sz
KukaDTlTUHjBVHGvAeIUcygk4qAp3K1iX9Hrhwin7hKF2nZTnPS0ZHJrRggR
v8hWiq4Z/gk/OPikepRom6UfdU01Q6Vo98rE0HviZDzfxsJhM+ysiv3gbviR
cBLrGJygm0NLt9dAoWyCEL6Ql2V+zhyJfR79+i7TRKuen23ynDnWXzhfF6D2
ici8rzfb7myBopqGAbbEv4Sjw0Khwl8WKGzgPrtWMk8I9T10CSRbQtHj8ZTk
rkWiJTCdVLnXEpqiiuldCl+IEwsud77dt4T+3CEr4c9LxJaU9QEOMjS81G9V
Gx1fJoQk30nlRtBw/bZiUOTiN6LlckXjcNuqz3mnUi/PI04YRh3W16bjYe/1
5n16JDjUEVpRyXTw96Tu73BdA8Gtwn0Nr+mICOuwFDhBRtNAT7o4zQp8L1z5
17TyIX3/RUvPXCuYix4TuCUrAM7XoPGiWSssbS+lfwmjgJKxOX/O0RrR0aV9
dd2CaJJddrQptoazakHrRwgjvYi7kkGyQX1VBcW1VgQc06zyXm8bNP7+nNEP
MVC4bntUamyQpcsd3NktjqfbVcRDpWxB7nepLDiwDsffjNdVh9liOODDW2RK
gB1+N5zcaguRBJwO85cE/49jKts0GTBR8m2uZUjhySn7rvxEBo6P87lKq0kj
jboueWyAAcLUe623kAzYZf3GxhYEUsJ7KmIXZcBPuzYal03ghv+IhduYLJ40
hea2TBNI33I4rndADtwbVHURTUBiOVJx4IU81A8lrtzeAQjukDyyrVcBKfT3
PW6JQJC8wEfZvvUYJTmWf6sAGnViOmWHqLBruZl6dQAwyIk5bTquiKtnpPY4
CNnh867vlbuWlLDGI9psxtwOlXf/XvARUYa/8mux3F/tQAj1mNDUVNAwhjFa
9mp/R9X33QZVqN4srht+ZAfaD3ba1wpVJB0WyUubtkPXZbnvz23VMGIdEa5P
ZaJZajrCq0sNq0dyuhyYKCywKjkdqI4rbTSVqCNMiOpQub4r6iDlXFpSvM6E
8kz4z4ZsDfh5krsaupho9/k0VaaviceqIaUhPCZyb1nvFnuqCdXxZ0niBiws
C6ZZD/tpIem2kWeVJwtxG3hfZXhaGIk6Z+yZwcLc3ea1JRe1AcaK8M97LGBC
0yvDRgdXBHxHi0ZZmF3M/n5rSAekjsYHThJseBQdtZNO0oXfn7q5c7ZsiD5O
HryhoYd67z9C80LZKLipe/5Aix5UNOZZNvlsHCK/rHUJ10fipLvSaBMbYtVB
L51lN+LNndrFjEU2fGV1ju6u2wgiVrVjk7o9UrXlnMOCDVCI48W9LvaIi1WU
TpHYBJ7gZHxsvD0aHmjLn63dBJ/Obe4q5fagozM4O8QQj/KqDJ/226O1352V
ILMZyj4KgqEUDsom6JHO3M1I0Ip/I2HGATVTPTqaZoTh6bc11f4cBGbuGzA/
awTGPc7ZPWc4kL6X4BQ0boTCY+X7yHUcXFK6yODBGDymhF3pJAeeakXUsXxj
/Adi3j1A
                 "]]}, 
               {RGBColor[0.6, 0.24, 0.4428931686004542], 
                LineBox[CompressedData["
1:eJwVkHk0FAgAh8eQKzKGkGTGmSNq3McwvzmFRDZtzii9WIV6ViRX5QqvQkKS
pCIVpShHM85VKNF62HIrSZbYVUhr//je733v99+ndjDE9TCRQCC4rvH/7vL0
yPD+ugNckjIh+wFJIDWlwS51okHyA/P5iSgZQUfEl/mFEhrOlzmffpYrLUgV
qy6GiBHIx72tCE/XCxyz49zSDhghwyzoG69XQrBey0G0r2btX4moSl8QE7RX
ylVrKBgjoyEx7C1ZVJDKen8k5LgxyElZRptpIgKHN7eVajuMkbOraNbPmSiQ
9A19IapjAmVyxYOSYwTByxnLU65nTWBSHtU/qPiDfz5aWL9gcM2trrgd3fud
7yDV+dcnS1NYtDx68/3iP3yJq9lpppdNwXF55ZTUOcd/oetrEz9riuSqnkxd
+Wl+ylPdmQ5HMyR3SKZx0sf59nbzBUp3zEBtOSvOlxrgi/fWOfsTzVE4Ojb3
6UcLv80/kVDhbQ7B+ViPvdYVjOR554fLT81RUUXTvq7Sw9h5ZtNBO3kLuLSM
5JlsHGGIy46RM0PWvPxu0ab8SUbb9XtNgy8tUNJh6RYrO8tINgwP09O2RDFT
tX/u7TzDrp6hFR5vibwqord/ziJDbJdEb8M7S+Tofxzu9VxmtA50J0pbWCGt
sN3fnvKTkRiYb+6eaYUWyf0L3seFwPt2eLJ4xgpcroOZ4i/CEE3anjtrb43m
WHpEl8k6tG78bk+/ZQ12jWFNioIYEosbl5IIdDQtUFdY38TBM04r6/Gkg7Vd
znalXxKijW5elGo6GgPXxT2plUKLC0U6iGwDevFiQ/C1DUgYmqyvOmYDn78X
hLIYJHCCHwUTX9ggT2qmKHSHLER+RFF2a9piQPcj20mNjOZUbldurC2U7YbH
dclyOKcsEz8xYAsP//4EUWF5cEr7aDQzBnLju7XH5uUhYlE0evoSA/0F7X/w
xzeiuTUos22aAaW65oD8PxXQeFdZXVIT2N9fLxHZqgj1E7FL5XuAnH+r7rpV
K+GM5Xi3WyzQJ1fhaFSyCaME+7Lle4AirXR6Q64ymG33z94YAFx3F6V/TtmM
GxfIXnbiTFwKumrYdkoFQr+eNPliysSb5KzXxUFb4Kf6TirzEBOk2+mh8V6q
aJjAhMUlJlyaEmV9nCig3r9VP/icCe4sw30LhYq4MMnsc9NMTMTUlaZeoWLY
OiRYT5mFBGnLpe8yaoDwW16XHQta+U8cApLVUPjSghL+OwstekZXewnqIGRc
W9x8kwX/Zw8+cyLV4etO7GroYkFkpz69ck4dAuqRkiOrLBT33klT+00D1Mn2
OOltbHAOa76/MKqBuPId7pXubIzPFxqsemhiOPwyzT2JjXNntsQc7VkLZ7sk
8fMxG5qyea8GHLVQuO7AaPEoG83XFSj2zVogdDbVOJA4OGSYGVJN14Zvlk7m
rA0HwvUyAq0n2uB7pgdlB3FQ6JhGyjLYCorGVzY9lwMMiPsRb29F7NQ+ldFW
DoYDEh6Gqupg6GHtQtICB3GLQsShbB0wIqmdBupcUBNjXJ1kdFGAhFs9zlzU
yS8X1SbpYlVsKjoymguvmyfndQl68Hm9ex+ljIsV2gI7J0IPz7MrDVv6uMgX
hGaJzulB1UdJLEiUB7rzl/GwQH3EaEUPkUx4ePc+0HRsRB+D0yPVVX48nD76
IWGPxzbYPuZd9LrAg8rywV5+9zYURJUFEOt5qEsZ0jZ0NMAqi8QsmeLBS8nr
ZH6TAf4DToc+pQ==
                 "]]}, 
               {RGBColor[0.6, 0.5470136627990908, 0.24], 
                LineBox[CompressedData["
1:eJwViXk01AkAx6dxX5s7hse4ahxhnOP8fWeGEYlN0Y47sVOxVGrSIZSGkqeQ
siLkKvVaRWylcZQkIhJvKqxjk7BCW1Ha9o/P+7zP++hFxPlFkUkkkt8P/rd3
UGB2yLwl2uP7bineEAnlpwzYVzfRkZDqF98fMCDsTJhZWKz60Vn20oV1fcIM
qfoyiFuhyVhi7Fl2t3BjXrL/mTAr9NB4obsMHwvljLwkB+9ageRgIqGC+8Kn
t1XqDdSt0aTs7NqoXirMYL3hxe21Bunw9ancaxWE1/MKjXud1pjz1tRe3NNE
yIbveSJJs8Gc4N5Wl66nRMesw2G/EzZg/L1hX9NwH3E6Ucy0aMgGtT89ixo2
EBFe8l2v3jnYIqaI35LIHSFkCvLO2J63xVZGH+902xjxxDjcJWXOFvr9X0vV
uG+JUw3Gs50b7fBs/0K8rtJ7wtNjoUij0g5+a+pFlbOzhPTL+76RZHtsGboS
PZDwgWiPFJD+CLFH/K1eG0rmApG+4Fuz3GCPVdKTG7RrPxIbjmtGeKgy8Hlo
rPLNzCdCWmlMOSeOgQj7ts2hjktE++XrrUMdDDgqZXGK8r8S6eb8/SZrHXAk
xlVQKPed8GgkjPgpDsg13C1t3k6ClLfMy+bXDijbQluYViGjTdQrUGA4gtfK
PSG3SwyCXZfsuTmOGI9faTj1WBycz1GTZbOOoESp5/IsJCGZZpE/5+kEiQsl
quXFUmhT++LpXO6EKpliR5aWDARlLUtpJGeQG5Ukicuy4Fifqe4LcoZyzb/8
AjN5SLb4B+vWO+PVhE/mtlYFPPpZVyFa2QX+QRTP+B2rcXJ4svHOby5oSzfz
PyhQhFvsrVjyExcwUk8OjocpQfzbEV0fQ1fIUi+ak12V8TDDvSc/yRWM4Mht
3VQVpFJWp0yIXNHMmPLzllaF29VBOt2OQFmdsd6hRVWIM0pHj54jMN6r3+I/
oYaHbdE57dMEks72246K1NFyjaIvawjwZ5lHdfrXQH9f0tLNzUD7NO+87AsN
HHcY7/VP+vEzPFIqBjQxSvKsXr4OJHWMEPPDFDDbb5woEQFDV62fz0xroSRL
OdhDmolCY9jmr2hj1baDNjO2TPzpKRmzqKqD7Tqv5XN2MGEpKzjw3UIXzROY
YJxjIqVumPZmHRXUG+WNQw+YULPjJivfpSJ5v2xe6jQTIoFF82UfPYw4xcWa
UFjorIx4nzqhB4i94PR4sDB9cX6l+Zg+ijsYuvwDLDgGDi8HUAxAyi78pHWF
hbr3tFF2gwHCueSe5h4WwjZ116T/YogmKq+Kt8KCXVLvbqNlQ1AnnyYrmLHh
lGKlQCk2QvJNS+5tLhuxW/65+KvHWozwz9O5aWx0f5T+Se7DWsB1SeZ7LRsh
O5NipArXoVgibLRslA3Nar/aoI00kLpa73opuoH84PiE1FcawnNpOXMubtAs
WU2Sv2kMYVBmdF60GwK3fhHbGWkCXYN5tnO+G7oGiA9a2qZImgrQHm1zQ6zp
2ON1L00xXHNvMW3RDc6+Y2kZ2WYgDlG71uu7g8EG3WPzehThZHmfrztCpJZa
A5XNsSI1lXgo0R21BYpo6zdHaLdPgG61OxxJqeWnCizwIO+2+aNBd/ApJod7
6ZbQCdWQipbk4O0lqMtfsMQxo8RhRRsOYtMkKvd+s8TQ9F/1d7ZzIC9KMBOL
osO1lnM2OIuD5tzfK5q66Cg6Ur2T3MhBZv1utWv2VlhhKTKrpjjYw3qXICy1
wn+Pizb3
                 "]]}}, {}},
             AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
             AxesOrigin->{16.94674029069874, 0},
             DisplayFunction:>$DisplayFunction,
             FormatType->TraditionalForm,
             Frame->True,
             FrameLabel->{{
                FormBox["\"value\"", TraditionalForm], None}, {
                FormBox["\"underlying price\"", TraditionalForm], None}},
             ImageSize->600,
             LabelStyle->{FontFamily -> "Verdana", FontSize -> 10},
             Method->{},
             
             PlotLabel->FormBox[
              "\"AmericanCall \[Delta]-\[Gamma] Hedge\"", TraditionalForm],
             
             PlotRange->{{16.94674029069874, 
              45.83325970930126}, {-4.170494081106942, 18.635734135578275`}},
             PlotRangeClipping->True,
             
             PlotRangePadding->{{0.5777303883720504, 0.5777303883720504}, {
              0.45612456433370435`, 
              0.45612456433370435`}}], {-1, -0.6180339887498948}, {
            Left, Bottom}, {2, 1.2360679774997896`}], GraphicsGroupBox[{
             {GrayLevel[0], 
              RectangleBox[{1.1500000000000001`, -0.45}, \
{1.9000000000000001`, 0.049999999999999975`}]}, 
             {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.001]}], 
              GraphicsGroupBox[{
                RectangleBox[{1.1, -0.4}, {1.85, 0.09999999999999998}], 
                InsetBox[
                 GraphicsBox[{{{InsetBox[
                    GraphicsBox[{
                    {Hue[0.1421359549995791, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 0.08}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta-Gamma\"\>", \
{1.2100000000000002`, 0.58}, {-1, 0}, Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.9060679774997897, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 1.24}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta\"\>", {1.2100000000000002`, 1.74}, {-1, 0},
                     Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.67, 0.6, 0.6], LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 2.4}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Value\"\>", {1.2100000000000002`, 2.9}, {-1, 0},
                     Automatic, {1, 0}]}}, {}},
                  AspectRatio->0.6666666666666666,
                  FormatType->TraditionalForm,
                  
                  PlotRange->{{-0.1, 3.26}, {-0.1, 
                   3.5799999999999996`}}], {1.1, -0.4}, {
                 Left, Bottom}, {0.75, 0.5}]}]}}]},
          AspectRatio->Automatic,
          Background->None,
          ColorOutput->Automatic,
          ImageSize->600.,
          PlotRange->All]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"18.55\"\>",
               18.55154692506555,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-64.46%\"\>", 
             "0.42855064402491627`", "\<\"-9.08%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"20.69\"\>",
               20.69128910422129,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-44.59%\"\>", 
             "0.46705309449133026`", "\<\"-6.14%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.83\"\>",
               22.831031283377033`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-28.13%\"\>", 
             "0.5055555449577444`", "\<\"-3.52%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.97\"\>",
               24.970773462532776`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-15.46%\"\>", 
             "0.5440579954241584`", "\<\"-1.61%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.11\"\>",
               27.11051564168852,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-6.66%\"\>", 
             "0.5825604458905725`", "\<\"-0.51%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.25\"\>",
               29.250257820844258`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-1.60%\"\>", 
             "0.6210628963569865`", "\<\"-0.07%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"31.39\"\>",
               31.390000000000004`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\" 0.00%\"\>", 
             "0.6595653468234007`", "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"33.53\"\>",
               33.52974217915575,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-1.47%\"\>", 
             "0.6980677972898147`", "\<\"+0.07%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"35.67\"\>",
               35.669484358311486`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-5.61%\"\>", 
             "0.7365702477562288`", "\<\"+0.54%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"37.81\"\>",
               37.809226537467225`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-12.03%\"\>", 
             "0.7750726982226428`", "\<\"+1.82%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"39.95\"\>",
               39.94896871662297,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-20.36%\"\>", 
             "0.813575148689057`", "\<\"+4.25%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"42.09\"\>",
               42.08871089577871,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-30.29%\"\>", 
             "0.852077599155471`", "\<\"+8.16%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"44.23\"\>",
               44.22845307493445,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.6595653468234006`", "\<\"-41.57%\"\>", 
             "0.890580049621885`", "\<\"+13.81%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         GraphicsBox[{InsetBox[
            GraphicsBox[{{}, {{}, {}, 
               {RGBColor[0.24720000000000014`, 0.24, 0.6], 
                LineBox[CompressedData["
1:eJwVz2k41AkAx/FZYiXKsJGjcdM4Z9xy/H+umcnVOnKFJDkidnsyEkKqxTii
UhqeVe1KVFJRTQ25W+ngocNmXD3oYBk5Wkfbvvg+n9df9fAE7/0iJBLJ+3v/
q3IjuyE6WR+ThVfFCraaQ1pSLetMgAFKwvdcfVhnhm+R93Y2WhpCM87PUZph
hplWT5UP8kZgNLoP5Q+YYkRtfFJuwQju8u53WAmm6E1Lq7fvN0Y6PXSOtc4U
4Qclm82CaKA+y+srLTXBgLKfbtdfNFysHOEwjE3g03Upf481HYopkZ5B7XR0
H5ma+1JFx1rNtkPDu+lw1rUOyt1iAkU7lv6EkAZ+/4nHqtkm8Go3O5aeS4PF
iZc69YsmqH5ekc/ToOGmiUq+a5QpfDrSlryTjKE7EjU39MoUlYpZb3nVRqgo
vBOY+P3Dr6ZB9MWQIbbYf2uSbDBDXGHaozp5QxR9dtWp0DaHfvyIzcmdBpDk
luSZnzNH7YMDBQdy9XF8x6iwa50FzHcElmZ26mF50TAw7LAF+NUx5h/F9XC4
MrlpfswCLnEBNm0sKj77tmtzfCzRqzyaZZy/DRGi5Dy1VkuEM1sn3Pp0IagL
FtabWGEu9T5hTdGFX1hVgNtlK/w9elBOIVYHzzd+aRwmW4P8lN28ytMGi09o
szOtcYdVdHpNWhuPYzmcDbPWsFkSJOtFaMFK6fVsRdh2aLAz2cV8TdQ90Qiw
eLkdQ6EX05lKmtBLim98Stjgk6dbQdBRDVzW5mntrbVB02g9992gOpT7xDgL
FFukp5iyBM7qOHvca5ZTYAsDxxi36Fo1SNHL/dXXbCF6+1VaylY1nBya5Dcc
tINvvVULjaKKtXwzLfdBO5w7Xz91TIICtm1G7oi7PZT09meOflXBPx+fzrAf
2YOel50RLFRGdKmCv5QBAcPBsOmpWSUMM/fxL3EJ/KEo7n1+SREGKa+LuGKA
h6pA0lNcETHeq86RdsDK9bKfV5S24E+q5hItEegP7RZwLBQwStpRs3wdmHu5
+Mt4gDwob+JDO94DR36/1jKfuRlBtWfJRSoOSI+MK7xS9xNKTvHadvs6QLul
q/jthBx6Q4aTdPIcEFMa4ZGpJYdN5uL6s60OkGDqfjgWJQt3KQPBw2UHZPj0
mtTdIiN7zKvolKkjWhumeQvfZNDGS3L2inUEP1pM1miXDEjF5YvKVxzxsMW+
KDZsE2xjWqvHBxyhR+cI3qhvRDI+hNTJOqFMSsRw77QUGhQ2kVNdnZDwdSy7
uX0DhNNmbYzjTtAqDFeovyoJo46gJDLPCdzRNfL8mfU4UJ6h927WCdNXUsq2
50qg8nDlYCXVGXZZ3AH73B8x5tZ9+te9ziinqc/wzohDVVPoZFvqDMvgF6To
SjEE/6uwKN7jDJWGaNq35nW40GNX3SPhgkRxmzbrcVH0Ve0LKYMLgux0FPtk
RSGTkSMTdcQFE/ZTN/OZIvDwr22l33LBhTh1qs6JH5Bj1M9emXDBgq6vfsgT
EjrElqmdqgwk9soHCuVIEBlUGyzyZwDc+RrXZ2uE/V3G6eBCBkbmNTixGavE
UU6ck24nA/Whl8U6sULcCy9emF1jYHWGTZmQXibmrO9fe2TBxGtXlYCwia+E
MVkQ/Fs8E6lvPt3o7F4i4iZFZbwrmaCIE8q3+YtEVRO1VUXAxHokcO8+WCDe
l+xkT2xm4ZCwnxrxeJ5Qj0+k3vZgoTinu3lXzxcixIX7LvUkCwPFOb2Uz3PE
f/EWQvo=
                 "]]}, 
               {RGBColor[0.6, 0.24, 0.4428931686004542], 
                LineBox[CompressedData["
1:eJwVkWk8FAgARyfXImcHYuQexox7DOOaP8MQOlCuEFGpEFs5WjZJuUOHrdBS
m6RDCMvGzK6Jkm2Ro+QmSccyRDXFth/e7314H5/G7kOee4QIBILnd/438U56
XXgCBcNPR0NLEowhLal+8pwvFesCVV+4WhtjZW/91mYLA+T11RTNfDbCbMsW
4hsFQwj41DRmkhHG1Kem1y4aYo9sWcx5ghG6k5Jq7XqN0ElRC3hz0hC7IyX/
pPkbg+FykW33gyEGVLx12x8b47cweZNzmQbwai/N2cUwgcyJTJVpaQN0xL+f
Xyg3QXyxsJhtPhWOugz/TCVTjDckzuavo6KpN5Wrlm4K976PA1O/UEBP7STV
Lpmijh/10FqFgrumxBzXfWZQl52uzLuiD92xffMjfWbIpIRcfqWhj5LcGr+j
bBoWnAdSra6ToWS3wpGsoyEozOtQrh4Z+e9cSSU65niU3OE3eUsPkoUF2eYX
zGFa7OTIMNJDyqZxfrsIHcUNzYZnqnUhWDLwCz5Ch1ifxYYJc10cKUvgfJyg
I5p/T9iygYR32x/qZHlZ4KWM/odsGxLChOWz1VsswKZcez7G0cFwVQC/1tQS
d52JLXSWDryDy33drlpCOezCnaxWbTyVWWgelWcgNVnm4ugmbbg0MXViTzDw
vigtxfxvLXAPZmWtnmPAt4EQmblNC5bK/XMlwVb4qzfBZ+SZJqoeafrSO61A
5fPtaT6a0I+Lan7CtEaBTAQ1Y0ADV3UatUMqrbGK8kphOFADKj2iWYsbbXDA
OWiV2Zg6zqd4zGWdsUFPaP/btDB1SJkU+2gs2+BnQunthn/UcGpkuqku0hYe
jHMnQvs2YjmHpu0+ZAudH095Sw+pItYmOXPM3Q5fKuIo9RNE/DvzZDb2gR2e
TuwnhMyoIPySoo8UlYlSYkCv5JwyRp1Dm0oLmYjbsaXi/tIGUH/qzy8UBdzP
4HjQshL2e35z3GsLbGwz3S4uqoTrZK1PxkeB+RVtcvVqRYwTNt0S3AZ4lorL
O9coYOPzqKDWSeByjMQz0Q3r4V95Xj6faI/oCsGNSrV1KDjdyNu53R7sifeJ
fqS16A4cjSNl20OFOOohbLAGsuZilLkW++8fu0l3zOThLkUd/kNgj+YcnsDb
Sg7pEx75p80cQMqJLF2VIgNeY5yjx0EHdC17uO3IlQLhbPGSyjUHJEXTP5YX
ScJmf0vF1IAD9MaVf/16UxwJeBNYtYaFdq8Vl231YqhTlJVPdGUh4uEE/xpP
BPwPNB47hQUli0dFS11CMGz1j5NvZIFXfpvtNkLAgeJk/cE5FgZpmmO2L74x
y46UDZWRHUFTekt7Nf+ZOeHWkRcT4oh4QU16tswiU02Lz7K55IjO4cRBMzKf
GfBFcUmsyxF6qVnBdWnvmBe7bCu6xJ3w3FVVXLRpktlTHhpYBCcQtIJ23Zh8
wZRLzpDbF+8EbrBwYMYVHnOzT2WLyT0nQPKgRLxSLSfDsDf262snGJtb1CS/
7OG0igrIbWpsyPVIVMdYjnOEhtSH8n3YCJeOl9QSnuHY3WfnBeSyEaB12GRm
apZzLCuCpdvGhggqhhw6Fjj1u88uzi2zwQ0Yyyis+sSZZ/x+8wHdGeEJSvSF
gq8cI/nhgLQoZ4g/0Y0h2RG4EdPCcp5l37sfq63bWIhbziG3EIed8eB1kOpx
LRHuZMHW2NfrXSAXe+wwRUGMqxF1lFy92QXRIgWP+8XFuYFOhYOJp1zAO1ul
liqQ4P4HNlQ/hA==
                 "]]}, 
               {RGBColor[0.6, 0.5470136627990908, 0.24], 
                LineBox[CompressedData["
1:eJwVknk0FAgAhzXjNmGyKNdgDLkmxxgmgx/DjCu5XuTWoaSUJVIp2dIUCaVL
lrLssEXayBMjDVnH2yeReEgqySYGkVXa9o/vfX98/356Ow767yZISEj4/+B/
a93l1+1NNcWN6hjqwEYm1srr/nIp2Ayk3sTZs6U2+B7zcKvQ1hztsz4rqxQb
zIp8tD6o0dGj8IXD/pWB17oTkyqLdOhTD3Y66TDQm5ZW69i/CS3MBzlyJdbY
cUC+hRFigUpue+51qjWGNLcZdXZYYMxf0DMjsEJA560LkSxLRIYG+ZAsrNB9
ZHp+QWAJ06g+uZl6S7gasULOr7eCSzSFeI1jiab+048pfCuURthtlumxAPN0
j2HtkhX8ginV7AgLVFlpXfDcY41LNwWiQ8ObYPR6z/yrF9bQOFX128J3Okou
/rn9MJcBuwjfNVJGdKx3/N4sX8fAJ+ucwVt+5sj76GlYQrMBi7DXvOukGeQL
r2TbFNhAs2Pka3qNKTI8xuc6JZko4M/wRBMmWFky3x6VxEQpihTzKSZIKk9t
/vyGCQ/xhO90qDE+BrbRsgJscfZGt2J/4UbsIpKzdUW2CGX7uHu8MsJoTdhc
rZUdnryI++ZhaIRtUYJgr9t2aIul0QcOGeJvxQXhGJmFsM9Hh2aFNLg3OdGS
T7HAT91PuKpMw+O4rCwFMQs+i8tlHbsNYKcxIC6J2oyKOGobX0hFzV/6wcye
zbgxOBnZp0GFSUq8sMvJHvrwTL5zVB+3aQ0G0dX2cCnmyZJH9aDZJ5W1qMPG
4uKYKsFND5cz/MRZOWw489SKT1brgmRZFKS3ygYt933pOW1dnHk12VR3wAH2
pRXu0KFg9QLDwHvEASHqjciU1UEyO/38a29H/H5c2uLdshZmprpmkxsdofec
rxY+p4m919WDSGZOaNfgLEyLNTDG29l0q9AJRQE2HVe/bIDZsYG8QimgOC2y
IER6A2L9v7nGOABd11qCmZrrUWZM/WJxGNhYFqpiaquOcQmPP1buAFW3zdvs
QtSg8zI+4ulbICbPNj7ytCpCqi+T87Sc4ZWQqlhc+xOuZDa0hgY6I9xlvmxp
WgW94WMphtnOKJQsY8Saq0DJRtpULHKGZH1Ow3ziOniTzEYfrfzoYfdsr7aQ
wX/jl5dp7YLoObk7AWpktDakuPrFuSAwtVDd+GdlSOQXLWmWumBqvGOBXqkE
dqyocmLIBZm13QKHE4pIxYfwmnUcJO9z8joRtRZ16krk454cPFmjPzzrS8Lc
J0YrN4OD+GNJoQVbFUB/GpJCbuAgcYDZERcmj31F6SbDYg56VWNpSSlyKE8q
Hyk3dkU2U+FQVYks3nh15yZEu+ImS7tC46UMKNQ5Dvu6KxQoxT312jII+1d9
SfqZK3omcif4CdK49syh8pmsGxZy56bOP5dCn2Bn+E24IUG7dUTIkYJy+jnl
PUfc4JEt1WzwRBJbgqpFlvfckDpSl9PoI4lz9P7kr+/dIEN+6Z35gYinUivG
7RQu/jGMXT6VTwRhRHckL4gLU8q+y9UeRDg+4OaGXeSifXlIW0mJiKNZ+zlG
7VwI6x4VlIwT8HBH/qJ4lQvSNtLXna0EzLPqKxqZPNQPdPtuf0DAJvJo2Nl4
HoT23y6l3ydg/yRR2b+cB42MorZBIQGCZmOR1igPfZV33+0aJODtla3J71Xd
MVVrvqBHIEIv/rDx/S3uCCzVFiuziAh3Kxw+fubHyolpw5YniPgP1aAycA==

                 "]]}}, {}},
             AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
             AxesOrigin->{13.73712702196513, 0},
             DisplayFunction:>$DisplayFunction,
             FormatType->TraditionalForm,
             Frame->True,
             FrameLabel->{{
                FormBox["\"value\"", TraditionalForm], None}, {
                FormBox["\"underlying price\"", TraditionalForm], None}},
             ImageSize->600,
             LabelStyle->{FontFamily -> "Verdana", FontSize -> 10},
             Method->{},
             
             PlotLabel->FormBox[
              "\"AmericanPut \[Delta]-\[Gamma] Hedge\"", TraditionalForm],
             
             PlotRange->{{13.73712702196513, 
              49.04287297803487}, {-3.247810599905593, 22.15953274971944}},
             PlotRangeClipping->True,
             
             PlotRangePadding->{{0.7061149191213949, 0.7061149191213949}, {
              0.5081468669925007, 
              0.5081468669925007}}], {-1, -0.6180339887498948}, {
            Left, Bottom}, {2, 1.2360679774997896`}], GraphicsGroupBox[{
             {GrayLevel[0], 
              RectangleBox[{1.1500000000000001`, -0.45}, \
{1.9000000000000001`, 0.049999999999999975`}]}, 
             {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.001]}], 
              GraphicsGroupBox[{
                RectangleBox[{1.1, -0.4}, {1.85, 0.09999999999999998}], 
                InsetBox[
                 GraphicsBox[{{{InsetBox[
                    GraphicsBox[{
                    {Hue[0.1421359549995791, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 0.08}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta-Gamma\"\>", \
{1.2100000000000002`, 0.58}, {-1, 0}, Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.9060679774997897, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 1.24}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta\"\>", {1.2100000000000002`, 1.74}, {-1, 0},
                     Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.67, 0.6, 0.6], LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 2.4}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Value\"\>", {1.2100000000000002`, 2.9}, {-1, 0},
                     Automatic, {1, 0}]}}, {}},
                  AspectRatio->0.6666666666666666,
                  FormatType->TraditionalForm,
                  
                  PlotRange->{{-0.1, 3.26}, {-0.1, 
                   3.5799999999999996`}}], {1.1, -0.4}, {
                 Left, Bottom}, {0.75, 0.5}]}]}}]},
          AspectRatio->Automatic,
          Background->None,
          ColorOutput->Automatic,
          ImageSize->600.,
          PlotRange->All]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"18.55\"\>",
               18.55154692506555,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-41.38%\"\>", 
             RowBox[{"-", "0.792822075246567`"}], "\<\"+4.08%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"20.69\"\>",
               20.69128910422129,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-29.81%\"\>", 
             RowBox[{"-", "0.7537903711817873`"}], "\<\"+1.76%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.83\"\>",
               22.831031283377033`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-19.62%\"\>", 
             RowBox[{"-", "0.7147586671170074`"}], "\<\"+0.59%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.97\"\>",
               24.970773462532776`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-11.24%\"\>", 
             RowBox[{"-", "0.6757269630522276`"}], "\<\"+0.13%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.11\"\>",
               27.11051564168852,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-5.04%\"\>", 
             RowBox[{"-", "0.6366952589874477`"}], "\<\"+0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.25\"\>",
               29.250257820844258`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-1.26%\"\>", 
             RowBox[{"-", "0.5976635549226679`"}], "\<\"+0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"31.39\"\>",
               31.390000000000004`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\" 0.00%\"\>", 
             RowBox[{"-", "0.5586318508578879`"}], "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"33.53\"\>",
               33.52974217915575,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-1.24%\"\>", 
             RowBox[{"-", "0.5196001467931081`"}], "\<\"+0.03%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"35.67\"\>",
               35.669484358311486`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-4.85%\"\>", 
             RowBox[{"-", "0.4805684427283283`"}], "\<\"+0.20%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"37.81\"\>",
               37.809226537467225`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-10.65%\"\>", 
             RowBox[{"-", "0.44153673866354853`"}], "\<\"+0.72%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"39.95\"\>",
               39.94896871662297,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-18.41%\"\>", 
             RowBox[{"-", "0.40250503459876863`"}], "\<\"+1.79%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"42.09\"\>",
               42.08871089577871,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-27.91%\"\>", 
             RowBox[{"-", "0.36347333053398884`"}], "\<\"+3.66%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"44.23\"\>",
               44.22845307493445,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.558631850857888`"}], "\<\"-38.89%\"\>", 
             RowBox[{"-", "0.32444162646920904`"}], "\<\"+6.57%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         GraphicsBox[{InsetBox[
            GraphicsBox[{{}, {{}, {}, 
               {RGBColor[0.24720000000000014`, 0.24, 0.6], 
                LineBox[CompressedData["
1:eJwV1Pk71AkAx/FpyJlCRMi4k9znjIzvZw6DQY6NsiRU1DNPWEk6rDOEtkXx
EFM5cmU7tPGQRMj5JCSrGJQeSSWUM+3uD+/n9R+81QNDPY6SSSSSx3/9r7PP
r5kH54zh3bZydkNFF7FpWpNV7mKCyowIcXfJXqI76tP8QpkJSHKnFHJi+4g0
0ZpiCJuC8vTbIyfqS8IpO9Yz/ZApDALUw59ZDBGS2lyRoTpTqFbc30s//5ro
qt5ao7nNDHIL264+3Cwg0pgjwaG/mSGQfOiYaNQ4wX1xS7G+2wymDj3sqIy3
hIR/WIeIrjl0qBqcDwOTROdn2lmPBHPwuhfHz7KmiNRood38UXN0fH3SazI6
TXA39bz+QLOAl9jjxO8lnwjxa9npFlctEKviGNbpMkt07PKnx81agFKQKzcq
+EpcrN31udvJEq8+OuTEXJwnHO3n+YqllvjyYPMv09xvhNjgI9cjZCu4T8v8
46S1SLQfSSLdPWiFa3kJDi3yy0TKvOu91Vor6HiU1gRRVgmH+O2B9nJUZKYN
V9IYPwgxmbeyWaFUCMqZfKtzP4n267efjnZS8cI1vLX0PQkphpERejo02NcL
t9xXJsO+gdCOjKOBr7h6r9xXCKLO4oNNb2joj8ooiigXRttwX5IU1RqGwoX6
ixtEkHQ838o7yxrGAc+rpYNEwVk6OlX82RpVx0pa81+KQSTZKHfWcQ/86rcG
n3STQJv8sqNNyR4o+NUGHR+URFJx80oyyQbzLvG33YKlwDFLr+z3scGJ9+zk
JfIWiDR7+lJqbKASMreavU8arW4UKZ4sHSlmH9dG9GVwQTDV8PAEHd3LB95Z
SMiCHXI/hNxBx62KAxnxM7IQ/nGOslfLFvvOLLNK+7eiJc2uNzfGFrQgi/qk
RjkkKm2Jmxy2RZgzzV3orjzY5UMmJpYEePRl+Z/F2yBMLZw4n0FgY57MlA9f
AS1tvKz2GQLS6Utpq9cU0VyhpCGhBfg7JTU1FmyHRnjMyh134OD3N/tTi5QQ
T3vX5xkDhDyrI+hVypggOVau3gYaFVn5dXUqYLRXJdwcBgZIzn3vunbg5mVZ
X3sxBhIOE9n8MVVs2H/a/JMFA3Ea15c6lygIUH2zKeswA1H7+bU6qWpomsQk
NYOBAde8hcTt6lCrKmkYfcwAM1MQEF6hjtgIiezEGQZsVOfDx200MLYnNERP
iQkakTva0qsBCA1weu2ZWEu5U7glSBM3OqmUyFNMeF7JFPl7TROkzIJF5SIm
6k4qFJRd0YK/N7m3qZcJcb4aZ9RAG0/UgsuC15kw6nlpxG3XhtpUV6yUPgvf
RJNejR3WQewdY+9qbxbQYi2RQ9qJscirJt7JLOg1kScD+DsB2xXxnw9YUPmw
MmBJ18WNjYcmiidYyLFWzpEc0QWp52kdV5qNqKAeq8HoXfC/ops1S2dDKtZD
9hJFD40+l3jZPDZiu9ee6zTrgaI5x7LJZcM4jBmcd3Q3Yqa9VCba2BDnVSkJ
xPUhuFe/kLzAhoxk1emZv/RBnFHrMdCwg261s2fdPgPwcaGk39UOnn/092HV
AOui09Fnou3gdsHNK6rQEH7P93pRKu2glyqf5s01wuPsasPWITssy2r7j8wZ
QdVPUZQnwsFNI27CuosxfteOFkibcxB4em5xqNAYozPjNQ8DOKBW7X6/smgM
2wecP30vc5DwLJ8d8N/n+Ocqj5EbOPDckbtTvMgE60xpRtk0B44X7Z58WTLB
vw7kPMI=
                 "]]}, 
               {RGBColor[0.6, 0.24, 0.4428931686004542], 
                LineBox[CompressedData["
1:eJwVxXk0FAgAB+BxjSNyVHKkceaW+2Z+cxgMlWwqR0iUHot6EiFSrhA10bOh
bEREpDesMOMMjRIdUuuYIlkkaRNljz++96kFRXqGCBIIBM///L+7r8+VQ0vG
oPxRJ0z2lOFKzmrQ7uwyAf8DcaK9fiOXFzv/ZbnSBIxDd9kiHElulmhjGYRN
UTW0N8eVJ8F1K0j2yg4whYTLtyM5r8W4G7SYxJFmU0S0Ftk+myZyHzdsatSQ
N8MTU6rslmVhbhb1z2ORJ8xgVPnhw0EBIS7z2W2FhzwzXFXJaSvaKMCVCIzq
I+qYY0YrRK/dap3Tv2BzxvO8OSpl6l65eK5yLiYK6ZeMmSN8bfXCYPjfHKbk
wJuPNhYwmHYyPZi+xBG/XpBtkW+BxVI1Doc2z+nTDXQ4t2iB2NONik9jpziZ
TboLPDdLLBb+NtPi+4bj6vylRKHCEhOZ2XaNWY84Yi9b9gQLWoGQFBVqmFxL
7g1OI9QdssJgMP/bdMgwOePLnvq1JivM+PmqvU+cJLukKAY5b7ZGaHp3z3OX
j2Qx2XdyrEhrLI5sZfMzF8m9N+52jvVbw3iBJ+YbuUzOMIqJ1tthgyihFN/h
fStk51ayVsw5G5QpWNW62f4gi7qLv2x/a4PP8jEEvjQBPaNDaVLWtsgqHdQt
ERRE2vEiK2+WLfQM9H/x+SoExkrITNmCLfrYqQnyMyIgpu8sXHS1w3HKRPnQ
qCh6tnx3tS+3gxjP9umlAXGklXWsphPsUbE/f4XJ3QCGWXb1sK89nCc/qYk2
SIHY4eVHarTHdBjTrbNcGt0eJKkwOQcg3rOZzJNB6vhMK/tXB+Rx/3lS3C0L
esT9CME+B7wVqXm31iYH4Z/xpN2ajjBw81nxbtqEriynwcIkRyTkiUo11W/G
BSXpc1OjjuC9eKAmX70F9DsjJiaWZCgrB1lGl8lD2Pp3fsJlMsICpd2Girei
qyeM1TtHRnN5S4DxNQV0VCmpS2gCEn8dj76Upwj1k0mr9/YCPsZbM+cylZBi
837IKwmoOtVVzDyvDD7BtXrtLvC9+cT9yoRtoPTWnC8dBWgE0iNijApKc+X8
nMUoYDnx3gRHbofAgdPm8xYU8C/GLXaEknB4+1tJ1hEKFENZKTImqmifwpT1
ZQraJWazOTWqUK0pbx1ro+BoDa5F6KkhOVqi4MIcBRs9rpWqVKhhwi4yQk+J
CvbSfDVPQx0Qes4YdKbCP5/Ojr+pjpv91qSYU1QQra9z9VQ0QLhS/E35FhW1
o5/7XxdqINBbcLB9kAqvRJcXGfKa4Koeqzy2TsVP0o1xK5YmVGceJ0sZ0FDe
8fXjtLQWku8Zezd40+Ae4r6cn62FiZh8E+90GpZFb63TxXcAjqvi/zygoajq
u9hy6g7cFAngl/FpoO/y2HRLUBuEgc5mpgwdc59uq3gmaSPwqg5r0YGOq1d+
agv80AbHNyesIIwOG4t9pnWxOiBpLNHsC+mYeFVlH/BVB0mz+7fxe+jIOCPg
vPGkLsbrHy6nL9NhrHJwb+uCLshxqgOG6k4Y4dT6hofpoQSp5cN7nHA2SOSo
8owe1kVnE+MSnaAl4hfVH6wP/6e795OqncCruH8mblIfbQUNRt0jTohmiqfq
+Btgu7+CaBiRgW3zAbmvRg1wVitxXMacga5cdmHaAUOMzU02sg8zEG4qVWbx
3BCODxh5frkMbH5xpPa9hxFK4qtDBVsZaDnd3MQaMMI6VYZSOctAsJJsJ5W5
E/8CNNxErQ==
                 "]]}, 
               {RGBColor[0.6, 0.5470136627990908, 0.24], 
                LineBox[CompressedData["
1:eJwVymk41AkAx/FJDIlNikTuW85xjfP/m8PIEbIpohzVqvUssjlaZp2RKCQT
W02lUSQrSeQad4hNWCvkTI+UWVG7pWLbF9/n8+arGhTmeVSIRCJ5fut/XX0P
XDi4ZIzh/LnB2uczfIl5dUbJbhOcqarLsYqc4vfELCy/LzZBzOPeE3vGXvAz
RKt5EKYgmzV4USp9mO/CSfDK9KcgZu5s5r3Ffv5GTWfycC0F9w7MVARpdfOf
VG6pVpc1RdP3anMuLXX8DPqL4LATpiAtLH8qk0/kOz+7JVfXY4rJnpeyitk1
hHhAeBdZxwzoUN9N1u8mugVWv3gmm0EnvJaitHuQOMtev5M7boZdI5QfvbtG
CWeJ3tHXVuYYzGa/8m6fIjZc5mSa55lD7Ga6QV7nLNGlG2CXuGiOoZt24oGC
10R6ja6gx8UC9NyCuHoLAeHkuMyVu22Bwhq3lgGPd4TYUL37ESFLvORqbM65
tEx0Hkkl3Ttoici4P/Q4f38gziy7V3yuscTePa6bZrw/EruStgc5bqUiTpHb
GD2wQohtnpHODaPizWQrda//V6Lz2t3W8W4qSi43sGO+rBFnDKNO6mlZYfhW
OyvCax0cGwjNqEQrsGNlzVyrhCDqumGoecwK3S7PyN2KwugY6U+VpFqjZts/
jW/OiyD1+BVLn1xreEyk+FWIiYL18egcT2CNzEL2hHyGGMhpRgWLTjYIC5x0
1JEVR4fMJyfbIht8UCjLe16yEam8lpU0ki1U+2c6DVmSYJlmlg742mI5OWVK
+813ILd4+SlX26Iq/3FYkKsU2j2UJUOk7YCFxKkk7c04PTHX8PAnO9wg3jl8
IEuDGXo/VKjLDn1ZMlcfzUtD+GusspuGPYZeCF497d+CtgyHvoJ4e/yuy1an
8rciRX5T4uyIPXx+bvJcKpcBs2TYxMSCwJ+1NSdXebIQphZOx+UQ0CT9kO7H
3Ya2jpDczrcEHBmd2RJX5NByR15NXAOwTZk4+x13O9Qi4lfK9wDCraXRQTx5
JFm97PeKB7hr+vvFyhUwTXIq/XwXELc+rEtq3AFaZ1nyjRGAEeEmcHqmiBtZ
0n6OYjR4FQuKZueUsG5/tNmCOQ07BKrFx4VUEKg0JpF7mIaP5NtR6RdU0DyL
WWoODfXcVPt+DVWolBU1jDfSEFzVtMZ4pIqEk+KclLc0rDp71Y67q2HSJixU
T56OeH9maOGcGrB+kNXnSMfrpXMKWcnquN5NVY6KpMNWhNLCU9EA6cLVfxVu
0hHDMQ6a4WsgwEeor7mPjqu30j87B2qiSSW4OHiVjrvmdudHhbWgMvckQVKf
AR7DRT7vjhYSyo19Kn0YON1XeS3aUxuTUXkmPmkMeIxFKSV/0QbsVzasPWBA
OPgip7pYB9dF/Kd50wwUhkuIyezXBam3tdZZigmdT+MRl0X1EHBRJ3fRjol8
ksRfzrV64PueC+GEMLGQmmumHrYTyupLDNsCJowyIzM0tPQRP79vx3QHE75S
90fdJvQxUVH3Pu09E+FbnDQLfzMAcUql10DNAaF51seUvA3BxemiAXcHeHJS
ea3bjLAqOs8+xXaAmqzBSM5zIxx66rZPufTbL34ppc3NGI2cSsP2YQegqy1/
sMIYSofkREPILKQ+vqb7ScYEv2qyJ6TMWKCJ6FhSYk0w/naq+mEgCyeSDjbH
T5nA/gEr2y+LBRkCnVO7KODGlh4TamDB0KbPxbuCglW6FK14noX6KEnXGXlT
/Ac6pkQx
                 "]]}}, {}},
             AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
             AxesOrigin->{16.94674029069874, 0},
             DisplayFunction:>$DisplayFunction,
             FormatType->TraditionalForm,
             Frame->True,
             FrameLabel->{{
                FormBox["\"value\"", TraditionalForm], None}, {
                FormBox["\"underlying price\"", TraditionalForm], None}},
             ImageSize->600,
             LabelStyle->{FontFamily -> "Verdana", FontSize -> 10},
             Method->{},
             
             PlotLabel->FormBox[
              "\"FutureEuropeanCall \[Delta]-\[Gamma] Hedge\"", 
               TraditionalForm],
             
             PlotRange->{{16.94674029069874, 
              45.83325970930126}, {-4.080318520819049, 19.105030778204977`}},
             PlotRangeClipping->True,
             
             PlotRangePadding->{{0.5777303883720504, 0.5777303883720504}, {
              0.46370698598048055`, 
              0.46370698598048055`}}], {-1, -0.6180339887498948}, {
            Left, Bottom}, {2, 1.2360679774997896`}], GraphicsGroupBox[{
             {GrayLevel[0], 
              RectangleBox[{1.1500000000000001`, -0.45}, \
{1.9000000000000001`, 0.049999999999999975`}]}, 
             {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.001]}], 
              GraphicsGroupBox[{
                RectangleBox[{1.1, -0.4}, {1.85, 0.09999999999999998}], 
                InsetBox[
                 GraphicsBox[{{{InsetBox[
                    GraphicsBox[{
                    {Hue[0.1421359549995791, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 0.08}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta-Gamma\"\>", \
{1.2100000000000002`, 0.58}, {-1, 0}, Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.9060679774997897, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 1.24}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta\"\>", {1.2100000000000002`, 1.74}, {-1, 0},
                     Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.67, 0.6, 0.6], LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 2.4}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Value\"\>", {1.2100000000000002`, 2.9}, {-1, 0},
                     Automatic, {1, 0}]}}, {}},
                  AspectRatio->0.6666666666666666,
                  FormatType->TraditionalForm,
                  
                  PlotRange->{{-0.1, 3.26}, {-0.1, 
                   3.5799999999999996`}}], {1.1, -0.4}, {
                 Left, Bottom}, {0.75, 0.5}]}]}}]},
          AspectRatio->Automatic,
          Background->None,
          ColorOutput->Automatic,
          ImageSize->600.,
          PlotRange->All]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"18.55\"\>",
               18.55154692506555,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-58.59%\"\>", 
             "0.46991696312191233`", "\<\"-11.31%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"20.69\"\>",
               20.69128910422129,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-40.15%\"\>", 
             "0.505406952730404`", "\<\"-7.32%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.83\"\>",
               22.831031283377033`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-25.08%\"\>", 
             "0.5408969423388958`", "\<\"-4.06%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.97\"\>",
               24.970773462532776`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-13.63%\"\>", 
             "0.5763869319473877`", "\<\"-1.81%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.11\"\>",
               27.11051564168852,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-5.81%\"\>", 
             "0.6118769215558795`", "\<\"-0.56%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.25\"\>",
               29.250257820844258`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-1.38%\"\>", 
             "0.6473669111643712`", "\<\"-0.07%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"31.39\"\>",
               31.390000000000004`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\" 0.00%\"\>", 
             "0.6828569007728631`", "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"33.53\"\>",
               33.52974217915575,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-1.24%\"\>", 
             "0.7183468903813548`", "\<\"+0.07%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"35.67\"\>",
               35.669484358311486`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-4.69%\"\>", 
             "0.7538368799898466`", "\<\"+0.57%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"37.81\"\>",
               37.809226537467225`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-9.93%\"\>", 
             "0.7893268695983383`", "\<\"+1.89%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"39.95\"\>",
               39.94896871662297,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-16.63%\"\>", 
             "0.8248168592068301`", "\<\"+4.38%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"42.09\"\>",
               42.08871089577871,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-24.48%\"\>", 
             "0.8603068488153219`", "\<\"+8.36%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"44.23\"\>",
               44.22845307493445,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.682856900772863`", "\<\"-33.22%\"\>", 
             "0.8957968384238136`", "\<\"+14.06%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         GraphicsBox[{InsetBox[
            GraphicsBox[{{}, {{}, {}, 
               {RGBColor[0.24720000000000014`, 0.24, 0.6], 
                LineBox[CompressedData["
1:eJwVx3k41AkAh3EJIYWINI5xk3GNMXL+vq6hIULl2BlJQmJa67YVIaWhqFar
4XnSxiIlFVNypGmxyq6UpYOIh5TKuEvY3T/e5/O8mqFHfA+KioiI+P7X/6re
OF0fmWIEWY/dUusf0bBBmpx5IYACxbLV0HA/GlbD+d7NVsboGTfpnxu1wJTA
S3VCyQRFfkF9gkQLDJPH3ivMmyBu5NaX15IW6Dl2rM6h1xRB0dc7mDwqQmOk
W2lBZgiO4iiqm1DxirRXv/NPM3w02nssrNUcfp2lefuszXHimsE54z3meJr8
aWa2whximenFORNmcNG3DjqzhYoQHaXSnONmaOrNeqhxmor0yYuahKIZ6Fnd
enULVLyQC1ZI3mOKm1TVPGaEBWIfOGzSzTKB/nDEzNt/LJBZnTVUedcYV87d
CUxg0HA8qk3FaJyCLQ6rLdL1NJg78WS7SBQUTDL1ruhaovC566k7vkaQ5hXm
Wv5iiQKrR6lrcrchY8e76U4xOhZqvwz0txtiacE4MCSejks1hyKDJAwRX57S
MjdCx65L6WFlbgaY3P2HLtfPCr5ZpZl9XH2ErZXPJQuscH2KdU/muR4Ga1nT
ddTtIKuQlfap6WFvSEWAx9XtCG/g1Y9F6eKvjbPNQ/LWoPY3Xrv/QAfuTYRu
4glrDJ+V6vooq4OHh7nc9UJrcDk6M2cjtLF9a5/wSogNRiIp1bcfaaG2QyuA
3m2D7pYydpimFrYlcZqfELYYiyhATaYmruo26OyvscVwvV9k8QQZpBfi3Hl1
OzTzJbuofmRczPARcs/aIf1me+3ndA3ImJf4a67YQaAQN/UyVB0n375vqo+x
x2rx7/6GnmpYyaPpeA7Yw7vwsM1rO1Uk2qWfGfZ0AHvuU+QHGglfPjyZSmx0
QGxeW7AXbSsii5T9ZSgElHm6cUs2KhhyO9BUyiNgUHhAesR9Cyg/9xXwxAHS
Bk7HDFsZh3yXXcLtgUy3ywKVVCWUGWovmiUAJYE/8R1KNuOdyI7rS9WAj4Sa
FbNdEer9nOC2UWCzgcxbzUUFBNVclC9QdQSfXnGy0lQBhdkNj3/Y7Yjml/ej
BDGb0MMeStLLdcQohXVw1215yFpKGAkFjtCP9ZAzW5aDpwxl8MHSf+8RPQsv
OZwe8SnItnBCQNdgaCtTFo8bklx8DjtBu2XRvV9sI0TOlyyQfnOCIqtKJa1T
BnaHBFVjr5zQLNvDiuGtRwom2LWbnEFPKxsNTJJGvbKs/FGmM9R2ZEsvsaUw
/Zn2mJHhDNEK/riEtyRM2oKS5BuckVMidsaCuQ5RJenb3gidkUKK1rHylkB5
fPlAuaEL4jM/2XawxTHi8TQ/dr8LqkcvdJckiEFDe9rZrsgFU1XDGUcK14L1
TXlB4pkLftzYWjfXIopfn9lXPZN0BfI1bkwI1+BFxQF2MVzBd2BVilPWQC49
Ry4i2RVXo2tXxTgi2OlfIzC/5Yplxex97kdWiRyT3sTv467ofzk36Si/QrSJ
Lxm2azDAs7rXGN/6nRAdIA8U+DNgk/fx8v60JcLhLiOfdY4BgzRbrVzmNyKV
G+2s386Azzj171StrwQ/9Py8cIWB7Lh6Wb7EIjFjfa+yke6GdXShV9f8PGEq
P8g6xXFDPv/rsuf0HBH9fq2cb7kbSMy4oo7FWaKixVCgOuiGweDo6l6pWWK0
0DtxfLM7Fnn8bhndGUKTk2B4e6c7yAHfqqWY0wTblffm6El3GIlXTEUlC4l/
AS0iPes=
                 "]]}, 
               {RGBColor[0.6, 0.24, 0.4428931686004542], 
                LineBox[CompressedData["
1:eJwVkns8EwgAxx1WHpFV4jLZsK0xk3mL7TebrUgdqSmrPHpQ0fXJ86pLkotF
5lxXOYVz+6h0KNQptpAcPVRcL+ZZreNkEpWj6/74fr5/fP/9UiL3Bm/X1tLS
Cv7C/yZdPl4bnWKPy8UT5kMZjjAyIB/9MZQJlUrEe2rkiM87rq1tcHfAPFJB
zN18Fsaa1pDeLGbBZ+OoTGnBQj/5lXrhJAtxp3h11SUOeHToUA2nyxHnHucP
lDEcEBlrcMtl03LcN1EbFFYy8dxiA73tz+WYDVzhLHNnYl1bcfZWTyewpDlh
xxrscTf5n3cTZU7Y0tp/NMXPHgK656YsczZyCK7lsXftUN+VrrQ6zkaD7/HO
iHV2cEvvoNVMsTF6+MW/658z8DublO2/0xlW9SyqfwQD9P6d73r/csaaT0cC
OeplKDp5dWOC0AXfu3clsPcugznns8Kg1gWV8cvO0SbpkI3404qoruitOtCy
5BAdBgWnTrj+5Arjt/dHjXXpSFs1MN6m6wYwrc10pDRMTzlsDI93w7cxCdwp
Ig3x8hTF+0E3nJe37hw+TcVIyG2qdJ07OgYtcnutqNimQzxBbnKHFmXv9cdy
W6iqJOM1bA84bmnsu+Ngiw3hZaEBJR4ILzDVv1ltg/vGEw19RE/InkY7Va6w
wcp6LjXxiCeUpjc3ljZaQ7lbKjXUeGIseH7a6VXW8FjyRFMU7gVKbuTFEx0U
VLVah7p1eCHoXs2jVDEFdklxDe3cFThioD8dryKjhFpnG1GxAldEEpuY7WRY
dBKkk0u90ai/9ee6p1bITwvSSHO8YZ1OUJe8Wop5ToViyqw30mcveUgnLHGs
V11fG+uDweTgzP3alpjNdrFd3eMD/rsPz8JMSEj0Ts3qX81Baex5O8FSC7z9
u30s8SYHumq/A0zmEkSfMRPPY3IRFTnSvsjra/SJouqLC7i43Z1HmhGZg3ng
iayAANDEnrEv15shJnhGsMMHSH/YW38vajF+Y9h8WJ4AvAzIMK7dZ4oBrVWX
pssBfgtz67nDi7D0adyWliGgFI8rMrIXYlNFPlFG4mHOjRStvQULcCqjrjks
hIdoV3KQ+AIRjzb3JdFO8NBW0VLMvWaC+a5z7DVNPASGPB9amzUfq+cxVTem
edBbRc8gy41wfDBIluHsi3afeLrmliGa65IEQbt9kcO+1XqrRx9aeYVTFr/6
IphuvCvv41x4xzRdfPXcF6akMMMo0zlIwZvNVQv4eGBSVu7spItas/nEg/58
ZBHeB+oGamN81KVZmMb/8i/vbWe0Flgtm5KIdXyQVZaUAP0Z7q7CVLtuDR9l
d65FjeAjVx4v75EzBFheFSTPTn7PHQy4m7svQoDSs8NqVqWGa2Uzzvc+I0Co
nqG46MEwV/LJbGrOQwHwgtM9wBninn7oc/Ghnh9yJS8b/SXPuJ1lUZt/gR/C
CWfPnk9o5pqkZprsTPaDUuJQXH72qiJQXNHkVPmlVw1a0vQ6FZmsrsR/X/uh
iNCQ2ZHfr2ghTDPuWAlxnZ2lm0N9o9DuIffIxEJ0Ol5SUMPGFJxqYa7kpBDf
CImH0m0mFN9J9/Dpd4RolSR5DQ5PKa5F5k1qZoUI2d8zxaueVrzzvH7hppsI
HZn8mqKDnxWORJXkhzgRbDtC/jhc8pVyj1rHJFguQvSLueYVGTrKMgWjiaQS
ofRVXaJqF0E5dGpt4mvTlejTxHYZrZ2rpMQlMK4ErsSyGbKLj7O+crNfQffB
YyuxTa8zb4+ZofI/M91EbA==
                 "]]}, 
               {RGBColor[0.6, 0.5470136627990908, 0.24], 
                LineBox[CompressedData["
1:eJwVznk0FAgAx3EzjCTFUFGukatxDGbGMZr4YQ7R8dBzZVwlKtGBScnK5siQ
o7LrWfscr1mlXOuKDB5ddFGOLZQk6mljtCmzse0f3/f592sQHusdQZSTk/P+
0f/q3Mxsiko0xzdplp9Chi3WKlN+vuRvgdhD1ZfTibZYOdi8R2JvibOOEYcH
f2Jirnu3zvuNNJgerBmZW2ZggvJuRuMLDdGz2a9GfmJg4OzZRqdBK3g++p6c
Q2Qg/KhyFzPQGj1KxOZ1GXS80PY17X1gjZHfizKC1tLh01uWE8KyQXpuz1zC
FRs8PPVx4XOlDZ68SJUK9G3AMWUFZmnRUZ/yPJtcZY32wfOd+pl0WJ+71ZHv
YA27809NGhfpyGvZv7E91wrVdJ0cj0gGFg3PjH+q+/E5EbnwaoiBPM6t4bZh
S5Tm/hkQz2MieLMe0YBgCS2nlQ7lJiYirl4T6NMskD/rYVJqbIuSqX0fmoLN
oVxcmG17xRbKL5mV0wVmSN3xRtqrYIeaNOYvdb1UyBYtA0Lj7JAxFdi8XpGK
OHFixz+Tdri09IcSmbsVs3vvGIt87DHUoy0SZ5jigDw5m9Jtj12cJqfBRyYY
rwuSNtIdsHhKaFiiaQLf0Ep/z3IH/BUewlo+YIzH6z5LXpNZmCPEpHxtNIJ7
u7NxwjkWWL4VX0XKRug8IhKtmWfhVshKWUu4IRw2D8+XhjoiVi81KVmyBXX3
t/jbPXWEf4F55pjuFpgJYyR9ztsgbJP1DKYYoNy41SisZhv6iqT0yGkKtJ+T
RF/02PC2VBvI96LgcqrXvOgiG/qzlZyqZH2o2JT4GSyzoTiTzI8I00Paq5n2
pqPb4bO7/IaXpy6Wc5hGO8e2Q0VfI+4YWwcJ7JSsiZ1OsArsL+liauPTh765
hNtOaFsZpXKZmxFVpOmnYuGMWlU7LZnjJrzm728vK3aGetZo1KS7FizODOcX
k4CxmKfaywJNHPL+zjm4HVCVkG08T2/EVarhV+t4oFpYWtlbsgFv5HZUyW4A
DcVJqUn310NvJCb47lvAxEwsCV3SQGDNZXK+jgvkDXUFQoYGCtNbe/btdYFH
+oSg86Q6BgSvhSbZLpD5LHRuayND1VbRfL7bBerZ3unvV5OxU8VivE3mgku0
lZsPQtSQOemVn85wBVEojW1JVEVPq5DjdcQV9RHn3F1d10GuoGRRu8IV9tSq
KetNa8E+1H393QtXXOyK5Z9fXoNEvBfUqbuhgfbkKFuqjCZNVXKShxtqjj3w
D/i8GtK/mT28VDekZgQrvVRYDdrdQCG51Q1bT15M6jJUwuGSFLPReTdUMAIa
VbxWQRwnHhNTOZDel9TfzlbEpOfDvONhHKgyOuL6h0jQN5S6sYs4IJ0IlHlY
kRC0pLmo2M9BX1oej1qogF/7t1/vV+IiMibMN3qNAp5X7hf8Bi5GzB+Zrc+V
h1rKBbXIU1zoSp51UwzkscuvptumlguGcbxBQRcRF2iDCf9Oc0EJq3OLOkbE
XZKMek+fh7HjmWYVlkQQxyhj+X48nPBbGnT9RoBTAy8vKJeHYfIqHv8ZAadF
0W6m93jQKKs+XdtGQHN4wZf5ZR4MSPMnk+sJWGC1XLttxwfR6bFNXTMBVuTx
oIwYPlo8eQ3ufQREz8ireYv54NACZJyPBFR2ULt1xvkon1JcJdYl4m3hnoTp
De4YOr5n+EgQEQYx8dT6Xe4YGaBHF14jQsAtHk1Kc0etUt0dY5I8/gMRRzDZ

                 "]]}}, {}},
             AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
             AxesOrigin->{13.73712702196513, 0},
             DisplayFunction:>$DisplayFunction,
             FormatType->TraditionalForm,
             Frame->True,
             FrameLabel->{{
                FormBox["\"value\"", TraditionalForm], None}, {
                FormBox["\"underlying price\"", TraditionalForm], None}},
             ImageSize->600,
             LabelStyle->{FontFamily -> "Verdana", FontSize -> 10},
             Method->{},
             
             PlotLabel->FormBox[
              "\"FutureEuropeanPut \[Delta]-\[Gamma] Hedge\"", 
               TraditionalForm],
             
             PlotRange->{{13.73712702196513, 
              49.04287297803487}, {-3.386437556358077, 21.527410003111957`}},
             PlotRangeClipping->True,
             
             PlotRangePadding->{{0.7061149191213949, 0.7061149191213949}, {
              0.49827695118940074`, 
              0.49827695118940074`}}], {-1, -0.6180339887498948}, {
            Left, Bottom}, {2, 1.2360679774997896`}], GraphicsGroupBox[{
             {GrayLevel[0], 
              RectangleBox[{1.1500000000000001`, -0.45}, \
{1.9000000000000001`, 0.049999999999999975`}]}, 
             {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.001]}], 
              GraphicsGroupBox[{
                RectangleBox[{1.1, -0.4}, {1.85, 0.09999999999999998}], 
                InsetBox[
                 GraphicsBox[{{{InsetBox[
                    GraphicsBox[{
                    {Hue[0.1421359549995791, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 0.08}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta-Gamma\"\>", \
{1.2100000000000002`, 0.58}, {-1, 0}, Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.9060679774997897, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 1.24}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta\"\>", {1.2100000000000002`, 1.74}, {-1, 0},
                     Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.67, 0.6, 0.6], LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 2.4}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Value\"\>", {1.2100000000000002`, 2.9}, {-1, 0},
                     Automatic, {1, 0}]}}, {}},
                  AspectRatio->0.6666666666666666,
                  FormatType->TraditionalForm,
                  
                  PlotRange->{{-0.1, 3.26}, {-0.1, 
                   3.5799999999999996`}}], {1.1, -0.4}, {
                 Left, Bottom}, {0.75, 0.5}]}]}}]},
          AspectRatio->Automatic,
          Background->None,
          ColorOutput->Automatic,
          ImageSize->600.,
          PlotRange->All]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"18.55\"\>",
               18.55154692506555,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-46.99%\"\>", 
             RowBox[{"-", "0.7798681077119067`"}], "\<\"+2.27%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"20.69\"\>",
               20.69128910422129,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-33.62%\"\>", 
             RowBox[{"-", "0.7402903727425358`"}], "\<\"+0.59%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.83\"\>",
               22.831031283377033`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-21.97%\"\>", 
             RowBox[{"-", "0.7007126377731647`"}], "\<\"-0.07%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.97\"\>",
               24.970773462532776`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-12.50%\"\>", 
             RowBox[{"-", "0.6611349028037938`"}], "\<\"-0.18%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.11\"\>",
               27.11051564168852,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-5.57%\"\>", 
             RowBox[{"-", "0.6215571678344228`"}], "\<\"-0.10%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.25\"\>",
               29.250257820844258`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-1.39%\"\>", 
             RowBox[{"-", "0.5819794328650519`"}], "\<\"-0.02%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"31.39\"\>",
               31.390000000000004`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\" 0.00%\"\>", 
             RowBox[{"-", "0.5424016978956808`"}], "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"33.53\"\>",
               33.52974217915575,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-1.34%\"\>", 
             RowBox[{"-", "0.5028239629263099`"}], "\<\"+0.02%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"35.67\"\>",
               35.669484358311486`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-5.25%\"\>", 
             RowBox[{"-", "0.463246227956939`"}], "\<\"+0.22%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"37.81\"\>",
               37.809226537467225`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-11.49%\"\>", 
             RowBox[{"-", "0.42366849298756803`"}], "\<\"+0.82%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"39.95\"\>",
               39.94896871662297,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-19.81%\"\>", 
             RowBox[{"-", "0.38409075801819703`"}], "\<\"+2.08%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"42.09\"\>",
               42.08871089577871,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-29.94%\"\>", 
             RowBox[{"-", "0.3445130230488261`"}], "\<\"+4.27%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"44.23\"\>",
               44.22845307493445,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.5424016978956809`"}], "\<\"-41.63%\"\>", 
             RowBox[{"-", "0.3049352880794552`"}], "\<\"+7.64%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         GraphicsBox[{InsetBox[
            GraphicsBox[{{}, {{}, {}, 
               {RGBColor[0.24720000000000014`, 0.24, 0.6], 
                LineBox[CompressedData["
1:eJwV0/k7FAgAh/FJuVWOQsS4cw1zMuP8zimUo6eUdVti09L2RNlISrTJklkT
CWVZuRNhlUKuEQ+VrKxotfaRh3lsWhZh2x/e5/MXvPqhMYfCpQgEwqEv/e8B
v6+yAz6SUSYOz5Vb3AWlWUNu+UEKck3+Ciy7tRv95+YXP92j4Fh4y4iEq450
2aYSbKPC+3lL0phEHe6ii0euB1FhVVv8OTxfA4rGbjKjLVToqvuqZLhq4nm9
WpOhOg3D8z533Vc0kc55GxHzHQ1JQaY1BRV74PbiF81H/TSkrMj4JAVoQSH4
lFjGlA5x2bWXcyra6JOwvj90mY7NkpizUz3auJa41aJwgg5ya0ydf9JeuCkN
/P6BxUBKCEn6GFMH8vmi64wcBhgU6x0vPupAbBbsmLzAQPGj2cTOGl380Gwm
6Xe3QaXfWy3rk0S4uiwWapbZwFLtzWTqbj3IjTz2DJOyRc0Gq7omVg+9YamE
+wG2OBc7HZsxooeri551a822OLqp/0yfqY/9l/aEuuxiQhL/wuTELX3IqbxX
FcYwkZigax++ro/eoqpnE31M1G6QilVCDHDVKu6MuQkLQWvD0tFdBnBpdTaO
S2ZBOOCtEW9uCNkD8iPt4yxQFeUzKVmG6B57mbqdaYeTpXxL0ZIhUr+5besr
tMNB7c8NpQFGEPwbPlMisUPkj1n/BHYZQSbNOm/B1R6nMora2kjG6N694upQ
ao/TUWKJWGSM1JKO1TSCA3LXkwLjCSYQ0K5XvvJzwHz+yOLACRPIdBzxJzY5
QIV3OLf7tQm6vIjbo1QdYfS0xy6UvQ9XJmdaG791hEONzmBR9T7woh9ES4kd
kR/K9LigZYpt6+eJHkZO6I4UP/ycZorOdP5QXpITVGst5bSWTJGitTN5eswJ
/RT+gddhZuCVj1IoNs54qOmXQRo2wzZm8VTCDWekUdfG9Hnm6OyOEvbOOaP8
8W/76xrM0VGhZaBgBDgfr5CMGVvA4HTSaq038PCCxkzBTQtcYv358kgSsIOd
fXhF3hJTBNfKtSpgnsQ5OpdgCXZv9eW7YwAp4oN63IIl7maq+rvIsTFO6G/N
CSNhy9Gz9HkGG+X2ufFub0gI0R1XEn7NBrHQ87zQwwrt05hm3mBDZYq8HNNp
Bb3q0taJJ2yIqoqNJu2scfGMgihljg0/WaLTuzprvLOPiTbX4oAmzsSvu8jA
1mHBkAsHZJr0zT4vMu70MYlxsRwUDe7sNMwgg5BdsKz9MwfanfUnOsVkBPtK
DbUPcTB538u6SoaCNr2IexEbHBQE5DWNcSnQm3l+cbslF9NV6RWeyRRcrCX7
1vtywX8VeV/hKQXv4nIovmlcUAerTyuuUwCnVfnNBi50iEq3ve2puCMdNFUy
xYVufejoeDwVhIFnLW7KPAxqNA1XNVMR/JOpcMGRB6lRK+f2ZSqe+mVEiaJ4
MFOT79ljSwPR8CPXIY+HcEHu3sa4L1/P+uyd6uZBUeDwd04jDZN1jz6lfeJB
+bj/cvMSDc7xegMkAz44gyFTurZ0FOJK6StPPto26473nKVjQ3Y2MT6RD7nY
ctaDZjoCBz18iJV8LCWKVCZX6HgiqrfqGuXDi9ZQetCeAd1ATdkoGQGicoxr
1hMYuGCcOKlMFyBtYOG95AkDE3N/NDWGCJB1Y5Wgv8UGTg2CLP9MATTLt7QJ
uTYoPF8ZKdUqgHv2rXFBqg02OMrse7MCdPAt1OzENvgPOYMyEQ==
                 "]]}, 
               {RGBColor[0.6, 0.24, 0.4428931686004542], 
                LineBox[CompressedData["
1:eJwV1P0/FAYAx3EhT1GerpA83Xk6wj2FPH3vnNOhFFEKnYc0u0VFCvMsWqc8
ZtNy64rEKVOGHtREOqQoK2RI2TxWw9JkWfvh83r/Bx/D0Gif/dJSUlI+X/pf
r717CoJmbfCB0/lbn1gVypNE18qtFNB338lsFqjh0fGZufkrFByKvEqr4qtD
IN9QBlkqqhOEowWeGvAsTvXL2UfFhCA3P9FCE6uMPeT6blFhUpqK8FUEdN7Q
aCCupSHs2uF3XlMECFi/H4g+TIPoXqiQ0bkWHj2XtW4/omGw23ernngdlHiH
2uXM6NAeZS/JCbTQ8dY+wSeDDv85hvjd19o4lSRjIRyio0jWdE+fhw48lLte
Ttgz0EPQUmwmr4fij8U5jLMMKJsqNlYq6aLdnOeU9p4Brt1iRMGkLr5rNH/7
yHMTsrhThMSODeC6zwm1Kjahdc9ga1iVHhSe3/EOl7bFMr8rxuuUPiThWVI/
B9lC6LwvX4dhgJNz3rWfGm3h+PDF+OpyA2xJ1w5117TDoPd2yBAMoaD2Wr0w
2g4JfZLvFzINIfmpumWoww5aIcx3U/OGOGkVF0s2sUfDxE3OSLgR3JtcjOPS
7OF3hCrs7TWCvJfi8+ZBe8wvVv0tYRPRNvA0S8VuM/IziFub6ojIijxvG1C4
GTbK58tqSSRwPu4fL3u7GY+LNJfKi0iQy7Yuec91wMENp33PyRqjjfAP17Hc
AcqXV4rPxBojq+z+YraUI6qskqUz3hiDQ8sRP9vrCG7Dh4BjO00gd98vUL/B
EeMu0bX8VhM82K6vwld3wgnJnwo8uilODI831R90AmkHj7ezzBTsqOtR0u1O
aO7va9iiaQbZfxP1t5GcwQvdscYp0wytArfukhRnfJ5sj6DMmyFTZ03a2IAz
SmNYd43DzcGu7KNQNrnAcekWQafXHLJ2F0e/zXfBQCbt4Go2Ga1t/ELJtAvi
VapbpevIuF+lY6REArSKSboLRAsYHUlZrNkB1OuVxkwVWiDd/s1TvxTAr4LQ
OSxjiVEprvhTNTBvfcaoN8YSTMnVDNEAkNcolyB5bQlRrnqguwITVsyUnju+
G7Fi1zH6DIOJrvYFs9qWjQjRG1QuDGPiG59DqeU0KzSPYcwunwmll+MvSi5Z
weBqedPQXSYqwkKsz2hYIzVWqThzmgnOdH9WeoY1Rhyio8g6LLyJ9RmKm7MG
ZHo53e4sNCePnfuFYoMLHXb6cUdZUGsRtdVE2kCqoHRh/SUWePLBs5UiG/AC
pLubu1mo8dTRK+u3wa8GB64c+MzCcu5zrlCNAoPxzlQVS1ds6y04+gOXgtQa
m4AbAa4o1fIWFaRRMBJ3lhKQ7YqZwFVdOTcpgPOi4nKdKxxFDz9m/UXBhZX7
RstGXSEYyyClmVMh1dVyy0OVjZfm2J4YQgWvyKzwvRMb5KilxKMlVNzbe5pf
zGfj+PXGiugeKvSJs66OJWxIPsQ+i1SkIWXSX3e0jY11DpTlMCYNw7W357Pn
2YhImSEHx9PgEm/QtdHIDfUtlf67a2kQ4kT5M283yCpEpPtM0PBZfjIpPskN
vl5G17wM6Qh+ss1fX+yGi3lD/ZwAOu4W37B60OeG2d5zK5n5dOgFa8nz5Thg
au+iOLTTkWycNKxK5yAvSCOIsYKBoelXDfUhHIyInpy0/vIJ5zpOXmAuB9Z/
COrMDzMgTBR/Jd3EQTJ5ywixkoHPLFXmlUkOHkfJKuu9YuA/8tsvWA==
                 "]]}, 
               {RGBColor[0.6, 0.5470136627990908, 0.24], 
                LineBox[CompressedData["
1:eJwVxXs8FAYAB/ALnUdakuNS8jjn/bonxzm/c+eEFimVOY+ahp2iPqUSIXkU
psKVNkKMQuSRVh4p+XhukvmUeZSljs/VFGuR2PbH9/M13B/le0CBQCD4/uf/
twV8cynwgx0Y45b1jRe0oD5DEdz4mobCB7blKy4k9J14OzdfQUNfoKgzcZaE
DOWmUijR8aAxSoNTog0vaaJfZjAdsV2VKWZ+OlhD9SQ+u0fHQt4i1VuVjN76
DU0UbQZ4W8Tvq1rJyHAdC4s6zMDWfQNv+Mc2wvPJz+T7fQyQgveofmWtC7WQ
6G6iGRM3dd77rX+ti553nFjfZCYUMwr6vYo24Xy8omXhOBOUX8TRLQGb4ane
/8c0hwXlEhved2Q9qP4ozWTlsXDLbYO9aFgP3eYhzkmzLOiVqgUE5m3Bubvm
7/q82NjRonWz0k8fHu5zheRyNsq6yJeurDGAynCzd6iCPZQu1L76GGmArtBU
Qm2gPTobnvTN/mqA9Dnv25/v2mOaHeeZSjPE1jMb97trOeCIdm1gU64hVNb/
qZkT5YCAnQeJZz8Zouta1aPxHgeUv60XysVGSLeJOWphwsGeqWTybLsR3Ftc
qDFJHIQ7jiVlm1KgvE11uH2UgzF5W2JPFgWdI4Opax0cUbdkSSqepyA14id7
/xxHyCMMXTaIjSH6dEBW+s4R6cyiZYMOYxDTbPNnPZyQJq7Y2WNFRSdpwYNb
5oTplxzeOikVqaUPF9MIXFR37Gr9a4UKESOz8mkAF0NKC08l35uA+NBPrN/E
RVCJSULy7yZ47KO/VqLpDI+CsTY23xQpE7KWOwedceVvPWlKtSmEh+oOKXQ7
Y2vlm1XRumZQ+nJKf7sxD+JWR8WPaWboyHAbyE/gYdBG56rORzOc1V2XNDXC
Q9VSXOdQqDmEN57RaGwXyEwj062HzKHkUDIZd9EFqbWvJgyFFujolOR0yV2Q
Ln3dd7vBAg9v6hqpGQPy54e9x6iWMDqSsFizA6iLTQ0rvWyJM5xXg34JwOgJ
Y5KymhUmCR6Vn6uA8CGvvavjrcDvqk4uHgF2ZS3ZXZu1QnG2pthdhY/S6+xr
Q6HWWLXnOPMti4+9OoslZc+tsW/LqHrOt3xEyURcTW8btE9hyuEiH2+09SS6
j21gUF3WMt7KR3tJnG2rky0Sj6pJz8r5IGQeOPelzhYvnKIOWei6wmdawo0k
2QGKQ6IBd1f43p8+Xb7DDkU9Dvoxx1yxmmuVafeDHQiXCv7ZdN0VERJGqHKv
HUL8FQbaB1yR4LFCtFKh4YFBWEXYsivch7OPFrrRYCDrTVxrJUDb+qmqoGQa
Emvs/Ov9BZB9Xq6JbKfhRUwezT9NgI7csfiuFRrAW1RdaRDAZzRR+wiPjqLV
wZOlkwJkDcpORsTTQeh/dM9TQ4j446SKW810hOSa5cw6C6HXSyzmL9HRFpAl
kUqEONjfHGrEZUCf8kHAzRci+rT9nE8cAwkzuzdPdgphPB6zrb+ZgYnb9+fT
5oU4L4+NvvyFAZeTBv3WRm4oviEIruExUYiUsqfebggnPSGTEplYVp6JPxnv
hpe2lIKudiaCftu+W7/SDeoLHHm3Igut0nqbx8/cIIsmETeKWNgSRFaWEEWI
udw405jOwmlq/IQGU4SGSN2rRb0sjMtfNt3ZJ0LZrEDr+Vds8BpEF8TZIogo
dP9gXzYKT1WGK7SIkK80Fc6QsrHsqsGvmBGhIFcs8Bth41+giTAG
                 "]]}}, {}},
             AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
             AxesOrigin->{16.94674029069874, 0},
             DisplayFunction:>$DisplayFunction,
             FormatType->TraditionalForm,
             Frame->True,
             FrameLabel->{{
                FormBox["\"value\"", TraditionalForm], None}, {
                FormBox["\"underlying price\"", TraditionalForm], None}},
             ImageSize->600,
             LabelStyle->{FontFamily -> "Verdana", FontSize -> 10},
             Method->{},
             
             PlotLabel->FormBox[
              "\"PerpetualAmericanCall \[Delta]-\[Gamma] Hedge\"", 
               TraditionalForm],
             
             PlotRange->{{16.94674029069874, 45.83325970930126}, {
               0, 22.852863512137095`}},
             PlotRangeClipping->True,
             
             PlotRangePadding->{{0.5777303883720504, 0.5777303883720504}, {
              0.4570572702427419, 
              0.4570572702427419}}], {-1, -0.6180339887498948}, {
            Left, Bottom}, {2, 1.2360679774997896`}], GraphicsGroupBox[{
             {GrayLevel[0], 
              RectangleBox[{1.1500000000000001`, -0.45}, \
{1.9000000000000001`, 0.049999999999999975`}]}, 
             {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.001]}], 
              GraphicsGroupBox[{
                RectangleBox[{1.1, -0.4}, {1.85, 0.09999999999999998}], 
                InsetBox[
                 GraphicsBox[{{{InsetBox[
                    GraphicsBox[{
                    {Hue[0.1421359549995791, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 0.08}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta-Gamma\"\>", \
{1.2100000000000002`, 0.58}, {-1, 0}, Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.9060679774997897, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 1.24}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta\"\>", {1.2100000000000002`, 1.74}, {-1, 0},
                     Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.67, 0.6, 0.6], LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 2.4}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Value\"\>", {1.2100000000000002`, 2.9}, {-1, 0},
                     Automatic, {1, 0}]}}, {}},
                  AspectRatio->0.6666666666666666,
                  FormatType->TraditionalForm,
                  
                  PlotRange->{{-0.1, 3.26}, {-0.1, 
                   3.5799999999999996`}}], {1.1, -0.4}, {
                 Left, Bottom}, {0.75, 0.5}]}]}}]},
          AspectRatio->Automatic,
          Background->None,
          ColorOutput->Automatic,
          ImageSize->600.,
          PlotRange->All]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"18.55\"\>",
               18.55154692506555,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-6.41%\"\>", 
             "0.5532297141389267`", "\<\"-0.50%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"20.69\"\>",
               20.69128910422129,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-4.38%\"\>", 
             "0.5632151360386091`", "\<\"-0.28%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.83\"\>",
               22.831031283377033`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-2.76%\"\>", 
             "0.5732005579382915`", "\<\"-0.14%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.97\"\>",
               24.970773462532776`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-1.53%\"\>", 
             "0.5831859798379739`", "\<\"-0.06%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.11\"\>",
               27.11051564168852,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-0.67%\"\>", 
             "0.5931714017376563`", "\<\"-0.02%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.25\"\>",
               29.250257820844258`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-0.17%\"\>", 
             "0.6031568236373386`", "\<\"-0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"31.39\"\>",
               31.390000000000004`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\" 0.00%\"\>", 
             "0.613142245537021`", "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"33.53\"\>",
               33.52974217915575,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-0.16%\"\>", 
             "0.6231276674367034`", "\<\"+0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"35.67\"\>",
               35.669484358311486`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-0.64%\"\>", 
             "0.6331130893363858`", "\<\"+0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"37.81\"\>",
               37.809226537467225`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-1.43%\"\>", 
             "0.6430985112360681`", "\<\"+0.05%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"39.95\"\>",
               39.94896871662297,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-2.51%\"\>", 
             "0.6530839331357505`", "\<\"+0.11%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"42.09\"\>",
               42.08871089577871,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-3.89%\"\>", 
             "0.663069355035433`", "\<\"+0.22%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"44.23\"\>",
               44.22845307493445,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             "0.613142245537021`", "\<\"-5.54%\"\>", 
             "0.6730547769351153`", "\<\"+0.37%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]},
    {
     TagBox[GridBox[{
        {
         GraphicsBox[{InsetBox[
            GraphicsBox[{{}, {{}, {}, 
               {RGBColor[0.24720000000000014`, 0.24, 0.6], 
                LineBox[CompressedData["
1:eJwV0Hk4FGgAx3Fb8bSTHKVYbKgQITO5JjPv+2MOR2ySNRLlqITY8oQc9Vgb
K5NKybOtbZPWPLpIoXL3DIo8FpEScpUcK0dya3f/+D6f/786fj+5HlomIyPj
+l//q3kvqehI1FZMzqW0G6RSrGZo/3LZwwinfZSK7MUUXw8/2lVuaYzEkqvm
6QkUY9IfNAfXm0CVp3BZMY6iR/vDx7VfTGDYnil4EE3RfOpUIWndhuyXs3Mx
4RR+IYynZp6maJXsTA06RtGu4a5fV2sKo+5ta2KDKfbU3Ug5wGZiwt84N/cw
Rf3JfyY/5zBRmdDwWMaPgq/P9kxWY8GqlZl9zJuirPVMpVYSC2TliuWLHhQW
Zxr1CqdZuOHYEvOXG0UuSzPFMWA7uGlFjYdcKPR7AibfvdqOljSD19SJIvPC
w73hQjO88bKMZdpTqJGvFYwiMzzh1D5m8ylSRxz1MnXNsRSy5XcRKBgZ6efM
r5jDXlZincyhiHfonahbYYHZ44dqGq0o5qeN9/qcsIBTpOCYoTnFCUlUxVSf
BXap9kenMylG3Kp1xXsswfIpZqmYUBxcrnxOW2oJ+TDn0SxDiq58r4lClhUC
gsJW2+pTuPvkeOzMsoKL8c2ZsU0UDQqfy7uV2XjL89PO06awL6O6ET+zwaV3
F2K+p6gMFotXjbNhS8PlReoUVupt45k+OyA8yGylqhT5zzd6WDTuQINaQK+5
CoVhZGj5C2qNQa5jtZUyRZZu8WbfPGuo+R5QsVeg0GiRFX/ZwMEiWy/YfxVF
WvzucfF5DpykdYHJKynkmddEOkscpLl1FJTKUiS8+1hWFMJFE4sxNbuMYinF
bLNTJxcfNN6/spGhiODEJfc4EZR6ZzPSFgk+Db0Yiygl6FOZ4o3NERy5qiqS
N6K4YlXOdp8h6LbzL7uRQXFz40J29RSBUUxbaoYsUOpwUUAmCQJdF/mHucDp
4e9eV4wRZBtsmjENB4YCG7UcRwl6ZRzuzN8F4nV9ejqGCTa8Dt1f0w8YZtX2
RQ4SeOalKadq2uB+re2Y+gBBemJx1T43G0RtVG+u7ido9u6O1Dtng5ctGe4n
ewkUzeW2jkttkOA148TqJnCSN+oqmbeB2jOjxMlOgqS+3amJ222h6jfSUvKW
oKo4kr872BbT5eLV4jcEMpeuTWvctMWPn0dkfdsIOIHS2x/abREmF3KF20oQ
hUHv/DU8uPo1p2m/JChSVVSOdeThkwen69smgolRsyphPA8jSWudZxsITGo8
I5WLeZDTny8brScIuhZn2DHOg/96qcJQHYHkhKRTYsAHV+q5Yfj5f5931l88
7suH4GFV/XgNgdamCR7nKh/rKhnzi1UEXnOq03JNfMyMscSKUoLfmri3m1YK
wBgy89F7StCS4+/9BwRwGfjkbVtBoBR3VingpABu1jqB/mUEzqI8KfO+APoO
+wLOlhCcNWmNWBgQIHBigRQ8IaiRnTd4piVEUJhBW98jgmWd2p2pIiEmrleq
qhURkALhRa8LQty7IBp0KSCIFh/l6T8T4lYq0/z8A4JHfpe+jC8JITnDfv/3
fYJJ9uNbpRZ28I6e71uXR7BNucvr11A7bMn5U9PnHsHRj8uVXCV2aLv+Ljr3
DkFOhYFUs8sOknrGsMxtgv70XRED6+yRaTq9V5RDoBMabvDA2R6j+78pzJcQ
eAsyOmIT7NGaJzekmE3wL0WqQxM=
                 "]]}, 
               {RGBColor[0.6, 0.24, 0.4428931686004542], 
                LineBox[CompressedData["
1:eJwV0Hk4FGgAx3EqaqXQpUNihZwxGIbxvj/GjDMeR5GwjpZSrJ5ydSwrRMix
IkutY1npkHK0ChWxSRuRSo4caaxyZ5Ro2z++z+f/r7z3Tw4/LhESEnL41v/K
XIurPBCuBtaCZfmoB8UqMbnTv7qow/ZPR4V9bhRffavsavU14GPvnta8l2Ki
3lZmZIMmwuZ9hQ2dKfrlhvlrZzWRVBgUdNmJ4tmpUxXk+U7k2x3v2+hA4R0g
dl/XVQtVn07bxtlRdG3Zo9z8SAstBUk1AhsKx+a8pB9Y2ujflanuZ0XREvZh
eqZYGwJBbnanOYWZMsv17EYGxPNLxHhciprn0fe2xTEgb1MeXmFKwYxuVaoQ
MMCcreFvB8V1hkySlZ8OrHObnNONKZT7/ab7OnXgadXWuNSIIjf51t5gni6C
Z7r0jhpQbCRf68QqdXH20tAfA3oUqe+tlHIV9fC7xdhaBx0KseyMRL3zeiif
EkTd16KIshyYal7GxKMc4SktTYp5gcZez2NM9PJWeuWqURwrCq/7OMjE9MS6
VgkVivdODxUTHPWxIluWRihR7F8qlShXr4+t3B3XxxQoesvcpioYBmCMa2/1
kKfY41nsYp1vAPMso8QnshT/rJ6pfSPFghuHO8+WobCooYohv7Bw5IOt/9VN
FPcOJSSsnGQhNtPl1RZpCoPNLyZzPQ2RbeJtkbCOouzv712YrYa4MXqo6rMU
hWpoYO1jaoSH54OV/CUo8hWrt3uVGqGLRpx/JU6xpUMkYVaWjfGRuGWWYhTp
UfaTCefYWJaedvT2cgpx7YvO8otsbCI5A8oiFDF9/JrKAGNo8gvtM5dQLCbp
brfpMQYnrfSeqBBFCDvybL8NgQv7r50hCwTj/z6eCLlLEDD84NLbzwQHsqSd
xdW/fU1pWbV7juCNuU9NXjbFBcPOkw0fCdRPvEjNFgGuDfWN6kwTHHRYMPM1
Bh6cG3EtmCAoVFGY0woGXhhMP1ozRjAgZHll/irwfuCLQdQogezLQI/GIUA4
SbR4kk/gWpoulSpjgg36ktJewwQZsdUN+5xMoNa/KbZ1kOCZ+5tQpUQTIEHh
I+0nkNATVZusN8FuPY39pb0ENuLqvXfmTeDfx2yX7SaIG7RPjdUxRUQ8TM+9
ImioDjWzP2SKdB2rsoVOAqG0i4ItBaa43OMoF9BBwD5YXzLcZYraM+7J3W0E
4RhxL1vDQbu236L1U4JKaQmpk1Yc8F8HBdxpIZga023gRXGwEHO8W7WZQLPR
NVSqmoM1WtHWvzUR+F+MVO2e5EC5K6n6u4cERceKeopUzMCOzlQJf0AwaN2S
csTLDPaaeRf4dQTbFKY47Cwz+L4sWe5SQ+D2WVog2maGE1HlIU3VBBfajEva
VnCRol77lnmboKPYxz0HXBR2NjkVVRBIRsZL+oVxUR3ZVr/+FsEu59J67Rtc
PFV9zYi5QRCv+TzkyzsuhjqG8mauETSKzKs0bePh089jkvuvECzpketJdeZh
tcpcRHsxASnnpbgl86DQLjxuWkRwPOEwR7mJB9aplR43CwiqvNNmJxd5sFVe
/0Q+j2CadfvyXaY5fNpk2amXCHZK9bqdCTRH2IkdV4RyCA7zl0o6FJkjSZGx
OSiLoLhOpV6m1xz5T43i+zIIhjLsQt6tt0BVOHfONp1APjBY5eYuC7Qo2PnV
phK4c7O7T8ZYoP+JS6dGMsF/HtdEKg==
                 "]]}, 
               {RGBColor[0.6, 0.5470136627990908, 0.24], 
                LineBox[CompressedData["
1:eJwVkmk0FWgAhh3FNFLcNpJCtqGbfbuW73u517VG5LgIoSllmzqJmmiRRJiI
6VQ4U2YSJUuhUrZzRQnFWErZyzJJLuoa65gf73n+P8+rFPCL6wFRERER1+X9
T/n78WWHTu6Ac+uNseYoijUSiufTPJiQ8mVrvzxBsXTwkXOl8U7sUDGrawyn
mOA7yY9u0kK2SkzxuyMU/YpDI+u/ayFin6zgawhFa3R0KWnXxu22hVipwxQB
oRI1Bl460InVCzU5QNG1xV294aUONoWV5QX5U+xpuJW8j6ULjysJpjk+FI0n
vkxN5+pCOHFP4bMnBUed5XVJVg+ChK2eLHeKivbYaoV4PXB9eoZSXCmMYt+o
lQr1MBM0/kLgRFGgJ59sH6iPlQ93Le11oFDvD5zq7dBHqOF8wmsbipuXH3oe
5xpAd/LfQ44cClmyVCVRZgCXUW5mKyhSx+zVbqoaokluUDnAgkIi42qS4e+G
uB3XvDTLooixG5hsWGmEt8wfdbKMKOaEOz39wo0QuCatxFafIjznZNW3QSO4
/BSSvKBNMeb2XDVxjzGuRaeXP2VS/LyCkaTIN4bpGknz8xoUPcXek6V6JjDu
bGW4qVG4++V6OGSbIPX9iJmWMkXz2unKPgYLXDmncoYihW0FVY04xwIvTTR5
UZ6iOjgxcbWAhVqueMn0ZgoTuU7BTT9TJBl4ak9voih+sd3D6I0pirznFufX
U2hGhlW+ombQqRrbLsWgyFYtV/EvNMNq750ZmmsptrSJJX7fZg62fkWg82qK
9BgXQeJv5ujgZMZHr6KQ1M3iKS2aozalYaFEjOJC70hFWagFpGRs67+JUiwm
G6g4dlugtHPDJypCEWF+9lK/I8GjVh1e2gLB139eTUQ8I9iwKnPrxCzBoesy
PMllL02R7ibuMwR9NvsrbmVQDCr53Xn+jYB5qjM1QwxwE38SRKYIDrsucA5a
AEqq/jHVEwS3NZRndI4Ddqc9xh3GCQZE7O7N5QNNjD8K+j4TbHsb5lv3Ecjv
NeCfHiXwKkxnpMpbYmR4M1NtmOBqXHntXjdLnNF0Gu34SNDq0xeplmSJo3da
ZlMGCKQMxXcI+Jao9v3Lz62PwFGS2fN0zhJBu+vklHoI4gddUuP0rXAkylhD
+J6gtjyS4xJshdYBYWLHOwKRK1nCLX9a4fL5H9hVnQTmh/l3h7qskOt70Km4
neAkRn2K17GxNXxDQf7fBGUyUowoeza+8BkBxS0Ek+MGtdwYNuScfIOqXhNo
1XlFMsrZyF43W9fRRBCUdVbzg4CNC4xPkcJXBDnhOd05Ghw8t1eIVmogGHRo
TDnqz4FfZW6H2wsCBeVJtvl1Dngh52JT6wi8Z2WE4i0c5LnlxXXWElxrsbjb
ssoavEjFbjU+QVvufp9MWMO/bejimRoC6bMJ0oEnrFEfPB/XX0Wwi1fI1y2y
RryFf5djJUGCVnvE/LA1cuw2xtQsd64Tm9OoV+BiW4rsafqUQLRbsTuVx8WU
dHBz3RMCUsJN8b7MhXKj5DHeY4JfE0PY6vVcFNUsBAvKln8TcOW7YJGLawKL
J+mlBFOsx3nPjGzwYW+Tl2UJgTajx/timA1OieTvFj4gCBlZIe2aY4OI3nc3
yooJcqs0+PI9NmiccWedKSL4eNU5YnijLc44KjNdCgmUwo5rPNhli+QucoxZ
QOBjnfEh6oIthNl5axn3Cf4DbjtG+w==
                 "]]}}, {}},
             AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
             AxesOrigin->{13.73712702196513, 0},
             DisplayFunction:>$DisplayFunction,
             FormatType->TraditionalForm,
             Frame->True,
             FrameLabel->{{
                FormBox["\"value\"", TraditionalForm], None}, {
                FormBox["\"underlying price\"", TraditionalForm], None}},
             ImageSize->600,
             LabelStyle->{FontFamily -> "Verdana", FontSize -> 10},
             Method->{},
             
             PlotLabel->FormBox[
              "\"PerpetualAmericanPut \[Delta]-\[Gamma] Hedge\"", 
               TraditionalForm],
             
             PlotRange->{{13.73712702196513, 49.04287297803487}, {
               0, 31.56704488722148}},
             PlotRangeClipping->True,
             
             PlotRangePadding->{{0.7061149191213949, 0.7061149191213949}, {
              0.6313408977444296, 
              0.6313408977444296}}], {-1, -0.6180339887498948}, {
            Left, Bottom}, {2, 1.2360679774997896`}], GraphicsGroupBox[{
             {GrayLevel[0], 
              RectangleBox[{1.1500000000000001`, -0.45}, \
{1.9000000000000001`, 0.049999999999999975`}]}, 
             {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.001]}], 
              GraphicsGroupBox[{
                RectangleBox[{1.1, -0.4}, {1.85, 0.09999999999999998}], 
                InsetBox[
                 GraphicsBox[{{{InsetBox[
                    GraphicsBox[{
                    {Hue[0.1421359549995791, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 0.08}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta-Gamma\"\>", \
{1.2100000000000002`, 0.58}, {-1, 0}, Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.9060679774997897, 0.6, 0.6], 
                    LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 1.24}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Delta\"\>", {1.2100000000000002`, 1.74}, {-1, 0},
                     Automatic, {1, 0}]}, {InsetBox[
                    GraphicsBox[{
                    {Hue[0.67, 0.6, 0.6], LineBox[{{0, 0.5}, {1, 0.5}}]}, {}},
                    PlotRange->{{0, 1}, {0, 1}}], {0.08, 2.4}, {
                    Left, Bottom}, {1, 1}], 
                    InsetBox["\<\"Value\"\>", {1.2100000000000002`, 2.9}, {-1, 0},
                     Automatic, {1, 0}]}}, {}},
                  AspectRatio->0.6666666666666666,
                  FormatType->TraditionalForm,
                  
                  PlotRange->{{-0.1, 3.26}, {-0.1, 
                   3.5799999999999996`}}], {1.1, -0.4}, {
                 Left, Bottom}, {0.75, 0.5}]}]}}]},
          AspectRatio->Automatic,
          Background->None,
          ColorOutput->Automatic,
          ImageSize->600.,
          PlotRange->All]},
        {
         InterpretationBox[
          StyleBox[
           GraphicsBox[{},
            BaselinePosition->Baseline,
            ImageSize->{20, 0}],
           CacheGraphics->False],
          Spacer[20]]},
        {
         TagBox[GridBox[{
            {
             StyleBox["\<\"price\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"shares short for \[Delta]-neutral\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-neutral tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] shares short\"\>",
              StripOnInput->False,
              FontWeight->Bold], 
             StyleBox["\<\"\[Delta]-\[Gamma] tracking error\"\>",
              StripOnInput->False,
              FontWeight->Bold]},
            {
             TagBox[
              InterpretationBox["\<\"18.55\"\>",
               18.55154692506555,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.28%\"\>", 
             RowBox[{"-", "0.027794531676752207`"}], "\<\"-0.08%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"20.69\"\>",
               20.69128910422129,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.18%\"\>", 
             RowBox[{"-", "0.026992887922389526`"}], "\<\"-0.04%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"22.83\"\>",
               22.831031283377033`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.11%\"\>", 
             RowBox[{"-", "0.026191244168026845`"}], "\<\"-0.02%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"24.97\"\>",
               24.970773462532776`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.06%\"\>", 
             RowBox[{"-", "0.02538960041366416`"}], "\<\"-0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"27.11\"\>",
               27.11051564168852,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.02%\"\>", 
             RowBox[{"-", "0.02458795665930148`"}], "\<\"-0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"29.25\"\>",
               29.250257820844258`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.01%\"\>", 
             RowBox[{"-", "0.023786312904938794`"}], "\<\"-0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"31.39\"\>",
               31.390000000000004`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\" 0.00%\"\>", 
             RowBox[{"-", "0.022984669150576113`"}], "\<\" 0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"33.53\"\>",
               33.52974217915575,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.01%\"\>", 
             RowBox[{"-", "0.02218302539621343`"}], "\<\"+0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"35.67\"\>",
               35.669484358311486`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.02%\"\>", 
             RowBox[{"-", "0.021381381641850748`"}], "\<\"+0.00%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"37.81\"\>",
               37.809226537467225`,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.04%\"\>", 
             RowBox[{"-", "0.020579737887488066`"}], "\<\"+0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"39.95\"\>",
               39.94896871662297,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.08%\"\>", 
             RowBox[{"-", "0.019778094133125382`"}], "\<\"+0.01%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"42.09\"\>",
               42.08871089577871,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.11%\"\>", 
             RowBox[{"-", "0.0189764503787627`"}], "\<\"+0.03%\"\>"},
            {
             TagBox[
              InterpretationBox["\<\"44.23\"\>",
               44.22845307493445,
               AutoDelete->True],
              NumberForm[#, {10, 2}]& ], 
             RowBox[{"-", "0.022984669150576113`"}], "\<\"-0.16%\"\>", 
             RowBox[{"-", "0.01817480662440002`"}], "\<\"+0.04%\"\>"}
           },
           AutoDelete->False,
           GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Grid"]}
       },
       DefaultBaseStyle->"Column",
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{3.5838115933064528`*^9}]
}, {2}]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 6: Financial Indicators for a list of securities\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}, {3.583805545995566*^9, 
  3.583805546363587*^9}, {3.5838068151691585`*^9, 3.583806822049552*^9}, {
  3.5838069601934533`*^9, 3.583806960626478*^9}, {3.58380760213317*^9, 
  3.583807631092827*^9}, {3.5838116233511705`*^9, 3.583811629062497*^9}, {
  3.5838116638304863`*^9, 3.58381166424651*^9}, {3.583812316825835*^9, 
  3.583812321610109*^9}}],

Cell["\<\
1)  Added Value: A graphics grid of a range of popular financial indicators \
allows one to see if there is any hidden pattern in the prices of a stock \
which can become the basis of a trading strategy.

2)  Caption: Trading stocks is a matter of elucidating some hidden pattern in \
the stock prices and indicators are the tools that are used for this purpose. \
If many of the popular indicators are arranged in a grid then it becomes \
possible to spot price patterns that would not have been apparent otherwise. \
In this way we can compare at a glance a range of different indicators for \
any given stock.

3)  Why we are better: We have over 100 different financial indicators with a \
full choice of structure parameters that make it more likely than other \
programs that one can find an optimal trading strategy. \
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}, {
   3.5841523050128965`*^9, 3.584152336611704*^9}, {3.5841524176203375`*^9, 
   3.584152584884905*^9}, {3.5841526407420993`*^9, 3.584152706260847*^9}, {
   3.5841527365015764`*^9, 3.584153095111088*^9}, {3.584153167688239*^9, 
   3.5841531828071036`*^9}, {3.5841532221193523`*^9, 3.584153542408672*^9}}],

Cell[CellGroupData[{

Cell["\<\
Financial Indicators for a range of securities\
\>", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9, 
   3.5838068609627776`*^9, {3.583811423989768*^9, 3.5838114473181024`*^9}, {
   3.5838116356548743`*^9, 3.5838116388550577`*^9}, {3.5838123767312613`*^9, 
   3.5838123817065463`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Comany: Financial Indicators for General Electric\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}, {
   3.583812331977702*^9, 3.5838123364259567`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"indic", ",", "par1", ",", "par2", ",", "par3", ",", "par4"}], 
    "}"}], ",", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"indic", "=", 
          RowBox[{"FinancialIndicator", "[", "indicator", "]"}]}], ";", 
         RowBox[{"par1", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "1"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par2", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "2"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par3", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "3"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "4", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par4", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "4"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "5", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"Quiet", "[", 
          RowBox[{"TradingChart", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<GE\>\"", ",", 
              RowBox[{"DatePlus", "[", 
               RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"FinancialIndicator", "[", 
              RowBox[{
              "indicator", ",", "par1", ",", "par2", ",", "par3", ",", 
               "par4"}], "]"}], "}"}], ",", 
            RowBox[{"PlotLabel", "\[Rule]", 
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{
               "\"\<Last \>\"", ",", "365", ",", " ", "\"\< days of \>\"", 
                ",", "\"\<GE\>\"", ",", "\"\< with \>\"", ",", "indicator", 
                ",", "\"\<(\>\"", ",", "par1", ",", "\"\<,\>\"", ",", "par2", 
                ",", "\"\<,\>\"", ",", "par3", ",", "\"\<,\>\"", ",", "par4", 
                ",", "\"\<)\>\""}], "}"}], "]"}]}], ",", 
            RowBox[{"ImageSize", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"450", ",", "310"}], "}"}]}]}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"indicator", ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<AverageTrueRange\>\"", ",", "\"\<FastStochastic\>\"", ",", 
            " ", "\"\<FullStochastic\>\"", ",", 
            "\"\<ParabolicStopAndReversal\>\"", ",", 
            "\"\<PolarizedFractalEfficiency\>\"", ",", 
            "\"\<RelativeStrengthIndex\>\"", ",", "\"\<TRIX\>\"", ",", 
            "\"\<WilliamsPercentR\>\""}], "}"}]}], "}"}]}], "]"}], ",", "2"}],
      "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.583811787947585*^9, {3.5838119623005576`*^9, 3.583812031980543*^9}, {
   3.583812156077641*^9, 3.583812211852831*^9}, {3.5838124507184935`*^9, 
   3.58381256150383*^9}, {3.583812608815536*^9, 3.5838126437915363`*^9}, {
   3.5838126817437077`*^9, 3.583812712720479*^9}, {3.583812927170745*^9, 
   3.5838129379693623`*^9}, {3.583813333539988*^9, 3.5838133966595984`*^9}, {
   3.5838134480685387`*^9, 3.583813448403558*^9}, {3.5838137582942824`*^9, 
   3.583813769668933*^9}, {3.583813999222063*^9, 3.5838139995740833`*^9}, {
   3.5838140562623253`*^9, 3.5838140665499134`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$541631 = 
        "Full", System`TradingChartDump`$highlightposition$541631 = Automatic,
         System`TradingChartDump`$maxohlc$541631 = 24.95`4., 
        System`TradingChartDump`$timestampstyle$541631 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$541631 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$541631 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$541631, 
        System`TradingChartDump`$subplotpoint$541631, 
        System`TradingChartDump`$ndigits$541631 = 4, 
        System`TradingChartDump`$highlightstyle$541631 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$541631 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$541631 = True, 
        System`TradingChartDump`$timestampQ$541631 = True, 
        System`TradingChartDump`$data$541631 = {{{2012, 7, 26}, {
          19.55155642023346, 20.035505836575872`, 19.512840466926068`, 19.9, 
           57275600}}, {{2012, 7, 27}, {
          19.96928776290631, 20.327437858508603`, 19.901529636711278`, 20.25, 
           80268300}}, {{2012, 7, 30}, {
          20.120322115384614`, 20.236456730769227`, 20.023543269230768`, 
           20.13, 44993600}}, {{2012, 7, 31}, {
          20.08, 20.21547951807229, 20.08, 20.08, 38328400}}, {{2012, 8, 1}, {
          20.185798359864926`, 20.27288953207911, 20.040646406174623`, 20.06, 
           35734300}}, {{2012, 8, 2}, {
          19.860000000000003`, 20.03421052631579, 19.55029239766082, 19.86, 
           44000400}}, {{2012, 8, 3}, {
          20.144541984732825`, 20.318702290076335`, 20.096164122137402`, 
           20.28, 37891500}}, {{2012, 8, 6}, {
          20.29, 20.493190271816882`, 20.22226990939437, 20.29, 34159500}}, {{
          2012, 8, 7}, {
          20.459356060606062`, 20.507746212121216`, 20.410965909090912`, 
           20.44, 31115300}}, {{2012, 8, 8}, {
          20.36870537839124, 20.407410756782483`, 20.22356020942408, 20.33, 
           32345900}}, {{2012, 8, 9}, {
          20.263874643874647`, 20.43806267806268, 20.263874643874647`, 20.38, 
           31159700}}, {{2012, 8, 10}, {
          20.323222748815166`, 20.42, 20.265156398104267`, 20.42, 
           24419100}}, {{2012, 8, 13}, {
          20.358380181038587`, 20.377732253454024`, 20.2035636017151, 20.31, 
           26873600}}, {{2012, 8, 14}, {
          20.395453677172874`, 20.42447946513849, 20.22129894937918, 20.26, 
           30095000}}, {{2012, 8, 15}, {
          20.18324427480916, 20.34772900763359, 20.11551526717557, 20.28, 
           28870100}}, {{2012, 8, 16}, {
          20.195814726840858`, 20.457092636579574`, 20.147429928741094`, 
           20.37, 33598000}}, {{2012, 8, 17}, {
          20.33935238095238, 20.368380952380953`, 20.26194285714286, 20.32, 
           30032500}}, {{2012, 8, 20}, {
          20.269350215002387`, 20.33707596751075, 20.153248924988052`, 20.25, 
           27385500}}, {{2012, 8, 21}, {
          20.296143884892086`, 20.373573141486812`, 20.131606714628298`, 
           20.18, 30438800}}, {{2012, 8, 22}, {
          20.100322425409047`, 20.197098171318576`, 20.04225697786333, 20.11, 
           28016800}}, {{2012, 8, 23}, {
          20.06675387596899, 20.115130813953485`, 19.960324612403095`, 19.97, 
           36538800}}, {{2012, 8, 24}, {
          19.92676442307692, 20.22677884615384, 19.888052884615384`, 20.13, 
           29338200}}, {{2012, 8, 27}, {
          20.15096402877698, 20.276786570743404`, 20.121928057553955`, 20.18, 
           28775600}}, {{2012, 8, 28}, {
          20.09160980297934, 20.246458433445465`, 20.09160980297934, 20.14, 
           25912400}}, {{2012, 8, 29}, {
          20.15, 20.275816522574445`, 20.140321805955807`, 20.15, 
           19925800}}, {{2012, 8, 30}, {
          20.04740310077519, 20.10545542635659, 19.9506492248062, 19.97, 
           21237800}}, {{2012, 8, 31}, {
          20.08838242394978, 20.156117817479473`, 19.94323515210043, 20.04, 
           29679000}}, {{2012, 9, 4}, {
          19.966138469039493`, 20.024207703559238`, 19.820965382740127`, 
           19.85, 38173600}}, {{2012, 9, 5}, {
          19.883244552058112`, 20.096106537530268`, 19.84454237288136, 19.98, 
           33033500}}, {{2012, 9, 6}, {
          20.19424683247302, 20.629676208352887`, 20.17489441576725, 20.62, 
           53178600}}, {{2012, 9, 7}, {
          20.628754052802222`, 20.89, 20.609402501157945`, 20.89, 
           36379800}}, {{2012, 9, 10}, {
          20.79, 20.954539106145248`, 20.741606145251396`, 20.79, 
           33672300}}, {{2012, 9, 11}, {
          20.7932422417786, 20.9867577582214, 20.70616025937934, 20.89, 
           33593100}}, {{2012, 9, 12}, {
          20.967135678391962`, 21.218702603928733`, 20.957460027409777`, 
           21.18, 43006000}}, {{2012, 9, 13}, {
          21.0680608537693, 21.522906448683013`, 21.048705722070842`, 21.31, 
           111794200}}, {{2012, 9, 14}, {
          21.487109905020354`, 21.651650836725466`, 21.27417458163727, 21.4, 
           100148400}}, {{2012, 9, 17}, {
          21.22386394557823, 21.34, 21.194829931972787`, 21.34, 79283200}}, {{
          2012, 9, 18}, {
          21.278093525179855`, 21.52, 21.24906474820144, 21.52, 38831200}}, {{
          2012, 9, 19}, {
          21.584172982612575`, 21.768074008024968`, 21.535777975925104`, 
           21.71, 40462600}}, {{2012, 9, 20}, {
          21.63599197503344, 21.909001337494427`, 21.567739634418192`, 21.87, 
           43677000}}, {{2012, 9, 21}, {
          21.989502885042164`, 22.126023080337326`, 21.901739902352418`, 
           21.97, 66551700}}, {{2012, 9, 24}, {
          21.838998211091234`, 21.887745974955276`, 21.74150268336315, 21.8, 
           36799800}}, {{2012, 9, 25}, {
          21.8380277902286, 22.11112505602869, 21.750246526221428`, 21.76, 
           47039200}}, {{2012, 9, 26}, {
          21.608506787330317`, 21.69626696832579, 21.520746606334843`, 21.55, 
           41123300}}, {{2012, 9, 27}, {
          21.682287725472943`, 22.286739991201056`, 21.575046194456664`, 
           22.16, 67300400}}, {{2012, 9, 28}, {
          22.20852047556142, 22.393835314839276`, 22.062219286657857`, 22.15, 
           70926100}}, {{2012, 10, 1}, {
          22.161999123191585`, 22.42525208241999, 22.14249890398948, 22.24, 
           42550700}}, {{2012, 10, 2}, {
          22.3564984642387, 22.414997806055286`, 22.142000877577885`, 22.22, 
           45297400}}, {{2012, 10, 3}, {
          22.29124399825404, 22.40825840244435, 22.154727193365343`, 22.34, 
           32929400}}, {{2012, 10, 4}, {
          22.38, 22.477516339869283`, 22.204470588235292`, 22.38, 
           40344600}}, {{2012, 10, 5}, {
          22.46200692041522, 22.598494809688578`, 22.423010380622834`, 22.54, 
           38312500}}, {{2012, 10, 8}, {
          22.301243455497385`, 22.418259162303666`, 22.281740837696336`, 
           22.35, 24202200}}, {{2012, 10, 9}, {
          22.37207780725022, 22.401335101679926`, 22.04049513704686, 22.06, 
           39176000}}, {{2012, 10, 10}, {
          22.04550601872492, 22.17226036558181, 21.850499331252788`, 21.87, 
           32784100}}, {{2012, 10, 11}, {
          22.02800977343403, 22.14502443358507, 21.92074633496224, 21.95, 
           24161800}}, {{2012, 10, 12}, {
          22.017508896797153`, 22.144270462633454`, 21.851743772241996`, 
           21.92, 32954600}}, {{2012, 10, 15}, {
          21.98247349823321, 22.138515901060067`, 21.933710247349822`, 22.08, 
           29578600}}, {{2012, 10, 16}, {
          22.226289752650175`, 22.314063604240282`, 22.01173144876325, 22.08, 
           35668800}}, {{2012, 10, 17}, {
          22.203483195111303`, 22.349751200349196`, 22.154727193365343`, 
           22.34, 28272500}}, {{2012, 10, 18}, {
          22.24, 22.50325295922841, 22.230249890398948`, 22.24, 43140700}}, {{
          2012, 10, 19}, {
          21.9480163413527, 21.967517022242397`, 21.323994552882436`, 21.48, 
           107879900}}, {{2012, 10, 22}, {
          21.316018433179725`, 21.40377880184332, 20.72119815668203, 21.16, 
           86735100}}, {{2012, 10, 23}, {
          20.81825657894737, 20.867011278195488`, 20.671992481203006`, 20.75, 
           56297300}}, {{2012, 10, 24}, {
          20.8957619943556, 20.925014111006586`, 20.71049858889934, 20.73, 
           42295500}}, {{2012, 10, 25}, {
          20.964016933207905`, 21.032271872060207`, 20.505733772342428`, 
           20.73, 45769600}}, {{2012, 10, 26}, {
          20.657991473235434`, 20.862719090478446`, 20.541004263382284`, 
           20.58, 42827400}}, {{2012, 10, 31}, {
          20.735061728395063`, 20.79358024691358, 20.452222222222222`, 20.54, 
           39179300}}, {{2012, 11, 1}, {
          20.50769915651359, 20.858758200562324`, 20.497947516401123`, 20.81, 
           46231300}}, {{2012, 11, 2}, {
          20.994528390427032`, 21.14079774753637, 20.731243547630225`, 20.78, 
           47475200}}, {{2012, 11, 5}, {
          20.67519850537132, 20.938514712751047`, 20.67519850537132, 20.88, 
           30000100}}, {{2012, 11, 6}, {
          20.972000926354795`, 21.235247799907366`, 20.913501621120886`, 
           21.05, 32733200}}, {{2012, 11, 7}, {
          20.824230951254144`, 20.980217699952675`, 20.54150496923805, 20.6, 
           45253400}}, {{2012, 11, 8}, {
          20.633279080899953`, 20.66253231211106, 20.36024892292963, 20.37, 
           40770700}}, {{2012, 11, 9}, {
          20.245942857142857`, 20.77257142857143, 20.18742857142857, 20.48, 
           40306800}}, {{2012, 11, 12}, {
          20.51626615605553, 20.613776926759215`, 20.36024892292963, 20.37, 
           21816400}}, {{2012, 11, 13}, {
          20.091972920696332`, 20.433341392649908`, 20.06271276595745, 20.17, 
           41073300}}, {{2012, 11, 14}, {
          20.21200899550225, 20.231509245377314`, 19.451499250374813`, 19.51, 
           65539500}}, {{2012, 11, 15}, {
          19.403988035892322`, 19.72576271186441, 19.403988035892322`, 19.56, 
           51760300}}, {{2012, 11, 16}, {
          19.601240694789084`, 19.689007444168734`, 19.376947890818858`, 
           19.65, 45287500}}, {{2012, 11, 19}, {
          19.90617134559535, 20.208518877057113`, 19.88666505324298, 20.15, 
           38283400}}, {{2012, 11, 20}, {
          20.15876333656644, 20.178268671193017`, 19.8661833171678, 20.11, 
           26845900}}, {{2012, 11, 21}, {
          20.189506769825922`, 20.22852030947776, 20.06271276595745, 20.17, 
           41020400}}, {{2012, 11, 23}, {
          20.295684410646388`, 20.52, 20.217661596958177`, 20.52, 
           35456500}}, {{2012, 11, 26}, {
          20.364444444444445`, 20.549753086419752`, 20.35469135802469, 20.54, 
           47741300}}, {{2012, 11, 27}, {
          20.515764254911353`, 20.67177767129851, 20.330498322951605`, 20.35, 
           33001700}}, {{2012, 11, 28}, {
          20.229777672658468`, 20.619749290444656`, 19.9860454115421, 20.61, 
           34782700}}, {{2012, 11, 29}, {
          20.70724088973024, 20.824230951254144`, 20.42451490771415, 20.6, 
           27632800}}, {{2012, 11, 30}, {
          20.60974917179366, 20.726739233317563`, 20.512257453857078`, 20.6, 
           37857000}}, {{2012, 12, 3}, {
          20.651008645533143`, 20.699759846301635`, 20.280499519692604`, 20.3,
            29981900}}, {{2012, 12, 4}, {
          20.34975071907958, 20.486260786193675`, 20.19373921380633, 20.34, 
           36817200}}, {{2012, 12, 5}, {
          20.38798869524258, 20.8267545925577, 20.339236928874232`, 20.7, 
           46466500}}, {{2012, 12, 6}, {
          20.67421619092185, 20.859503977538605`, 20.557192325690217`, 20.84, 
           32751200}}, {{2012, 12, 7}, {
          20.910493942218082`, 20.94950605778192, 20.71543336439888, 20.93, 
           33548600}}, {{2012, 12, 10}, {
          20.899008882655444`, 20.967274427302478`, 20.830743338008414`, 
           20.86, 27604300}}, {{2012, 12, 11}, {
          20.940753138075312`, 21.203974895397486`, 20.823765690376565`, 
           20.97, 45757200}}, {{2012, 12, 12}, {
          21.074214876033054`, 21.40578512396694, 21.035206611570246`, 21.24, 
           42413600}}, {{2012, 12, 13}, {
          21.197002775208137`, 21.37250693802035, 21.011748381128584`, 21.08, 
           33966000}}, {{2012, 12, 14}, {
          21.07024976873265, 21.21650323774283, 21.011748381128584`, 21.08, 
           47536600}}, {{2012, 12, 17}, {
          21.146019151846783`, 21.399498404012764`, 21.146019151846783`, 
           21.38, 48483700}}, {{2012, 12, 18}, {
          21.30601659751037, 21.36452282157676, 20.876970954356842`, 21.15, 
           81119200}}, {{2012, 12, 19}, {
          21.104407425035696`, 21.123912422655877`, 20.450990004759635`, 
           20.49, 92330700}}, {{2012, 12, 20}, {
          20.57226128266033, 20.89693111638955, 20.532907363420428`, 20.71, 
           50831400}}, {{2012, 12, 21}, {
          20.510632183908047`, 20.658261494252873`, 20.235057471264366`, 
           20.55, 80833800}}, {{2012, 12, 24}, {
          20.460475504322766`, 20.62778097982709, 20.421109510086453`, 20.49, 
           15097200}}, {{2012, 12, 26}, {
          20.479364467982666`, 20.60729898892634, 20.380953298026, 20.44, 
           28557100}}, {{2012, 12, 27}, {
          20.468245529241177`, 20.537129047849202`, 20.094306428226197`, 
           20.36, 38330700}}, {{2012, 12, 28}, {
          20.119838551859097`, 20.375640900195695`, 20.1001614481409, 20.11, 
           32403400}}, {{2012, 12, 31}, {
          19.961338732729867`, 20.65983801810386, 19.931824678418295`, 20.65, 
           58785000}}, {{2013, 1, 2}, {
          21.167291471415183`, 21.196813495782568`, 20.8622305529522, 21., 
           46089500}}, {{2013, 1, 3}, {
          21.133876777251185`, 21.143715639810427`, 20.710805687203795`, 
           20.76, 48509100}}, {{2013, 1, 4}, {
          20.86983962264151, 20.91903773584906, 20.781283018867928`, 20.86, 
           29802600}}, {{2013, 1, 7}, {
          20.819517274017986`, 20.87855182205395, 20.622735447231427`, 20.79, 
           32746700}}, {{2013, 1, 8}, {
          20.766842105263162`, 20.786526315789477`, 20.353473684210527`, 
           20.57, 40045500}}, {{2013, 1, 9}, {
          20.708582338902147`, 20.738109785202866`, 20.600315035799525`, 
           20.62, 28540500}}, {{2013, 1, 10}, {
          20.702087860179493`, 20.88903637222484, 20.623372697213032`, 20.83, 
           33348200}}, {{2013, 1, 11}, {
          20.87855182205395, 20.898230004732607`, 20.68176999526739, 20.79, 
           41839700}}, {{2013, 1, 14}, {
          20.83903409090909, 20.898068181818182`, 20.730804924242427`, 20.78, 
           31715900}}, {{2013, 1, 15}, {
          20.70256603773585, 20.86983962264151, 20.673047169811323`, 20.86, 
           26551000}}, {{2013, 1, 16}, {
          20.809517045454545`, 20.858712121212122`, 20.72096590909091, 20.78, 
           38932100}}, {{2013, 1, 17}, {
          20.88127699530516, 21.196169014084504`, 20.78287323943662, 20.96, 
           63851700}}, {{2013, 1, 18}, {
          21.591588021778588`, 21.83761796733213, 21.247146098003633`, 21.69, 
           113079400}}, {{2013, 1, 22}, {
          21.82729668332576, 21.846978646069967`, 21.55174920490686, 21.66, 
           55165800}}, {{2013, 1, 23}, {
          21.629361896080216`, 21.67856426618049, 21.40303099361896, 21.59, 
           47228500}}, {{2013, 1, 24}, {
          21.611428571428572`, 21.837777777777777`, 21.6015873015873, 21.7, 
           46991100}}, {{2013, 1, 25}, {
          21.920161507402426`, 21.949676985195154`, 21.752907133243607`, 
           21.93, 41919800}}, {{2013, 1, 28}, {
          22.080960000000005`, 22.179360000000003`, 21.903840000000002`, 
           22.14, 49558400}}, {{2013, 1, 29}, {
          22.13016, 22.21872, 22.041600000000003`, 22.14, 34148000}}, {{2013, 
          1, 30}, {
          22.155303643724697`, 22.184817813765186`, 21.87, 21.87, 
           36200400}}, {{2013, 1, 31}, {
          21.85113105924596, 22.03806104129264, 21.8216157989228, 21.92, 
           34427700}}, {{2013, 2, 1}, {
          22.073023872679045`, 22.27968169761273, 21.964774535809017`, 22.26, 
           43840300}}, {{2013, 2, 4}, {
          22.0483863738234, 22.127095472882115`, 21.920484087852984`, 21.95, 
           35836600}}, {{2013, 2, 5}, {
          22.120958296362023`, 22.258722271517303`, 22.091437444543033`, 
           22.18, 30917700}}, {{2013, 2, 6}, {
          22.109518716577536`, 22.139037433155078`, 21.952085561497324`, 
           22.08, 42985800}}, {{2013, 2, 7}, {
          22.139679715302492`, 22.14951957295374, 21.913362989323847`, 22.12, 
           38325900}}, {{2013, 2, 8}, {
          22.14, 22.19904, 22.0908, 22.14, 24424600}}, {{2013, 2, 11}, {
          22.129358574610244`, 22.14903786191537, 21.99160356347439, 22.09, 
           19738700}}, {{2013, 2, 12}, {
          22.121594331266607`, 22.288883968113375`, 22.121594331266607`, 
           22.22, 34297500}}, {{2013, 2, 13}, {
          22.744429243266353`, 23.108576314664386`, 22.675536554082942`, 
           23.02, 84926900}}, {{2013, 2, 14}, {
          22.882528833831696`, 23.11873558308415, 22.74474156343443, 23.04, 
           53996500}}, {{2013, 2, 15}, {
          23.106981537140406`, 23.175869471876346`, 22.86095319879777, 22.92, 
           39283000}}, {{2013, 2, 19}, {
          23.04528, 23.37, 23.03544, 23.37, 41219000}}, {{2013, 2, 20}, {
          23.33525843656557, 23.374626228107648`, 22.980948312686888`, 23.04, 
           38107400}}, {{2013, 2, 21}, {
          23.000619088564054`, 23.169303525365432`, 22.9410834049871, 23.08, 
           47811200}}, {{2013, 2, 22}, {
          23.1603249251817, 23.259512612227446`, 23.041299700726807`, 23.2, 
           27836300}}, {{2013, 2, 25}, {
          23.314555019728193`, 23.344318281455507`, 22.630000000000003`, 
           22.63, 51619800}}, {{2013, 2, 26}, {
          22.790624728850325`, 22.96921908893709, 22.73109327548807, 22.87, 
           41316300}}, {{2013, 2, 27}, {
          22.83284552845528, 23.20975609756097, 22.813008130081297`, 23.18, 
           29676400}}, {{2013, 2, 28}, {
          23.188837209302328`, 23.27813953488372, 23.02015503875969, 23.04, 
           39714600}}, {{2013, 3, 1}, {
          22.841319534282018`, 23.158835705045277`, 22.821474773609314`, 
           23.01, 41226900}}, {{2013, 3, 4}, {
          22.970928233777396`, 23.09992264718522, 22.851856467554793`, 23.09, 
           25457800}}, {{2013, 3, 5}, {
          23.27104705383637, 23.519033488766425`, 23.251208139041967`, 23.4, 
           35728000}}, {{2013, 3, 6}, {
          23.648635403464297`, 23.648635403464297`, 23.48, 23.48, 
           31539100}}, {{2013, 3, 7}, {
          23.509839527027022`, 23.638796452702696`, 23.480080236486486`, 
           23.49, 22955700}}, {{2013, 3, 8}, {
          23.669280605805636`, 23.708960875052586`, 23.49071939419436, 23.58, 
           28952100}}, {{2013, 3, 11}, {
          23.499436917866216`, 23.558954276037255`, 23.261367485182046`, 
           23.43, 34947200}}, {{2013, 3, 12}, {
          23.39853908586074, 23.408457923964118`, 23.140649295173, 23.22, 
           36593000}}, {{2013, 3, 13}, {
          23.250404427415926`, 23.329757343550448`, 23.21072796934866, 23.3, 
           24152400}}, {{2013, 3, 14}, {
          23.361122836639932`, 23.569438581680036`, 23.321443647108484`, 23.5,
            34629800}}, {{2013, 3, 15}, {
          23.25, 23.527730375426618`, 23.17064846416382, 23.25, 58857200}}, {{
          2013, 3, 18}, {
          22.990619354838714`, 23.169225806451614`, 22.950929032258063`, 
           23.07, 33700000}}, {{2013, 3, 19}, {
          23.12015437392796, 23.17969125214408, 22.991157804459693`, 23.14, 
           36150200}}, {{2013, 3, 20}, {
          23.537813299232738`, 23.607246376811595`, 23.141052855924976`, 
           23.27, 39254000}}, {{2013, 3, 21}, {
          23.238995276942894`, 23.417604121940748`, 23.109999999999996`, 
           23.11, 38543900}}, {{2013, 3, 22}, {
          23.130406504065036`, 23.20975609756097, 23.090731707317072`, 23.18, 
           30606100}}, {{2013, 3, 25}, {
          23.268373493975904`, 23.298141135972465`, 22.87147160068847, 23.06, 
           41684400}}, {{2013, 3, 26}, {
          23.088832179930794`, 23.118598615916955`, 22.830856401384082`, 
           22.94, 32353500}}, {{2013, 3, 27}, {
          22.840623376623377`, 22.95968831168831, 22.671948051948053`, 22.92, 
           27492500}}, {{2013, 3, 28}, {
          22.95984429065744, 23.019377162629755`, 22.81101211072664, 22.94, 
           31151000}}, {{2013, 4, 1}, {
          22.85038994800693, 22.91984402079723, 22.79085788561525, 22.9, 
           27449700}}, {{2013, 4, 2}, {
          22.991311053984575`, 23.189768637532133`, 22.92185089974293, 23.16, 
           29180100}}, {{2013, 4, 3}, {
          23.19702608695652, 23.21686956521739, 22.740626086956524`, 22.82, 
           52570300}}, {{2013, 4, 4}, {
          22.830545927209705`, 22.949610051993066`, 22.780935875216638`, 22.9,
            30472100}}, {{2013, 4, 5}, {
          22.621020497165286`, 22.75992150021806, 22.58133449629307, 22.75, 
           31402200}}, {{2013, 4, 8}, {
          22.870544982698963`, 22.94, 22.652257785467125`, 22.94, 
           30493600}}, {{2013, 4, 9}, {
          23.068516912402426`, 23.068516912402426`, 22.721248915871637`, 
           22.88, 31668200}}, {{2013, 4, 10}, {
          22.913867684478376`, 23.45943596268024, 22.87418999151824, 23.39, 
           39772300}}, {{2013, 4, 11}, {
          23.36032217041119, 23.528952946163628`, 23.241288681644765`, 23.4, 
           27084400}}, {{2013, 4, 12}, {
          23.29975703324808, 23.39894714407502, 23.141052855924976`, 23.27, 
           27234300}}, {{2013, 4, 15}, {
          23.096291100394566`, 23.11613327487944, 22.630000000000003`, 22.63, 
           46453800}}, {{2013, 4, 16}, {
          22.890233766233766`, 22.92, 22.72155844155844, 22.92, 36016700}}, {{
          2013, 4, 17}, {
          22.778418277680135`, 22.847864674868188`, 22.470869947275915`, 
           22.58, 42672900}}, {{2013, 4, 18}, {
          22.579285399206, 22.668570798412, 22.39079400088222, 22.49, 
           41170900}}, {{2013, 4, 19}, {
          21.768514942528736`, 21.85781149425287, 21.44109425287356, 21.58, 
           108837900}}, {{2013, 4, 22}, {
          21.497451990632317`, 21.507372365339577`, 20.94191100702576, 21.18, 
           87828900}}, {{2013, 4, 23}, {
          21.37960465116279, 21.518497674418605`, 21.191106976744184`, 21.33, 
           65489600}}, {{2013, 4, 24}, {
          21.522090163934426`, 21.859458105646628`, 21.482399817850634`, 
           21.79, 51506700}}, {{2013, 4, 25}, {
          22.037986332574036`, 22.05783143507973, 21.74030979498861, 21.78, 
           41462900}}, {{2013, 4, 26}, {
          21.801864025213867`, 22.218460153084195`, 21.791945069788383`, 
           22.03, 47012500}}, {{2013, 4, 29}, {
          22.129676695105523`, 22.139595868881905`, 21.82218230803772, 22.09, 
           36531800}}, {{2013, 4, 30}, {
          22.11, 22.1992732166891, 22.03064602960969, 22.11, 34054800}}, {{
          2013, 5, 1}, {
          21.920406320541762`, 22.168374717832958`, 21.920406320541762`, 
           21.97, 39201600}}, {{2013, 5, 2}, {
          22.070564516129032`, 22.14, 21.971370967741933`, 22.14, 
           27651500}}, {{2013, 5, 3}, {
          22.39, 22.667766947275148`, 22.370159503766065`, 22.39, 
           45523300}}, {{2013, 5, 6}, {
          22.38015943312666, 22.45952170062002, 22.14207263064659, 22.4, 
           28563900}}, {{2013, 5, 7}, {
          22.509920634920633`, 22.60912698412698, 22.44047619047619, 22.5, 
           28211700}}, {{2013, 5, 8}, {
          22.502581486310298`, 22.83992177314211, 22.443050847457627`, 22.83, 
           39977300}}, {{2013, 5, 9}, {
          22.808340649692713`, 22.91747146619842, 22.510711150131694`, 22.6, 
           29974300}}, {{2013, 5, 10}, {
          22.591021834061134`, 22.729921397379915`, 22.412436681222708`, 
           22.72, 35117300}}, {{2013, 5, 13}, {
          22.67992122538293, 22.699763676148795`, 22.441811816192562`, 22.67, 
           30283800}}, {{2013, 5, 14}, {
          22.671251629726207`, 22.889530638852673`, 22.631564537157754`, 
           22.83, 39592300}}, {{2013, 5, 15}, {
          22.86154905335628, 23.069922547332187`, 22.732555938037866`, 23.06, 
           40153000}}, {{2013, 5, 16}, {
          22.921314997851315`, 23.16938117748174, 22.921314997851315`, 23.09, 
           33023300}}, {{2013, 5, 17}, {
          23.081538789428816`, 23.289838022165387`, 23.012105711849955`, 
           23.27, 41037700}}, {{2013, 5, 20}, {
          23.270886720407294`, 23.389919389053876`, 23.241128553245648`, 
           23.38, 32884800}}, {{2013, 5, 21}, {
          23.400562130177512`, 23.58903634826712, 23.400562130177512`, 23.47, 
           33815000}}, {{2013, 5, 22}, {
          23.590637049455157`, 23.937849958088854`, 23.56087594300084, 23.67, 
           68514400}}, {{2013, 5, 23}, {
          23.33112426035503, 23.559277261200336`, 23.261686390532542`, 23.47, 
           44383600}}, {{2013, 5, 24}, {
          23.3102422439439, 23.478869528261797`, 23.3003229919252, 23.34, 
           41015200}}, {{2013, 5, 28}, {
          23.578631355932202`, 23.648067796610167`, 23.39016101694915, 23.41, 
           47323000}}, {{2013, 5, 29}, {
          23.231768189509307`, 23.50951776649746, 23.21192893401015, 23.45, 
           39236500}}, {{2013, 5, 30}, {
          23.39016101694915, 23.56871186440678, 23.310805084745763`, 23.41, 
           29347100}}, {{2013, 5, 31}, {
          23.407915951972555`, 23.606372212692968`, 23.13007718696398, 23.14, 
           49247600}}, {{2013, 6, 3}, {
          23.18217005076142, 23.588874788494078`, 23.132571912013535`, 23.45, 
           45218400}}, {{2013, 6, 4}, {
          23.400562130177512`, 23.569196956889265`, 23.22200760777684, 23.47, 
           38701300}}, {{2013, 6, 5}, {
          23.368224699828474`, 23.397993138936535`, 23.030849056603774`, 
           23.14, 44756200}}, {{2013, 6, 6}, {
          23.06105645851155, 23.19991873396065, 22.9122754491018, 23.19, 
           42677500}}, {{2013, 6, 7}, {
          23.35254819782062, 23.759283319362954`, 23.28310561609388, 23.67, 
           49041200}}, {{2013, 6, 10}, {
          23.689201009251473`, 23.728881412952063`, 23.45111858704794, 23.59, 
           41626500}}, {{2013, 6, 11}, {
          23.300725190839696`, 23.49911365564038, 23.290805767599664`, 23.39, 
           36183000}}, {{2013, 6, 12}, {
          23.508382978723404`, 23.538140425531914`, 23.230646808510638`, 
           23.31, 33842000}}, {{2013, 6, 13}, {
          23.261845439189184`, 23.599117398648644`, 23.152728040540538`, 
           23.49, 34930500}}, {{2013, 6, 14}, {
          23.488707482993195`, 23.55814200680272, 23.27048469387755, 23.33, 
           27846000}}, {{2013, 6, 17}, {
          23.560159865376523`, 23.6593605384939, 23.460959192259146`, 23.58, 
           39278300}}, {{2013, 6, 18}, {
          23.64390464447185, 24.259062885326763`, 23.58437320180847, 24.14, 
           72766900}}, {{2013, 6, 19}, {
          24.008256880733942`, 24.15706839032527, 23.79, 23.79, 46082200}}, {{
          2013, 6, 20}, {23.63, 23.69, 23.2, 23.25, 62733200}}, {{2013, 6, 
          21}, {
          23.579999999999995`, 23.639999999999997`, 23.209999999999997`, 
           23.36, 65025200}}, {{2013, 6, 24}, {
          23.12, 23.15, 22.76, 22.93, 48760800}}, {{2013, 6, 25}, {
          23.169999999999998`, 23.249999999999996`, 22.939999999999998`, 
           23.11, 36569100}}, {{2013, 6, 26}, {
          23.43, 23.44, 23.02, 23.25, 32531700}}, {{2013, 6, 27}, {
          23.41, 23.48, 23.26, 23.32, 30867900}}, {{2013, 6, 28}, {
          23.32, 23.44, 23.16, 23.19, 45923200}}, {{2013, 7, 1}, {
          23.209999999999997`, 23.639999999999997`, 23.189999999999998`, 
           23.34, 35784800}}, {{2013, 7, 2}, {
          23.27, 23.34, 22.88, 22.9, 47571200}}, {{2013, 7, 3}, {
          22.83, 22.98, 22.76, 22.91, 21448500}}, {{2013, 7, 5}, {
          23.17, 23.24, 22.95, 23.24, 22688900}}, {{2013, 7, 8}, {
          23.36, 23.53, 23.27, 23.32, 35481100}}, {{2013, 7, 9}, {
          23.52, 23.8, 23.51, 23.62, 31541400}}, {{2013, 7, 10}, {
          23.719999999999995`, 23.729999999999997`, 23.359999999999996`, 
           23.54, 28457100}}, {{2013, 7, 11}, {
          23.91, 23.96, 23.63, 23.94, 32618400}}, {{2013, 7, 12}, {
          23.99, 24., 23.59, 23.76, 33257700}}, {{2013, 7, 15}, {
          23.73, 23.74, 23.56, 23.63, 35853500}}, {{2013, 7, 16}, {
          23.659999999999997`, 23.669999999999998`, 23.339999999999996`, 
           23.43, 38192400}}, {{2013, 7, 17}, {
          23.539999999999996`, 23.609999999999996`, 23.429999999999996`, 
           23.54, 26858500}}, {{2013, 7, 18}, {
          23.6, 23.94, 23.56, 23.63, 41438200}}, {{2013, 7, 19}, {
          24.21, 24.95, 24.1, 24.72, 103708900}}, {{2013, 7, 22}, {
          24.77, 24.92, 24.73, 24.86, 41560800}}, {{2013, 7, 23}, {
          24.87, 24.88, 24.63, 24.71, 32553000}}, {{2013, 7, 24}, {
          24.79, 24.84, 24.56, 24.62, 27485000}}, {{2013, 7, 25}, {
          24.61, 24.69, 24.52, 24.69, 29951700}}}, 
        System`TradingChartDump`$markerstyle$541631 = 1, 
        System`TradingChartDump`$controlmin$541631 = 0.5, 
        System`TradingChartDump`$controlmax$541631 = 250.5, 
        System`TradingChartDump`$datescope$541631 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$541631 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$541631, 
        System`TradingChartDump`$max$541631, 
        System`TradingChartDump`$ohlclabel$541631 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541631, 
              System`TradingChartDump`$opens$541631]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541631, 
              System`TradingChartDump`$highs$541631]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541631, 
              System`TradingChartDump`$lows$541631]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541631, 
              System`TradingChartDump`$closes$541631]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541631, 
              System`TradingChartDump`$visdates$541631]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$541631 = {}, 
        System`TradingChartDump`$subpricegridlines$541631 = Automatic, 
        System`TradingChartDump`$overlaypoint$541631, 
        System`TradingChartDump`$overlayvalue$541631, 
        System`TradingChartDump`$subplotvalue$541631, 
        System`TradingChartDump`$opts$541631 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "GE", " with ", "AverageTrueRange", 
            "(", 14, ",", Null, ",", Null, ",", Null, ")"}], 
         ImageSize -> {450, 310}, AlignmentPoint -> Center, AspectRatio -> 
         GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> None, AxesOrigin -> 
         Automatic, AxesStyle -> {}, Background -> None, BaselinePosition -> 
         Automatic, BaseStyle -> {}, ColorOutput -> Automatic, 
         ContentSelectable -> Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$541631 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmglczWkXx2/W7PuSl9RLZClS3WtQPcooqUkLiVT3tt5uC5ooBo09IVt6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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyFmndUVNcWxkfFhihRiF0CAoKABikjiOJRmgrCUJUqMDAgzUKMihKwRohi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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$541631 = 
        System`TradingChartDump`$staticindicatorpos$541631, 
        System`TradingChartDump`$length$541631 = 250, 
        System`TradingChartDump`$gridlinesflag$541631 = True, 
        System`TradingChartDump`$opens$541631 = 
        Dispatch[{
         1 -> 19.55`4., 2 -> 19.97`4., 3 -> 20.12`4., 4 -> 20.08`4., 5 -> 
          20.19`4., 6 -> 19.86`4., 7 -> 20.14`4., 8 -> 20.29`4., 9 -> 
          20.46`4., 10 -> 20.37`4., 11 -> 20.26`4., 12 -> 20.32`4., 13 -> 
          20.36`4., 14 -> 20.4`4., 15 -> 20.18`4., 16 -> 20.2`4., 17 -> 
          20.34`4., 18 -> 20.27`4., 19 -> 20.3`4., 20 -> 20.1`4., 21 -> 
          20.07`4., 22 -> 19.93`4., 23 -> 20.15`4., 24 -> 20.09`4., 25 -> 
          20.15`4., 26 -> 20.05`4., 27 -> 20.09`4., 28 -> 19.97`4., 29 -> 
          19.88`4., 30 -> 20.19`4., 31 -> 20.63`4., 32 -> 20.79`4., 33 -> 
          20.79`4., 34 -> 20.97`4., 35 -> 21.07`4., 36 -> 21.49`4., 37 -> 
          21.22`4., 38 -> 21.28`4., 39 -> 21.58`4., 40 -> 21.64`4., 41 -> 
          21.99`4., 42 -> 21.84`4., 43 -> 21.84`4., 44 -> 21.61`4., 45 -> 
          21.68`4., 46 -> 22.21`4., 47 -> 22.16`4., 48 -> 22.36`4., 49 -> 
          22.29`4., 50 -> 22.38`4., 51 -> 22.46`4., 52 -> 22.3`4., 53 -> 
          22.37`4., 54 -> 22.05`4., 55 -> 22.03`4., 56 -> 22.02`4., 57 -> 
          21.98`4., 58 -> 22.23`4., 59 -> 22.2`4., 60 -> 22.24`4., 61 -> 
          21.95`4., 62 -> 21.32`4., 63 -> 20.82`4., 64 -> 20.9`4., 65 -> 
          20.96`4., 66 -> 20.66`4., 67 -> 20.74`4., 68 -> 20.51`4., 69 -> 
          20.99`4., 70 -> 20.68`4., 71 -> 20.97`4., 72 -> 20.82`4., 73 -> 
          20.63`4., 74 -> 20.25`4., 75 -> 20.52`4., 76 -> 20.09`4., 77 -> 
          20.21`4., 78 -> 19.4`4., 79 -> 19.6`4., 80 -> 19.91`4., 81 -> 
          20.16`4., 82 -> 20.19`4., 83 -> 20.3`4., 84 -> 20.36`4., 85 -> 
          20.52`4., 86 -> 20.23`4., 87 -> 20.71`4., 88 -> 20.61`4., 89 -> 
          20.65`4., 90 -> 20.35`4., 91 -> 20.39`4., 92 -> 20.67`4., 93 -> 
          20.91`4., 94 -> 20.9`4., 95 -> 20.94`4., 96 -> 21.07`4., 97 -> 
          21.2`4., 98 -> 21.07`4., 99 -> 21.15`4., 100 -> 21.31`4., 101 -> 
          21.1`4., 102 -> 20.57`4., 103 -> 20.51`4., 104 -> 20.46`4., 105 -> 
          20.48`4., 106 -> 20.47`4., 107 -> 20.12`4., 108 -> 19.96`4., 109 -> 
          21.17`4., 110 -> 21.13`4., 111 -> 20.87`4., 112 -> 20.82`4., 113 -> 
          20.77`4., 114 -> 20.71`4., 115 -> 20.7`4., 116 -> 20.88`4., 117 -> 
          20.84`4., 118 -> 20.7`4., 119 -> 20.81`4., 120 -> 20.88`4., 121 -> 
          21.59`4., 122 -> 21.83`4., 123 -> 21.63`4., 124 -> 21.61`4., 125 -> 
          21.92`4., 126 -> 22.08`4., 127 -> 22.13`4., 128 -> 22.16`4., 129 -> 
          21.85`4., 130 -> 22.07`4., 131 -> 22.05`4., 132 -> 22.12`4., 133 -> 
          22.11`4., 134 -> 22.14`4., 135 -> 22.14`4., 136 -> 22.13`4., 137 -> 
          22.12`4., 138 -> 22.74`4., 139 -> 22.88`4., 140 -> 23.11`4., 141 -> 
          23.05`4., 142 -> 23.34`4., 143 -> 23.`4., 144 -> 23.16`4., 145 -> 
          23.31`4., 146 -> 22.79`4., 147 -> 22.83`4., 148 -> 23.19`4., 149 -> 
          22.84`4., 150 -> 22.97`4., 151 -> 23.27`4., 152 -> 23.65`4., 153 -> 
          23.51`4., 154 -> 23.67`4., 155 -> 23.5`4., 156 -> 23.4`4., 157 -> 
          23.25`4., 158 -> 23.36`4., 159 -> 23.25`4., 160 -> 22.99`4., 161 -> 
          23.12`4., 162 -> 23.54`4., 163 -> 23.24`4., 164 -> 23.13`4., 165 -> 
          23.27`4., 166 -> 23.09`4., 167 -> 22.84`4., 168 -> 22.96`4., 169 -> 
          22.85`4., 170 -> 22.99`4., 171 -> 23.2`4., 172 -> 22.83`4., 173 -> 
          22.62`4., 174 -> 22.87`4., 175 -> 23.07`4., 176 -> 22.91`4., 177 -> 
          23.36`4., 178 -> 23.3`4., 179 -> 23.1`4., 180 -> 22.89`4., 181 -> 
          22.78`4., 182 -> 22.58`4., 183 -> 21.77`4., 184 -> 21.5`4., 185 -> 
          21.38`4., 186 -> 21.52`4., 187 -> 22.04`4., 188 -> 21.8`4., 189 -> 
          22.13`4., 190 -> 22.11`4., 191 -> 21.92`4., 192 -> 22.07`4., 193 -> 
          22.39`4., 194 -> 22.38`4., 195 -> 22.51`4., 196 -> 22.5`4., 197 -> 
          22.81`4., 198 -> 22.59`4., 199 -> 22.68`4., 200 -> 22.67`4., 201 -> 
          22.86`4., 202 -> 22.92`4., 203 -> 23.08`4., 204 -> 23.27`4., 205 -> 
          23.4`4., 206 -> 23.59`4., 207 -> 23.33`4., 208 -> 23.31`4., 209 -> 
          23.58`4., 210 -> 23.23`4., 211 -> 23.39`4., 212 -> 23.41`4., 213 -> 
          23.18`4., 214 -> 23.4`4., 215 -> 23.37`4., 216 -> 23.06`4., 217 -> 
          23.35`4., 218 -> 23.69`4., 219 -> 23.3`4., 220 -> 23.51`4., 221 -> 
          23.26`4., 222 -> 23.49`4., 223 -> 23.56`4., 224 -> 23.64`4., 225 -> 
          24.01`4., 226 -> 23.63`4., 227 -> 23.58`4., 228 -> 23.12`4., 229 -> 
          23.17`4., 230 -> 23.43`4., 231 -> 23.41`4., 232 -> 23.32`4., 233 -> 
          23.21`4., 234 -> 23.27`4., 235 -> 22.83`4., 236 -> 23.17`4., 237 -> 
          23.36`4., 238 -> 23.52`4., 239 -> 23.72`4., 240 -> 23.91`4., 241 -> 
          23.99`4., 242 -> 23.73`4., 243 -> 23.66`4., 244 -> 23.54`4., 245 -> 
          23.6`4., 246 -> 24.21`4., 247 -> 24.77`4., 248 -> 24.87`4., 249 -> 
          24.79`4., 250 -> 24.61`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$541631 = 
        Dispatch[{
         1 -> 20.04`4., 2 -> 20.33`4., 3 -> 20.24`4., 4 -> 20.22`4., 5 -> 
          20.27`4., 6 -> 20.03`4., 7 -> 20.32`4., 8 -> 20.49`4., 9 -> 
          20.51`4., 10 -> 20.41`4., 11 -> 20.44`4., 12 -> 20.42`4., 13 -> 
          20.38`4., 14 -> 20.42`4., 15 -> 20.35`4., 16 -> 20.46`4., 17 -> 
          20.37`4., 18 -> 20.34`4., 19 -> 20.37`4., 20 -> 20.2`4., 21 -> 
          20.12`4., 22 -> 20.23`4., 23 -> 20.28`4., 24 -> 20.25`4., 25 -> 
          20.28`4., 26 -> 20.11`4., 27 -> 20.16`4., 28 -> 20.02`4., 29 -> 
          20.1`4., 30 -> 20.63`4., 31 -> 20.89`4., 32 -> 20.95`4., 33 -> 
          20.99`4., 34 -> 21.22`4., 35 -> 21.52`4., 36 -> 21.65`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.77`4., 40 -> 21.91`4., 41 -> 
          22.13`4., 42 -> 21.89`4., 43 -> 22.11`4., 44 -> 21.7`4., 45 -> 
          22.29`4., 46 -> 22.39`4., 47 -> 22.43`4., 48 -> 22.41`4., 49 -> 
          22.41`4., 50 -> 22.48`4., 51 -> 22.6`4., 52 -> 22.42`4., 53 -> 
          22.4`4., 54 -> 22.17`4., 55 -> 22.15`4., 56 -> 22.14`4., 57 -> 
          22.14`4., 58 -> 22.31`4., 59 -> 22.35`4., 60 -> 22.5`4., 61 -> 
          21.97`4., 62 -> 21.4`4., 63 -> 20.87`4., 64 -> 20.93`4., 65 -> 
          21.03`4., 66 -> 20.86`4., 67 -> 20.79`4., 68 -> 20.86`4., 69 -> 
          21.14`4., 70 -> 20.94`4., 71 -> 21.24`4., 72 -> 20.98`4., 73 -> 
          20.66`4., 74 -> 20.77`4., 75 -> 20.61`4., 76 -> 20.43`4., 77 -> 
          20.23`4., 78 -> 19.73`4., 79 -> 19.69`4., 80 -> 20.21`4., 81 -> 
          20.18`4., 82 -> 20.23`4., 83 -> 20.52`4., 84 -> 20.55`4., 85 -> 
          20.67`4., 86 -> 20.62`4., 87 -> 20.82`4., 88 -> 20.73`4., 89 -> 
          20.7`4., 90 -> 20.49`4., 91 -> 20.83`4., 92 -> 20.86`4., 93 -> 
          20.95`4., 94 -> 20.97`4., 95 -> 21.2`4., 96 -> 21.41`4., 97 -> 
          21.37`4., 98 -> 21.22`4., 99 -> 21.4`4., 100 -> 21.36`4., 101 -> 
          21.12`4., 102 -> 20.9`4., 103 -> 20.66`4., 104 -> 20.63`4., 105 -> 
          20.61`4., 106 -> 20.54`4., 107 -> 20.38`4., 108 -> 20.66`4., 109 -> 
          21.2`4., 110 -> 21.14`4., 111 -> 20.92`4., 112 -> 20.88`4., 113 -> 
          20.79`4., 114 -> 20.74`4., 115 -> 20.89`4., 116 -> 20.9`4., 117 -> 
          20.9`4., 118 -> 20.87`4., 119 -> 20.86`4., 120 -> 21.2`4., 121 -> 
          21.84`4., 122 -> 21.85`4., 123 -> 21.68`4., 124 -> 21.84`4., 125 -> 
          21.95`4., 126 -> 22.18`4., 127 -> 22.22`4., 128 -> 22.18`4., 129 -> 
          22.04`4., 130 -> 22.28`4., 131 -> 22.13`4., 132 -> 22.26`4., 133 -> 
          22.14`4., 134 -> 22.15`4., 135 -> 22.2`4., 136 -> 22.15`4., 137 -> 
          22.29`4., 138 -> 23.11`4., 139 -> 23.12`4., 140 -> 23.18`4., 141 -> 
          23.37`4., 142 -> 23.37`4., 143 -> 23.17`4., 144 -> 23.26`4., 145 -> 
          23.34`4., 146 -> 22.97`4., 147 -> 23.21`4., 148 -> 23.28`4., 149 -> 
          23.16`4., 150 -> 23.1`4., 151 -> 23.52`4., 152 -> 23.65`4., 153 -> 
          23.64`4., 154 -> 23.71`4., 155 -> 23.56`4., 156 -> 23.41`4., 157 -> 
          23.33`4., 158 -> 23.57`4., 159 -> 23.53`4., 160 -> 23.17`4., 161 -> 
          23.18`4., 162 -> 23.61`4., 163 -> 23.42`4., 164 -> 23.21`4., 165 -> 
          23.3`4., 166 -> 23.12`4., 167 -> 22.96`4., 168 -> 23.02`4., 169 -> 
          22.92`4., 170 -> 23.19`4., 171 -> 23.22`4., 172 -> 22.95`4., 173 -> 
          22.76`4., 174 -> 22.94`4., 175 -> 23.07`4., 176 -> 23.46`4., 177 -> 
          23.53`4., 178 -> 23.4`4., 179 -> 23.12`4., 180 -> 22.92`4., 181 -> 
          22.85`4., 182 -> 22.67`4., 183 -> 21.86`4., 184 -> 21.51`4., 185 -> 
          21.52`4., 186 -> 21.86`4., 187 -> 22.06`4., 188 -> 22.22`4., 189 -> 
          22.14`4., 190 -> 22.2`4., 191 -> 22.17`4., 192 -> 22.14`4., 193 -> 
          22.67`4., 194 -> 22.46`4., 195 -> 22.61`4., 196 -> 22.84`4., 197 -> 
          22.92`4., 198 -> 22.73`4., 199 -> 22.7`4., 200 -> 22.89`4., 201 -> 
          23.07`4., 202 -> 23.17`4., 203 -> 23.29`4., 204 -> 23.39`4., 205 -> 
          23.59`4., 206 -> 23.94`4., 207 -> 23.56`4., 208 -> 23.48`4., 209 -> 
          23.65`4., 210 -> 23.51`4., 211 -> 23.57`4., 212 -> 23.61`4., 213 -> 
          23.59`4., 214 -> 23.57`4., 215 -> 23.4`4., 216 -> 23.2`4., 217 -> 
          23.76`4., 218 -> 23.73`4., 219 -> 23.5`4., 220 -> 23.54`4., 221 -> 
          23.6`4., 222 -> 23.56`4., 223 -> 23.66`4., 224 -> 24.26`4., 225 -> 
          24.16`4., 226 -> 23.69`4., 227 -> 23.64`4., 228 -> 23.15`4., 229 -> 
          23.25`4., 230 -> 23.44`4., 231 -> 23.48`4., 232 -> 23.44`4., 233 -> 
          23.64`4., 234 -> 23.34`4., 235 -> 22.98`4., 236 -> 23.24`4., 237 -> 
          23.53`4., 238 -> 23.8`4., 239 -> 23.73`4., 240 -> 23.96`4., 241 -> 
          24.`4., 242 -> 23.74`4., 243 -> 23.67`4., 244 -> 23.61`4., 245 -> 
          23.94`4., 246 -> 24.95`4., 247 -> 24.92`4., 248 -> 24.88`4., 249 -> 
          24.84`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$541631 = 
        Dispatch[{
         1 -> 19.51`4., 2 -> 19.9`4., 3 -> 20.02`4., 4 -> 20.08`4., 5 -> 
          20.04`4., 6 -> 19.55`4., 7 -> 20.1`4., 8 -> 20.22`4., 9 -> 20.41`4.,
           10 -> 20.22`4., 11 -> 20.26`4., 12 -> 20.27`4., 13 -> 20.2`4., 14 -> 
          20.22`4., 15 -> 20.12`4., 16 -> 20.15`4., 17 -> 20.26`4., 18 -> 
          20.15`4., 19 -> 20.13`4., 20 -> 20.04`4., 21 -> 19.96`4., 22 -> 
          19.89`4., 23 -> 20.12`4., 24 -> 20.09`4., 25 -> 20.14`4., 26 -> 
          19.95`4., 27 -> 19.94`4., 28 -> 19.82`4., 29 -> 19.84`4., 30 -> 
          20.17`4., 31 -> 20.61`4., 32 -> 20.74`4., 33 -> 20.71`4., 34 -> 
          20.96`4., 35 -> 21.05`4., 36 -> 21.27`4., 37 -> 21.19`4., 38 -> 
          21.25`4., 39 -> 21.54`4., 40 -> 21.57`4., 41 -> 21.9`4., 42 -> 
          21.74`4., 43 -> 21.75`4., 44 -> 21.52`4., 45 -> 21.58`4., 46 -> 
          22.06`4., 47 -> 22.14`4., 48 -> 22.14`4., 49 -> 22.15`4., 50 -> 
          22.2`4., 51 -> 22.42`4., 52 -> 22.28`4., 53 -> 22.04`4., 54 -> 
          21.85`4., 55 -> 21.92`4., 56 -> 21.85`4., 57 -> 21.93`4., 58 -> 
          22.01`4., 59 -> 22.15`4., 60 -> 22.23`4., 61 -> 21.32`4., 62 -> 
          20.72`4., 63 -> 20.67`4., 64 -> 20.71`4., 65 -> 20.51`4., 66 -> 
          20.54`4., 67 -> 20.45`4., 68 -> 20.5`4., 69 -> 20.73`4., 70 -> 
          20.68`4., 71 -> 20.91`4., 72 -> 20.54`4., 73 -> 20.36`4., 74 -> 
          20.19`4., 75 -> 20.36`4., 76 -> 20.06`4., 77 -> 19.45`4., 78 -> 
          19.4`4., 79 -> 19.38`4., 80 -> 19.89`4., 81 -> 19.87`4., 82 -> 
          20.06`4., 83 -> 20.22`4., 84 -> 20.35`4., 85 -> 20.33`4., 86 -> 
          19.99`4., 87 -> 20.42`4., 88 -> 20.51`4., 89 -> 20.28`4., 90 -> 
          20.19`4., 91 -> 20.34`4., 92 -> 20.56`4., 93 -> 20.72`4., 94 -> 
          20.83`4., 95 -> 20.82`4., 96 -> 21.04`4., 97 -> 21.01`4., 98 -> 
          21.01`4., 99 -> 21.15`4., 100 -> 20.88`4., 101 -> 20.45`4., 102 -> 
          20.53`4., 103 -> 20.24`4., 104 -> 20.42`4., 105 -> 20.38`4., 106 -> 
          20.09`4., 107 -> 20.1`4., 108 -> 19.93`4., 109 -> 20.86`4., 110 -> 
          20.71`4., 111 -> 20.78`4., 112 -> 20.62`4., 113 -> 20.35`4., 114 -> 
          20.6`4., 115 -> 20.62`4., 116 -> 20.68`4., 117 -> 20.73`4., 118 -> 
          20.67`4., 119 -> 20.72`4., 120 -> 20.78`4., 121 -> 21.25`4., 122 -> 
          21.55`4., 123 -> 21.4`4., 124 -> 21.6`4., 125 -> 21.75`4., 126 -> 
          21.9`4., 127 -> 22.04`4., 128 -> 21.87`4., 129 -> 21.82`4., 130 -> 
          21.96`4., 131 -> 21.92`4., 132 -> 22.09`4., 133 -> 21.95`4., 134 -> 
          21.91`4., 135 -> 22.09`4., 136 -> 21.99`4., 137 -> 22.12`4., 138 -> 
          22.68`4., 139 -> 22.74`4., 140 -> 22.86`4., 141 -> 23.04`4., 142 -> 
          22.98`4., 143 -> 22.94`4., 144 -> 23.04`4., 145 -> 22.63`4., 146 -> 
          22.73`4., 147 -> 22.81`4., 148 -> 23.02`4., 149 -> 22.82`4., 150 -> 
          22.85`4., 151 -> 23.25`4., 152 -> 23.48`4., 153 -> 23.48`4., 154 -> 
          23.49`4., 155 -> 23.26`4., 156 -> 23.14`4., 157 -> 23.21`4., 158 -> 
          23.32`4., 159 -> 23.17`4., 160 -> 22.95`4., 161 -> 22.99`4., 162 -> 
          23.14`4., 163 -> 23.11`4., 164 -> 23.09`4., 165 -> 22.87`4., 166 -> 
          22.83`4., 167 -> 22.67`4., 168 -> 22.81`4., 169 -> 22.79`4., 170 -> 
          22.92`4., 171 -> 22.74`4., 172 -> 22.78`4., 173 -> 22.58`4., 174 -> 
          22.65`4., 175 -> 22.72`4., 176 -> 22.87`4., 177 -> 23.24`4., 178 -> 
          23.14`4., 179 -> 22.63`4., 180 -> 22.72`4., 181 -> 22.47`4., 182 -> 
          22.39`4., 183 -> 21.44`4., 184 -> 20.94`4., 185 -> 21.19`4., 186 -> 
          21.48`4., 187 -> 21.74`4., 188 -> 21.79`4., 189 -> 21.82`4., 190 -> 
          22.03`4., 191 -> 21.92`4., 192 -> 21.97`4., 193 -> 22.37`4., 194 -> 
          22.14`4., 195 -> 22.44`4., 196 -> 22.44`4., 197 -> 22.51`4., 198 -> 
          22.41`4., 199 -> 22.44`4., 200 -> 22.63`4., 201 -> 22.73`4., 202 -> 
          22.92`4., 203 -> 23.01`4., 204 -> 23.24`4., 205 -> 23.4`4., 206 -> 
          23.56`4., 207 -> 23.26`4., 208 -> 23.3`4., 209 -> 23.39`4., 210 -> 
          23.21`4., 211 -> 23.31`4., 212 -> 23.13`4., 213 -> 23.13`4., 214 -> 
          23.22`4., 215 -> 23.03`4., 216 -> 22.91`4., 217 -> 23.28`4., 218 -> 
          23.45`4., 219 -> 23.29`4., 220 -> 23.23`4., 221 -> 23.15`4., 222 -> 
          23.27`4., 223 -> 23.46`4., 224 -> 23.58`4., 225 -> 23.79`4., 226 -> 
          23.2`4., 227 -> 23.21`4., 228 -> 22.76`4., 229 -> 22.94`4., 230 -> 
          23.02`4., 231 -> 23.26`4., 232 -> 23.16`4., 233 -> 23.19`4., 234 -> 
          22.88`4., 235 -> 22.76`4., 236 -> 22.95`4., 237 -> 23.27`4., 238 -> 
          23.51`4., 239 -> 23.36`4., 240 -> 23.63`4., 241 -> 23.59`4., 242 -> 
          23.56`4., 243 -> 23.34`4., 244 -> 23.43`4., 245 -> 23.56`4., 246 -> 
          24.1`4., 247 -> 24.73`4., 248 -> 24.63`4., 249 -> 24.56`4., 250 -> 
          24.52`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$541631 = 
        Dispatch[{
         1 -> 19.9`4., 2 -> 20.25`4., 3 -> 20.13`4., 4 -> 20.08`4., 5 -> 
          20.06`4., 6 -> 19.86`4., 7 -> 20.28`4., 8 -> 20.29`4., 9 -> 
          20.44`4., 10 -> 20.33`4., 11 -> 20.38`4., 12 -> 20.42`4., 13 -> 
          20.31`4., 14 -> 20.26`4., 15 -> 20.28`4., 16 -> 20.37`4., 17 -> 
          20.32`4., 18 -> 20.25`4., 19 -> 20.18`4., 20 -> 20.11`4., 21 -> 
          19.97`4., 22 -> 20.13`4., 23 -> 20.18`4., 24 -> 20.14`4., 25 -> 
          20.15`4., 26 -> 19.97`4., 27 -> 20.04`4., 28 -> 19.85`4., 29 -> 
          19.98`4., 30 -> 20.62`4., 31 -> 20.89`4., 32 -> 20.79`4., 33 -> 
          20.89`4., 34 -> 21.18`4., 35 -> 21.31`4., 36 -> 21.4`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.71`4., 40 -> 21.87`4., 41 -> 
          21.97`4., 42 -> 21.8`4., 43 -> 21.76`4., 44 -> 21.55`4., 45 -> 
          22.16`4., 46 -> 22.15`4., 47 -> 22.24`4., 48 -> 22.22`4., 49 -> 
          22.34`4., 50 -> 22.38`4., 51 -> 22.54`4., 52 -> 22.35`4., 53 -> 
          22.06`4., 54 -> 21.87`4., 55 -> 21.95`4., 56 -> 21.92`4., 57 -> 
          22.08`4., 58 -> 22.08`4., 59 -> 22.34`4., 60 -> 22.24`4., 61 -> 
          21.48`4., 62 -> 21.16`4., 63 -> 20.75`4., 64 -> 20.73`4., 65 -> 
          20.73`4., 66 -> 20.58`4., 67 -> 20.54`4., 68 -> 20.81`4., 69 -> 
          20.78`4., 70 -> 20.88`4., 71 -> 21.05`4., 72 -> 20.6`4., 73 -> 
          20.37`4., 74 -> 20.48`4., 75 -> 20.37`4., 76 -> 20.17`4., 77 -> 
          19.51`4., 78 -> 19.56`4., 79 -> 19.65`4., 80 -> 20.15`4., 81 -> 
          20.11`4., 82 -> 20.17`4., 83 -> 20.52`4., 84 -> 20.54`4., 85 -> 
          20.35`4., 86 -> 20.61`4., 87 -> 20.6`4., 88 -> 20.6`4., 89 -> 
          20.3`4., 90 -> 20.34`4., 91 -> 20.7`4., 92 -> 20.84`4., 93 -> 
          20.93`4., 94 -> 20.86`4., 95 -> 20.97`4., 96 -> 21.24`4., 97 -> 
          21.08`4., 98 -> 21.08`4., 99 -> 21.38`4., 100 -> 21.15`4., 101 -> 
          20.49`4., 102 -> 20.71`4., 103 -> 20.55`4., 104 -> 20.49`4., 105 -> 
          20.44`4., 106 -> 20.36`4., 107 -> 20.11`4., 108 -> 20.65`4., 109 -> 
          21.`4., 110 -> 20.76`4., 111 -> 20.86`4., 112 -> 20.79`4., 113 -> 
          20.57`4., 114 -> 20.62`4., 115 -> 20.83`4., 116 -> 20.79`4., 117 -> 
          20.78`4., 118 -> 20.86`4., 119 -> 20.78`4., 120 -> 20.96`4., 121 -> 
          21.69`4., 122 -> 21.66`4., 123 -> 21.59`4., 124 -> 21.7`4., 125 -> 
          21.93`4., 126 -> 22.14`4., 127 -> 22.14`4., 128 -> 21.87`4., 129 -> 
          21.92`4., 130 -> 22.26`4., 131 -> 21.95`4., 132 -> 22.18`4., 133 -> 
          22.08`4., 134 -> 22.12`4., 135 -> 22.14`4., 136 -> 22.09`4., 137 -> 
          22.22`4., 138 -> 23.02`4., 139 -> 23.04`4., 140 -> 22.92`4., 141 -> 
          23.37`4., 142 -> 23.04`4., 143 -> 23.08`4., 144 -> 23.2`4., 145 -> 
          22.63`4., 146 -> 22.87`4., 147 -> 23.18`4., 148 -> 23.04`4., 149 -> 
          23.01`4., 150 -> 23.09`4., 151 -> 23.4`4., 152 -> 23.48`4., 153 -> 
          23.49`4., 154 -> 23.58`4., 155 -> 23.43`4., 156 -> 23.22`4., 157 -> 
          23.3`4., 158 -> 23.5`4., 159 -> 23.25`4., 160 -> 23.07`4., 161 -> 
          23.14`4., 162 -> 23.27`4., 163 -> 23.11`4., 164 -> 23.18`4., 165 -> 
          23.06`4., 166 -> 22.94`4., 167 -> 22.92`4., 168 -> 22.94`4., 169 -> 
          22.9`4., 170 -> 23.16`4., 171 -> 22.82`4., 172 -> 22.9`4., 173 -> 
          22.75`4., 174 -> 22.94`4., 175 -> 22.88`4., 176 -> 23.39`4., 177 -> 
          23.4`4., 178 -> 23.27`4., 179 -> 22.63`4., 180 -> 22.92`4., 181 -> 
          22.58`4., 182 -> 22.49`4., 183 -> 21.58`4., 184 -> 21.18`4., 185 -> 
          21.33`4., 186 -> 21.79`4., 187 -> 21.78`4., 188 -> 22.03`4., 189 -> 
          22.09`4., 190 -> 22.11`4., 191 -> 21.97`4., 192 -> 22.14`4., 193 -> 
          22.39`4., 194 -> 22.4`4., 195 -> 22.5`4., 196 -> 22.83`4., 197 -> 
          22.6`4., 198 -> 22.72`4., 199 -> 22.67`4., 200 -> 22.83`4., 201 -> 
          23.06`4., 202 -> 23.09`4., 203 -> 23.27`4., 204 -> 23.38`4., 205 -> 
          23.47`4., 206 -> 23.67`4., 207 -> 23.47`4., 208 -> 23.34`4., 209 -> 
          23.41`4., 210 -> 23.45`4., 211 -> 23.41`4., 212 -> 23.14`4., 213 -> 
          23.45`4., 214 -> 23.47`4., 215 -> 23.14`4., 216 -> 23.19`4., 217 -> 
          23.67`4., 218 -> 23.59`4., 219 -> 23.39`4., 220 -> 23.31`4., 221 -> 
          23.49`4., 222 -> 23.33`4., 223 -> 23.58`4., 224 -> 24.14`4., 225 -> 
          23.79`4., 226 -> 23.25`4., 227 -> 23.36`4., 228 -> 22.93`4., 229 -> 
          23.11`4., 230 -> 23.25`4., 231 -> 23.32`4., 232 -> 23.19`4., 233 -> 
          23.34`4., 234 -> 22.9`4., 235 -> 22.91`4., 236 -> 23.24`4., 237 -> 
          23.32`4., 238 -> 23.62`4., 239 -> 23.54`4., 240 -> 23.94`4., 241 -> 
          23.76`4., 242 -> 23.63`4., 243 -> 23.43`4., 244 -> 23.54`4., 245 -> 
          23.63`4., 246 -> 24.72`4., 247 -> 24.86`4., 248 -> 24.71`4., 249 -> 
          24.62`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$541631 = True, 
        System`TradingChartDump`$gridlines$541631 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$541631, 
        System`TradingChartDump`$plotrangemin$541631 = 19.0982952853598, 
        System`TradingChartDump`$plotrangemax$541631 = 25.507305210918112`, 
        System`TradingChartDump`$layoutData$541631, 
        System`TradingChartDump`$gridlinesscope$541631 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$541631 = {True, True}, 
        System`TradingChartDump`$indicators$541631 = {
         FinancialIndicator["AverageTrueRange", 14]}, 
        System`TradingChartDump`$mouseQ$541631 = False, 
        System`TradingChartDump`$modelData$541631 = 
        System`TradingChartDump`modelData$538696, 
        System`TradingChartDump`$sy$541631 = Identity, 
        System`TradingChartDump`$isy$541631 = Identity, 
        System`TradingChartDump`$appearance$541631 = Automatic, 
        System`TradingChartDump`$perfgoal$541631 = "Quality", 
        System`TradingChartDump`$axesorigin$541631 = Automatic, 
        System`TradingChartDump`$framestyle$541631 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$541631 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$541631 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$541631 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$541631 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$541631, 
        System`TradingChartDump`$newgridlines$541631 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{19.0982952853598, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$541631 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$541631 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$541631 = "GraphicsFrame", 
        System`TradingChartDump`$frame$541631 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$541631 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$541631 = 
              Switch[System`TradingChartDump`$highlightposition$541631, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$541631], {
                 1, System`TradingChartDump`$length$541631}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$541631], {
                 1, System`TradingChartDump`$length$541631}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$541631, 
                   Charting`nearestDate[System`TradingChartDump`$dates$541631, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$541631]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$541631]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$541631, 
                    Floor[System`TradingChartDump`$controlmin$541631] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$541631, 
                    Floor[System`TradingChartDump`$controlmax$541631]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$541631 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$541631 = 
            If[System`TradingChartDump`$fastpos$541631 =!= True, 
              System`TradingChartDump`$fastpos$541631 = 
               Clip[System`TradingChartDump`$fastpos$541631, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$541631 = (
                  Floor[System`TradingChartDump`$controlmax$541631] - Floor[
                  System`TradingChartDump`$controlmin$541631]) (
                  System`TradingChartDump`$fastpos$541631/100) + 
                Floor[System`TradingChartDump`$controlmin$541631]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$541631], {
                Floor[System`TradingChartDump`$controlmin$541631] + 1, 
                 Floor[System`TradingChartDump`$controlmax$541631]}], 
              System`TradingChartDump`$staticindicatorpos$541631]; 
           System`TradingChartDump`$mouseQ$541631 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$541631]], 
              System`TradingChartDump`$highlightposition$541631 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$541631 = If[
              And[
              System`TradingChartDump`$bouncingballQ$541631, 
               System`TradingChartDump`$mouseQ$541631, 
               System`TradingChartDump`$appearance$541631 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$541631[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$541631]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$541631[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$541631, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$541631[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$541631]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$541631[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$541631[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541631, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541631[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541631, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541631, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541631[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541631[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$541631 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$541631, 
                 System`TradingChartDump`$defaultframeticksstyle$541631, 
                 System`TradingChartDump`$defaultlabelstyle$541631, 
                 System`TradingChartDump`$framestyle$541631, 
                 System`TradingChartDump`$frameticksstyle$541631, 
                 System`TradingChartDump`$labelstyle$541631}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541631 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$541631, 
                 System`TradingChartDump`$labelstyle$541631, 
                 System`TradingChartDump`$defaultframeticksstyle$541631, 
                 System`TradingChartDump`$defaultlabelstyle$541631}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541631 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541631, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$541631 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541631, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$541631 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541631, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$541631 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$541631 = 
             Part[System`TradingChartDump`$tickstextstyle$541631, 1], 
             System`TradingChartDump`$tickstextstyle$541631 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541631[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541631, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541631[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541631[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541631[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$541631[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541631, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$541631]], 
                    Style[":", System`TradingChartDump`$textstyle$541631]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$541631[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541631]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541631[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$541631[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$541631, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$541631]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$541631[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541631, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541631[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541631, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541631, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$541631[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541631[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541631[
               "SubplotIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$541631[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$541631[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$541631], 1], 
                   Floor[System`TradingChartDump`$controlmax$541631]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$541631[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$541631[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$541631[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$541631[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$541631[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541631[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$541631[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$541631[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$541631[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541631[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$541631[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$541631[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$541631[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$541631[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$541631[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$541631, 
                  System`TradingChartDump`$mouseQ$541631], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$541631 - 0.5, 
                   System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$541631 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$541631 + 0.5, 
                    System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541631, 1]}, {
                    System`TradingChartDump`$indicatorpos$541631 + 0.5, 
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$541631[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$541631, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$541631[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541631]]], {}]; 
              System`TradingChartDump`$subplotgridlines$541631[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$541631[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$541631[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541631[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$541631 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$541631, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541631, 
                   System`TradingChartDump`$opens$541631]], 12, 
                 System`TradingChartDump`$textstyle$541631, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$541631, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541631, 
                   System`TradingChartDump`$highs$541631]], 12, 
                 System`TradingChartDump`$textstyle$541631, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$541631, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541631, 
                   System`TradingChartDump`$lows$541631]], 12, 
                 System`TradingChartDump`$textstyle$541631, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$541631, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541631, 
                   System`TradingChartDump`$closes$541631]], 12, 
                 System`TradingChartDump`$textstyle$541631, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541631, 
                   System`TradingChartDump`$visdates$541631]], 12, 
                 System`TradingChartDump`$textstyle$541631, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$541631, 
                  System`TradingChartDump`$mouseQ$541631], {{
                  System`TradingChartDump`$timestampstyle$541631, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$541631 - 0.5, 
                    System`TradingChartDump`$plotrangemin$541631}, 
                    If[
                    System`TradingChartDump`$timestampdepth$541631 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$541631[1]}, {
                    System`TradingChartDump`$indicatorpos$541631 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541631}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541631, 1]}, {
                    System`TradingChartDump`$indicatorpos$541631 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541631}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$541631, {
               System`TradingChartDump`$highlightstyle$541631, 
                Dynamic[System`TradingChartDump`$ohlcpoint$541631]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$541631[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541631, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$541631[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$541631[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$541631, Length[
                    System`TradingChartDump`$layoutData$541631[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$541631}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$541631] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$541631] + 0.5}, {
                System`TradingChartDump`$plotrangemin$541631, 
                 System`TradingChartDump`$plotrangemax$541631}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$541631, Left, {
                 False, System`TradingChartDump`$frame$541631}, 
                 Blank[], {System`TradingChartDump`$frame$541631, False}], {
                False, System`TradingChartDump`$frame$541631}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$541631, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$541631]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$541631 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           387.0228610767757}, {-286.92264150943396`, -65.76792452830186}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541631 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541631, 1]], 
               Part[System`TradingChartDump`$framestyle$541631, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$541631]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$541631} -> 
                   System`TradingChartDump`$isy$541631[
                    System`TradingChartDump`$plotrangemin$541631], {
                    0, System`TradingChartDump`$plotrangemax$541631} -> 
                   System`TradingChartDump`$isy$541631[
                    System`TradingChartDump`$plotrangemax$541631]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$541631[
                   System`TradingChartDump`$plotrangemin$541631], 
                   System`TradingChartDump`$isy$541631[
                   System`TradingChartDump`$plotrangemax$541631]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$541631, 
                   System`TradingChartDump`$isy$541631}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541631, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541631 > 
                    System`TradingChartDump`$plotrangemin$541631, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541631 > 
                    System`TradingChartDump`$plotrangemin$541631, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541631, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541631 > 
                    System`TradingChartDump`$plotrangemin$541631, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541631 > 
                    System`TradingChartDump`$plotrangemin$541631, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541631, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541631, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541631 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541631,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541631], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541631 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541631, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541631]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$541631, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$541631[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$541631[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541631, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$541631[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$541631, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541631[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541631, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541631[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541631[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541631[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541631[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541631], 
                    Style[":", System`TradingChartDump`$textstyle$541631]], 
                    Style[":", System`TradingChartDump`$textstyle$541631]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$541631[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541631]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541631[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$541631}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$541631, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$541631 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$541631[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$541631, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$541631, Left, {
                    False, System`TradingChartDump`$frame$541631}, 
                    Blank[], {
                    System`TradingChartDump`$frame$541631, False}], {
                   System`TradingChartDump`$frame$541631, 
                    System`TradingChartDump`$frame$541631}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$541631, 
                    System`TradingChartDump`$controlmax$541631}] + 0.5, {
                   System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$541631]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$541631) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$541631 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$541631 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$541631, 1]], 
                   Part[System`TradingChartDump`$framestyle$541631, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$541631]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541631[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541631[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$541631[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541631, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541631, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$541631, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$541631, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$541631 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
541631, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$541631], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$541631 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$541631, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$541631]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$541631, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$541631) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$541631 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$541631[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           475.9407855006933}, {-55.989622641509435`, -0.7009433962264069}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$541631, 
              Dynamic[System`TradingChartDump`$ohlclabel$541631], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$541631}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541631 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541631, 2]], 
               Part[System`TradingChartDump`$framestyle$541631, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$541631]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$541631, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$541631, 
                    System`TradingChartDump`$controlmax$541631}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$541631] + 
                    0.5, System`TradingChartDump`$plotrangemin$541631}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$541631], 
                    System`TradingChartDump`$plotrangemin$541631}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$541631, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541631, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541631, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541631 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541631, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541631], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541631 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541631,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541631]]]}, 
              StandardForm, Graphics],
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$541631] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$541631[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$541631] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$541631[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$541631] = {HoldPattern[
               System`TradingChartDump`$min$541631[1]] :> 0.24}}, {
          DownValues[System`TradingChartDump`$max$541631] = {HoldPattern[
               System`TradingChartDump`$max$541631[1]] :> 0.43}}, {
          DownValues[System`TradingChartDump`$subplotvalue$541631] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$541631[1, 1]] :> 
             Invisible[0.37]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$541631] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$541631[1]] :> {
               Rational[2, 5]}}}, {
          DownValues[System`TradingChartDump`$layoutData$541631] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$541631["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "AllValues"]] :> CompressedData["
1:eJxFVwk4lVsXppIh0aCkJH7kIJGzv72PhCUVlTKkQVcqXSKKkooGqWSoaLjI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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541631["AppendedAdjust"]] :> 
             0.018671863698629332`, HoldPattern[
               System`TradingChartDump`$layoutData$541631["AppendedBox"]] :> {
              0.20461133829396413`, 0.5556692160611852}, HoldPattern[
               System`TradingChartDump`$layoutData$541631["AppendedMin"]] :> 
             0.23138328967299607`, HoldPattern[
               System`TradingChartDump`$layoutData$541631["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$541631["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$541631["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$541631["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541631["DataMax"]] :> 
             24.95, HoldPattern[
               System`TradingChartDump`$layoutData$541631["DataMin"]] :> 
             19.376947890818858`, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "MainChartAllValues"]] :> CompressedData["
1:eJxFVwk81csXp5Il0aKkJP4Rkcid38yVcCRRKUta9KToka2QVLRok6Wi5SFb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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "MainChartPoints"]] :> CompressedData["
1:eJxdV1toXFUUvRZFKYIKBf0ocapS6oNSTR/xEbubNk2apk1mMslkksnkztyZ
O487M6n4IxXhIuRHhFAoSEVkRBFBEEEKoV+X+CGIIoJQBJEpQhEiUpCK9MuZ
2Wt97HMhDOvuu886e+3HOTlQ3shU7/c8717/7z787fH43DkZDp7bo4IX+itH
gR+SW5f3fTV1gPhR6aP+K+J9srVz91DhEeInpDB48RvX2y/TwwVoT8nem59e
Gp8hfkreGB+8IX5G188SH1T+EvEh+Su9PbIZET+n/HPEL8i3fbg1QXzY4T8i
T27upreLxC9Kpr/cbpr4JSf+URmGe5j4qMa3n/iYDN3/Y7zHHb1OOP5j8tml
fsBPE78sQ/0PEr/irPeq6rWX9tfkw2v951fax+XtgWD3iF/X+D7m9yeV7w9i
0fW+B47FsZ/Cfo/Bfgr6AnsTut+Q9gkZbi9H+2kZ0I9s0n5a/u2nY+c67Wd0
f7/Tfgbx0j4pP/4weGif1Hzu0H5W7e/TflaeHSbkOOxT0BM4npJheY3TPq18
Y7RPY/+0n0O90X5O9XqP9hnVP0/7DOqf9vNOfOdldPD8w/3Pav3u0j6LfqL/
BYvjC87+Ltp44oua/8tcfw56cP05/U2Y33n9/gawODieV/6rwMk84qd/WuP9
if5p7a/v6J9W/W7RP635epj7y6h+1+ifsf0YZxAP/R27t6D6PU//Ba2Pd1H/
8YLubws4WdB6+Jz9kbX9Jlnbz3HWrp9kUc/kX7R6yCLqgf6Lut5H9F+08XpL
TvxLqs8s/ZeQb/ovaf18Q/+c2m/SP6f9+jf9c5i/9M+hv+i/jPpBPmQZ9cZ6
cXCyjH5g/vLQj/55Xe8d8ufR7+TPo1/Jv2K/lxU7/+MV3X+B/ivOvF1FPum/
ivfc/yrmBf1XrR5ewc4/Kej8v0L+gp2fSUH1+IX+a47/mlP/a47+jt0rqj53
6V/U+L/m/ovav19Q/6Lm+wPqv456oP7ryD/913G+YD4kDvZ8O59Svp1H4uP8
xPe+b+dX7ON8gL3r23mVYP0R4J7v8Jc0nseBUyU7j6Wk/fbACfCXcP4BxyXs
l/wlzAfYE+f7Xgn7A/bKGs8ocKqs9f0J+cvQh/GXES/5y3b9bln12kP+MuIj
fxnnJfkDzDfyB+gHYAkwfxl/oPwd8gfQi/wB5gf5A3xHfmAhf0Xr/THyV5Af
8ldU/0nyV9B/5K9YPboVnH/kr2g932H+KzZfXtXaU1XV5zb1r+L8In9V9/sz
zzvn+24VvKw/Z/1eFecR+UONN2D8oc2PhE78oa2POHTqL0S+yB8in+Snnf1b
s/erVA33XfZfDfMF2K9hfrD/gB8kf832U1JDvshfc+5XdduPKeCA+tehB+u/
Dl7GX8c8JH8d5xn568q3Tf666vUl9W9Y/1TD1o80bP/4DZuPuIHziPXXUL63
WH8N8LH+HbvXxPnK/De13urkb+p8eJP8jj1u2n7pOt8nTcvXc773Iq3PI+SP
7H4lwrwnf2TrNY5wHyd/ZOdHEqGeyB/ZeeK1sJ8x8LdQb+Rv4Zf8LZzH5G/h
vGH+W3Y+JI5/r4X/r8jfduJv23xI2/a331b9/2T9tXF/Yfxtu37SxvlN/jbu
a+TvYD6Qv4P7Avk76HfG33Hmb8eu13W+Tzqof+jb6+A+AOxt4H5E/TewX2DZ
wH1gTP4HLlcf7Q==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541631["NewSubplot"]] :> {
               FinancialIndicator["AverageTrueRange", 14]}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541631["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541631["PlotRangeMin"]] :> 
             0.23138328967299607`, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$541631["Space"]] :> 2.495, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541631["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {{}}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJw9lwk41fkax02o0XJpU1zLSWaSyFrpRr4YW/YtO8dZOItzaKaJ0nKmGXEx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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "SubplotIndicatorGridLines"]] :> {{
                Rational[3, 10], 
                Rational[2, 5], 
                Rational[1, 2]}}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "ATR"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["AverageTrueRange", 14]}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "SubplotIndicatorParameters"]] :> {{{14}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "SubplotIndicatorPoints"]] :> {{{}, {{2., 0.43}}, {{3., 
                0.41000000000000003`}}, {{4., 0.39}}, {{5., 0.38}}, {{6., 
                0.39}}, {{7., 0.4}}, {{8., 0.39}}, {{9., 0.37}}, {{10., 
                0.36}}, {{11., 0.35000000000000003`}}, {{12., 0.34}}, {{13., 
                0.33}}, {{14., 0.32}}, {{15., 0.31}}, {{16., 0.31}}, {{17., 
                0.3}}, {{18., 0.29}}, {{19., 0.29}}, {{20., 0.28}}, {{21., 
                0.27}}, {{22., 0.27}}, {{23., 0.26}}, {{24., 0.26}}, {{25., 
                0.25}}, {{26., 0.24}}, {{27., 0.24}}, {{28., 0.24}}, {{29., 
                0.24}}, {{30., 0.27}}, {{31., 0.27}}, {{32., 0.27}}, {{33., 
                0.27}}, {{34., 0.27}}, {{35., 0.29}}, {{36., 0.29}}, {{37., 
                0.29}}, {{38., 0.29}}, {{39., 0.28}}, {{40., 0.29}}, {{41., 
                0.29}}, {{42., 0.28}}, {{43., 0.29}}, {{44., 0.28}}, {{45., 
                0.32}}, {{46., 0.32}}, {{47., 0.31}}, {{48., 0.31}}, {{49., 
                0.31}}, {{50., 0.3}}, {{51., 0.3}}, {{52., 0.3}}, {{53., 
                0.3}}, {{54., 0.3}}, {{55., 0.3}}, {{56., 0.3}}, {{57., 
                0.29}}, {{58., 0.29}}, {{59., 0.29}}, {{60., 0.29}}, {{61., 
                0.34}}, {{62., 0.37}}, {{63., 0.37}}, {{64., 0.36}}, {{65., 
                0.37}}, {{66., 0.37}}, {{67., 0.37}}, {{68., 0.37}}, {{69., 
                0.37}}, {{70., 0.36}}, {{71., 0.36}}, {{72., 0.37}}, {{73., 
                0.37}}, {{74., 0.38}}, {{75., 0.37}}, {{76., 0.37}}, {{77., 
                0.4}}, {{78., 0.4}}, {{79., 0.39}}, {{80., 0.4}}, {{81., 
                0.4}}, {{82., 0.38}}, {{83., 0.38}}, {{84., 0.37}}, {{85., 
                0.36}}, {{86., 0.38}}, {{87., 0.38}}, {{88., 0.37}}, {{89., 
                0.38}}, {{90., 0.37}}, {{91., 0.38}}, {{92., 0.37}}, {{93., 
                0.36}}, {{94., 0.35000000000000003`}}, {{95., 
                0.35000000000000003`}}, {{96., 0.35000000000000003`}}, {{97., 
                0.36}}, {{98., 0.34}}, {{99., 0.34}}, {{100., 
                0.35000000000000003`}}, {{101., 0.38}}, {{102., 0.38}}, {{
                103., 0.39}}, {{104., 0.37}}, {{105., 0.36}}, {{106., 
                0.37}}, {{107., 0.36}}, {{108., 0.39}}, {{109., 0.4}}, {{110.,
                 0.4}}, {{111., 0.39}}, {{112., 0.38}}, {{113., 0.38}}, {{
                114., 0.37}}, {{115., 0.36}}, {{116., 
                0.35000000000000003`}}, {{117., 0.34}}, {{118., 0.33}}, {{
                119., 0.31}}, {{120., 0.32}}, {{121., 0.36}}, {{122., 
                0.35000000000000003`}}, {{123., 0.35000000000000003`}}, {{
                124., 0.34}}, {{125., 0.34}}, {{126., 0.33}}, {{127., 
                0.32}}, {{128., 0.32}}, {{129., 0.31}}, {{130., 0.32}}, {{
                131., 0.32}}, {{132., 0.32}}, {{133., 0.31}}, {{134., 
                0.31}}, {{135., 0.29}}, {{136., 0.28}}, {{137., 0.28}}, {{
                138., 0.32}}, {{139., 0.32}}, {{140., 0.32}}, {{141., 
                0.33}}, {{142., 0.34}}, {{143., 0.33}}, {{144., 0.32}}, {{
                145., 0.35000000000000003`}}, {{146., 
                0.35000000000000003`}}, {{147., 0.35000000000000003`}}, {{
                148., 0.34}}, {{149., 0.34}}, {{150., 0.34}}, {{151., 
                0.34}}, {{152., 0.34}}, {{153., 0.32}}, {{154., 0.32}}, {{
                155., 0.32}}, {{156., 0.32}}, {{157., 0.3}}, {{158., 0.3}}, {{
                159., 0.3}}, {{160., 0.3}}, {{161., 0.29}}, {{162., 0.31}}, {{
                163., 0.31}}, {{164., 0.29}}, {{165., 0.3}}, {{166., 0.3}}, {{
                167., 0.3}}, {{168., 0.29}}, {{169., 0.28}}, {{170., 
                0.28}}, {{171., 0.3}}, {{172., 0.29}}, {{173., 0.29}}, {{174.,
                 0.29}}, {{175., 0.29}}, {{176., 0.32}}, {{177., 0.31}}, {{
                178., 0.31}}, {{179., 0.33}}, {{180., 0.33}}, {{181., 
                0.34}}, {{182., 0.33}}, {{183., 0.39}}, {{184., 0.4}}, {{185.,
                 0.4}}, {{186., 0.41000000000000003`}}, {{187., 0.4}}, {{188.,
                 0.4}}, {{189., 0.4}}, {{190., 0.38}}, {{191., 0.37}}, {{192.,
                 0.36}}, {{193., 0.37}}, {{194., 0.37}}, {{195., 
                0.35000000000000003`}}, {{196., 0.36}}, {{197., 0.36}}, {{
                198., 0.36}}, {{199., 0.35000000000000003`}}, {{200., 
                0.35000000000000003`}}, {{201., 0.35000000000000003`}}, {{
                202., 0.34}}, {{203., 0.33}}, {{204., 0.32}}, {{205., 
                0.31}}, {{206., 0.32}}, {{207., 0.33}}, {{208., 0.32}}, {{
                209., 0.32}}, {{210., 0.32}}, {{211., 0.31}}, {{212., 
                0.32}}, {{213., 0.33}}, {{214., 0.33}}, {{215., 0.34}}, {{
                216., 0.34}}, {{217., 0.35000000000000003`}}, {{218., 
                0.35000000000000003`}}, {{219., 0.35000000000000003`}}, {{
                220., 0.34}}, {{221., 0.35000000000000003`}}, {{222., 
                0.35000000000000003`}}, {{223., 0.34}}, {{224., 0.37}}, {{
                225., 0.37}}, {{226., 0.38}}, {{227., 0.39}}, {{228., 
                0.4}}, {{229., 0.4}}, {{230., 0.4}}, {{231., 0.39}}, {{232., 
                0.38}}, {{233., 0.38}}, {{234., 0.39}}, {{235., 0.38}}, {{
                236., 0.37}}, {{237., 0.37}}, {{238., 0.38}}, {{239., 
                0.38}}, {{240., 0.38}}, {{241., 0.38}}, {{242., 0.37}}, {{
                243., 0.37}}, {{244., 0.35000000000000003`}}, {{245., 
                0.36}}, {{246., 0.42}}, {{247., 0.41000000000000003`}}, {{
                248., 0.4}}, {{249., 0.39}}, {{250., 0.37}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "SubplotIndicatorValues"]] :> {{{""}, {0.43}, {
                0.41000000000000003`}, {0.39}, {0.38}, {0.39}, {0.4}, {
                0.39}, {0.37}, {0.36}, {0.35000000000000003`}, {0.34}, {
                0.33}, {0.32}, {0.31}, {0.31}, {0.3}, {0.29}, {0.29}, {
                0.28}, {0.27}, {0.27}, {0.26}, {0.26}, {0.25}, {0.24}, {
                0.24}, {0.24}, {0.24}, {0.27}, {0.27}, {0.27}, {0.27}, {
                0.27}, {0.29}, {0.29}, {0.29}, {0.29}, {0.28}, {0.29}, {
                0.29}, {0.28}, {0.29}, {0.28}, {0.32}, {0.32}, {0.31}, {
                0.31}, {0.31}, {0.3}, {0.3}, {0.3}, {0.3}, {0.3}, {0.3}, {
                0.3}, {0.29}, {0.29}, {0.29}, {0.29}, {0.34}, {0.37}, {
                0.37}, {0.36}, {0.37}, {0.37}, {0.37}, {0.37}, {0.37}, {
                0.36}, {0.36}, {0.37}, {0.37}, {0.38}, {0.37}, {0.37}, {
                0.4}, {0.4}, {0.39}, {0.4}, {0.4}, {0.38}, {0.38}, {0.37}, {
                0.36}, {0.38}, {0.38}, {0.37}, {0.38}, {0.37}, {0.38}, {
                0.37}, {0.36}, {0.35000000000000003`}, {
                0.35000000000000003`}, {0.35000000000000003`}, {0.36}, {
                0.34}, {0.34}, {0.35000000000000003`}, {0.38}, {0.38}, {
                0.39}, {0.37}, {0.36}, {0.37}, {0.36}, {0.39}, {0.4}, {0.4}, {
                0.39}, {0.38}, {0.38}, {0.37}, {0.36}, {
                0.35000000000000003`}, {0.34}, {0.33}, {0.31}, {0.32}, {
                0.36}, {0.35000000000000003`}, {0.35000000000000003`}, {
                0.34}, {0.34}, {0.33}, {0.32}, {0.32}, {0.31}, {0.32}, {
                0.32}, {0.32}, {0.31}, {0.31}, {0.29}, {0.28}, {0.28}, {
                0.32}, {0.32}, {0.32}, {0.33}, {0.34}, {0.33}, {0.32}, {
                0.35000000000000003`}, {0.35000000000000003`}, {
                0.35000000000000003`}, {0.34}, {0.34}, {0.34}, {0.34}, {
                0.34}, {0.32}, {0.32}, {0.32}, {0.32}, {0.3}, {0.3}, {0.3}, {
                0.3}, {0.29}, {0.31}, {0.31}, {0.29}, {0.3}, {0.3}, {0.3}, {
                0.29}, {0.28}, {0.28}, {0.3}, {0.29}, {0.29}, {0.29}, {
                0.29}, {0.32}, {0.31}, {0.31}, {0.33}, {0.33}, {0.34}, {
                0.33}, {0.39}, {0.4}, {0.4}, {0.41000000000000003`}, {0.4}, {
                0.4}, {0.4}, {0.38}, {0.37}, {0.36}, {0.37}, {0.37}, {
                0.35000000000000003`}, {0.36}, {0.36}, {0.36}, {
                0.35000000000000003`}, {0.35000000000000003`}, {
                0.35000000000000003`}, {0.34}, {0.33}, {0.32}, {0.31}, {
                0.32}, {0.33}, {0.32}, {0.32}, {0.32}, {0.31}, {0.32}, {
                0.33}, {0.33}, {0.34}, {0.34}, {0.35000000000000003`}, {
                0.35000000000000003`}, {0.35000000000000003`}, {0.34}, {
                0.35000000000000003`}, {0.35000000000000003`}, {0.34}, {
                0.37}, {0.37}, {0.38}, {0.39}, {0.4}, {0.4}, {0.4}, {0.39}, {
                0.38}, {0.38}, {0.39}, {0.38}, {0.37}, {0.37}, {0.38}, {
                0.38}, {0.38}, {0.38}, {0.37}, {0.37}, {
                0.35000000000000003`}, {0.36}, {0.42}, {
                0.41000000000000003`}, {0.4}, {0.39}, {0.37}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$541631["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$541631["YRange"]] :> 24.95,
              HoldPattern[
               System`TradingChartDump`$layoutData$541631[
               "SubplotPoints", {1}]] :> {{}, {0.43}, {
               0.41000000000000003`}, {0.39}, {0.38}, {0.39}, {0.4}, {0.39}, {
               0.37}, {0.36}, {0.35000000000000003`}, {0.34}, {0.33}, {
               0.32}, {0.31}, {0.31}, {0.3}, {0.29}, {0.29}, {0.28}, {0.27}, {
               0.27}, {0.26}, {0.26}, {0.25}, {0.24}, {0.24}, {0.24}, {
               0.24}, {0.27}, {0.27}, {0.27}, {0.27}, {0.27}, {0.29}, {
               0.29}, {0.29}, {0.29}, {0.28}, {0.29}, {0.29}, {0.28}, {
               0.29}, {0.28}, {0.32}, {0.32}, {0.31}, {0.31}, {0.31}, {0.3}, {
               0.3}, {0.3}, {0.3}, {0.3}, {0.3}, {0.3}, {0.29}, {0.29}, {
               0.29}, {0.29}, {0.34}, {0.37}, {0.37}, {0.36}, {0.37}, {
               0.37}, {0.37}, {0.37}, {0.37}, {0.36}, {0.36}, {0.37}, {
               0.37}, {0.38}, {0.37}, {0.37}, {0.4}, {0.4}, {0.39}, {0.4}, {
               0.4}, {0.38}, {0.38}, {0.37}, {0.36}, {0.38}, {0.38}, {0.37}, {
               0.38}, {0.37}, {0.38}, {0.37}, {0.36}, {
               0.35000000000000003`}, {0.35000000000000003`}, {
               0.35000000000000003`}, {0.36}, {0.34}, {0.34}, {
               0.35000000000000003`}, {0.38}, {0.38}, {0.39}, {0.37}, {
               0.36}, {0.37}, {0.36}, {0.39}, {0.4}, {0.4}, {0.39}, {0.38}, {
               0.38}, {0.37}, {0.36}, {0.35000000000000003`}, {0.34}, {
               0.33}, {0.31}, {0.32}, {0.36}, {0.35000000000000003`}, {
               0.35000000000000003`}, {0.34}, {0.34}, {0.33}, {0.32}, {
               0.32}, {0.31}, {0.32}, {0.32}, {0.32}, {0.31}, {0.31}, {
               0.29}, {0.28}, {0.28}, {0.32}, {0.32}, {0.32}, {0.33}, {
               0.34}, {0.33}, {0.32}, {0.35000000000000003`}, {
               0.35000000000000003`}, {0.35000000000000003`}, {0.34}, {
               0.34}, {0.34}, {0.34}, {0.34}, {0.32}, {0.32}, {0.32}, {
               0.32}, {0.3}, {0.3}, {0.3}, {0.3}, {0.29}, {0.31}, {0.31}, {
               0.29}, {0.3}, {0.3}, {0.3}, {0.29}, {0.28}, {0.28}, {0.3}, {
               0.29}, {0.29}, {0.29}, {0.29}, {0.32}, {0.31}, {0.31}, {
               0.33}, {0.33}, {0.34}, {0.33}, {0.39}, {0.4}, {0.4}, {
               0.41000000000000003`}, {0.4}, {0.4}, {0.4}, {0.38}, {0.37}, {
               0.36}, {0.37}, {0.37}, {0.35000000000000003`}, {0.36}, {
               0.36}, {0.36}, {0.35000000000000003`}, {
               0.35000000000000003`}, {0.35000000000000003`}, {0.34}, {
               0.33}, {0.32}, {0.31}, {0.32}, {0.33}, {0.32}, {0.32}, {
               0.32}, {0.31}, {0.32}, {0.33}, {0.33}, {0.34}, {0.34}, {
               0.35000000000000003`}, {0.35000000000000003`}, {
               0.35000000000000003`}, {0.34}, {0.35000000000000003`}, {
               0.35000000000000003`}, {0.34}, {0.37}, {0.37}, {0.38}, {
               0.39}, {0.4}, {0.4}, {0.4}, {0.39}, {0.38}, {0.38}, {0.39}, {
               0.38}, {0.37}, {0.37}, {0.38}, {0.38}, {0.38}, {0.38}, {
               0.37}, {0.37}, {0.35000000000000003`}, {0.36}, {0.42}, {
               0.41000000000000003`}, {0.4}, {0.39}, {0.37}}, HoldPattern[
               System`TradingChartDump`$layoutData$541631[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$541631[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$541631[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$541631[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$541631[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$541631 = 
           System`TradingChartDump`$length$541631; 
          System`TradingChartDump`$layoutData$541631["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$541631; 
          System`TradingChartDump`$modelData$541631["Data"] = 
           System`TradingChartDump`$data$541631; 
          System`TradingChartDump`$modelData$541631["Indicators"] = 
           System`TradingChartDump`$indicators$541631; 
          System`TradingChartDump`$layoutData$541631[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541631["ScalingFunctions"] = {
            System`TradingChartDump`$sy$541631, 
             System`TradingChartDump`$isy$541631}; 
          System`TradingChartDump`$layoutData$541631["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541631["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541631[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541631["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$541631["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$541631, 
            System`TradingChartDump`$layoutData$541631, 
            System`TradingChartDump`$indicators$541631]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$541631, 
            System`TradingChartDump`$layoutData$541631, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$541631[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$541631["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$541631[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$541631[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$541631["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$541631[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$541631 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541631["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541631, 
                 System`TradingChartDump`$controlmax$541631}]]]; 
          System`TradingChartDump`$plotrangemax$541631 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541631["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541631, 
                 System`TradingChartDump`$controlmax$541631}]]]; {
            System`TradingChartDump`$plotrangemin$541631, 
             System`TradingChartDump`$plotrangemax$541631} = ReplaceAll[
             
             System`TradingChartDump`$sy$541631[{
              System`TradingChartDump`$plotrangemin$541631, 
               System`TradingChartDump`$plotrangemax$541631}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$541631[
                Min[System`TradingChartDump`$lows$541631]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$541631 == 
            System`TradingChartDump`$plotrangemax$541631, {
             System`TradingChartDump`$plotrangemin$541631, 
              System`TradingChartDump`$plotrangemax$541631} = {
             System`TradingChartDump`$plotrangemin$541631 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$541631], 
              System`TradingChartDump`$plotrangemax$541631 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$541631]}]; 
          System`TradingChartDump`$newgridlines$541631 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$541631, 
            Part[System`TradingChartDump`$newgridlines$541631, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$541631, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$541631], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$541631, 1]]; 
            Part[System`TradingChartDump`$newgridlines$541631, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$541631, 1] =!= None,
                 System`TradingChartDump`$length$541631 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$541631, 
                 Part[System`TradingChartDump`$newgridlines$541631, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$541631, 1]]; 
            System`TradingChartDump`$subpricegridlines$541631 = 
             Part[System`TradingChartDump`$gridlines$541631, 2]; 
            Part[System`TradingChartDump`$newgridlines$541631, 2] = 
             If[System`TradingChartDump`$sy$541631 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541631}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541631, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541631, 2]]], 
               With[{
                System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$541631, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$541631, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541631}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541631, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541631, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$541631 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$541631]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"GE\"", "\" with \"", 
           "\"AverageTrueRange\"", "\"(\"", "14", "\",\"", "", "\",\"", "", 
           "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {240., -167.4}, ImageScaled[{0.5, 0.5}], {450, 310}], 
     InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$541645 = 
        "Full", System`TradingChartDump`$highlightposition$541645 = Automatic,
         System`TradingChartDump`$maxohlc$541645 = 24.95`4., 
        System`TradingChartDump`$timestampstyle$541645 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$541645 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$541645 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$541645, 
        System`TradingChartDump`$subplotpoint$541645, 
        System`TradingChartDump`$ndigits$541645 = 4, 
        System`TradingChartDump`$highlightstyle$541645 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$541645 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$541645 = True, 
        System`TradingChartDump`$timestampQ$541645 = True, 
        System`TradingChartDump`$data$541645 = {{{2012, 7, 26}, {
          19.55155642023346, 20.035505836575872`, 19.512840466926068`, 19.9, 
           57275600}}, {{2012, 7, 27}, {
          19.96928776290631, 20.327437858508603`, 19.901529636711278`, 20.25, 
           80268300}}, {{2012, 7, 30}, {
          20.120322115384614`, 20.236456730769227`, 20.023543269230768`, 
           20.13, 44993600}}, {{2012, 7, 31}, {
          20.08, 20.21547951807229, 20.08, 20.08, 38328400}}, {{2012, 8, 1}, {
          20.185798359864926`, 20.27288953207911, 20.040646406174623`, 20.06, 
           35734300}}, {{2012, 8, 2}, {
          19.860000000000003`, 20.03421052631579, 19.55029239766082, 19.86, 
           44000400}}, {{2012, 8, 3}, {
          20.144541984732825`, 20.318702290076335`, 20.096164122137402`, 
           20.28, 37891500}}, {{2012, 8, 6}, {
          20.29, 20.493190271816882`, 20.22226990939437, 20.29, 34159500}}, {{
          2012, 8, 7}, {
          20.459356060606062`, 20.507746212121216`, 20.410965909090912`, 
           20.44, 31115300}}, {{2012, 8, 8}, {
          20.36870537839124, 20.407410756782483`, 20.22356020942408, 20.33, 
           32345900}}, {{2012, 8, 9}, {
          20.263874643874647`, 20.43806267806268, 20.263874643874647`, 20.38, 
           31159700}}, {{2012, 8, 10}, {
          20.323222748815166`, 20.42, 20.265156398104267`, 20.42, 
           24419100}}, {{2012, 8, 13}, {
          20.358380181038587`, 20.377732253454024`, 20.2035636017151, 20.31, 
           26873600}}, {{2012, 8, 14}, {
          20.395453677172874`, 20.42447946513849, 20.22129894937918, 20.26, 
           30095000}}, {{2012, 8, 15}, {
          20.18324427480916, 20.34772900763359, 20.11551526717557, 20.28, 
           28870100}}, {{2012, 8, 16}, {
          20.195814726840858`, 20.457092636579574`, 20.147429928741094`, 
           20.37, 33598000}}, {{2012, 8, 17}, {
          20.33935238095238, 20.368380952380953`, 20.26194285714286, 20.32, 
           30032500}}, {{2012, 8, 20}, {
          20.269350215002387`, 20.33707596751075, 20.153248924988052`, 20.25, 
           27385500}}, {{2012, 8, 21}, {
          20.296143884892086`, 20.373573141486812`, 20.131606714628298`, 
           20.18, 30438800}}, {{2012, 8, 22}, {
          20.100322425409047`, 20.197098171318576`, 20.04225697786333, 20.11, 
           28016800}}, {{2012, 8, 23}, {
          20.06675387596899, 20.115130813953485`, 19.960324612403095`, 19.97, 
           36538800}}, {{2012, 8, 24}, {
          19.92676442307692, 20.22677884615384, 19.888052884615384`, 20.13, 
           29338200}}, {{2012, 8, 27}, {
          20.15096402877698, 20.276786570743404`, 20.121928057553955`, 20.18, 
           28775600}}, {{2012, 8, 28}, {
          20.09160980297934, 20.246458433445465`, 20.09160980297934, 20.14, 
           25912400}}, {{2012, 8, 29}, {
          20.15, 20.275816522574445`, 20.140321805955807`, 20.15, 
           19925800}}, {{2012, 8, 30}, {
          20.04740310077519, 20.10545542635659, 19.9506492248062, 19.97, 
           21237800}}, {{2012, 8, 31}, {
          20.08838242394978, 20.156117817479473`, 19.94323515210043, 20.04, 
           29679000}}, {{2012, 9, 4}, {
          19.966138469039493`, 20.024207703559238`, 19.820965382740127`, 
           19.85, 38173600}}, {{2012, 9, 5}, {
          19.883244552058112`, 20.096106537530268`, 19.84454237288136, 19.98, 
           33033500}}, {{2012, 9, 6}, {
          20.19424683247302, 20.629676208352887`, 20.17489441576725, 20.62, 
           53178600}}, {{2012, 9, 7}, {
          20.628754052802222`, 20.89, 20.609402501157945`, 20.89, 
           36379800}}, {{2012, 9, 10}, {
          20.79, 20.954539106145248`, 20.741606145251396`, 20.79, 
           33672300}}, {{2012, 9, 11}, {
          20.7932422417786, 20.9867577582214, 20.70616025937934, 20.89, 
           33593100}}, {{2012, 9, 12}, {
          20.967135678391962`, 21.218702603928733`, 20.957460027409777`, 
           21.18, 43006000}}, {{2012, 9, 13}, {
          21.0680608537693, 21.522906448683013`, 21.048705722070842`, 21.31, 
           111794200}}, {{2012, 9, 14}, {
          21.487109905020354`, 21.651650836725466`, 21.27417458163727, 21.4, 
           100148400}}, {{2012, 9, 17}, {
          21.22386394557823, 21.34, 21.194829931972787`, 21.34, 79283200}}, {{
          2012, 9, 18}, {
          21.278093525179855`, 21.52, 21.24906474820144, 21.52, 38831200}}, {{
          2012, 9, 19}, {
          21.584172982612575`, 21.768074008024968`, 21.535777975925104`, 
           21.71, 40462600}}, {{2012, 9, 20}, {
          21.63599197503344, 21.909001337494427`, 21.567739634418192`, 21.87, 
           43677000}}, {{2012, 9, 21}, {
          21.989502885042164`, 22.126023080337326`, 21.901739902352418`, 
           21.97, 66551700}}, {{2012, 9, 24}, {
          21.838998211091234`, 21.887745974955276`, 21.74150268336315, 21.8, 
           36799800}}, {{2012, 9, 25}, {
          21.8380277902286, 22.11112505602869, 21.750246526221428`, 21.76, 
           47039200}}, {{2012, 9, 26}, {
          21.608506787330317`, 21.69626696832579, 21.520746606334843`, 21.55, 
           41123300}}, {{2012, 9, 27}, {
          21.682287725472943`, 22.286739991201056`, 21.575046194456664`, 
           22.16, 67300400}}, {{2012, 9, 28}, {
          22.20852047556142, 22.393835314839276`, 22.062219286657857`, 22.15, 
           70926100}}, {{2012, 10, 1}, {
          22.161999123191585`, 22.42525208241999, 22.14249890398948, 22.24, 
           42550700}}, {{2012, 10, 2}, {
          22.3564984642387, 22.414997806055286`, 22.142000877577885`, 22.22, 
           45297400}}, {{2012, 10, 3}, {
          22.29124399825404, 22.40825840244435, 22.154727193365343`, 22.34, 
           32929400}}, {{2012, 10, 4}, {
          22.38, 22.477516339869283`, 22.204470588235292`, 22.38, 
           40344600}}, {{2012, 10, 5}, {
          22.46200692041522, 22.598494809688578`, 22.423010380622834`, 22.54, 
           38312500}}, {{2012, 10, 8}, {
          22.301243455497385`, 22.418259162303666`, 22.281740837696336`, 
           22.35, 24202200}}, {{2012, 10, 9}, {
          22.37207780725022, 22.401335101679926`, 22.04049513704686, 22.06, 
           39176000}}, {{2012, 10, 10}, {
          22.04550601872492, 22.17226036558181, 21.850499331252788`, 21.87, 
           32784100}}, {{2012, 10, 11}, {
          22.02800977343403, 22.14502443358507, 21.92074633496224, 21.95, 
           24161800}}, {{2012, 10, 12}, {
          22.017508896797153`, 22.144270462633454`, 21.851743772241996`, 
           21.92, 32954600}}, {{2012, 10, 15}, {
          21.98247349823321, 22.138515901060067`, 21.933710247349822`, 22.08, 
           29578600}}, {{2012, 10, 16}, {
          22.226289752650175`, 22.314063604240282`, 22.01173144876325, 22.08, 
           35668800}}, {{2012, 10, 17}, {
          22.203483195111303`, 22.349751200349196`, 22.154727193365343`, 
           22.34, 28272500}}, {{2012, 10, 18}, {
          22.24, 22.50325295922841, 22.230249890398948`, 22.24, 43140700}}, {{
          2012, 10, 19}, {
          21.9480163413527, 21.967517022242397`, 21.323994552882436`, 21.48, 
           107879900}}, {{2012, 10, 22}, {
          21.316018433179725`, 21.40377880184332, 20.72119815668203, 21.16, 
           86735100}}, {{2012, 10, 23}, {
          20.81825657894737, 20.867011278195488`, 20.671992481203006`, 20.75, 
           56297300}}, {{2012, 10, 24}, {
          20.8957619943556, 20.925014111006586`, 20.71049858889934, 20.73, 
           42295500}}, {{2012, 10, 25}, {
          20.964016933207905`, 21.032271872060207`, 20.505733772342428`, 
           20.73, 45769600}}, {{2012, 10, 26}, {
          20.657991473235434`, 20.862719090478446`, 20.541004263382284`, 
           20.58, 42827400}}, {{2012, 10, 31}, {
          20.735061728395063`, 20.79358024691358, 20.452222222222222`, 20.54, 
           39179300}}, {{2012, 11, 1}, {
          20.50769915651359, 20.858758200562324`, 20.497947516401123`, 20.81, 
           46231300}}, {{2012, 11, 2}, {
          20.994528390427032`, 21.14079774753637, 20.731243547630225`, 20.78, 
           47475200}}, {{2012, 11, 5}, {
          20.67519850537132, 20.938514712751047`, 20.67519850537132, 20.88, 
           30000100}}, {{2012, 11, 6}, {
          20.972000926354795`, 21.235247799907366`, 20.913501621120886`, 
           21.05, 32733200}}, {{2012, 11, 7}, {
          20.824230951254144`, 20.980217699952675`, 20.54150496923805, 20.6, 
           45253400}}, {{2012, 11, 8}, {
          20.633279080899953`, 20.66253231211106, 20.36024892292963, 20.37, 
           40770700}}, {{2012, 11, 9}, {
          20.245942857142857`, 20.77257142857143, 20.18742857142857, 20.48, 
           40306800}}, {{2012, 11, 12}, {
          20.51626615605553, 20.613776926759215`, 20.36024892292963, 20.37, 
           21816400}}, {{2012, 11, 13}, {
          20.091972920696332`, 20.433341392649908`, 20.06271276595745, 20.17, 
           41073300}}, {{2012, 11, 14}, {
          20.21200899550225, 20.231509245377314`, 19.451499250374813`, 19.51, 
           65539500}}, {{2012, 11, 15}, {
          19.403988035892322`, 19.72576271186441, 19.403988035892322`, 19.56, 
           51760300}}, {{2012, 11, 16}, {
          19.601240694789084`, 19.689007444168734`, 19.376947890818858`, 
           19.65, 45287500}}, {{2012, 11, 19}, {
          19.90617134559535, 20.208518877057113`, 19.88666505324298, 20.15, 
           38283400}}, {{2012, 11, 20}, {
          20.15876333656644, 20.178268671193017`, 19.8661833171678, 20.11, 
           26845900}}, {{2012, 11, 21}, {
          20.189506769825922`, 20.22852030947776, 20.06271276595745, 20.17, 
           41020400}}, {{2012, 11, 23}, {
          20.295684410646388`, 20.52, 20.217661596958177`, 20.52, 
           35456500}}, {{2012, 11, 26}, {
          20.364444444444445`, 20.549753086419752`, 20.35469135802469, 20.54, 
           47741300}}, {{2012, 11, 27}, {
          20.515764254911353`, 20.67177767129851, 20.330498322951605`, 20.35, 
           33001700}}, {{2012, 11, 28}, {
          20.229777672658468`, 20.619749290444656`, 19.9860454115421, 20.61, 
           34782700}}, {{2012, 11, 29}, {
          20.70724088973024, 20.824230951254144`, 20.42451490771415, 20.6, 
           27632800}}, {{2012, 11, 30}, {
          20.60974917179366, 20.726739233317563`, 20.512257453857078`, 20.6, 
           37857000}}, {{2012, 12, 3}, {
          20.651008645533143`, 20.699759846301635`, 20.280499519692604`, 20.3,
            29981900}}, {{2012, 12, 4}, {
          20.34975071907958, 20.486260786193675`, 20.19373921380633, 20.34, 
           36817200}}, {{2012, 12, 5}, {
          20.38798869524258, 20.8267545925577, 20.339236928874232`, 20.7, 
           46466500}}, {{2012, 12, 6}, {
          20.67421619092185, 20.859503977538605`, 20.557192325690217`, 20.84, 
           32751200}}, {{2012, 12, 7}, {
          20.910493942218082`, 20.94950605778192, 20.71543336439888, 20.93, 
           33548600}}, {{2012, 12, 10}, {
          20.899008882655444`, 20.967274427302478`, 20.830743338008414`, 
           20.86, 27604300}}, {{2012, 12, 11}, {
          20.940753138075312`, 21.203974895397486`, 20.823765690376565`, 
           20.97, 45757200}}, {{2012, 12, 12}, {
          21.074214876033054`, 21.40578512396694, 21.035206611570246`, 21.24, 
           42413600}}, {{2012, 12, 13}, {
          21.197002775208137`, 21.37250693802035, 21.011748381128584`, 21.08, 
           33966000}}, {{2012, 12, 14}, {
          21.07024976873265, 21.21650323774283, 21.011748381128584`, 21.08, 
           47536600}}, {{2012, 12, 17}, {
          21.146019151846783`, 21.399498404012764`, 21.146019151846783`, 
           21.38, 48483700}}, {{2012, 12, 18}, {
          21.30601659751037, 21.36452282157676, 20.876970954356842`, 21.15, 
           81119200}}, {{2012, 12, 19}, {
          21.104407425035696`, 21.123912422655877`, 20.450990004759635`, 
           20.49, 92330700}}, {{2012, 12, 20}, {
          20.57226128266033, 20.89693111638955, 20.532907363420428`, 20.71, 
           50831400}}, {{2012, 12, 21}, {
          20.510632183908047`, 20.658261494252873`, 20.235057471264366`, 
           20.55, 80833800}}, {{2012, 12, 24}, {
          20.460475504322766`, 20.62778097982709, 20.421109510086453`, 20.49, 
           15097200}}, {{2012, 12, 26}, {
          20.479364467982666`, 20.60729898892634, 20.380953298026, 20.44, 
           28557100}}, {{2012, 12, 27}, {
          20.468245529241177`, 20.537129047849202`, 20.094306428226197`, 
           20.36, 38330700}}, {{2012, 12, 28}, {
          20.119838551859097`, 20.375640900195695`, 20.1001614481409, 20.11, 
           32403400}}, {{2012, 12, 31}, {
          19.961338732729867`, 20.65983801810386, 19.931824678418295`, 20.65, 
           58785000}}, {{2013, 1, 2}, {
          21.167291471415183`, 21.196813495782568`, 20.8622305529522, 21., 
           46089500}}, {{2013, 1, 3}, {
          21.133876777251185`, 21.143715639810427`, 20.710805687203795`, 
           20.76, 48509100}}, {{2013, 1, 4}, {
          20.86983962264151, 20.91903773584906, 20.781283018867928`, 20.86, 
           29802600}}, {{2013, 1, 7}, {
          20.819517274017986`, 20.87855182205395, 20.622735447231427`, 20.79, 
           32746700}}, {{2013, 1, 8}, {
          20.766842105263162`, 20.786526315789477`, 20.353473684210527`, 
           20.57, 40045500}}, {{2013, 1, 9}, {
          20.708582338902147`, 20.738109785202866`, 20.600315035799525`, 
           20.62, 28540500}}, {{2013, 1, 10}, {
          20.702087860179493`, 20.88903637222484, 20.623372697213032`, 20.83, 
           33348200}}, {{2013, 1, 11}, {
          20.87855182205395, 20.898230004732607`, 20.68176999526739, 20.79, 
           41839700}}, {{2013, 1, 14}, {
          20.83903409090909, 20.898068181818182`, 20.730804924242427`, 20.78, 
           31715900}}, {{2013, 1, 15}, {
          20.70256603773585, 20.86983962264151, 20.673047169811323`, 20.86, 
           26551000}}, {{2013, 1, 16}, {
          20.809517045454545`, 20.858712121212122`, 20.72096590909091, 20.78, 
           38932100}}, {{2013, 1, 17}, {
          20.88127699530516, 21.196169014084504`, 20.78287323943662, 20.96, 
           63851700}}, {{2013, 1, 18}, {
          21.591588021778588`, 21.83761796733213, 21.247146098003633`, 21.69, 
           113079400}}, {{2013, 1, 22}, {
          21.82729668332576, 21.846978646069967`, 21.55174920490686, 21.66, 
           55165800}}, {{2013, 1, 23}, {
          21.629361896080216`, 21.67856426618049, 21.40303099361896, 21.59, 
           47228500}}, {{2013, 1, 24}, {
          21.611428571428572`, 21.837777777777777`, 21.6015873015873, 21.7, 
           46991100}}, {{2013, 1, 25}, {
          21.920161507402426`, 21.949676985195154`, 21.752907133243607`, 
           21.93, 41919800}}, {{2013, 1, 28}, {
          22.080960000000005`, 22.179360000000003`, 21.903840000000002`, 
           22.14, 49558400}}, {{2013, 1, 29}, {
          22.13016, 22.21872, 22.041600000000003`, 22.14, 34148000}}, {{2013, 
          1, 30}, {
          22.155303643724697`, 22.184817813765186`, 21.87, 21.87, 
           36200400}}, {{2013, 1, 31}, {
          21.85113105924596, 22.03806104129264, 21.8216157989228, 21.92, 
           34427700}}, {{2013, 2, 1}, {
          22.073023872679045`, 22.27968169761273, 21.964774535809017`, 22.26, 
           43840300}}, {{2013, 2, 4}, {
          22.0483863738234, 22.127095472882115`, 21.920484087852984`, 21.95, 
           35836600}}, {{2013, 2, 5}, {
          22.120958296362023`, 22.258722271517303`, 22.091437444543033`, 
           22.18, 30917700}}, {{2013, 2, 6}, {
          22.109518716577536`, 22.139037433155078`, 21.952085561497324`, 
           22.08, 42985800}}, {{2013, 2, 7}, {
          22.139679715302492`, 22.14951957295374, 21.913362989323847`, 22.12, 
           38325900}}, {{2013, 2, 8}, {
          22.14, 22.19904, 22.0908, 22.14, 24424600}}, {{2013, 2, 11}, {
          22.129358574610244`, 22.14903786191537, 21.99160356347439, 22.09, 
           19738700}}, {{2013, 2, 12}, {
          22.121594331266607`, 22.288883968113375`, 22.121594331266607`, 
           22.22, 34297500}}, {{2013, 2, 13}, {
          22.744429243266353`, 23.108576314664386`, 22.675536554082942`, 
           23.02, 84926900}}, {{2013, 2, 14}, {
          22.882528833831696`, 23.11873558308415, 22.74474156343443, 23.04, 
           53996500}}, {{2013, 2, 15}, {
          23.106981537140406`, 23.175869471876346`, 22.86095319879777, 22.92, 
           39283000}}, {{2013, 2, 19}, {
          23.04528, 23.37, 23.03544, 23.37, 41219000}}, {{2013, 2, 20}, {
          23.33525843656557, 23.374626228107648`, 22.980948312686888`, 23.04, 
           38107400}}, {{2013, 2, 21}, {
          23.000619088564054`, 23.169303525365432`, 22.9410834049871, 23.08, 
           47811200}}, {{2013, 2, 22}, {
          23.1603249251817, 23.259512612227446`, 23.041299700726807`, 23.2, 
           27836300}}, {{2013, 2, 25}, {
          23.314555019728193`, 23.344318281455507`, 22.630000000000003`, 
           22.63, 51619800}}, {{2013, 2, 26}, {
          22.790624728850325`, 22.96921908893709, 22.73109327548807, 22.87, 
           41316300}}, {{2013, 2, 27}, {
          22.83284552845528, 23.20975609756097, 22.813008130081297`, 23.18, 
           29676400}}, {{2013, 2, 28}, {
          23.188837209302328`, 23.27813953488372, 23.02015503875969, 23.04, 
           39714600}}, {{2013, 3, 1}, {
          22.841319534282018`, 23.158835705045277`, 22.821474773609314`, 
           23.01, 41226900}}, {{2013, 3, 4}, {
          22.970928233777396`, 23.09992264718522, 22.851856467554793`, 23.09, 
           25457800}}, {{2013, 3, 5}, {
          23.27104705383637, 23.519033488766425`, 23.251208139041967`, 23.4, 
           35728000}}, {{2013, 3, 6}, {
          23.648635403464297`, 23.648635403464297`, 23.48, 23.48, 
           31539100}}, {{2013, 3, 7}, {
          23.509839527027022`, 23.638796452702696`, 23.480080236486486`, 
           23.49, 22955700}}, {{2013, 3, 8}, {
          23.669280605805636`, 23.708960875052586`, 23.49071939419436, 23.58, 
           28952100}}, {{2013, 3, 11}, {
          23.499436917866216`, 23.558954276037255`, 23.261367485182046`, 
           23.43, 34947200}}, {{2013, 3, 12}, {
          23.39853908586074, 23.408457923964118`, 23.140649295173, 23.22, 
           36593000}}, {{2013, 3, 13}, {
          23.250404427415926`, 23.329757343550448`, 23.21072796934866, 23.3, 
           24152400}}, {{2013, 3, 14}, {
          23.361122836639932`, 23.569438581680036`, 23.321443647108484`, 23.5,
            34629800}}, {{2013, 3, 15}, {
          23.25, 23.527730375426618`, 23.17064846416382, 23.25, 58857200}}, {{
          2013, 3, 18}, {
          22.990619354838714`, 23.169225806451614`, 22.950929032258063`, 
           23.07, 33700000}}, {{2013, 3, 19}, {
          23.12015437392796, 23.17969125214408, 22.991157804459693`, 23.14, 
           36150200}}, {{2013, 3, 20}, {
          23.537813299232738`, 23.607246376811595`, 23.141052855924976`, 
           23.27, 39254000}}, {{2013, 3, 21}, {
          23.238995276942894`, 23.417604121940748`, 23.109999999999996`, 
           23.11, 38543900}}, {{2013, 3, 22}, {
          23.130406504065036`, 23.20975609756097, 23.090731707317072`, 23.18, 
           30606100}}, {{2013, 3, 25}, {
          23.268373493975904`, 23.298141135972465`, 22.87147160068847, 23.06, 
           41684400}}, {{2013, 3, 26}, {
          23.088832179930794`, 23.118598615916955`, 22.830856401384082`, 
           22.94, 32353500}}, {{2013, 3, 27}, {
          22.840623376623377`, 22.95968831168831, 22.671948051948053`, 22.92, 
           27492500}}, {{2013, 3, 28}, {
          22.95984429065744, 23.019377162629755`, 22.81101211072664, 22.94, 
           31151000}}, {{2013, 4, 1}, {
          22.85038994800693, 22.91984402079723, 22.79085788561525, 22.9, 
           27449700}}, {{2013, 4, 2}, {
          22.991311053984575`, 23.189768637532133`, 22.92185089974293, 23.16, 
           29180100}}, {{2013, 4, 3}, {
          23.19702608695652, 23.21686956521739, 22.740626086956524`, 22.82, 
           52570300}}, {{2013, 4, 4}, {
          22.830545927209705`, 22.949610051993066`, 22.780935875216638`, 22.9,
            30472100}}, {{2013, 4, 5}, {
          22.621020497165286`, 22.75992150021806, 22.58133449629307, 22.75, 
           31402200}}, {{2013, 4, 8}, {
          22.870544982698963`, 22.94, 22.652257785467125`, 22.94, 
           30493600}}, {{2013, 4, 9}, {
          23.068516912402426`, 23.068516912402426`, 22.721248915871637`, 
           22.88, 31668200}}, {{2013, 4, 10}, {
          22.913867684478376`, 23.45943596268024, 22.87418999151824, 23.39, 
           39772300}}, {{2013, 4, 11}, {
          23.36032217041119, 23.528952946163628`, 23.241288681644765`, 23.4, 
           27084400}}, {{2013, 4, 12}, {
          23.29975703324808, 23.39894714407502, 23.141052855924976`, 23.27, 
           27234300}}, {{2013, 4, 15}, {
          23.096291100394566`, 23.11613327487944, 22.630000000000003`, 22.63, 
           46453800}}, {{2013, 4, 16}, {
          22.890233766233766`, 22.92, 22.72155844155844, 22.92, 36016700}}, {{
          2013, 4, 17}, {
          22.778418277680135`, 22.847864674868188`, 22.470869947275915`, 
           22.58, 42672900}}, {{2013, 4, 18}, {
          22.579285399206, 22.668570798412, 22.39079400088222, 22.49, 
           41170900}}, {{2013, 4, 19}, {
          21.768514942528736`, 21.85781149425287, 21.44109425287356, 21.58, 
           108837900}}, {{2013, 4, 22}, {
          21.497451990632317`, 21.507372365339577`, 20.94191100702576, 21.18, 
           87828900}}, {{2013, 4, 23}, {
          21.37960465116279, 21.518497674418605`, 21.191106976744184`, 21.33, 
           65489600}}, {{2013, 4, 24}, {
          21.522090163934426`, 21.859458105646628`, 21.482399817850634`, 
           21.79, 51506700}}, {{2013, 4, 25}, {
          22.037986332574036`, 22.05783143507973, 21.74030979498861, 21.78, 
           41462900}}, {{2013, 4, 26}, {
          21.801864025213867`, 22.218460153084195`, 21.791945069788383`, 
           22.03, 47012500}}, {{2013, 4, 29}, {
          22.129676695105523`, 22.139595868881905`, 21.82218230803772, 22.09, 
           36531800}}, {{2013, 4, 30}, {
          22.11, 22.1992732166891, 22.03064602960969, 22.11, 34054800}}, {{
          2013, 5, 1}, {
          21.920406320541762`, 22.168374717832958`, 21.920406320541762`, 
           21.97, 39201600}}, {{2013, 5, 2}, {
          22.070564516129032`, 22.14, 21.971370967741933`, 22.14, 
           27651500}}, {{2013, 5, 3}, {
          22.39, 22.667766947275148`, 22.370159503766065`, 22.39, 
           45523300}}, {{2013, 5, 6}, {
          22.38015943312666, 22.45952170062002, 22.14207263064659, 22.4, 
           28563900}}, {{2013, 5, 7}, {
          22.509920634920633`, 22.60912698412698, 22.44047619047619, 22.5, 
           28211700}}, {{2013, 5, 8}, {
          22.502581486310298`, 22.83992177314211, 22.443050847457627`, 22.83, 
           39977300}}, {{2013, 5, 9}, {
          22.808340649692713`, 22.91747146619842, 22.510711150131694`, 22.6, 
           29974300}}, {{2013, 5, 10}, {
          22.591021834061134`, 22.729921397379915`, 22.412436681222708`, 
           22.72, 35117300}}, {{2013, 5, 13}, {
          22.67992122538293, 22.699763676148795`, 22.441811816192562`, 22.67, 
           30283800}}, {{2013, 5, 14}, {
          22.671251629726207`, 22.889530638852673`, 22.631564537157754`, 
           22.83, 39592300}}, {{2013, 5, 15}, {
          22.86154905335628, 23.069922547332187`, 22.732555938037866`, 23.06, 
           40153000}}, {{2013, 5, 16}, {
          22.921314997851315`, 23.16938117748174, 22.921314997851315`, 23.09, 
           33023300}}, {{2013, 5, 17}, {
          23.081538789428816`, 23.289838022165387`, 23.012105711849955`, 
           23.27, 41037700}}, {{2013, 5, 20}, {
          23.270886720407294`, 23.389919389053876`, 23.241128553245648`, 
           23.38, 32884800}}, {{2013, 5, 21}, {
          23.400562130177512`, 23.58903634826712, 23.400562130177512`, 23.47, 
           33815000}}, {{2013, 5, 22}, {
          23.590637049455157`, 23.937849958088854`, 23.56087594300084, 23.67, 
           68514400}}, {{2013, 5, 23}, {
          23.33112426035503, 23.559277261200336`, 23.261686390532542`, 23.47, 
           44383600}}, {{2013, 5, 24}, {
          23.3102422439439, 23.478869528261797`, 23.3003229919252, 23.34, 
           41015200}}, {{2013, 5, 28}, {
          23.578631355932202`, 23.648067796610167`, 23.39016101694915, 23.41, 
           47323000}}, {{2013, 5, 29}, {
          23.231768189509307`, 23.50951776649746, 23.21192893401015, 23.45, 
           39236500}}, {{2013, 5, 30}, {
          23.39016101694915, 23.56871186440678, 23.310805084745763`, 23.41, 
           29347100}}, {{2013, 5, 31}, {
          23.407915951972555`, 23.606372212692968`, 23.13007718696398, 23.14, 
           49247600}}, {{2013, 6, 3}, {
          23.18217005076142, 23.588874788494078`, 23.132571912013535`, 23.45, 
           45218400}}, {{2013, 6, 4}, {
          23.400562130177512`, 23.569196956889265`, 23.22200760777684, 23.47, 
           38701300}}, {{2013, 6, 5}, {
          23.368224699828474`, 23.397993138936535`, 23.030849056603774`, 
           23.14, 44756200}}, {{2013, 6, 6}, {
          23.06105645851155, 23.19991873396065, 22.9122754491018, 23.19, 
           42677500}}, {{2013, 6, 7}, {
          23.35254819782062, 23.759283319362954`, 23.28310561609388, 23.67, 
           49041200}}, {{2013, 6, 10}, {
          23.689201009251473`, 23.728881412952063`, 23.45111858704794, 23.59, 
           41626500}}, {{2013, 6, 11}, {
          23.300725190839696`, 23.49911365564038, 23.290805767599664`, 23.39, 
           36183000}}, {{2013, 6, 12}, {
          23.508382978723404`, 23.538140425531914`, 23.230646808510638`, 
           23.31, 33842000}}, {{2013, 6, 13}, {
          23.261845439189184`, 23.599117398648644`, 23.152728040540538`, 
           23.49, 34930500}}, {{2013, 6, 14}, {
          23.488707482993195`, 23.55814200680272, 23.27048469387755, 23.33, 
           27846000}}, {{2013, 6, 17}, {
          23.560159865376523`, 23.6593605384939, 23.460959192259146`, 23.58, 
           39278300}}, {{2013, 6, 18}, {
          23.64390464447185, 24.259062885326763`, 23.58437320180847, 24.14, 
           72766900}}, {{2013, 6, 19}, {
          24.008256880733942`, 24.15706839032527, 23.79, 23.79, 46082200}}, {{
          2013, 6, 20}, {23.63, 23.69, 23.2, 23.25, 62733200}}, {{2013, 6, 
          21}, {23.579999999999995`, 23.639999999999997`, 23.209999999999997`,
            23.36, 65025200}}, {{2013, 6, 24}, {
          23.12, 23.15, 22.76, 22.93, 48760800}}, {{2013, 6, 25}, {
          23.169999999999998`, 23.249999999999996`, 22.939999999999998`, 
           23.11, 36569100}}, {{2013, 6, 26}, {
          23.43, 23.44, 23.02, 23.25, 32531700}}, {{2013, 6, 27}, {
          23.41, 23.48, 23.26, 23.32, 30867900}}, {{2013, 6, 28}, {
          23.32, 23.44, 23.16, 23.19, 45923200}}, {{2013, 7, 1}, {
          23.209999999999997`, 23.639999999999997`, 23.189999999999998`, 
           23.34, 35784800}}, {{2013, 7, 2}, {
          23.27, 23.34, 22.88, 22.9, 47571200}}, {{2013, 7, 3}, {
          22.83, 22.98, 22.76, 22.91, 21448500}}, {{2013, 7, 5}, {
          23.17, 23.24, 22.95, 23.24, 22688900}}, {{2013, 7, 8}, {
          23.36, 23.53, 23.27, 23.32, 35481100}}, {{2013, 7, 9}, {
          23.52, 23.8, 23.51, 23.62, 31541400}}, {{2013, 7, 10}, {
          23.719999999999995`, 23.729999999999997`, 23.359999999999996`, 
           23.54, 28457100}}, {{2013, 7, 11}, {
          23.91, 23.96, 23.63, 23.94, 32618400}}, {{2013, 7, 12}, {
          23.99, 24., 23.59, 23.76, 33257700}}, {{2013, 7, 15}, {
          23.73, 23.74, 23.56, 23.63, 35853500}}, {{2013, 7, 16}, {
          23.659999999999997`, 23.669999999999998`, 23.339999999999996`, 
           23.43, 38192400}}, {{2013, 7, 17}, {
          23.539999999999996`, 23.609999999999996`, 23.429999999999996`, 
           23.54, 26858500}}, {{2013, 7, 18}, {
          23.6, 23.94, 23.56, 23.63, 41438200}}, {{2013, 7, 19}, {
          24.21, 24.95, 24.1, 24.72, 103708900}}, {{2013, 7, 22}, {
          24.77, 24.92, 24.73, 24.86, 41560800}}, {{2013, 7, 23}, {
          24.87, 24.88, 24.63, 24.71, 32553000}}, {{2013, 7, 24}, {
          24.79, 24.84, 24.56, 24.62, 27485000}}, {{2013, 7, 25}, {
          24.61, 24.69, 24.52, 24.69, 29951700}}}, 
        System`TradingChartDump`$markerstyle$541645 = 1, 
        System`TradingChartDump`$controlmin$541645 = 0.5, 
        System`TradingChartDump`$controlmax$541645 = 250.5, 
        System`TradingChartDump`$datescope$541645 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$541645 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$541645, 
        System`TradingChartDump`$max$541645, 
        System`TradingChartDump`$ohlclabel$541645 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541645, 
              System`TradingChartDump`$opens$541645]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541645, 
              System`TradingChartDump`$highs$541645]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541645, 
              System`TradingChartDump`$lows$541645]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541645, 
              System`TradingChartDump`$closes$541645]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541645, 
              System`TradingChartDump`$visdates$541645]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$541645 = {}, 
        System`TradingChartDump`$subpricegridlines$541645 = Automatic, 
        System`TradingChartDump`$overlaypoint$541645, 
        System`TradingChartDump`$overlayvalue$541645, 
        System`TradingChartDump`$subplotvalue$541645, 
        System`TradingChartDump`$opts$541645 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "GE", " with ", "FastStochastic", 
            "(", 14, ",", 3, ",", Null, ",", Null, ")"}], 
         ImageSize -> {450, 310}, AlignmentPoint -> Center, AspectRatio -> 
         GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> None, AxesOrigin -> 
         Automatic, AxesStyle -> {}, Background -> None, BaselinePosition -> 
         Automatic, BaseStyle -> {}, ColorOutput -> Automatic, 
         ContentSelectable -> Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$541645 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmglczWkXx2/W7PuSl9RLZClS3WtQPcooqUkLiVT3tt5uC5ooBo09IVt6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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyFmndUVNcWxkfFhihRiF0CAoKABikjiOJRmgrCUJUqMDAgzUKMihKwRohi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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$541645 = 
        System`TradingChartDump`$staticindicatorpos$541645, 
        System`TradingChartDump`$length$541645 = 250, 
        System`TradingChartDump`$gridlinesflag$541645 = True, 
        System`TradingChartDump`$opens$541645 = 
        Dispatch[{
         1 -> 19.55`4., 2 -> 19.97`4., 3 -> 20.12`4., 4 -> 20.08`4., 5 -> 
          20.19`4., 6 -> 19.86`4., 7 -> 20.14`4., 8 -> 20.29`4., 9 -> 
          20.46`4., 10 -> 20.37`4., 11 -> 20.26`4., 12 -> 20.32`4., 13 -> 
          20.36`4., 14 -> 20.4`4., 15 -> 20.18`4., 16 -> 20.2`4., 17 -> 
          20.34`4., 18 -> 20.27`4., 19 -> 20.3`4., 20 -> 20.1`4., 21 -> 
          20.07`4., 22 -> 19.93`4., 23 -> 20.15`4., 24 -> 20.09`4., 25 -> 
          20.15`4., 26 -> 20.05`4., 27 -> 20.09`4., 28 -> 19.97`4., 29 -> 
          19.88`4., 30 -> 20.19`4., 31 -> 20.63`4., 32 -> 20.79`4., 33 -> 
          20.79`4., 34 -> 20.97`4., 35 -> 21.07`4., 36 -> 21.49`4., 37 -> 
          21.22`4., 38 -> 21.28`4., 39 -> 21.58`4., 40 -> 21.64`4., 41 -> 
          21.99`4., 42 -> 21.84`4., 43 -> 21.84`4., 44 -> 21.61`4., 45 -> 
          21.68`4., 46 -> 22.21`4., 47 -> 22.16`4., 48 -> 22.36`4., 49 -> 
          22.29`4., 50 -> 22.38`4., 51 -> 22.46`4., 52 -> 22.3`4., 53 -> 
          22.37`4., 54 -> 22.05`4., 55 -> 22.03`4., 56 -> 22.02`4., 57 -> 
          21.98`4., 58 -> 22.23`4., 59 -> 22.2`4., 60 -> 22.24`4., 61 -> 
          21.95`4., 62 -> 21.32`4., 63 -> 20.82`4., 64 -> 20.9`4., 65 -> 
          20.96`4., 66 -> 20.66`4., 67 -> 20.74`4., 68 -> 20.51`4., 69 -> 
          20.99`4., 70 -> 20.68`4., 71 -> 20.97`4., 72 -> 20.82`4., 73 -> 
          20.63`4., 74 -> 20.25`4., 75 -> 20.52`4., 76 -> 20.09`4., 77 -> 
          20.21`4., 78 -> 19.4`4., 79 -> 19.6`4., 80 -> 19.91`4., 81 -> 
          20.16`4., 82 -> 20.19`4., 83 -> 20.3`4., 84 -> 20.36`4., 85 -> 
          20.52`4., 86 -> 20.23`4., 87 -> 20.71`4., 88 -> 20.61`4., 89 -> 
          20.65`4., 90 -> 20.35`4., 91 -> 20.39`4., 92 -> 20.67`4., 93 -> 
          20.91`4., 94 -> 20.9`4., 95 -> 20.94`4., 96 -> 21.07`4., 97 -> 
          21.2`4., 98 -> 21.07`4., 99 -> 21.15`4., 100 -> 21.31`4., 101 -> 
          21.1`4., 102 -> 20.57`4., 103 -> 20.51`4., 104 -> 20.46`4., 105 -> 
          20.48`4., 106 -> 20.47`4., 107 -> 20.12`4., 108 -> 19.96`4., 109 -> 
          21.17`4., 110 -> 21.13`4., 111 -> 20.87`4., 112 -> 20.82`4., 113 -> 
          20.77`4., 114 -> 20.71`4., 115 -> 20.7`4., 116 -> 20.88`4., 117 -> 
          20.84`4., 118 -> 20.7`4., 119 -> 20.81`4., 120 -> 20.88`4., 121 -> 
          21.59`4., 122 -> 21.83`4., 123 -> 21.63`4., 124 -> 21.61`4., 125 -> 
          21.92`4., 126 -> 22.08`4., 127 -> 22.13`4., 128 -> 22.16`4., 129 -> 
          21.85`4., 130 -> 22.07`4., 131 -> 22.05`4., 132 -> 22.12`4., 133 -> 
          22.11`4., 134 -> 22.14`4., 135 -> 22.14`4., 136 -> 22.13`4., 137 -> 
          22.12`4., 138 -> 22.74`4., 139 -> 22.88`4., 140 -> 23.11`4., 141 -> 
          23.05`4., 142 -> 23.34`4., 143 -> 23.`4., 144 -> 23.16`4., 145 -> 
          23.31`4., 146 -> 22.79`4., 147 -> 22.83`4., 148 -> 23.19`4., 149 -> 
          22.84`4., 150 -> 22.97`4., 151 -> 23.27`4., 152 -> 23.65`4., 153 -> 
          23.51`4., 154 -> 23.67`4., 155 -> 23.5`4., 156 -> 23.4`4., 157 -> 
          23.25`4., 158 -> 23.36`4., 159 -> 23.25`4., 160 -> 22.99`4., 161 -> 
          23.12`4., 162 -> 23.54`4., 163 -> 23.24`4., 164 -> 23.13`4., 165 -> 
          23.27`4., 166 -> 23.09`4., 167 -> 22.84`4., 168 -> 22.96`4., 169 -> 
          22.85`4., 170 -> 22.99`4., 171 -> 23.2`4., 172 -> 22.83`4., 173 -> 
          22.62`4., 174 -> 22.87`4., 175 -> 23.07`4., 176 -> 22.91`4., 177 -> 
          23.36`4., 178 -> 23.3`4., 179 -> 23.1`4., 180 -> 22.89`4., 181 -> 
          22.78`4., 182 -> 22.58`4., 183 -> 21.77`4., 184 -> 21.5`4., 185 -> 
          21.38`4., 186 -> 21.52`4., 187 -> 22.04`4., 188 -> 21.8`4., 189 -> 
          22.13`4., 190 -> 22.11`4., 191 -> 21.92`4., 192 -> 22.07`4., 193 -> 
          22.39`4., 194 -> 22.38`4., 195 -> 22.51`4., 196 -> 22.5`4., 197 -> 
          22.81`4., 198 -> 22.59`4., 199 -> 22.68`4., 200 -> 22.67`4., 201 -> 
          22.86`4., 202 -> 22.92`4., 203 -> 23.08`4., 204 -> 23.27`4., 205 -> 
          23.4`4., 206 -> 23.59`4., 207 -> 23.33`4., 208 -> 23.31`4., 209 -> 
          23.58`4., 210 -> 23.23`4., 211 -> 23.39`4., 212 -> 23.41`4., 213 -> 
          23.18`4., 214 -> 23.4`4., 215 -> 23.37`4., 216 -> 23.06`4., 217 -> 
          23.35`4., 218 -> 23.69`4., 219 -> 23.3`4., 220 -> 23.51`4., 221 -> 
          23.26`4., 222 -> 23.49`4., 223 -> 23.56`4., 224 -> 23.64`4., 225 -> 
          24.01`4., 226 -> 23.63`4., 227 -> 23.58`4., 228 -> 23.12`4., 229 -> 
          23.17`4., 230 -> 23.43`4., 231 -> 23.41`4., 232 -> 23.32`4., 233 -> 
          23.21`4., 234 -> 23.27`4., 235 -> 22.83`4., 236 -> 23.17`4., 237 -> 
          23.36`4., 238 -> 23.52`4., 239 -> 23.72`4., 240 -> 23.91`4., 241 -> 
          23.99`4., 242 -> 23.73`4., 243 -> 23.66`4., 244 -> 23.54`4., 245 -> 
          23.6`4., 246 -> 24.21`4., 247 -> 24.77`4., 248 -> 24.87`4., 249 -> 
          24.79`4., 250 -> 24.61`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$541645 = 
        Dispatch[{
         1 -> 20.04`4., 2 -> 20.33`4., 3 -> 20.24`4., 4 -> 20.22`4., 5 -> 
          20.27`4., 6 -> 20.03`4., 7 -> 20.32`4., 8 -> 20.49`4., 9 -> 
          20.51`4., 10 -> 20.41`4., 11 -> 20.44`4., 12 -> 20.42`4., 13 -> 
          20.38`4., 14 -> 20.42`4., 15 -> 20.35`4., 16 -> 20.46`4., 17 -> 
          20.37`4., 18 -> 20.34`4., 19 -> 20.37`4., 20 -> 20.2`4., 21 -> 
          20.12`4., 22 -> 20.23`4., 23 -> 20.28`4., 24 -> 20.25`4., 25 -> 
          20.28`4., 26 -> 20.11`4., 27 -> 20.16`4., 28 -> 20.02`4., 29 -> 
          20.1`4., 30 -> 20.63`4., 31 -> 20.89`4., 32 -> 20.95`4., 33 -> 
          20.99`4., 34 -> 21.22`4., 35 -> 21.52`4., 36 -> 21.65`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.77`4., 40 -> 21.91`4., 41 -> 
          22.13`4., 42 -> 21.89`4., 43 -> 22.11`4., 44 -> 21.7`4., 45 -> 
          22.29`4., 46 -> 22.39`4., 47 -> 22.43`4., 48 -> 22.41`4., 49 -> 
          22.41`4., 50 -> 22.48`4., 51 -> 22.6`4., 52 -> 22.42`4., 53 -> 
          22.4`4., 54 -> 22.17`4., 55 -> 22.15`4., 56 -> 22.14`4., 57 -> 
          22.14`4., 58 -> 22.31`4., 59 -> 22.35`4., 60 -> 22.5`4., 61 -> 
          21.97`4., 62 -> 21.4`4., 63 -> 20.87`4., 64 -> 20.93`4., 65 -> 
          21.03`4., 66 -> 20.86`4., 67 -> 20.79`4., 68 -> 20.86`4., 69 -> 
          21.14`4., 70 -> 20.94`4., 71 -> 21.24`4., 72 -> 20.98`4., 73 -> 
          20.66`4., 74 -> 20.77`4., 75 -> 20.61`4., 76 -> 20.43`4., 77 -> 
          20.23`4., 78 -> 19.73`4., 79 -> 19.69`4., 80 -> 20.21`4., 81 -> 
          20.18`4., 82 -> 20.23`4., 83 -> 20.52`4., 84 -> 20.55`4., 85 -> 
          20.67`4., 86 -> 20.62`4., 87 -> 20.82`4., 88 -> 20.73`4., 89 -> 
          20.7`4., 90 -> 20.49`4., 91 -> 20.83`4., 92 -> 20.86`4., 93 -> 
          20.95`4., 94 -> 20.97`4., 95 -> 21.2`4., 96 -> 21.41`4., 97 -> 
          21.37`4., 98 -> 21.22`4., 99 -> 21.4`4., 100 -> 21.36`4., 101 -> 
          21.12`4., 102 -> 20.9`4., 103 -> 20.66`4., 104 -> 20.63`4., 105 -> 
          20.61`4., 106 -> 20.54`4., 107 -> 20.38`4., 108 -> 20.66`4., 109 -> 
          21.2`4., 110 -> 21.14`4., 111 -> 20.92`4., 112 -> 20.88`4., 113 -> 
          20.79`4., 114 -> 20.74`4., 115 -> 20.89`4., 116 -> 20.9`4., 117 -> 
          20.9`4., 118 -> 20.87`4., 119 -> 20.86`4., 120 -> 21.2`4., 121 -> 
          21.84`4., 122 -> 21.85`4., 123 -> 21.68`4., 124 -> 21.84`4., 125 -> 
          21.95`4., 126 -> 22.18`4., 127 -> 22.22`4., 128 -> 22.18`4., 129 -> 
          22.04`4., 130 -> 22.28`4., 131 -> 22.13`4., 132 -> 22.26`4., 133 -> 
          22.14`4., 134 -> 22.15`4., 135 -> 22.2`4., 136 -> 22.15`4., 137 -> 
          22.29`4., 138 -> 23.11`4., 139 -> 23.12`4., 140 -> 23.18`4., 141 -> 
          23.37`4., 142 -> 23.37`4., 143 -> 23.17`4., 144 -> 23.26`4., 145 -> 
          23.34`4., 146 -> 22.97`4., 147 -> 23.21`4., 148 -> 23.28`4., 149 -> 
          23.16`4., 150 -> 23.1`4., 151 -> 23.52`4., 152 -> 23.65`4., 153 -> 
          23.64`4., 154 -> 23.71`4., 155 -> 23.56`4., 156 -> 23.41`4., 157 -> 
          23.33`4., 158 -> 23.57`4., 159 -> 23.53`4., 160 -> 23.17`4., 161 -> 
          23.18`4., 162 -> 23.61`4., 163 -> 23.42`4., 164 -> 23.21`4., 165 -> 
          23.3`4., 166 -> 23.12`4., 167 -> 22.96`4., 168 -> 23.02`4., 169 -> 
          22.92`4., 170 -> 23.19`4., 171 -> 23.22`4., 172 -> 22.95`4., 173 -> 
          22.76`4., 174 -> 22.94`4., 175 -> 23.07`4., 176 -> 23.46`4., 177 -> 
          23.53`4., 178 -> 23.4`4., 179 -> 23.12`4., 180 -> 22.92`4., 181 -> 
          22.85`4., 182 -> 22.67`4., 183 -> 21.86`4., 184 -> 21.51`4., 185 -> 
          21.52`4., 186 -> 21.86`4., 187 -> 22.06`4., 188 -> 22.22`4., 189 -> 
          22.14`4., 190 -> 22.2`4., 191 -> 22.17`4., 192 -> 22.14`4., 193 -> 
          22.67`4., 194 -> 22.46`4., 195 -> 22.61`4., 196 -> 22.84`4., 197 -> 
          22.92`4., 198 -> 22.73`4., 199 -> 22.7`4., 200 -> 22.89`4., 201 -> 
          23.07`4., 202 -> 23.17`4., 203 -> 23.29`4., 204 -> 23.39`4., 205 -> 
          23.59`4., 206 -> 23.94`4., 207 -> 23.56`4., 208 -> 23.48`4., 209 -> 
          23.65`4., 210 -> 23.51`4., 211 -> 23.57`4., 212 -> 23.61`4., 213 -> 
          23.59`4., 214 -> 23.57`4., 215 -> 23.4`4., 216 -> 23.2`4., 217 -> 
          23.76`4., 218 -> 23.73`4., 219 -> 23.5`4., 220 -> 23.54`4., 221 -> 
          23.6`4., 222 -> 23.56`4., 223 -> 23.66`4., 224 -> 24.26`4., 225 -> 
          24.16`4., 226 -> 23.69`4., 227 -> 23.64`4., 228 -> 23.15`4., 229 -> 
          23.25`4., 230 -> 23.44`4., 231 -> 23.48`4., 232 -> 23.44`4., 233 -> 
          23.64`4., 234 -> 23.34`4., 235 -> 22.98`4., 236 -> 23.24`4., 237 -> 
          23.53`4., 238 -> 23.8`4., 239 -> 23.73`4., 240 -> 23.96`4., 241 -> 
          24.`4., 242 -> 23.74`4., 243 -> 23.67`4., 244 -> 23.61`4., 245 -> 
          23.94`4., 246 -> 24.95`4., 247 -> 24.92`4., 248 -> 24.88`4., 249 -> 
          24.84`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$541645 = 
        Dispatch[{
         1 -> 19.51`4., 2 -> 19.9`4., 3 -> 20.02`4., 4 -> 20.08`4., 5 -> 
          20.04`4., 6 -> 19.55`4., 7 -> 20.1`4., 8 -> 20.22`4., 9 -> 20.41`4.,
           10 -> 20.22`4., 11 -> 20.26`4., 12 -> 20.27`4., 13 -> 20.2`4., 14 -> 
          20.22`4., 15 -> 20.12`4., 16 -> 20.15`4., 17 -> 20.26`4., 18 -> 
          20.15`4., 19 -> 20.13`4., 20 -> 20.04`4., 21 -> 19.96`4., 22 -> 
          19.89`4., 23 -> 20.12`4., 24 -> 20.09`4., 25 -> 20.14`4., 26 -> 
          19.95`4., 27 -> 19.94`4., 28 -> 19.82`4., 29 -> 19.84`4., 30 -> 
          20.17`4., 31 -> 20.61`4., 32 -> 20.74`4., 33 -> 20.71`4., 34 -> 
          20.96`4., 35 -> 21.05`4., 36 -> 21.27`4., 37 -> 21.19`4., 38 -> 
          21.25`4., 39 -> 21.54`4., 40 -> 21.57`4., 41 -> 21.9`4., 42 -> 
          21.74`4., 43 -> 21.75`4., 44 -> 21.52`4., 45 -> 21.58`4., 46 -> 
          22.06`4., 47 -> 22.14`4., 48 -> 22.14`4., 49 -> 22.15`4., 50 -> 
          22.2`4., 51 -> 22.42`4., 52 -> 22.28`4., 53 -> 22.04`4., 54 -> 
          21.85`4., 55 -> 21.92`4., 56 -> 21.85`4., 57 -> 21.93`4., 58 -> 
          22.01`4., 59 -> 22.15`4., 60 -> 22.23`4., 61 -> 21.32`4., 62 -> 
          20.72`4., 63 -> 20.67`4., 64 -> 20.71`4., 65 -> 20.51`4., 66 -> 
          20.54`4., 67 -> 20.45`4., 68 -> 20.5`4., 69 -> 20.73`4., 70 -> 
          20.68`4., 71 -> 20.91`4., 72 -> 20.54`4., 73 -> 20.36`4., 74 -> 
          20.19`4., 75 -> 20.36`4., 76 -> 20.06`4., 77 -> 19.45`4., 78 -> 
          19.4`4., 79 -> 19.38`4., 80 -> 19.89`4., 81 -> 19.87`4., 82 -> 
          20.06`4., 83 -> 20.22`4., 84 -> 20.35`4., 85 -> 20.33`4., 86 -> 
          19.99`4., 87 -> 20.42`4., 88 -> 20.51`4., 89 -> 20.28`4., 90 -> 
          20.19`4., 91 -> 20.34`4., 92 -> 20.56`4., 93 -> 20.72`4., 94 -> 
          20.83`4., 95 -> 20.82`4., 96 -> 21.04`4., 97 -> 21.01`4., 98 -> 
          21.01`4., 99 -> 21.15`4., 100 -> 20.88`4., 101 -> 20.45`4., 102 -> 
          20.53`4., 103 -> 20.24`4., 104 -> 20.42`4., 105 -> 20.38`4., 106 -> 
          20.09`4., 107 -> 20.1`4., 108 -> 19.93`4., 109 -> 20.86`4., 110 -> 
          20.71`4., 111 -> 20.78`4., 112 -> 20.62`4., 113 -> 20.35`4., 114 -> 
          20.6`4., 115 -> 20.62`4., 116 -> 20.68`4., 117 -> 20.73`4., 118 -> 
          20.67`4., 119 -> 20.72`4., 120 -> 20.78`4., 121 -> 21.25`4., 122 -> 
          21.55`4., 123 -> 21.4`4., 124 -> 21.6`4., 125 -> 21.75`4., 126 -> 
          21.9`4., 127 -> 22.04`4., 128 -> 21.87`4., 129 -> 21.82`4., 130 -> 
          21.96`4., 131 -> 21.92`4., 132 -> 22.09`4., 133 -> 21.95`4., 134 -> 
          21.91`4., 135 -> 22.09`4., 136 -> 21.99`4., 137 -> 22.12`4., 138 -> 
          22.68`4., 139 -> 22.74`4., 140 -> 22.86`4., 141 -> 23.04`4., 142 -> 
          22.98`4., 143 -> 22.94`4., 144 -> 23.04`4., 145 -> 22.63`4., 146 -> 
          22.73`4., 147 -> 22.81`4., 148 -> 23.02`4., 149 -> 22.82`4., 150 -> 
          22.85`4., 151 -> 23.25`4., 152 -> 23.48`4., 153 -> 23.48`4., 154 -> 
          23.49`4., 155 -> 23.26`4., 156 -> 23.14`4., 157 -> 23.21`4., 158 -> 
          23.32`4., 159 -> 23.17`4., 160 -> 22.95`4., 161 -> 22.99`4., 162 -> 
          23.14`4., 163 -> 23.11`4., 164 -> 23.09`4., 165 -> 22.87`4., 166 -> 
          22.83`4., 167 -> 22.67`4., 168 -> 22.81`4., 169 -> 22.79`4., 170 -> 
          22.92`4., 171 -> 22.74`4., 172 -> 22.78`4., 173 -> 22.58`4., 174 -> 
          22.65`4., 175 -> 22.72`4., 176 -> 22.87`4., 177 -> 23.24`4., 178 -> 
          23.14`4., 179 -> 22.63`4., 180 -> 22.72`4., 181 -> 22.47`4., 182 -> 
          22.39`4., 183 -> 21.44`4., 184 -> 20.94`4., 185 -> 21.19`4., 186 -> 
          21.48`4., 187 -> 21.74`4., 188 -> 21.79`4., 189 -> 21.82`4., 190 -> 
          22.03`4., 191 -> 21.92`4., 192 -> 21.97`4., 193 -> 22.37`4., 194 -> 
          22.14`4., 195 -> 22.44`4., 196 -> 22.44`4., 197 -> 22.51`4., 198 -> 
          22.41`4., 199 -> 22.44`4., 200 -> 22.63`4., 201 -> 22.73`4., 202 -> 
          22.92`4., 203 -> 23.01`4., 204 -> 23.24`4., 205 -> 23.4`4., 206 -> 
          23.56`4., 207 -> 23.26`4., 208 -> 23.3`4., 209 -> 23.39`4., 210 -> 
          23.21`4., 211 -> 23.31`4., 212 -> 23.13`4., 213 -> 23.13`4., 214 -> 
          23.22`4., 215 -> 23.03`4., 216 -> 22.91`4., 217 -> 23.28`4., 218 -> 
          23.45`4., 219 -> 23.29`4., 220 -> 23.23`4., 221 -> 23.15`4., 222 -> 
          23.27`4., 223 -> 23.46`4., 224 -> 23.58`4., 225 -> 23.79`4., 226 -> 
          23.2`4., 227 -> 23.21`4., 228 -> 22.76`4., 229 -> 22.94`4., 230 -> 
          23.02`4., 231 -> 23.26`4., 232 -> 23.16`4., 233 -> 23.19`4., 234 -> 
          22.88`4., 235 -> 22.76`4., 236 -> 22.95`4., 237 -> 23.27`4., 238 -> 
          23.51`4., 239 -> 23.36`4., 240 -> 23.63`4., 241 -> 23.59`4., 242 -> 
          23.56`4., 243 -> 23.34`4., 244 -> 23.43`4., 245 -> 23.56`4., 246 -> 
          24.1`4., 247 -> 24.73`4., 248 -> 24.63`4., 249 -> 24.56`4., 250 -> 
          24.52`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$541645 = 
        Dispatch[{
         1 -> 19.9`4., 2 -> 20.25`4., 3 -> 20.13`4., 4 -> 20.08`4., 5 -> 
          20.06`4., 6 -> 19.86`4., 7 -> 20.28`4., 8 -> 20.29`4., 9 -> 
          20.44`4., 10 -> 20.33`4., 11 -> 20.38`4., 12 -> 20.42`4., 13 -> 
          20.31`4., 14 -> 20.26`4., 15 -> 20.28`4., 16 -> 20.37`4., 17 -> 
          20.32`4., 18 -> 20.25`4., 19 -> 20.18`4., 20 -> 20.11`4., 21 -> 
          19.97`4., 22 -> 20.13`4., 23 -> 20.18`4., 24 -> 20.14`4., 25 -> 
          20.15`4., 26 -> 19.97`4., 27 -> 20.04`4., 28 -> 19.85`4., 29 -> 
          19.98`4., 30 -> 20.62`4., 31 -> 20.89`4., 32 -> 20.79`4., 33 -> 
          20.89`4., 34 -> 21.18`4., 35 -> 21.31`4., 36 -> 21.4`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.71`4., 40 -> 21.87`4., 41 -> 
          21.97`4., 42 -> 21.8`4., 43 -> 21.76`4., 44 -> 21.55`4., 45 -> 
          22.16`4., 46 -> 22.15`4., 47 -> 22.24`4., 48 -> 22.22`4., 49 -> 
          22.34`4., 50 -> 22.38`4., 51 -> 22.54`4., 52 -> 22.35`4., 53 -> 
          22.06`4., 54 -> 21.87`4., 55 -> 21.95`4., 56 -> 21.92`4., 57 -> 
          22.08`4., 58 -> 22.08`4., 59 -> 22.34`4., 60 -> 22.24`4., 61 -> 
          21.48`4., 62 -> 21.16`4., 63 -> 20.75`4., 64 -> 20.73`4., 65 -> 
          20.73`4., 66 -> 20.58`4., 67 -> 20.54`4., 68 -> 20.81`4., 69 -> 
          20.78`4., 70 -> 20.88`4., 71 -> 21.05`4., 72 -> 20.6`4., 73 -> 
          20.37`4., 74 -> 20.48`4., 75 -> 20.37`4., 76 -> 20.17`4., 77 -> 
          19.51`4., 78 -> 19.56`4., 79 -> 19.65`4., 80 -> 20.15`4., 81 -> 
          20.11`4., 82 -> 20.17`4., 83 -> 20.52`4., 84 -> 20.54`4., 85 -> 
          20.35`4., 86 -> 20.61`4., 87 -> 20.6`4., 88 -> 20.6`4., 89 -> 
          20.3`4., 90 -> 20.34`4., 91 -> 20.7`4., 92 -> 20.84`4., 93 -> 
          20.93`4., 94 -> 20.86`4., 95 -> 20.97`4., 96 -> 21.24`4., 97 -> 
          21.08`4., 98 -> 21.08`4., 99 -> 21.38`4., 100 -> 21.15`4., 101 -> 
          20.49`4., 102 -> 20.71`4., 103 -> 20.55`4., 104 -> 20.49`4., 105 -> 
          20.44`4., 106 -> 20.36`4., 107 -> 20.11`4., 108 -> 20.65`4., 109 -> 
          21.`4., 110 -> 20.76`4., 111 -> 20.86`4., 112 -> 20.79`4., 113 -> 
          20.57`4., 114 -> 20.62`4., 115 -> 20.83`4., 116 -> 20.79`4., 117 -> 
          20.78`4., 118 -> 20.86`4., 119 -> 20.78`4., 120 -> 20.96`4., 121 -> 
          21.69`4., 122 -> 21.66`4., 123 -> 21.59`4., 124 -> 21.7`4., 125 -> 
          21.93`4., 126 -> 22.14`4., 127 -> 22.14`4., 128 -> 21.87`4., 129 -> 
          21.92`4., 130 -> 22.26`4., 131 -> 21.95`4., 132 -> 22.18`4., 133 -> 
          22.08`4., 134 -> 22.12`4., 135 -> 22.14`4., 136 -> 22.09`4., 137 -> 
          22.22`4., 138 -> 23.02`4., 139 -> 23.04`4., 140 -> 22.92`4., 141 -> 
          23.37`4., 142 -> 23.04`4., 143 -> 23.08`4., 144 -> 23.2`4., 145 -> 
          22.63`4., 146 -> 22.87`4., 147 -> 23.18`4., 148 -> 23.04`4., 149 -> 
          23.01`4., 150 -> 23.09`4., 151 -> 23.4`4., 152 -> 23.48`4., 153 -> 
          23.49`4., 154 -> 23.58`4., 155 -> 23.43`4., 156 -> 23.22`4., 157 -> 
          23.3`4., 158 -> 23.5`4., 159 -> 23.25`4., 160 -> 23.07`4., 161 -> 
          23.14`4., 162 -> 23.27`4., 163 -> 23.11`4., 164 -> 23.18`4., 165 -> 
          23.06`4., 166 -> 22.94`4., 167 -> 22.92`4., 168 -> 22.94`4., 169 -> 
          22.9`4., 170 -> 23.16`4., 171 -> 22.82`4., 172 -> 22.9`4., 173 -> 
          22.75`4., 174 -> 22.94`4., 175 -> 22.88`4., 176 -> 23.39`4., 177 -> 
          23.4`4., 178 -> 23.27`4., 179 -> 22.63`4., 180 -> 22.92`4., 181 -> 
          22.58`4., 182 -> 22.49`4., 183 -> 21.58`4., 184 -> 21.18`4., 185 -> 
          21.33`4., 186 -> 21.79`4., 187 -> 21.78`4., 188 -> 22.03`4., 189 -> 
          22.09`4., 190 -> 22.11`4., 191 -> 21.97`4., 192 -> 22.14`4., 193 -> 
          22.39`4., 194 -> 22.4`4., 195 -> 22.5`4., 196 -> 22.83`4., 197 -> 
          22.6`4., 198 -> 22.72`4., 199 -> 22.67`4., 200 -> 22.83`4., 201 -> 
          23.06`4., 202 -> 23.09`4., 203 -> 23.27`4., 204 -> 23.38`4., 205 -> 
          23.47`4., 206 -> 23.67`4., 207 -> 23.47`4., 208 -> 23.34`4., 209 -> 
          23.41`4., 210 -> 23.45`4., 211 -> 23.41`4., 212 -> 23.14`4., 213 -> 
          23.45`4., 214 -> 23.47`4., 215 -> 23.14`4., 216 -> 23.19`4., 217 -> 
          23.67`4., 218 -> 23.59`4., 219 -> 23.39`4., 220 -> 23.31`4., 221 -> 
          23.49`4., 222 -> 23.33`4., 223 -> 23.58`4., 224 -> 24.14`4., 225 -> 
          23.79`4., 226 -> 23.25`4., 227 -> 23.36`4., 228 -> 22.93`4., 229 -> 
          23.11`4., 230 -> 23.25`4., 231 -> 23.32`4., 232 -> 23.19`4., 233 -> 
          23.34`4., 234 -> 22.9`4., 235 -> 22.91`4., 236 -> 23.24`4., 237 -> 
          23.32`4., 238 -> 23.62`4., 239 -> 23.54`4., 240 -> 23.94`4., 241 -> 
          23.76`4., 242 -> 23.63`4., 243 -> 23.43`4., 244 -> 23.54`4., 245 -> 
          23.63`4., 246 -> 24.72`4., 247 -> 24.86`4., 248 -> 24.71`4., 249 -> 
          24.62`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$541645 = True, 
        System`TradingChartDump`$gridlines$541645 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$541645, 
        System`TradingChartDump`$plotrangemin$541645 = 19.0982952853598, 
        System`TradingChartDump`$plotrangemax$541645 = 25.507305210918112`, 
        System`TradingChartDump`$layoutData$541645, 
        System`TradingChartDump`$gridlinesscope$541645 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$541645 = {True, True}, 
        System`TradingChartDump`$indicators$541645 = {
         FinancialIndicator["FastStochastic", 14, 3]}, 
        System`TradingChartDump`$mouseQ$541645 = False, 
        System`TradingChartDump`$modelData$541645 = 
        System`TradingChartDump`modelData$539004, 
        System`TradingChartDump`$sy$541645 = Identity, 
        System`TradingChartDump`$isy$541645 = Identity, 
        System`TradingChartDump`$appearance$541645 = Automatic, 
        System`TradingChartDump`$perfgoal$541645 = "Quality", 
        System`TradingChartDump`$axesorigin$541645 = Automatic, 
        System`TradingChartDump`$framestyle$541645 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$541645 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$541645 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$541645 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$541645 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$541645, 
        System`TradingChartDump`$newgridlines$541645 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{19.0982952853598, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$541645 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$541645 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$541645 = "GraphicsFrame", 
        System`TradingChartDump`$frame$541645 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$541645 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$541645 = 
              Switch[System`TradingChartDump`$highlightposition$541645, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$541645], {
                 1, System`TradingChartDump`$length$541645}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$541645], {
                 1, System`TradingChartDump`$length$541645}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$541645, 
                   Charting`nearestDate[System`TradingChartDump`$dates$541645, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$541645]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$541645]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$541645, 
                    Floor[System`TradingChartDump`$controlmin$541645] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$541645, 
                    Floor[System`TradingChartDump`$controlmax$541645]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$541645 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$541645 = 
            If[System`TradingChartDump`$fastpos$541645 =!= True, 
              System`TradingChartDump`$fastpos$541645 = 
               Clip[System`TradingChartDump`$fastpos$541645, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$541645 = (
                  Floor[System`TradingChartDump`$controlmax$541645] - Floor[
                  System`TradingChartDump`$controlmin$541645]) (
                  System`TradingChartDump`$fastpos$541645/100) + 
                Floor[System`TradingChartDump`$controlmin$541645]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$541645], {
                Floor[System`TradingChartDump`$controlmin$541645] + 1, 
                 Floor[System`TradingChartDump`$controlmax$541645]}], 
              System`TradingChartDump`$staticindicatorpos$541645]; 
           System`TradingChartDump`$mouseQ$541645 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$541645]], 
              System`TradingChartDump`$highlightposition$541645 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$541645 = If[
              And[
              System`TradingChartDump`$bouncingballQ$541645, 
               System`TradingChartDump`$mouseQ$541645, 
               System`TradingChartDump`$appearance$541645 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$541645[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$541645]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$541645[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$541645, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$541645[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$541645]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$541645[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$541645[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541645, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541645[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541645, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541645, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541645[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541645[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$541645 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$541645, 
                 System`TradingChartDump`$defaultframeticksstyle$541645, 
                 System`TradingChartDump`$defaultlabelstyle$541645, 
                 System`TradingChartDump`$framestyle$541645, 
                 System`TradingChartDump`$frameticksstyle$541645, 
                 System`TradingChartDump`$labelstyle$541645}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541645 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$541645, 
                 System`TradingChartDump`$labelstyle$541645, 
                 System`TradingChartDump`$defaultframeticksstyle$541645, 
                 System`TradingChartDump`$defaultlabelstyle$541645}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541645 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541645, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$541645 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541645, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$541645 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541645, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$541645 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$541645 = 
             Part[System`TradingChartDump`$tickstextstyle$541645, 1], 
             System`TradingChartDump`$tickstextstyle$541645 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541645[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541645, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541645[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541645[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541645[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$541645[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541645, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$541645]], 
                    Style[":", System`TradingChartDump`$textstyle$541645]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$541645[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541645]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541645[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$541645[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$541645, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$541645]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$541645[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541645, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541645[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541645, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541645, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$541645[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541645[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541645[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$541645[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$541645[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$541645], 1], 
                   Floor[System`TradingChartDump`$controlmax$541645]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$541645[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$541645[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$541645[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$541645[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$541645[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541645[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$541645[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$541645[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$541645[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541645[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$541645[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$541645[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$541645[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$541645[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$541645[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$541645, 
                  System`TradingChartDump`$mouseQ$541645], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$541645 - 0.5, 
                   System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$541645 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$541645 + 0.5, 
                    System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541645, 1]}, {
                    System`TradingChartDump`$indicatorpos$541645 + 0.5, 
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$541645[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$541645, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$541645[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541645]]], {}]; 
              System`TradingChartDump`$subplotgridlines$541645[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$541645[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$541645[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541645[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$541645 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$541645, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541645, 
                   System`TradingChartDump`$opens$541645]], 12, 
                 System`TradingChartDump`$textstyle$541645, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$541645, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541645, 
                   System`TradingChartDump`$highs$541645]], 12, 
                 System`TradingChartDump`$textstyle$541645, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$541645, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541645, 
                   System`TradingChartDump`$lows$541645]], 12, 
                 System`TradingChartDump`$textstyle$541645, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$541645, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541645, 
                   System`TradingChartDump`$closes$541645]], 12, 
                 System`TradingChartDump`$textstyle$541645, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541645, 
                   System`TradingChartDump`$visdates$541645]], 12, 
                 System`TradingChartDump`$textstyle$541645, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$541645, 
                  System`TradingChartDump`$mouseQ$541645], {{
                  System`TradingChartDump`$timestampstyle$541645, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$541645 - 0.5, 
                    System`TradingChartDump`$plotrangemin$541645}, 
                    If[
                    System`TradingChartDump`$timestampdepth$541645 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$541645[1]}, {
                    System`TradingChartDump`$indicatorpos$541645 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541645}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541645, 1]}, {
                    System`TradingChartDump`$indicatorpos$541645 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541645}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$541645, {
               System`TradingChartDump`$highlightstyle$541645, 
                Dynamic[System`TradingChartDump`$ohlcpoint$541645]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$541645[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541645, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$541645[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$541645[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$541645, Length[
                    System`TradingChartDump`$layoutData$541645[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$541645}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$541645] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$541645] + 0.5}, {
                System`TradingChartDump`$plotrangemin$541645, 
                 System`TradingChartDump`$plotrangemax$541645}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$541645, Left, {
                 False, System`TradingChartDump`$frame$541645}, 
                 Blank[], {System`TradingChartDump`$frame$541645, False}], {
                False, System`TradingChartDump`$frame$541645}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$541645, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$541645]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$541645 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           387.02286107677577`}, {-286.92264150943396`, -65.76792452830186}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541645 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541645, 1]], 
               Part[System`TradingChartDump`$framestyle$541645, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$541645]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$541645} -> 
                   System`TradingChartDump`$isy$541645[
                    System`TradingChartDump`$plotrangemin$541645], {
                    0, System`TradingChartDump`$plotrangemax$541645} -> 
                   System`TradingChartDump`$isy$541645[
                    System`TradingChartDump`$plotrangemax$541645]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$541645[
                   System`TradingChartDump`$plotrangemin$541645], 
                   System`TradingChartDump`$isy$541645[
                   System`TradingChartDump`$plotrangemax$541645]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$541645, 
                   System`TradingChartDump`$isy$541645}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541645, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541645 > 
                    System`TradingChartDump`$plotrangemin$541645, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541645 > 
                    System`TradingChartDump`$plotrangemin$541645, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541645, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541645 > 
                    System`TradingChartDump`$plotrangemin$541645, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541645 > 
                    System`TradingChartDump`$plotrangemin$541645, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541645, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541645, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541645 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541645,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541645], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541645 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541645, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541645]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$541645, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$541645[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$541645[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541645, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$541645[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$541645, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541645[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541645, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541645[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541645[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541645[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541645[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541645], 
                    Style[":", System`TradingChartDump`$textstyle$541645]], 
                    Style[":", System`TradingChartDump`$textstyle$541645]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$541645[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541645]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541645[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$541645}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$541645, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$541645 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$541645[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$541645, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$541645, Left, {
                    False, System`TradingChartDump`$frame$541645}, 
                    Blank[], {
                    System`TradingChartDump`$frame$541645, False}], {
                   System`TradingChartDump`$frame$541645, 
                    System`TradingChartDump`$frame$541645}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$541645, 
                    System`TradingChartDump`$controlmax$541645}] + 0.5, {
                   System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$541645]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$541645) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$541645 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$541645 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$541645, 1]], 
                   Part[System`TradingChartDump`$framestyle$541645, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$541645]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541645[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541645[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$541645[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541645, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541645, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$541645, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$541645, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$541645 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
541645, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$541645], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$541645 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$541645, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$541645]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$541645, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$541645) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$541645 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$541645[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          ImageSizeCache->{{29.187012228940432`, 
           475.9407855006933}, {-55.989622641509435`, -0.7009433962264069}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$541645, 
              Dynamic[System`TradingChartDump`$ohlclabel$541645], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$541645}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541645 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541645, 2]], 
               Part[System`TradingChartDump`$framestyle$541645, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$541645]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$541645, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$541645, 
                    System`TradingChartDump`$controlmax$541645}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$541645] + 
                    0.5, System`TradingChartDump`$plotrangemin$541645}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$541645], 
                    System`TradingChartDump`$plotrangemin$541645}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$541645, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541645, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541645, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541645 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541645, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541645], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541645 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541645,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541645]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$541645] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$541645[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$541645] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$541645[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$541645] = {HoldPattern[
               System`TradingChartDump`$min$541645[1]] :> 0.46}}, {
          DownValues[System`TradingChartDump`$max$541645] = {HoldPattern[
               System`TradingChartDump`$max$541645[1]] :> 100.}}, {
          DownValues[System`TradingChartDump`$subplotvalue$541645] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$541645[1, 1]] :> 
             Invisible[84.52], HoldPattern[
               System`TradingChartDump`$subplotvalue$541645[1, 2]] :> 
             Invisible[85.69]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$541645] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$541645[1]] :> {50, 
              100}}}, {
          DownValues[System`TradingChartDump`$layoutData$541645] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$541645["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "AllValues"]] :> CompressedData["
1:eJxFVwk4lVsXppIh0aCkJH7kIJGzv72PhCUVlTKkQVcqXSKKkooGqWSoaLjI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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541645["AppendedAdjust"]] :> 
             9.954498092839758, HoldPattern[
               System`TradingChartDump`$layoutData$541645["AppendedBox"]] :> {
              0.38676621086206414`, 130.}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "AppendedMin"]] :> -4.522229974817451, HoldPattern[
               System`TradingChartDump`$layoutData$541645["AppendedRatio"]] :> 
             0.9999999999999999, HoldPattern[
               System`TradingChartDump`$layoutData$541645["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$541645["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$541645["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541645["DataMax"]] :> 
             24.95, HoldPattern[
               System`TradingChartDump`$layoutData$541645["DataMin"]] :> 
             19.376947890818858`, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "MainChartAllValues"]] :> CompressedData["
1:eJxFVwk81csXp5Il0aKkJP4Rkcid38yVcCRRKUta9KToka2QVLRok6Wi5SFb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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "MainChartPoints"]] :> CompressedData["
1:eJxdV1toXFUUvRZFKYIKBf0ocapS6oNSTR/xEbubNk2apk1mMslkksnkztyZ
O487M6n4IxXhIuRHhFAoSEVkRBFBEEEKoV+X+CGIIoJQBJEpQhEiUpCK9MuZ
2Wt97HMhDOvuu886e+3HOTlQ3shU7/c8717/7z787fH43DkZDp7bo4IX+itH
gR+SW5f3fTV1gPhR6aP+K+J9srVz91DhEeInpDB48RvX2y/TwwVoT8nem59e
Gp8hfkreGB+8IX5G188SH1T+EvEh+Su9PbIZET+n/HPEL8i3fbg1QXzY4T8i
T27upreLxC9Kpr/cbpr4JSf+URmGe5j4qMa3n/iYDN3/Y7zHHb1OOP5j8tml
fsBPE78sQ/0PEr/irPeq6rWX9tfkw2v951fax+XtgWD3iF/X+D7m9yeV7w9i
0fW+B47FsZ/Cfo/Bfgr6AnsTut+Q9gkZbi9H+2kZ0I9s0n5a/u2nY+c67Wd0
f7/Tfgbx0j4pP/4weGif1Hzu0H5W7e/TflaeHSbkOOxT0BM4npJheY3TPq18
Y7RPY/+0n0O90X5O9XqP9hnVP0/7DOqf9vNOfOdldPD8w/3Pav3u0j6LfqL/
BYvjC87+Ltp44oua/8tcfw56cP05/U2Y33n9/gawODieV/6rwMk84qd/WuP9
if5p7a/v6J9W/W7RP635epj7y6h+1+ifsf0YZxAP/R27t6D6PU//Ba2Pd1H/
8YLubws4WdB6+Jz9kbX9Jlnbz3HWrp9kUc/kX7R6yCLqgf6Lut5H9F+08XpL
TvxLqs8s/ZeQb/ovaf18Q/+c2m/SP6f9+jf9c5i/9M+hv+i/jPpBPmQZ9cZ6
cXCyjH5g/vLQj/55Xe8d8ufR7+TPo1/Jv2K/lxU7/+MV3X+B/ivOvF1FPum/
ivfc/yrmBf1XrR5ewc4/Kej8v0L+gp2fSUH1+IX+a47/mlP/a47+jt0rqj53
6V/U+L/m/ovav19Q/6Lm+wPqv456oP7ryD/913G+YD4kDvZ8O59Svp1H4uP8
xPe+b+dX7ON8gL3r23mVYP0R4J7v8Jc0nseBUyU7j6Wk/fbACfCXcP4BxyXs
l/wlzAfYE+f7Xgn7A/bKGs8ocKqs9f0J+cvQh/GXES/5y3b9bln12kP+MuIj
fxnnJfkDzDfyB+gHYAkwfxl/oPwd8gfQi/wB5gf5A3xHfmAhf0Xr/THyV5Af
8ldU/0nyV9B/5K9YPboVnH/kr2g932H+KzZfXtXaU1XV5zb1r+L8In9V9/sz
zzvn+24VvKw/Z/1eFecR+UONN2D8oc2PhE78oa2POHTqL0S+yB8in+Snnf1b
s/erVA33XfZfDfMF2K9hfrD/gB8kf832U1JDvshfc+5XdduPKeCA+tehB+u/
Dl7GX8c8JH8d5xn568q3Tf666vUl9W9Y/1TD1o80bP/4DZuPuIHziPXXUL63
WH8N8LH+HbvXxPnK/De13urkb+p8eJP8jj1u2n7pOt8nTcvXc773Iq3PI+SP
7H4lwrwnf2TrNY5wHyd/ZOdHEqGeyB/ZeeK1sJ8x8LdQb+Rv4Zf8LZzH5G/h
vGH+W3Y+JI5/r4X/r8jfduJv23xI2/a331b9/2T9tXF/Yfxtu37SxvlN/jbu
a+TvYD6Qv4P7Avk76HfG33Hmb8eu13W+Tzqof+jb6+A+AOxt4H5E/TewX2DZ
wH1gTP4HLlcf7Q==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541645["NewSubplot"]] :> {
               FinancialIndicator["FastStochastic", 14, 3]}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541645["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "PlotRangeMin"]] :> -4.522229974817451, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$541645["Space"]] :> 2.495, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541645["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, 20}, {250., 20}}], 
                    Line[{{0, 80}, {250., 80}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJxdVwlUE2YSjoCCFiwqVgXUgAcihweCgBwfRyL3EQiHXAkJBEIC0ireGhAo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                    "]]}, {
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Line[CompressedData["
1:eJxdV3dU1NcSJpgIRFAQTJC6WCIoLSIISMJH79J724XdZYEFQYqhqGvjWaIC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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "SubplotIndicatorGridLines"]] :> {{50, 100}}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "FastStochastic"}]], 
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], " ", ""}]]}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["FastStochastic", 14, 3]}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "SubplotIndicatorParameters"]] :> {{{14, 3}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "SubplotIndicatorPoints"]] :> CompressedData["
1:eJxtmQmM3GUZxpdLm1pCC4sUqHVaarOt9Nxu723/e5/dnes/M9tut7P33Rbx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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "SubplotIndicatorValues"]] :> CompressedData["
1:eJxVlwlsFGUYhguIEIRAochpbaGSFoXSlra09Pi7Pbbttt3dmZ2ZxVQ8EDCK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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$541645["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$541645["YRange"]] :> 24.95,
              HoldPattern[
               System`TradingChartDump`$layoutData$541645[
               "SubplotPoints", {1}]] :> CompressedData["
1:eJxVlwlsFGUYhguIkAqBQpHT2kIlLQqlLW1p6fH33LbbdndndmYWU/FAwCiG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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541645[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$541645[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$541645[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$541645[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$541645[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$541645 = 
           System`TradingChartDump`$length$541645; 
          System`TradingChartDump`$layoutData$541645["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$541645; 
          System`TradingChartDump`$modelData$541645["Data"] = 
           System`TradingChartDump`$data$541645; 
          System`TradingChartDump`$modelData$541645["Indicators"] = 
           System`TradingChartDump`$indicators$541645; 
          System`TradingChartDump`$layoutData$541645[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541645["ScalingFunctions"] = {
            System`TradingChartDump`$sy$541645, 
             System`TradingChartDump`$isy$541645}; 
          System`TradingChartDump`$layoutData$541645["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541645["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541645[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541645["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$541645["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$541645, 
            System`TradingChartDump`$layoutData$541645, 
            System`TradingChartDump`$indicators$541645]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$541645, 
            System`TradingChartDump`$layoutData$541645, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$541645[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$541645["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$541645[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$541645[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$541645["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$541645[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$541645 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541645["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541645, 
                 System`TradingChartDump`$controlmax$541645}]]]; 
          System`TradingChartDump`$plotrangemax$541645 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541645["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541645, 
                 System`TradingChartDump`$controlmax$541645}]]]; {
            System`TradingChartDump`$plotrangemin$541645, 
             System`TradingChartDump`$plotrangemax$541645} = ReplaceAll[
             
             System`TradingChartDump`$sy$541645[{
              System`TradingChartDump`$plotrangemin$541645, 
               System`TradingChartDump`$plotrangemax$541645}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$541645[
                Min[System`TradingChartDump`$lows$541645]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$541645 == 
            System`TradingChartDump`$plotrangemax$541645, {
             System`TradingChartDump`$plotrangemin$541645, 
              System`TradingChartDump`$plotrangemax$541645} = {
             System`TradingChartDump`$plotrangemin$541645 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$541645], 
              System`TradingChartDump`$plotrangemax$541645 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$541645]}]; 
          System`TradingChartDump`$newgridlines$541645 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$541645, 
            Part[System`TradingChartDump`$newgridlines$541645, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$541645, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$541645], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$541645, 1]]; 
            Part[System`TradingChartDump`$newgridlines$541645, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$541645, 1] =!= None,
                 System`TradingChartDump`$length$541645 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$541645, 
                 Part[System`TradingChartDump`$newgridlines$541645, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$541645, 1]]; 
            System`TradingChartDump`$subpricegridlines$541645 = 
             Part[System`TradingChartDump`$gridlines$541645, 2]; 
            Part[System`TradingChartDump`$newgridlines$541645, 2] = 
             If[System`TradingChartDump`$sy$541645 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541645}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541645, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541645, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$541645, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$541645, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541645}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541645, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541645, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$541645 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$541645]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"GE\"", "\" with \"", 
           "\"FastStochastic\"", "\"(\"", "14", "\",\"", "3", "\",\"", "", 
           "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {720., -167.4}, 
      ImageScaled[{0.5, 0.5}], {450, 310}]}, {InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$541660 = 
        "Full", System`TradingChartDump`$highlightposition$541660 = Automatic,
         System`TradingChartDump`$maxohlc$541660 = 24.95`4., 
        System`TradingChartDump`$timestampstyle$541660 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$541660 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$541660 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$541660, 
        System`TradingChartDump`$subplotpoint$541660, 
        System`TradingChartDump`$ndigits$541660 = 4, 
        System`TradingChartDump`$highlightstyle$541660 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$541660 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$541660 = True, 
        System`TradingChartDump`$timestampQ$541660 = True, 
        System`TradingChartDump`$data$541660 = {{{2012, 7, 26}, {
          19.55155642023346, 20.035505836575872`, 19.512840466926068`, 19.9, 
           57275600}}, {{2012, 7, 27}, {
          19.96928776290631, 20.327437858508603`, 19.901529636711278`, 20.25, 
           80268300}}, {{2012, 7, 30}, {
          20.120322115384614`, 20.236456730769227`, 20.023543269230768`, 
           20.13, 44993600}}, {{2012, 7, 31}, {
          20.08, 20.21547951807229, 20.08, 20.08, 38328400}}, {{2012, 8, 1}, {
          20.185798359864926`, 20.27288953207911, 20.040646406174623`, 20.06, 
           35734300}}, {{2012, 8, 2}, {
          19.860000000000003`, 20.03421052631579, 19.55029239766082, 19.86, 
           44000400}}, {{2012, 8, 3}, {
          20.144541984732825`, 20.318702290076335`, 20.096164122137402`, 
           20.28, 37891500}}, {{2012, 8, 6}, {
          20.29, 20.493190271816882`, 20.22226990939437, 20.29, 34159500}}, {{
          2012, 8, 7}, {
          20.459356060606062`, 20.507746212121216`, 20.410965909090912`, 
           20.44, 31115300}}, {{2012, 8, 8}, {
          20.36870537839124, 20.407410756782483`, 20.22356020942408, 20.33, 
           32345900}}, {{2012, 8, 9}, {
          20.263874643874647`, 20.43806267806268, 20.263874643874647`, 20.38, 
           31159700}}, {{2012, 8, 10}, {
          20.323222748815166`, 20.42, 20.265156398104267`, 20.42, 
           24419100}}, {{2012, 8, 13}, {
          20.358380181038587`, 20.377732253454024`, 20.2035636017151, 20.31, 
           26873600}}, {{2012, 8, 14}, {
          20.395453677172874`, 20.42447946513849, 20.22129894937918, 20.26, 
           30095000}}, {{2012, 8, 15}, {
          20.18324427480916, 20.34772900763359, 20.11551526717557, 20.28, 
           28870100}}, {{2012, 8, 16}, {
          20.195814726840858`, 20.457092636579574`, 20.147429928741094`, 
           20.37, 33598000}}, {{2012, 8, 17}, {
          20.33935238095238, 20.368380952380953`, 20.26194285714286, 20.32, 
           30032500}}, {{2012, 8, 20}, {
          20.269350215002387`, 20.33707596751075, 20.153248924988052`, 20.25, 
           27385500}}, {{2012, 8, 21}, {
          20.296143884892086`, 20.373573141486812`, 20.131606714628298`, 
           20.18, 30438800}}, {{2012, 8, 22}, {
          20.100322425409047`, 20.197098171318576`, 20.04225697786333, 20.11, 
           28016800}}, {{2012, 8, 23}, {
          20.06675387596899, 20.115130813953485`, 19.960324612403095`, 19.97, 
           36538800}}, {{2012, 8, 24}, {
          19.92676442307692, 20.22677884615384, 19.888052884615384`, 20.13, 
           29338200}}, {{2012, 8, 27}, {
          20.15096402877698, 20.276786570743404`, 20.121928057553955`, 20.18, 
           28775600}}, {{2012, 8, 28}, {
          20.09160980297934, 20.246458433445465`, 20.09160980297934, 20.14, 
           25912400}}, {{2012, 8, 29}, {
          20.15, 20.275816522574445`, 20.140321805955807`, 20.15, 
           19925800}}, {{2012, 8, 30}, {
          20.04740310077519, 20.10545542635659, 19.9506492248062, 19.97, 
           21237800}}, {{2012, 8, 31}, {
          20.08838242394978, 20.156117817479473`, 19.94323515210043, 20.04, 
           29679000}}, {{2012, 9, 4}, {
          19.966138469039493`, 20.024207703559238`, 19.820965382740127`, 
           19.85, 38173600}}, {{2012, 9, 5}, {
          19.883244552058112`, 20.096106537530268`, 19.84454237288136, 19.98, 
           33033500}}, {{2012, 9, 6}, {
          20.19424683247302, 20.629676208352887`, 20.17489441576725, 20.62, 
           53178600}}, {{2012, 9, 7}, {
          20.628754052802222`, 20.89, 20.609402501157945`, 20.89, 
           36379800}}, {{2012, 9, 10}, {
          20.79, 20.954539106145248`, 20.741606145251396`, 20.79, 
           33672300}}, {{2012, 9, 11}, {
          20.7932422417786, 20.9867577582214, 20.70616025937934, 20.89, 
           33593100}}, {{2012, 9, 12}, {
          20.967135678391962`, 21.218702603928733`, 20.957460027409777`, 
           21.18, 43006000}}, {{2012, 9, 13}, {
          21.0680608537693, 21.522906448683013`, 21.048705722070842`, 21.31, 
           111794200}}, {{2012, 9, 14}, {
          21.487109905020354`, 21.651650836725466`, 21.27417458163727, 21.4, 
           100148400}}, {{2012, 9, 17}, {
          21.22386394557823, 21.34, 21.194829931972787`, 21.34, 79283200}}, {{
          2012, 9, 18}, {
          21.278093525179855`, 21.52, 21.24906474820144, 21.52, 38831200}}, {{
          2012, 9, 19}, {
          21.584172982612575`, 21.768074008024968`, 21.535777975925104`, 
           21.71, 40462600}}, {{2012, 9, 20}, {
          21.63599197503344, 21.909001337494427`, 21.567739634418192`, 21.87, 
           43677000}}, {{2012, 9, 21}, {
          21.989502885042164`, 22.126023080337326`, 21.901739902352418`, 
           21.97, 66551700}}, {{2012, 9, 24}, {
          21.838998211091234`, 21.887745974955276`, 21.74150268336315, 21.8, 
           36799800}}, {{2012, 9, 25}, {
          21.8380277902286, 22.11112505602869, 21.750246526221428`, 21.76, 
           47039200}}, {{2012, 9, 26}, {
          21.608506787330317`, 21.69626696832579, 21.520746606334843`, 21.55, 
           41123300}}, {{2012, 9, 27}, {
          21.682287725472943`, 22.286739991201056`, 21.575046194456664`, 
           22.16, 67300400}}, {{2012, 9, 28}, {
          22.20852047556142, 22.393835314839276`, 22.062219286657857`, 22.15, 
           70926100}}, {{2012, 10, 1}, {
          22.161999123191585`, 22.42525208241999, 22.14249890398948, 22.24, 
           42550700}}, {{2012, 10, 2}, {
          22.3564984642387, 22.414997806055286`, 22.142000877577885`, 22.22, 
           45297400}}, {{2012, 10, 3}, {
          22.29124399825404, 22.40825840244435, 22.154727193365343`, 22.34, 
           32929400}}, {{2012, 10, 4}, {
          22.38, 22.477516339869283`, 22.204470588235292`, 22.38, 
           40344600}}, {{2012, 10, 5}, {
          22.46200692041522, 22.598494809688578`, 22.423010380622834`, 22.54, 
           38312500}}, {{2012, 10, 8}, {
          22.301243455497385`, 22.418259162303666`, 22.281740837696336`, 
           22.35, 24202200}}, {{2012, 10, 9}, {
          22.37207780725022, 22.401335101679926`, 22.04049513704686, 22.06, 
           39176000}}, {{2012, 10, 10}, {
          22.04550601872492, 22.17226036558181, 21.850499331252788`, 21.87, 
           32784100}}, {{2012, 10, 11}, {
          22.02800977343403, 22.14502443358507, 21.92074633496224, 21.95, 
           24161800}}, {{2012, 10, 12}, {
          22.017508896797153`, 22.144270462633454`, 21.851743772241996`, 
           21.92, 32954600}}, {{2012, 10, 15}, {
          21.98247349823321, 22.138515901060067`, 21.933710247349822`, 22.08, 
           29578600}}, {{2012, 10, 16}, {
          22.226289752650175`, 22.314063604240282`, 22.01173144876325, 22.08, 
           35668800}}, {{2012, 10, 17}, {
          22.203483195111303`, 22.349751200349196`, 22.154727193365343`, 
           22.34, 28272500}}, {{2012, 10, 18}, {
          22.24, 22.50325295922841, 22.230249890398948`, 22.24, 43140700}}, {{
          2012, 10, 19}, {
          21.9480163413527, 21.967517022242397`, 21.323994552882436`, 21.48, 
           107879900}}, {{2012, 10, 22}, {
          21.316018433179725`, 21.40377880184332, 20.72119815668203, 21.16, 
           86735100}}, {{2012, 10, 23}, {
          20.81825657894737, 20.867011278195488`, 20.671992481203006`, 20.75, 
           56297300}}, {{2012, 10, 24}, {
          20.8957619943556, 20.925014111006586`, 20.71049858889934, 20.73, 
           42295500}}, {{2012, 10, 25}, {
          20.964016933207905`, 21.032271872060207`, 20.505733772342428`, 
           20.73, 45769600}}, {{2012, 10, 26}, {
          20.657991473235434`, 20.862719090478446`, 20.541004263382284`, 
           20.58, 42827400}}, {{2012, 10, 31}, {
          20.735061728395063`, 20.79358024691358, 20.452222222222222`, 20.54, 
           39179300}}, {{2012, 11, 1}, {
          20.50769915651359, 20.858758200562324`, 20.497947516401123`, 20.81, 
           46231300}}, {{2012, 11, 2}, {
          20.994528390427032`, 21.14079774753637, 20.731243547630225`, 20.78, 
           47475200}}, {{2012, 11, 5}, {
          20.67519850537132, 20.938514712751047`, 20.67519850537132, 20.88, 
           30000100}}, {{2012, 11, 6}, {
          20.972000926354795`, 21.235247799907366`, 20.913501621120886`, 
           21.05, 32733200}}, {{2012, 11, 7}, {
          20.824230951254144`, 20.980217699952675`, 20.54150496923805, 20.6, 
           45253400}}, {{2012, 11, 8}, {
          20.633279080899953`, 20.66253231211106, 20.36024892292963, 20.37, 
           40770700}}, {{2012, 11, 9}, {
          20.245942857142857`, 20.77257142857143, 20.18742857142857, 20.48, 
           40306800}}, {{2012, 11, 12}, {
          20.51626615605553, 20.613776926759215`, 20.36024892292963, 20.37, 
           21816400}}, {{2012, 11, 13}, {
          20.091972920696332`, 20.433341392649908`, 20.06271276595745, 20.17, 
           41073300}}, {{2012, 11, 14}, {
          20.21200899550225, 20.231509245377314`, 19.451499250374813`, 19.51, 
           65539500}}, {{2012, 11, 15}, {
          19.403988035892322`, 19.72576271186441, 19.403988035892322`, 19.56, 
           51760300}}, {{2012, 11, 16}, {
          19.601240694789084`, 19.689007444168734`, 19.376947890818858`, 
           19.65, 45287500}}, {{2012, 11, 19}, {
          19.90617134559535, 20.208518877057113`, 19.88666505324298, 20.15, 
           38283400}}, {{2012, 11, 20}, {
          20.15876333656644, 20.178268671193017`, 19.8661833171678, 20.11, 
           26845900}}, {{2012, 11, 21}, {
          20.189506769825922`, 20.22852030947776, 20.06271276595745, 20.17, 
           41020400}}, {{2012, 11, 23}, {
          20.295684410646388`, 20.52, 20.217661596958177`, 20.52, 
           35456500}}, {{2012, 11, 26}, {
          20.364444444444445`, 20.549753086419752`, 20.35469135802469, 20.54, 
           47741300}}, {{2012, 11, 27}, {
          20.515764254911353`, 20.67177767129851, 20.330498322951605`, 20.35, 
           33001700}}, {{2012, 11, 28}, {
          20.229777672658468`, 20.619749290444656`, 19.9860454115421, 20.61, 
           34782700}}, {{2012, 11, 29}, {
          20.70724088973024, 20.824230951254144`, 20.42451490771415, 20.6, 
           27632800}}, {{2012, 11, 30}, {
          20.60974917179366, 20.726739233317563`, 20.512257453857078`, 20.6, 
           37857000}}, {{2012, 12, 3}, {
          20.651008645533143`, 20.699759846301635`, 20.280499519692604`, 20.3,
            29981900}}, {{2012, 12, 4}, {
          20.34975071907958, 20.486260786193675`, 20.19373921380633, 20.34, 
           36817200}}, {{2012, 12, 5}, {
          20.38798869524258, 20.8267545925577, 20.339236928874232`, 20.7, 
           46466500}}, {{2012, 12, 6}, {
          20.67421619092185, 20.859503977538605`, 20.557192325690217`, 20.84, 
           32751200}}, {{2012, 12, 7}, {
          20.910493942218082`, 20.94950605778192, 20.71543336439888, 20.93, 
           33548600}}, {{2012, 12, 10}, {
          20.899008882655444`, 20.967274427302478`, 20.830743338008414`, 
           20.86, 27604300}}, {{2012, 12, 11}, {
          20.940753138075312`, 21.203974895397486`, 20.823765690376565`, 
           20.97, 45757200}}, {{2012, 12, 12}, {
          21.074214876033054`, 21.40578512396694, 21.035206611570246`, 21.24, 
           42413600}}, {{2012, 12, 13}, {
          21.197002775208137`, 21.37250693802035, 21.011748381128584`, 21.08, 
           33966000}}, {{2012, 12, 14}, {
          21.07024976873265, 21.21650323774283, 21.011748381128584`, 21.08, 
           47536600}}, {{2012, 12, 17}, {
          21.146019151846783`, 21.399498404012764`, 21.146019151846783`, 
           21.38, 48483700}}, {{2012, 12, 18}, {
          21.30601659751037, 21.36452282157676, 20.876970954356842`, 21.15, 
           81119200}}, {{2012, 12, 19}, {
          21.104407425035696`, 21.123912422655877`, 20.450990004759635`, 
           20.49, 92330700}}, {{2012, 12, 20}, {
          20.57226128266033, 20.89693111638955, 20.532907363420428`, 20.71, 
           50831400}}, {{2012, 12, 21}, {
          20.510632183908047`, 20.658261494252873`, 20.235057471264366`, 
           20.55, 80833800}}, {{2012, 12, 24}, {
          20.460475504322766`, 20.62778097982709, 20.421109510086453`, 20.49, 
           15097200}}, {{2012, 12, 26}, {
          20.479364467982666`, 20.60729898892634, 20.380953298026, 20.44, 
           28557100}}, {{2012, 12, 27}, {
          20.468245529241177`, 20.537129047849202`, 20.094306428226197`, 
           20.36, 38330700}}, {{2012, 12, 28}, {
          20.119838551859097`, 20.375640900195695`, 20.1001614481409, 20.11, 
           32403400}}, {{2012, 12, 31}, {
          19.961338732729867`, 20.65983801810386, 19.931824678418295`, 20.65, 
           58785000}}, {{2013, 1, 2}, {
          21.167291471415183`, 21.196813495782568`, 20.8622305529522, 21., 
           46089500}}, {{2013, 1, 3}, {
          21.133876777251185`, 21.143715639810427`, 20.710805687203795`, 
           20.76, 48509100}}, {{2013, 1, 4}, {
          20.86983962264151, 20.91903773584906, 20.781283018867928`, 20.86, 
           29802600}}, {{2013, 1, 7}, {
          20.819517274017986`, 20.87855182205395, 20.622735447231427`, 20.79, 
           32746700}}, {{2013, 1, 8}, {
          20.766842105263162`, 20.786526315789477`, 20.353473684210527`, 
           20.57, 40045500}}, {{2013, 1, 9}, {
          20.708582338902147`, 20.738109785202866`, 20.600315035799525`, 
           20.62, 28540500}}, {{2013, 1, 10}, {
          20.702087860179493`, 20.88903637222484, 20.623372697213032`, 20.83, 
           33348200}}, {{2013, 1, 11}, {
          20.87855182205395, 20.898230004732607`, 20.68176999526739, 20.79, 
           41839700}}, {{2013, 1, 14}, {
          20.83903409090909, 20.898068181818182`, 20.730804924242427`, 20.78, 
           31715900}}, {{2013, 1, 15}, {
          20.70256603773585, 20.86983962264151, 20.673047169811323`, 20.86, 
           26551000}}, {{2013, 1, 16}, {
          20.809517045454545`, 20.858712121212122`, 20.72096590909091, 20.78, 
           38932100}}, {{2013, 1, 17}, {
          20.88127699530516, 21.196169014084504`, 20.78287323943662, 20.96, 
           63851700}}, {{2013, 1, 18}, {
          21.591588021778588`, 21.83761796733213, 21.247146098003633`, 21.69, 
           113079400}}, {{2013, 1, 22}, {
          21.82729668332576, 21.846978646069967`, 21.55174920490686, 21.66, 
           55165800}}, {{2013, 1, 23}, {
          21.629361896080216`, 21.67856426618049, 21.40303099361896, 21.59, 
           47228500}}, {{2013, 1, 24}, {
          21.611428571428572`, 21.837777777777777`, 21.6015873015873, 21.7, 
           46991100}}, {{2013, 1, 25}, {
          21.920161507402426`, 21.949676985195154`, 21.752907133243607`, 
           21.93, 41919800}}, {{2013, 1, 28}, {
          22.080960000000005`, 22.179360000000003`, 21.903840000000002`, 
           22.14, 49558400}}, {{2013, 1, 29}, {
          22.13016, 22.21872, 22.041600000000003`, 22.14, 34148000}}, {{2013, 
          1, 30}, {
          22.155303643724697`, 22.184817813765186`, 21.87, 21.87, 
           36200400}}, {{2013, 1, 31}, {
          21.85113105924596, 22.03806104129264, 21.8216157989228, 21.92, 
           34427700}}, {{2013, 2, 1}, {
          22.073023872679045`, 22.27968169761273, 21.964774535809017`, 22.26, 
           43840300}}, {{2013, 2, 4}, {
          22.0483863738234, 22.127095472882115`, 21.920484087852984`, 21.95, 
           35836600}}, {{2013, 2, 5}, {
          22.120958296362023`, 22.258722271517303`, 22.091437444543033`, 
           22.18, 30917700}}, {{2013, 2, 6}, {
          22.109518716577536`, 22.139037433155078`, 21.952085561497324`, 
           22.08, 42985800}}, {{2013, 2, 7}, {
          22.139679715302492`, 22.14951957295374, 21.913362989323847`, 22.12, 
           38325900}}, {{2013, 2, 8}, {
          22.14, 22.19904, 22.0908, 22.14, 24424600}}, {{2013, 2, 11}, {
          22.129358574610244`, 22.14903786191537, 21.99160356347439, 22.09, 
           19738700}}, {{2013, 2, 12}, {
          22.121594331266607`, 22.288883968113375`, 22.121594331266607`, 
           22.22, 34297500}}, {{2013, 2, 13}, {
          22.744429243266353`, 23.108576314664386`, 22.675536554082942`, 
           23.02, 84926900}}, {{2013, 2, 14}, {
          22.882528833831696`, 23.11873558308415, 22.74474156343443, 23.04, 
           53996500}}, {{2013, 2, 15}, {
          23.106981537140406`, 23.175869471876346`, 22.86095319879777, 22.92, 
           39283000}}, {{2013, 2, 19}, {
          23.04528, 23.37, 23.03544, 23.37, 41219000}}, {{2013, 2, 20}, {
          23.33525843656557, 23.374626228107648`, 22.980948312686888`, 23.04, 
           38107400}}, {{2013, 2, 21}, {
          23.000619088564054`, 23.169303525365432`, 22.9410834049871, 23.08, 
           47811200}}, {{2013, 2, 22}, {
          23.1603249251817, 23.259512612227446`, 23.041299700726807`, 23.2, 
           27836300}}, {{2013, 2, 25}, {
          23.314555019728193`, 23.344318281455507`, 22.630000000000003`, 
           22.63, 51619800}}, {{2013, 2, 26}, {
          22.790624728850325`, 22.96921908893709, 22.73109327548807, 22.87, 
           41316300}}, {{2013, 2, 27}, {
          22.83284552845528, 23.20975609756097, 22.813008130081297`, 23.18, 
           29676400}}, {{2013, 2, 28}, {
          23.188837209302328`, 23.27813953488372, 23.02015503875969, 23.04, 
           39714600}}, {{2013, 3, 1}, {
          22.841319534282018`, 23.158835705045277`, 22.821474773609314`, 
           23.01, 41226900}}, {{2013, 3, 4}, {
          22.970928233777396`, 23.09992264718522, 22.851856467554793`, 23.09, 
           25457800}}, {{2013, 3, 5}, {
          23.27104705383637, 23.519033488766425`, 23.251208139041967`, 23.4, 
           35728000}}, {{2013, 3, 6}, {
          23.648635403464297`, 23.648635403464297`, 23.48, 23.48, 
           31539100}}, {{2013, 3, 7}, {
          23.509839527027022`, 23.638796452702696`, 23.480080236486486`, 
           23.49, 22955700}}, {{2013, 3, 8}, {
          23.669280605805636`, 23.708960875052586`, 23.49071939419436, 23.58, 
           28952100}}, {{2013, 3, 11}, {
          23.499436917866216`, 23.558954276037255`, 23.261367485182046`, 
           23.43, 34947200}}, {{2013, 3, 12}, {
          23.39853908586074, 23.408457923964118`, 23.140649295173, 23.22, 
           36593000}}, {{2013, 3, 13}, {
          23.250404427415926`, 23.329757343550448`, 23.21072796934866, 23.3, 
           24152400}}, {{2013, 3, 14}, {
          23.361122836639932`, 23.569438581680036`, 23.321443647108484`, 23.5,
            34629800}}, {{2013, 3, 15}, {
          23.25, 23.527730375426618`, 23.17064846416382, 23.25, 58857200}}, {{
          2013, 3, 18}, {
          22.990619354838714`, 23.169225806451614`, 22.950929032258063`, 
           23.07, 33700000}}, {{2013, 3, 19}, {
          23.12015437392796, 23.17969125214408, 22.991157804459693`, 23.14, 
           36150200}}, {{2013, 3, 20}, {
          23.537813299232738`, 23.607246376811595`, 23.141052855924976`, 
           23.27, 39254000}}, {{2013, 3, 21}, {
          23.238995276942894`, 23.417604121940748`, 23.109999999999996`, 
           23.11, 38543900}}, {{2013, 3, 22}, {
          23.130406504065036`, 23.20975609756097, 23.090731707317072`, 23.18, 
           30606100}}, {{2013, 3, 25}, {
          23.268373493975904`, 23.298141135972465`, 22.87147160068847, 23.06, 
           41684400}}, {{2013, 3, 26}, {
          23.088832179930794`, 23.118598615916955`, 22.830856401384082`, 
           22.94, 32353500}}, {{2013, 3, 27}, {
          22.840623376623377`, 22.95968831168831, 22.671948051948053`, 22.92, 
           27492500}}, {{2013, 3, 28}, {
          22.95984429065744, 23.019377162629755`, 22.81101211072664, 22.94, 
           31151000}}, {{2013, 4, 1}, {
          22.85038994800693, 22.91984402079723, 22.79085788561525, 22.9, 
           27449700}}, {{2013, 4, 2}, {
          22.991311053984575`, 23.189768637532133`, 22.92185089974293, 23.16, 
           29180100}}, {{2013, 4, 3}, {
          23.19702608695652, 23.21686956521739, 22.740626086956524`, 22.82, 
           52570300}}, {{2013, 4, 4}, {
          22.830545927209705`, 22.949610051993066`, 22.780935875216638`, 22.9,
            30472100}}, {{2013, 4, 5}, {
          22.621020497165286`, 22.75992150021806, 22.58133449629307, 22.75, 
           31402200}}, {{2013, 4, 8}, {
          22.870544982698963`, 22.94, 22.652257785467125`, 22.94, 
           30493600}}, {{2013, 4, 9}, {
          23.068516912402426`, 23.068516912402426`, 22.721248915871637`, 
           22.88, 31668200}}, {{2013, 4, 10}, {
          22.913867684478376`, 23.45943596268024, 22.87418999151824, 23.39, 
           39772300}}, {{2013, 4, 11}, {
          23.36032217041119, 23.528952946163628`, 23.241288681644765`, 23.4, 
           27084400}}, {{2013, 4, 12}, {
          23.29975703324808, 23.39894714407502, 23.141052855924976`, 23.27, 
           27234300}}, {{2013, 4, 15}, {
          23.096291100394566`, 23.11613327487944, 22.630000000000003`, 22.63, 
           46453800}}, {{2013, 4, 16}, {
          22.890233766233766`, 22.92, 22.72155844155844, 22.92, 36016700}}, {{
          2013, 4, 17}, {
          22.778418277680135`, 22.847864674868188`, 22.470869947275915`, 
           22.58, 42672900}}, {{2013, 4, 18}, {
          22.579285399206, 22.668570798412, 22.39079400088222, 22.49, 
           41170900}}, {{2013, 4, 19}, {
          21.768514942528736`, 21.85781149425287, 21.44109425287356, 21.58, 
           108837900}}, {{2013, 4, 22}, {
          21.497451990632317`, 21.507372365339577`, 20.94191100702576, 21.18, 
           87828900}}, {{2013, 4, 23}, {
          21.37960465116279, 21.518497674418605`, 21.191106976744184`, 21.33, 
           65489600}}, {{2013, 4, 24}, {
          21.522090163934426`, 21.859458105646628`, 21.482399817850634`, 
           21.79, 51506700}}, {{2013, 4, 25}, {
          22.037986332574036`, 22.05783143507973, 21.74030979498861, 21.78, 
           41462900}}, {{2013, 4, 26}, {
          21.801864025213867`, 22.218460153084195`, 21.791945069788383`, 
           22.03, 47012500}}, {{2013, 4, 29}, {
          22.129676695105523`, 22.139595868881905`, 21.82218230803772, 22.09, 
           36531800}}, {{2013, 4, 30}, {
          22.11, 22.1992732166891, 22.03064602960969, 22.11, 34054800}}, {{
          2013, 5, 1}, {
          21.920406320541762`, 22.168374717832958`, 21.920406320541762`, 
           21.97, 39201600}}, {{2013, 5, 2}, {
          22.070564516129032`, 22.14, 21.971370967741933`, 22.14, 
           27651500}}, {{2013, 5, 3}, {
          22.39, 22.667766947275148`, 22.370159503766065`, 22.39, 
           45523300}}, {{2013, 5, 6}, {
          22.38015943312666, 22.45952170062002, 22.14207263064659, 22.4, 
           28563900}}, {{2013, 5, 7}, {
          22.509920634920633`, 22.60912698412698, 22.44047619047619, 22.5, 
           28211700}}, {{2013, 5, 8}, {
          22.502581486310298`, 22.83992177314211, 22.443050847457627`, 22.83, 
           39977300}}, {{2013, 5, 9}, {
          22.808340649692713`, 22.91747146619842, 22.510711150131694`, 22.6, 
           29974300}}, {{2013, 5, 10}, {
          22.591021834061134`, 22.729921397379915`, 22.412436681222708`, 
           22.72, 35117300}}, {{2013, 5, 13}, {
          22.67992122538293, 22.699763676148795`, 22.441811816192562`, 22.67, 
           30283800}}, {{2013, 5, 14}, {
          22.671251629726207`, 22.889530638852673`, 22.631564537157754`, 
           22.83, 39592300}}, {{2013, 5, 15}, {
          22.86154905335628, 23.069922547332187`, 22.732555938037866`, 23.06, 
           40153000}}, {{2013, 5, 16}, {
          22.921314997851315`, 23.16938117748174, 22.921314997851315`, 23.09, 
           33023300}}, {{2013, 5, 17}, {
          23.081538789428816`, 23.289838022165387`, 23.012105711849955`, 
           23.27, 41037700}}, {{2013, 5, 20}, {
          23.270886720407294`, 23.389919389053876`, 23.241128553245648`, 
           23.38, 32884800}}, {{2013, 5, 21}, {
          23.400562130177512`, 23.58903634826712, 23.400562130177512`, 23.47, 
           33815000}}, {{2013, 5, 22}, {
          23.590637049455157`, 23.937849958088854`, 23.56087594300084, 23.67, 
           68514400}}, {{2013, 5, 23}, {
          23.33112426035503, 23.559277261200336`, 23.261686390532542`, 23.47, 
           44383600}}, {{2013, 5, 24}, {
          23.3102422439439, 23.478869528261797`, 23.3003229919252, 23.34, 
           41015200}}, {{2013, 5, 28}, {
          23.578631355932202`, 23.648067796610167`, 23.39016101694915, 23.41, 
           47323000}}, {{2013, 5, 29}, {
          23.231768189509307`, 23.50951776649746, 23.21192893401015, 23.45, 
           39236500}}, {{2013, 5, 30}, {
          23.39016101694915, 23.56871186440678, 23.310805084745763`, 23.41, 
           29347100}}, {{2013, 5, 31}, {
          23.407915951972555`, 23.606372212692968`, 23.13007718696398, 23.14, 
           49247600}}, {{2013, 6, 3}, {
          23.18217005076142, 23.588874788494078`, 23.132571912013535`, 23.45, 
           45218400}}, {{2013, 6, 4}, {
          23.400562130177512`, 23.569196956889265`, 23.22200760777684, 23.47, 
           38701300}}, {{2013, 6, 5}, {
          23.368224699828474`, 23.397993138936535`, 23.030849056603774`, 
           23.14, 44756200}}, {{2013, 6, 6}, {
          23.06105645851155, 23.19991873396065, 22.9122754491018, 23.19, 
           42677500}}, {{2013, 6, 7}, {
          23.35254819782062, 23.759283319362954`, 23.28310561609388, 23.67, 
           49041200}}, {{2013, 6, 10}, {
          23.689201009251473`, 23.728881412952063`, 23.45111858704794, 23.59, 
           41626500}}, {{2013, 6, 11}, {
          23.300725190839696`, 23.49911365564038, 23.290805767599664`, 23.39, 
           36183000}}, {{2013, 6, 12}, {
          23.508382978723404`, 23.538140425531914`, 23.230646808510638`, 
           23.31, 33842000}}, {{2013, 6, 13}, {
          23.261845439189184`, 23.599117398648644`, 23.152728040540538`, 
           23.49, 34930500}}, {{2013, 6, 14}, {
          23.488707482993195`, 23.55814200680272, 23.27048469387755, 23.33, 
           27846000}}, {{2013, 6, 17}, {
          23.560159865376523`, 23.6593605384939, 23.460959192259146`, 23.58, 
           39278300}}, {{2013, 6, 18}, {
          23.64390464447185, 24.259062885326763`, 23.58437320180847, 24.14, 
           72766900}}, {{2013, 6, 19}, {
          24.008256880733942`, 24.15706839032527, 23.79, 23.79, 46082200}}, {{
          2013, 6, 20}, {23.63, 23.69, 23.2, 23.25, 62733200}}, {{2013, 6, 
          21}, {23.579999999999995`, 23.639999999999997`, 23.209999999999997`,
            23.36, 65025200}}, {{2013, 6, 24}, {
          23.12, 23.15, 22.76, 22.93, 48760800}}, {{2013, 6, 25}, {
          23.169999999999998`, 23.249999999999996`, 22.939999999999998`, 
           23.11, 36569100}}, {{2013, 6, 26}, {
          23.43, 23.44, 23.02, 23.25, 32531700}}, {{2013, 6, 27}, {
          23.41, 23.48, 23.26, 23.32, 30867900}}, {{2013, 6, 28}, {
          23.32, 23.44, 23.16, 23.19, 45923200}}, {{2013, 7, 1}, {
          23.209999999999997`, 23.639999999999997`, 23.189999999999998`, 
           23.34, 35784800}}, {{2013, 7, 2}, {
          23.27, 23.34, 22.88, 22.9, 47571200}}, {{2013, 7, 3}, {
          22.83, 22.98, 22.76, 22.91, 21448500}}, {{2013, 7, 5}, {
          23.17, 23.24, 22.95, 23.24, 22688900}}, {{2013, 7, 8}, {
          23.36, 23.53, 23.27, 23.32, 35481100}}, {{2013, 7, 9}, {
          23.52, 23.8, 23.51, 23.62, 31541400}}, {{2013, 7, 10}, {
          23.719999999999995`, 23.729999999999997`, 23.359999999999996`, 
           23.54, 28457100}}, {{2013, 7, 11}, {
          23.91, 23.96, 23.63, 23.94, 32618400}}, {{2013, 7, 12}, {
          23.99, 24., 23.59, 23.76, 33257700}}, {{2013, 7, 15}, {
          23.73, 23.74, 23.56, 23.63, 35853500}}, {{2013, 7, 16}, {
          23.659999999999997`, 23.669999999999998`, 23.339999999999996`, 
           23.43, 38192400}}, {{2013, 7, 17}, {
          23.539999999999996`, 23.609999999999996`, 23.429999999999996`, 
           23.54, 26858500}}, {{2013, 7, 18}, {
          23.6, 23.94, 23.56, 23.63, 41438200}}, {{2013, 7, 19}, {
          24.21, 24.95, 24.1, 24.72, 103708900}}, {{2013, 7, 22}, {
          24.77, 24.92, 24.73, 24.86, 41560800}}, {{2013, 7, 23}, {
          24.87, 24.88, 24.63, 24.71, 32553000}}, {{2013, 7, 24}, {
          24.79, 24.84, 24.56, 24.62, 27485000}}, {{2013, 7, 25}, {
          24.61, 24.69, 24.52, 24.69, 29951700}}}, 
        System`TradingChartDump`$markerstyle$541660 = 1, 
        System`TradingChartDump`$controlmin$541660 = 0.5, 
        System`TradingChartDump`$controlmax$541660 = 250.5, 
        System`TradingChartDump`$datescope$541660 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$541660 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$541660, 
        System`TradingChartDump`$max$541660, 
        System`TradingChartDump`$ohlclabel$541660 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541660, 
              System`TradingChartDump`$opens$541660]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541660, 
              System`TradingChartDump`$highs$541660]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541660, 
              System`TradingChartDump`$lows$541660]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541660, 
              System`TradingChartDump`$closes$541660]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541660, 
              System`TradingChartDump`$visdates$541660]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$541660 = {}, 
        System`TradingChartDump`$subpricegridlines$541660 = Automatic, 
        System`TradingChartDump`$overlaypoint$541660, 
        System`TradingChartDump`$overlayvalue$541660, 
        System`TradingChartDump`$subplotvalue$541660, 
        System`TradingChartDump`$opts$541660 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "GE", " with ", "FullStochastic", 
            "(", 14, ",", 3, ",", 3, ",", Null, ")"}], 
         ImageSize -> {450, 310}, AlignmentPoint -> Center, AspectRatio -> 
         GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> None, AxesOrigin -> 
         Automatic, AxesStyle -> {}, Background -> None, BaselinePosition -> 
         Automatic, BaseStyle -> {}, ColorOutput -> Automatic, 
         ContentSelectable -> Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$541660 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmglczWkXx2/W7PuSl9RLZClS3WtQPcooqUkLiVT3tt5uC5ooBo09IVt6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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyFmndUVNcWxkfFhihRiF0CAoKABikjiOJRmgrCUJUqMDAgzUKMihKwRohi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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$541660 = 
        System`TradingChartDump`$staticindicatorpos$541660, 
        System`TradingChartDump`$length$541660 = 250, 
        System`TradingChartDump`$gridlinesflag$541660 = True, 
        System`TradingChartDump`$opens$541660 = 
        Dispatch[{
         1 -> 19.55`4., 2 -> 19.97`4., 3 -> 20.12`4., 4 -> 20.08`4., 5 -> 
          20.19`4., 6 -> 19.86`4., 7 -> 20.14`4., 8 -> 20.29`4., 9 -> 
          20.46`4., 10 -> 20.37`4., 11 -> 20.26`4., 12 -> 20.32`4., 13 -> 
          20.36`4., 14 -> 20.4`4., 15 -> 20.18`4., 16 -> 20.2`4., 17 -> 
          20.34`4., 18 -> 20.27`4., 19 -> 20.3`4., 20 -> 20.1`4., 21 -> 
          20.07`4., 22 -> 19.93`4., 23 -> 20.15`4., 24 -> 20.09`4., 25 -> 
          20.15`4., 26 -> 20.05`4., 27 -> 20.09`4., 28 -> 19.97`4., 29 -> 
          19.88`4., 30 -> 20.19`4., 31 -> 20.63`4., 32 -> 20.79`4., 33 -> 
          20.79`4., 34 -> 20.97`4., 35 -> 21.07`4., 36 -> 21.49`4., 37 -> 
          21.22`4., 38 -> 21.28`4., 39 -> 21.58`4., 40 -> 21.64`4., 41 -> 
          21.99`4., 42 -> 21.84`4., 43 -> 21.84`4., 44 -> 21.61`4., 45 -> 
          21.68`4., 46 -> 22.21`4., 47 -> 22.16`4., 48 -> 22.36`4., 49 -> 
          22.29`4., 50 -> 22.38`4., 51 -> 22.46`4., 52 -> 22.3`4., 53 -> 
          22.37`4., 54 -> 22.05`4., 55 -> 22.03`4., 56 -> 22.02`4., 57 -> 
          21.98`4., 58 -> 22.23`4., 59 -> 22.2`4., 60 -> 22.24`4., 61 -> 
          21.95`4., 62 -> 21.32`4., 63 -> 20.82`4., 64 -> 20.9`4., 65 -> 
          20.96`4., 66 -> 20.66`4., 67 -> 20.74`4., 68 -> 20.51`4., 69 -> 
          20.99`4., 70 -> 20.68`4., 71 -> 20.97`4., 72 -> 20.82`4., 73 -> 
          20.63`4., 74 -> 20.25`4., 75 -> 20.52`4., 76 -> 20.09`4., 77 -> 
          20.21`4., 78 -> 19.4`4., 79 -> 19.6`4., 80 -> 19.91`4., 81 -> 
          20.16`4., 82 -> 20.19`4., 83 -> 20.3`4., 84 -> 20.36`4., 85 -> 
          20.52`4., 86 -> 20.23`4., 87 -> 20.71`4., 88 -> 20.61`4., 89 -> 
          20.65`4., 90 -> 20.35`4., 91 -> 20.39`4., 92 -> 20.67`4., 93 -> 
          20.91`4., 94 -> 20.9`4., 95 -> 20.94`4., 96 -> 21.07`4., 97 -> 
          21.2`4., 98 -> 21.07`4., 99 -> 21.15`4., 100 -> 21.31`4., 101 -> 
          21.1`4., 102 -> 20.57`4., 103 -> 20.51`4., 104 -> 20.46`4., 105 -> 
          20.48`4., 106 -> 20.47`4., 107 -> 20.12`4., 108 -> 19.96`4., 109 -> 
          21.17`4., 110 -> 21.13`4., 111 -> 20.87`4., 112 -> 20.82`4., 113 -> 
          20.77`4., 114 -> 20.71`4., 115 -> 20.7`4., 116 -> 20.88`4., 117 -> 
          20.84`4., 118 -> 20.7`4., 119 -> 20.81`4., 120 -> 20.88`4., 121 -> 
          21.59`4., 122 -> 21.83`4., 123 -> 21.63`4., 124 -> 21.61`4., 125 -> 
          21.92`4., 126 -> 22.08`4., 127 -> 22.13`4., 128 -> 22.16`4., 129 -> 
          21.85`4., 130 -> 22.07`4., 131 -> 22.05`4., 132 -> 22.12`4., 133 -> 
          22.11`4., 134 -> 22.14`4., 135 -> 22.14`4., 136 -> 22.13`4., 137 -> 
          22.12`4., 138 -> 22.74`4., 139 -> 22.88`4., 140 -> 23.11`4., 141 -> 
          23.05`4., 142 -> 23.34`4., 143 -> 23.`4., 144 -> 23.16`4., 145 -> 
          23.31`4., 146 -> 22.79`4., 147 -> 22.83`4., 148 -> 23.19`4., 149 -> 
          22.84`4., 150 -> 22.97`4., 151 -> 23.27`4., 152 -> 23.65`4., 153 -> 
          23.51`4., 154 -> 23.67`4., 155 -> 23.5`4., 156 -> 23.4`4., 157 -> 
          23.25`4., 158 -> 23.36`4., 159 -> 23.25`4., 160 -> 22.99`4., 161 -> 
          23.12`4., 162 -> 23.54`4., 163 -> 23.24`4., 164 -> 23.13`4., 165 -> 
          23.27`4., 166 -> 23.09`4., 167 -> 22.84`4., 168 -> 22.96`4., 169 -> 
          22.85`4., 170 -> 22.99`4., 171 -> 23.2`4., 172 -> 22.83`4., 173 -> 
          22.62`4., 174 -> 22.87`4., 175 -> 23.07`4., 176 -> 22.91`4., 177 -> 
          23.36`4., 178 -> 23.3`4., 179 -> 23.1`4., 180 -> 22.89`4., 181 -> 
          22.78`4., 182 -> 22.58`4., 183 -> 21.77`4., 184 -> 21.5`4., 185 -> 
          21.38`4., 186 -> 21.52`4., 187 -> 22.04`4., 188 -> 21.8`4., 189 -> 
          22.13`4., 190 -> 22.11`4., 191 -> 21.92`4., 192 -> 22.07`4., 193 -> 
          22.39`4., 194 -> 22.38`4., 195 -> 22.51`4., 196 -> 22.5`4., 197 -> 
          22.81`4., 198 -> 22.59`4., 199 -> 22.68`4., 200 -> 22.67`4., 201 -> 
          22.86`4., 202 -> 22.92`4., 203 -> 23.08`4., 204 -> 23.27`4., 205 -> 
          23.4`4., 206 -> 23.59`4., 207 -> 23.33`4., 208 -> 23.31`4., 209 -> 
          23.58`4., 210 -> 23.23`4., 211 -> 23.39`4., 212 -> 23.41`4., 213 -> 
          23.18`4., 214 -> 23.4`4., 215 -> 23.37`4., 216 -> 23.06`4., 217 -> 
          23.35`4., 218 -> 23.69`4., 219 -> 23.3`4., 220 -> 23.51`4., 221 -> 
          23.26`4., 222 -> 23.49`4., 223 -> 23.56`4., 224 -> 23.64`4., 225 -> 
          24.01`4., 226 -> 23.63`4., 227 -> 23.58`4., 228 -> 23.12`4., 229 -> 
          23.17`4., 230 -> 23.43`4., 231 -> 23.41`4., 232 -> 23.32`4., 233 -> 
          23.21`4., 234 -> 23.27`4., 235 -> 22.83`4., 236 -> 23.17`4., 237 -> 
          23.36`4., 238 -> 23.52`4., 239 -> 23.72`4., 240 -> 23.91`4., 241 -> 
          23.99`4., 242 -> 23.73`4., 243 -> 23.66`4., 244 -> 23.54`4., 245 -> 
          23.6`4., 246 -> 24.21`4., 247 -> 24.77`4., 248 -> 24.87`4., 249 -> 
          24.79`4., 250 -> 24.61`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$541660 = 
        Dispatch[{
         1 -> 20.04`4., 2 -> 20.33`4., 3 -> 20.24`4., 4 -> 20.22`4., 5 -> 
          20.27`4., 6 -> 20.03`4., 7 -> 20.32`4., 8 -> 20.49`4., 9 -> 
          20.51`4., 10 -> 20.41`4., 11 -> 20.44`4., 12 -> 20.42`4., 13 -> 
          20.38`4., 14 -> 20.42`4., 15 -> 20.35`4., 16 -> 20.46`4., 17 -> 
          20.37`4., 18 -> 20.34`4., 19 -> 20.37`4., 20 -> 20.2`4., 21 -> 
          20.12`4., 22 -> 20.23`4., 23 -> 20.28`4., 24 -> 20.25`4., 25 -> 
          20.28`4., 26 -> 20.11`4., 27 -> 20.16`4., 28 -> 20.02`4., 29 -> 
          20.1`4., 30 -> 20.63`4., 31 -> 20.89`4., 32 -> 20.95`4., 33 -> 
          20.99`4., 34 -> 21.22`4., 35 -> 21.52`4., 36 -> 21.65`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.77`4., 40 -> 21.91`4., 41 -> 
          22.13`4., 42 -> 21.89`4., 43 -> 22.11`4., 44 -> 21.7`4., 45 -> 
          22.29`4., 46 -> 22.39`4., 47 -> 22.43`4., 48 -> 22.41`4., 49 -> 
          22.41`4., 50 -> 22.48`4., 51 -> 22.6`4., 52 -> 22.42`4., 53 -> 
          22.4`4., 54 -> 22.17`4., 55 -> 22.15`4., 56 -> 22.14`4., 57 -> 
          22.14`4., 58 -> 22.31`4., 59 -> 22.35`4., 60 -> 22.5`4., 61 -> 
          21.97`4., 62 -> 21.4`4., 63 -> 20.87`4., 64 -> 20.93`4., 65 -> 
          21.03`4., 66 -> 20.86`4., 67 -> 20.79`4., 68 -> 20.86`4., 69 -> 
          21.14`4., 70 -> 20.94`4., 71 -> 21.24`4., 72 -> 20.98`4., 73 -> 
          20.66`4., 74 -> 20.77`4., 75 -> 20.61`4., 76 -> 20.43`4., 77 -> 
          20.23`4., 78 -> 19.73`4., 79 -> 19.69`4., 80 -> 20.21`4., 81 -> 
          20.18`4., 82 -> 20.23`4., 83 -> 20.52`4., 84 -> 20.55`4., 85 -> 
          20.67`4., 86 -> 20.62`4., 87 -> 20.82`4., 88 -> 20.73`4., 89 -> 
          20.7`4., 90 -> 20.49`4., 91 -> 20.83`4., 92 -> 20.86`4., 93 -> 
          20.95`4., 94 -> 20.97`4., 95 -> 21.2`4., 96 -> 21.41`4., 97 -> 
          21.37`4., 98 -> 21.22`4., 99 -> 21.4`4., 100 -> 21.36`4., 101 -> 
          21.12`4., 102 -> 20.9`4., 103 -> 20.66`4., 104 -> 20.63`4., 105 -> 
          20.61`4., 106 -> 20.54`4., 107 -> 20.38`4., 108 -> 20.66`4., 109 -> 
          21.2`4., 110 -> 21.14`4., 111 -> 20.92`4., 112 -> 20.88`4., 113 -> 
          20.79`4., 114 -> 20.74`4., 115 -> 20.89`4., 116 -> 20.9`4., 117 -> 
          20.9`4., 118 -> 20.87`4., 119 -> 20.86`4., 120 -> 21.2`4., 121 -> 
          21.84`4., 122 -> 21.85`4., 123 -> 21.68`4., 124 -> 21.84`4., 125 -> 
          21.95`4., 126 -> 22.18`4., 127 -> 22.22`4., 128 -> 22.18`4., 129 -> 
          22.04`4., 130 -> 22.28`4., 131 -> 22.13`4., 132 -> 22.26`4., 133 -> 
          22.14`4., 134 -> 22.15`4., 135 -> 22.2`4., 136 -> 22.15`4., 137 -> 
          22.29`4., 138 -> 23.11`4., 139 -> 23.12`4., 140 -> 23.18`4., 141 -> 
          23.37`4., 142 -> 23.37`4., 143 -> 23.17`4., 144 -> 23.26`4., 145 -> 
          23.34`4., 146 -> 22.97`4., 147 -> 23.21`4., 148 -> 23.28`4., 149 -> 
          23.16`4., 150 -> 23.1`4., 151 -> 23.52`4., 152 -> 23.65`4., 153 -> 
          23.64`4., 154 -> 23.71`4., 155 -> 23.56`4., 156 -> 23.41`4., 157 -> 
          23.33`4., 158 -> 23.57`4., 159 -> 23.53`4., 160 -> 23.17`4., 161 -> 
          23.18`4., 162 -> 23.61`4., 163 -> 23.42`4., 164 -> 23.21`4., 165 -> 
          23.3`4., 166 -> 23.12`4., 167 -> 22.96`4., 168 -> 23.02`4., 169 -> 
          22.92`4., 170 -> 23.19`4., 171 -> 23.22`4., 172 -> 22.95`4., 173 -> 
          22.76`4., 174 -> 22.94`4., 175 -> 23.07`4., 176 -> 23.46`4., 177 -> 
          23.53`4., 178 -> 23.4`4., 179 -> 23.12`4., 180 -> 22.92`4., 181 -> 
          22.85`4., 182 -> 22.67`4., 183 -> 21.86`4., 184 -> 21.51`4., 185 -> 
          21.52`4., 186 -> 21.86`4., 187 -> 22.06`4., 188 -> 22.22`4., 189 -> 
          22.14`4., 190 -> 22.2`4., 191 -> 22.17`4., 192 -> 22.14`4., 193 -> 
          22.67`4., 194 -> 22.46`4., 195 -> 22.61`4., 196 -> 22.84`4., 197 -> 
          22.92`4., 198 -> 22.73`4., 199 -> 22.7`4., 200 -> 22.89`4., 201 -> 
          23.07`4., 202 -> 23.17`4., 203 -> 23.29`4., 204 -> 23.39`4., 205 -> 
          23.59`4., 206 -> 23.94`4., 207 -> 23.56`4., 208 -> 23.48`4., 209 -> 
          23.65`4., 210 -> 23.51`4., 211 -> 23.57`4., 212 -> 23.61`4., 213 -> 
          23.59`4., 214 -> 23.57`4., 215 -> 23.4`4., 216 -> 23.2`4., 217 -> 
          23.76`4., 218 -> 23.73`4., 219 -> 23.5`4., 220 -> 23.54`4., 221 -> 
          23.6`4., 222 -> 23.56`4., 223 -> 23.66`4., 224 -> 24.26`4., 225 -> 
          24.16`4., 226 -> 23.69`4., 227 -> 23.64`4., 228 -> 23.15`4., 229 -> 
          23.25`4., 230 -> 23.44`4., 231 -> 23.48`4., 232 -> 23.44`4., 233 -> 
          23.64`4., 234 -> 23.34`4., 235 -> 22.98`4., 236 -> 23.24`4., 237 -> 
          23.53`4., 238 -> 23.8`4., 239 -> 23.73`4., 240 -> 23.96`4., 241 -> 
          24.`4., 242 -> 23.74`4., 243 -> 23.67`4., 244 -> 23.61`4., 245 -> 
          23.94`4., 246 -> 24.95`4., 247 -> 24.92`4., 248 -> 24.88`4., 249 -> 
          24.84`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$541660 = 
        Dispatch[{
         1 -> 19.51`4., 2 -> 19.9`4., 3 -> 20.02`4., 4 -> 20.08`4., 5 -> 
          20.04`4., 6 -> 19.55`4., 7 -> 20.1`4., 8 -> 20.22`4., 9 -> 20.41`4.,
           10 -> 20.22`4., 11 -> 20.26`4., 12 -> 20.27`4., 13 -> 20.2`4., 14 -> 
          20.22`4., 15 -> 20.12`4., 16 -> 20.15`4., 17 -> 20.26`4., 18 -> 
          20.15`4., 19 -> 20.13`4., 20 -> 20.04`4., 21 -> 19.96`4., 22 -> 
          19.89`4., 23 -> 20.12`4., 24 -> 20.09`4., 25 -> 20.14`4., 26 -> 
          19.95`4., 27 -> 19.94`4., 28 -> 19.82`4., 29 -> 19.84`4., 30 -> 
          20.17`4., 31 -> 20.61`4., 32 -> 20.74`4., 33 -> 20.71`4., 34 -> 
          20.96`4., 35 -> 21.05`4., 36 -> 21.27`4., 37 -> 21.19`4., 38 -> 
          21.25`4., 39 -> 21.54`4., 40 -> 21.57`4., 41 -> 21.9`4., 42 -> 
          21.74`4., 43 -> 21.75`4., 44 -> 21.52`4., 45 -> 21.58`4., 46 -> 
          22.06`4., 47 -> 22.14`4., 48 -> 22.14`4., 49 -> 22.15`4., 50 -> 
          22.2`4., 51 -> 22.42`4., 52 -> 22.28`4., 53 -> 22.04`4., 54 -> 
          21.85`4., 55 -> 21.92`4., 56 -> 21.85`4., 57 -> 21.93`4., 58 -> 
          22.01`4., 59 -> 22.15`4., 60 -> 22.23`4., 61 -> 21.32`4., 62 -> 
          20.72`4., 63 -> 20.67`4., 64 -> 20.71`4., 65 -> 20.51`4., 66 -> 
          20.54`4., 67 -> 20.45`4., 68 -> 20.5`4., 69 -> 20.73`4., 70 -> 
          20.68`4., 71 -> 20.91`4., 72 -> 20.54`4., 73 -> 20.36`4., 74 -> 
          20.19`4., 75 -> 20.36`4., 76 -> 20.06`4., 77 -> 19.45`4., 78 -> 
          19.4`4., 79 -> 19.38`4., 80 -> 19.89`4., 81 -> 19.87`4., 82 -> 
          20.06`4., 83 -> 20.22`4., 84 -> 20.35`4., 85 -> 20.33`4., 86 -> 
          19.99`4., 87 -> 20.42`4., 88 -> 20.51`4., 89 -> 20.28`4., 90 -> 
          20.19`4., 91 -> 20.34`4., 92 -> 20.56`4., 93 -> 20.72`4., 94 -> 
          20.83`4., 95 -> 20.82`4., 96 -> 21.04`4., 97 -> 21.01`4., 98 -> 
          21.01`4., 99 -> 21.15`4., 100 -> 20.88`4., 101 -> 20.45`4., 102 -> 
          20.53`4., 103 -> 20.24`4., 104 -> 20.42`4., 105 -> 20.38`4., 106 -> 
          20.09`4., 107 -> 20.1`4., 108 -> 19.93`4., 109 -> 20.86`4., 110 -> 
          20.71`4., 111 -> 20.78`4., 112 -> 20.62`4., 113 -> 20.35`4., 114 -> 
          20.6`4., 115 -> 20.62`4., 116 -> 20.68`4., 117 -> 20.73`4., 118 -> 
          20.67`4., 119 -> 20.72`4., 120 -> 20.78`4., 121 -> 21.25`4., 122 -> 
          21.55`4., 123 -> 21.4`4., 124 -> 21.6`4., 125 -> 21.75`4., 126 -> 
          21.9`4., 127 -> 22.04`4., 128 -> 21.87`4., 129 -> 21.82`4., 130 -> 
          21.96`4., 131 -> 21.92`4., 132 -> 22.09`4., 133 -> 21.95`4., 134 -> 
          21.91`4., 135 -> 22.09`4., 136 -> 21.99`4., 137 -> 22.12`4., 138 -> 
          22.68`4., 139 -> 22.74`4., 140 -> 22.86`4., 141 -> 23.04`4., 142 -> 
          22.98`4., 143 -> 22.94`4., 144 -> 23.04`4., 145 -> 22.63`4., 146 -> 
          22.73`4., 147 -> 22.81`4., 148 -> 23.02`4., 149 -> 22.82`4., 150 -> 
          22.85`4., 151 -> 23.25`4., 152 -> 23.48`4., 153 -> 23.48`4., 154 -> 
          23.49`4., 155 -> 23.26`4., 156 -> 23.14`4., 157 -> 23.21`4., 158 -> 
          23.32`4., 159 -> 23.17`4., 160 -> 22.95`4., 161 -> 22.99`4., 162 -> 
          23.14`4., 163 -> 23.11`4., 164 -> 23.09`4., 165 -> 22.87`4., 166 -> 
          22.83`4., 167 -> 22.67`4., 168 -> 22.81`4., 169 -> 22.79`4., 170 -> 
          22.92`4., 171 -> 22.74`4., 172 -> 22.78`4., 173 -> 22.58`4., 174 -> 
          22.65`4., 175 -> 22.72`4., 176 -> 22.87`4., 177 -> 23.24`4., 178 -> 
          23.14`4., 179 -> 22.63`4., 180 -> 22.72`4., 181 -> 22.47`4., 182 -> 
          22.39`4., 183 -> 21.44`4., 184 -> 20.94`4., 185 -> 21.19`4., 186 -> 
          21.48`4., 187 -> 21.74`4., 188 -> 21.79`4., 189 -> 21.82`4., 190 -> 
          22.03`4., 191 -> 21.92`4., 192 -> 21.97`4., 193 -> 22.37`4., 194 -> 
          22.14`4., 195 -> 22.44`4., 196 -> 22.44`4., 197 -> 22.51`4., 198 -> 
          22.41`4., 199 -> 22.44`4., 200 -> 22.63`4., 201 -> 22.73`4., 202 -> 
          22.92`4., 203 -> 23.01`4., 204 -> 23.24`4., 205 -> 23.4`4., 206 -> 
          23.56`4., 207 -> 23.26`4., 208 -> 23.3`4., 209 -> 23.39`4., 210 -> 
          23.21`4., 211 -> 23.31`4., 212 -> 23.13`4., 213 -> 23.13`4., 214 -> 
          23.22`4., 215 -> 23.03`4., 216 -> 22.91`4., 217 -> 23.28`4., 218 -> 
          23.45`4., 219 -> 23.29`4., 220 -> 23.23`4., 221 -> 23.15`4., 222 -> 
          23.27`4., 223 -> 23.46`4., 224 -> 23.58`4., 225 -> 23.79`4., 226 -> 
          23.2`4., 227 -> 23.21`4., 228 -> 22.76`4., 229 -> 22.94`4., 230 -> 
          23.02`4., 231 -> 23.26`4., 232 -> 23.16`4., 233 -> 23.19`4., 234 -> 
          22.88`4., 235 -> 22.76`4., 236 -> 22.95`4., 237 -> 23.27`4., 238 -> 
          23.51`4., 239 -> 23.36`4., 240 -> 23.63`4., 241 -> 23.59`4., 242 -> 
          23.56`4., 243 -> 23.34`4., 244 -> 23.43`4., 245 -> 23.56`4., 246 -> 
          24.1`4., 247 -> 24.73`4., 248 -> 24.63`4., 249 -> 24.56`4., 250 -> 
          24.52`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$541660 = 
        Dispatch[{
         1 -> 19.9`4., 2 -> 20.25`4., 3 -> 20.13`4., 4 -> 20.08`4., 5 -> 
          20.06`4., 6 -> 19.86`4., 7 -> 20.28`4., 8 -> 20.29`4., 9 -> 
          20.44`4., 10 -> 20.33`4., 11 -> 20.38`4., 12 -> 20.42`4., 13 -> 
          20.31`4., 14 -> 20.26`4., 15 -> 20.28`4., 16 -> 20.37`4., 17 -> 
          20.32`4., 18 -> 20.25`4., 19 -> 20.18`4., 20 -> 20.11`4., 21 -> 
          19.97`4., 22 -> 20.13`4., 23 -> 20.18`4., 24 -> 20.14`4., 25 -> 
          20.15`4., 26 -> 19.97`4., 27 -> 20.04`4., 28 -> 19.85`4., 29 -> 
          19.98`4., 30 -> 20.62`4., 31 -> 20.89`4., 32 -> 20.79`4., 33 -> 
          20.89`4., 34 -> 21.18`4., 35 -> 21.31`4., 36 -> 21.4`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.71`4., 40 -> 21.87`4., 41 -> 
          21.97`4., 42 -> 21.8`4., 43 -> 21.76`4., 44 -> 21.55`4., 45 -> 
          22.16`4., 46 -> 22.15`4., 47 -> 22.24`4., 48 -> 22.22`4., 49 -> 
          22.34`4., 50 -> 22.38`4., 51 -> 22.54`4., 52 -> 22.35`4., 53 -> 
          22.06`4., 54 -> 21.87`4., 55 -> 21.95`4., 56 -> 21.92`4., 57 -> 
          22.08`4., 58 -> 22.08`4., 59 -> 22.34`4., 60 -> 22.24`4., 61 -> 
          21.48`4., 62 -> 21.16`4., 63 -> 20.75`4., 64 -> 20.73`4., 65 -> 
          20.73`4., 66 -> 20.58`4., 67 -> 20.54`4., 68 -> 20.81`4., 69 -> 
          20.78`4., 70 -> 20.88`4., 71 -> 21.05`4., 72 -> 20.6`4., 73 -> 
          20.37`4., 74 -> 20.48`4., 75 -> 20.37`4., 76 -> 20.17`4., 77 -> 
          19.51`4., 78 -> 19.56`4., 79 -> 19.65`4., 80 -> 20.15`4., 81 -> 
          20.11`4., 82 -> 20.17`4., 83 -> 20.52`4., 84 -> 20.54`4., 85 -> 
          20.35`4., 86 -> 20.61`4., 87 -> 20.6`4., 88 -> 20.6`4., 89 -> 
          20.3`4., 90 -> 20.34`4., 91 -> 20.7`4., 92 -> 20.84`4., 93 -> 
          20.93`4., 94 -> 20.86`4., 95 -> 20.97`4., 96 -> 21.24`4., 97 -> 
          21.08`4., 98 -> 21.08`4., 99 -> 21.38`4., 100 -> 21.15`4., 101 -> 
          20.49`4., 102 -> 20.71`4., 103 -> 20.55`4., 104 -> 20.49`4., 105 -> 
          20.44`4., 106 -> 20.36`4., 107 -> 20.11`4., 108 -> 20.65`4., 109 -> 
          21.`4., 110 -> 20.76`4., 111 -> 20.86`4., 112 -> 20.79`4., 113 -> 
          20.57`4., 114 -> 20.62`4., 115 -> 20.83`4., 116 -> 20.79`4., 117 -> 
          20.78`4., 118 -> 20.86`4., 119 -> 20.78`4., 120 -> 20.96`4., 121 -> 
          21.69`4., 122 -> 21.66`4., 123 -> 21.59`4., 124 -> 21.7`4., 125 -> 
          21.93`4., 126 -> 22.14`4., 127 -> 22.14`4., 128 -> 21.87`4., 129 -> 
          21.92`4., 130 -> 22.26`4., 131 -> 21.95`4., 132 -> 22.18`4., 133 -> 
          22.08`4., 134 -> 22.12`4., 135 -> 22.14`4., 136 -> 22.09`4., 137 -> 
          22.22`4., 138 -> 23.02`4., 139 -> 23.04`4., 140 -> 22.92`4., 141 -> 
          23.37`4., 142 -> 23.04`4., 143 -> 23.08`4., 144 -> 23.2`4., 145 -> 
          22.63`4., 146 -> 22.87`4., 147 -> 23.18`4., 148 -> 23.04`4., 149 -> 
          23.01`4., 150 -> 23.09`4., 151 -> 23.4`4., 152 -> 23.48`4., 153 -> 
          23.49`4., 154 -> 23.58`4., 155 -> 23.43`4., 156 -> 23.22`4., 157 -> 
          23.3`4., 158 -> 23.5`4., 159 -> 23.25`4., 160 -> 23.07`4., 161 -> 
          23.14`4., 162 -> 23.27`4., 163 -> 23.11`4., 164 -> 23.18`4., 165 -> 
          23.06`4., 166 -> 22.94`4., 167 -> 22.92`4., 168 -> 22.94`4., 169 -> 
          22.9`4., 170 -> 23.16`4., 171 -> 22.82`4., 172 -> 22.9`4., 173 -> 
          22.75`4., 174 -> 22.94`4., 175 -> 22.88`4., 176 -> 23.39`4., 177 -> 
          23.4`4., 178 -> 23.27`4., 179 -> 22.63`4., 180 -> 22.92`4., 181 -> 
          22.58`4., 182 -> 22.49`4., 183 -> 21.58`4., 184 -> 21.18`4., 185 -> 
          21.33`4., 186 -> 21.79`4., 187 -> 21.78`4., 188 -> 22.03`4., 189 -> 
          22.09`4., 190 -> 22.11`4., 191 -> 21.97`4., 192 -> 22.14`4., 193 -> 
          22.39`4., 194 -> 22.4`4., 195 -> 22.5`4., 196 -> 22.83`4., 197 -> 
          22.6`4., 198 -> 22.72`4., 199 -> 22.67`4., 200 -> 22.83`4., 201 -> 
          23.06`4., 202 -> 23.09`4., 203 -> 23.27`4., 204 -> 23.38`4., 205 -> 
          23.47`4., 206 -> 23.67`4., 207 -> 23.47`4., 208 -> 23.34`4., 209 -> 
          23.41`4., 210 -> 23.45`4., 211 -> 23.41`4., 212 -> 23.14`4., 213 -> 
          23.45`4., 214 -> 23.47`4., 215 -> 23.14`4., 216 -> 23.19`4., 217 -> 
          23.67`4., 218 -> 23.59`4., 219 -> 23.39`4., 220 -> 23.31`4., 221 -> 
          23.49`4., 222 -> 23.33`4., 223 -> 23.58`4., 224 -> 24.14`4., 225 -> 
          23.79`4., 226 -> 23.25`4., 227 -> 23.36`4., 228 -> 22.93`4., 229 -> 
          23.11`4., 230 -> 23.25`4., 231 -> 23.32`4., 232 -> 23.19`4., 233 -> 
          23.34`4., 234 -> 22.9`4., 235 -> 22.91`4., 236 -> 23.24`4., 237 -> 
          23.32`4., 238 -> 23.62`4., 239 -> 23.54`4., 240 -> 23.94`4., 241 -> 
          23.76`4., 242 -> 23.63`4., 243 -> 23.43`4., 244 -> 23.54`4., 245 -> 
          23.63`4., 246 -> 24.72`4., 247 -> 24.86`4., 248 -> 24.71`4., 249 -> 
          24.62`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$541660 = True, 
        System`TradingChartDump`$gridlines$541660 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$541660, 
        System`TradingChartDump`$plotrangemin$541660 = 19.0982952853598, 
        System`TradingChartDump`$plotrangemax$541660 = 25.507305210918112`, 
        System`TradingChartDump`$layoutData$541660, 
        System`TradingChartDump`$gridlinesscope$541660 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$541660 = {True, True}, 
        System`TradingChartDump`$indicators$541660 = {
         FinancialIndicator["FullStochastic", 14, 3, 3]}, 
        System`TradingChartDump`$mouseQ$541660 = False, 
        System`TradingChartDump`$modelData$541660 = 
        System`TradingChartDump`modelData$539312, 
        System`TradingChartDump`$sy$541660 = Identity, 
        System`TradingChartDump`$isy$541660 = Identity, 
        System`TradingChartDump`$appearance$541660 = Automatic, 
        System`TradingChartDump`$perfgoal$541660 = "Quality", 
        System`TradingChartDump`$axesorigin$541660 = Automatic, 
        System`TradingChartDump`$framestyle$541660 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$541660 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$541660 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$541660 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$541660 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$541660, 
        System`TradingChartDump`$newgridlines$541660 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{19.0982952853598, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$541660 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$541660 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$541660 = "GraphicsFrame", 
        System`TradingChartDump`$frame$541660 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$541660 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$541660 = 
              Switch[System`TradingChartDump`$highlightposition$541660, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$541660], {
                 1, System`TradingChartDump`$length$541660}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$541660], {
                 1, System`TradingChartDump`$length$541660}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$541660, 
                   Charting`nearestDate[System`TradingChartDump`$dates$541660, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$541660]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$541660]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$541660, 
                    Floor[System`TradingChartDump`$controlmin$541660] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$541660, 
                    Floor[System`TradingChartDump`$controlmax$541660]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$541660 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$541660 = 
            If[System`TradingChartDump`$fastpos$541660 =!= True, 
              System`TradingChartDump`$fastpos$541660 = 
               Clip[System`TradingChartDump`$fastpos$541660, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$541660 = (
                  Floor[System`TradingChartDump`$controlmax$541660] - Floor[
                  System`TradingChartDump`$controlmin$541660]) (
                  System`TradingChartDump`$fastpos$541660/100) + 
                Floor[System`TradingChartDump`$controlmin$541660]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$541660], {
                Floor[System`TradingChartDump`$controlmin$541660] + 1, 
                 Floor[System`TradingChartDump`$controlmax$541660]}], 
              System`TradingChartDump`$staticindicatorpos$541660]; 
           System`TradingChartDump`$mouseQ$541660 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$541660]], 
              System`TradingChartDump`$highlightposition$541660 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$541660 = If[
              And[
              System`TradingChartDump`$bouncingballQ$541660, 
               System`TradingChartDump`$mouseQ$541660, 
               System`TradingChartDump`$appearance$541660 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$541660[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$541660]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$541660[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$541660, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$541660[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$541660]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$541660[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$541660[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541660, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541660[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541660, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541660, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541660[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541660[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$541660 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$541660, 
                 System`TradingChartDump`$defaultframeticksstyle$541660, 
                 System`TradingChartDump`$defaultlabelstyle$541660, 
                 System`TradingChartDump`$framestyle$541660, 
                 System`TradingChartDump`$frameticksstyle$541660, 
                 System`TradingChartDump`$labelstyle$541660}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541660 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$541660, 
                 System`TradingChartDump`$labelstyle$541660, 
                 System`TradingChartDump`$defaultframeticksstyle$541660, 
                 System`TradingChartDump`$defaultlabelstyle$541660}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541660 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541660, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$541660 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541660, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$541660 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541660, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$541660 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$541660 = 
             Part[System`TradingChartDump`$tickstextstyle$541660, 1], 
             System`TradingChartDump`$tickstextstyle$541660 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541660[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541660, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541660[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541660[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541660[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$541660[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541660, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$541660]], 
                    Style[":", System`TradingChartDump`$textstyle$541660]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$541660[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541660]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541660[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$541660[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$541660, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$541660]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$541660[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541660, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541660[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541660, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541660, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$541660[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541660[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541660[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$541660[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$541660[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$541660], 1], 
                   Floor[System`TradingChartDump`$controlmax$541660]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$541660[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$541660[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$541660[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$541660[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$541660[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541660[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$541660[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$541660[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$541660[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541660[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$541660[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$541660[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$541660[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$541660[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$541660[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$541660, 
                  System`TradingChartDump`$mouseQ$541660], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$541660 - 0.5, 
                   System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$541660 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$541660 + 0.5, 
                    System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] + 
                    0.5 
                    Abs[System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541660, 1]}, {
                    System`TradingChartDump`$indicatorpos$541660 + 0.5, 
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$541660[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$541660, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$541660[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541660]]], {}]; 
              System`TradingChartDump`$subplotgridlines$541660[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$541660[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$541660[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541660[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$541660 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$541660, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541660, 
                   System`TradingChartDump`$opens$541660]], 12, 
                 System`TradingChartDump`$textstyle$541660, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$541660, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541660, 
                   System`TradingChartDump`$highs$541660]], 12, 
                 System`TradingChartDump`$textstyle$541660, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$541660, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541660, 
                   System`TradingChartDump`$lows$541660]], 12, 
                 System`TradingChartDump`$textstyle$541660, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$541660, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541660, 
                   System`TradingChartDump`$closes$541660]], 12, 
                 System`TradingChartDump`$textstyle$541660, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541660, 
                   System`TradingChartDump`$visdates$541660]], 12, 
                 System`TradingChartDump`$textstyle$541660, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$541660, 
                  System`TradingChartDump`$mouseQ$541660], {{
                  System`TradingChartDump`$timestampstyle$541660, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$541660 - 0.5, 
                    System`TradingChartDump`$plotrangemin$541660}, 
                    If[
                    System`TradingChartDump`$timestampdepth$541660 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$541660[1]}, {
                    System`TradingChartDump`$indicatorpos$541660 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541660}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541660, 1]}, {
                    System`TradingChartDump`$indicatorpos$541660 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541660}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$541660, {
               System`TradingChartDump`$highlightstyle$541660, 
                Dynamic[System`TradingChartDump`$ohlcpoint$541660]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$541660[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541660, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$541660[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$541660[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$541660, Length[
                    System`TradingChartDump`$layoutData$541660[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$541660}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$541660] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$541660] + 0.5}, {
                System`TradingChartDump`$plotrangemin$541660, 
                 System`TradingChartDump`$plotrangemax$541660}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$541660, Left, {
                 False, System`TradingChartDump`$frame$541660}, 
                 Blank[], {System`TradingChartDump`$frame$541660, False}], {
                False, System`TradingChartDump`$frame$541660}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$541660, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$541660]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$541660 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           387.0228610767757}, {-286.92264150943396`, -65.76792452830183}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541660 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541660, 1]], 
               Part[System`TradingChartDump`$framestyle$541660, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$541660]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$541660} -> 
                   System`TradingChartDump`$isy$541660[
                    System`TradingChartDump`$plotrangemin$541660], {
                    0, System`TradingChartDump`$plotrangemax$541660} -> 
                   System`TradingChartDump`$isy$541660[
                    System`TradingChartDump`$plotrangemax$541660]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$541660[
                   System`TradingChartDump`$plotrangemin$541660], 
                   System`TradingChartDump`$isy$541660[
                   System`TradingChartDump`$plotrangemax$541660]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$541660, 
                   System`TradingChartDump`$isy$541660}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541660, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541660 > 
                    System`TradingChartDump`$plotrangemin$541660, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541660 > 
                    System`TradingChartDump`$plotrangemin$541660, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541660, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541660 > 
                    System`TradingChartDump`$plotrangemin$541660, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541660 > 
                    System`TradingChartDump`$plotrangemin$541660, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541660, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541660, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541660 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541660,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541660], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541660 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541660, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541660]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$541660, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$541660[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$541660[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541660, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$541660[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$541660, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541660[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541660, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541660[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541660[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541660[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541660[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541660], 
                    Style[":", System`TradingChartDump`$textstyle$541660]], 
                    Style[":", System`TradingChartDump`$textstyle$541660]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$541660[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541660]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541660[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$541660}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$541660, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$541660 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$541660[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$541660, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$541660, Left, {
                    False, System`TradingChartDump`$frame$541660}, 
                    Blank[], {
                    System`TradingChartDump`$frame$541660, False}], {
                   System`TradingChartDump`$frame$541660, 
                    System`TradingChartDump`$frame$541660}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$541660, 
                    System`TradingChartDump`$controlmax$541660}] + 0.5, {
                   System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$541660]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$541660) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$541660 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$541660 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$541660, 1]], 
                   Part[System`TradingChartDump`$framestyle$541660, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$541660]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541660[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541660[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$541660[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541660, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541660, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$541660, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$541660, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$541660 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
541660, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$541660], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$541660 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$541660, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$541660]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$541660, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$541660) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$541660 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$541660[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           475.9407855006933}, {-55.989622641509406`, -0.7009433962263785}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$541660, 
              Dynamic[System`TradingChartDump`$ohlclabel$541660], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$541660}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541660 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541660, 2]], 
               Part[System`TradingChartDump`$framestyle$541660, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$541660]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$541660, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$541660, 
                    System`TradingChartDump`$controlmax$541660}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$541660] + 
                    0.5, System`TradingChartDump`$plotrangemin$541660}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$541660], 
                    System`TradingChartDump`$plotrangemin$541660}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$541660, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541660, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541660, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541660 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541660, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541660], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541660 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541660,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541660]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, \
-20.802201552843357`}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$541660] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$541660[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$541660] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$541660[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$541660] = {HoldPattern[
               System`TradingChartDump`$min$541660[1]] :> 5.99}}, {
          DownValues[System`TradingChartDump`$max$541660] = {HoldPattern[
               System`TradingChartDump`$max$541660[1]] :> 97.33}}, {
          DownValues[System`TradingChartDump`$subplotvalue$541660] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$541660[1, 1]] :> 
             Invisible[85.69], HoldPattern[
               System`TradingChartDump`$subplotvalue$541660[1, 2]] :> 
             Invisible[88.88]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$541660] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$541660[1]] :> {50, 
              100}}}, {
          DownValues[System`TradingChartDump`$layoutData$541660] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$541660["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "AllValues"]] :> CompressedData["
1:eJxFVwk4lVsXppIh0aCkJH7kIJGzv72PhCUVlTKkQVcqXSKKkooGqWSoaLjI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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541660["AppendedAdjust"]] :> 
             9.134261816993625, HoldPattern[
               System`TradingChartDump`$layoutData$541660["AppendedBox"]] :> {
              5.087586754021082, 126.52641865647877`}, HoldPattern[
               System`TradingChartDump`$layoutData$541660["AppendedMin"]] :> 
             1.4182652727044598`, HoldPattern[
               System`TradingChartDump`$layoutData$541660["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$541660["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$541660["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$541660["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541660["DataMax"]] :> 
             24.95, HoldPattern[
               System`TradingChartDump`$layoutData$541660["DataMin"]] :> 
             19.376947890818858`, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "MainChartAllValues"]] :> CompressedData["
1:eJxFVwk81csXp5Il0aKkJP4Rkcid38yVcCRRKUta9KToka2QVLRok6Wi5SFb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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "MainChartPoints"]] :> CompressedData["
1:eJxdV1toXFUUvRZFKYIKBf0ocapS6oNSTR/xEbubNk2apk1mMslkksnkztyZ
O487M6n4IxXhIuRHhFAoSEVkRBFBEEEKoV+X+CGIIoJQBJEpQhEiUpCK9MuZ
2Wt97HMhDOvuu886e+3HOTlQ3shU7/c8717/7z787fH43DkZDp7bo4IX+itH
gR+SW5f3fTV1gPhR6aP+K+J9srVz91DhEeInpDB48RvX2y/TwwVoT8nem59e
Gp8hfkreGB+8IX5G188SH1T+EvEh+Su9PbIZET+n/HPEL8i3fbg1QXzY4T8i
T27upreLxC9Kpr/cbpr4JSf+URmGe5j4qMa3n/iYDN3/Y7zHHb1OOP5j8tml
fsBPE78sQ/0PEr/irPeq6rWX9tfkw2v951fax+XtgWD3iF/X+D7m9yeV7w9i
0fW+B47FsZ/Cfo/Bfgr6AnsTut+Q9gkZbi9H+2kZ0I9s0n5a/u2nY+c67Wd0
f7/Tfgbx0j4pP/4weGif1Hzu0H5W7e/TflaeHSbkOOxT0BM4npJheY3TPq18
Y7RPY/+0n0O90X5O9XqP9hnVP0/7DOqf9vNOfOdldPD8w/3Pav3u0j6LfqL/
BYvjC87+Ltp44oua/8tcfw56cP05/U2Y33n9/gawODieV/6rwMk84qd/WuP9
if5p7a/v6J9W/W7RP635epj7y6h+1+ifsf0YZxAP/R27t6D6PU//Ba2Pd1H/
8YLubws4WdB6+Jz9kbX9Jlnbz3HWrp9kUc/kX7R6yCLqgf6Lut5H9F+08XpL
TvxLqs8s/ZeQb/ovaf18Q/+c2m/SP6f9+jf9c5i/9M+hv+i/jPpBPmQZ9cZ6
cXCyjH5g/vLQj/55Xe8d8ufR7+TPo1/Jv2K/lxU7/+MV3X+B/ivOvF1FPum/
ivfc/yrmBf1XrR5ewc4/Kej8v0L+gp2fSUH1+IX+a47/mlP/a47+jt0rqj53
6V/U+L/m/ovav19Q/6Lm+wPqv456oP7ryD/913G+YD4kDvZ8O59Svp1H4uP8
xPe+b+dX7ON8gL3r23mVYP0R4J7v8Jc0nseBUyU7j6Wk/fbACfCXcP4BxyXs
l/wlzAfYE+f7Xgn7A/bKGs8ocKqs9f0J+cvQh/GXES/5y3b9bln12kP+MuIj
fxnnJfkDzDfyB+gHYAkwfxl/oPwd8gfQi/wB5gf5A3xHfmAhf0Xr/THyV5Af
8ldU/0nyV9B/5K9YPboVnH/kr2g932H+KzZfXtXaU1XV5zb1r+L8In9V9/sz
zzvn+24VvKw/Z/1eFecR+UONN2D8oc2PhE78oa2POHTqL0S+yB8in+Snnf1b
s/erVA33XfZfDfMF2K9hfrD/gB8kf832U1JDvshfc+5XdduPKeCA+tehB+u/
Dl7GX8c8JH8d5xn568q3Tf666vUl9W9Y/1TD1o80bP/4DZuPuIHziPXXUL63
WH8N8LH+HbvXxPnK/De13urkb+p8eJP8jj1u2n7pOt8nTcvXc773Iq3PI+SP
7H4lwrwnf2TrNY5wHyd/ZOdHEqGeyB/ZeeK1sJ8x8LdQb+Rv4Zf8LZzH5G/h
vGH+W3Y+JI5/r4X/r8jfduJv23xI2/a331b9/2T9tXF/Yfxtu37SxvlN/jbu
a+TvYD6Qv4P7Avk76HfG33Hmb8eu13W+Tzqof+jb6+A+AOxt4H5E/TewX2DZ
wH1gTP4HLlcf7Q==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541660["NewSubplot"]] :> {
               FinancialIndicator["FullStochastic", 14, 3, 3]}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541660["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541660["PlotRangeMin"]] :> 
             1.4182652727044598`, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$541660["Space"]] :> 2.495, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541660["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, 20}, {250., 20}}], 
                    Line[{{0, 80}, {250., 80}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJxdV3dU1NcSJpgIRFAQTJC6WCIoLSIISMJH79J724XdZYEFQYqhqGvjWaIC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                    "]]}, {
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Line[CompressedData["
1:eJw9Vws4FeYbP8mkaWMuOTPqMBNyS+40P0TuuXVyd3Dcj0ulKFqnC6v+atPF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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "SubplotIndicatorGridLines"]] :> {{50, 100}}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "FullStochastic"}]], 
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], " ", ""}]]}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["FullStochastic", 14, 3, 3]}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "SubplotIndicatorParameters"]] :> {{{14, 3, 3}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "SubplotIndicatorPoints"]] :> CompressedData["
1:eJxtmQuM1FcVxrettgSbFFoq9EUHShWohbLbBXZhd/87u8suO8vuvP4zCyww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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "SubplotIndicatorValues"]] :> CompressedData["
1:eJxFlwlsFGUUxwtEINgEkCKXHOXQAgGky/ZeOt12u+3udrszszNTTb1QClEM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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$541660["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$541660["YRange"]] :> 24.95,
              HoldPattern[
               System`TradingChartDump`$layoutData$541660[
               "SubplotPoints", {1}]] :> CompressedData["
1:eJxFlwtsFFUUhitEINgEkCIvgVZAWwhgu2xLC9tOt112u7vd7szszFRTXyiP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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541660[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$541660[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$541660[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$541660[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$541660[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$541660 = 
           System`TradingChartDump`$length$541660; 
          System`TradingChartDump`$layoutData$541660["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$541660; 
          System`TradingChartDump`$modelData$541660["Data"] = 
           System`TradingChartDump`$data$541660; 
          System`TradingChartDump`$modelData$541660["Indicators"] = 
           System`TradingChartDump`$indicators$541660; 
          System`TradingChartDump`$layoutData$541660[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541660["ScalingFunctions"] = {
            System`TradingChartDump`$sy$541660, 
             System`TradingChartDump`$isy$541660}; 
          System`TradingChartDump`$layoutData$541660["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541660["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541660[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541660["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$541660["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$541660, 
            System`TradingChartDump`$layoutData$541660, 
            System`TradingChartDump`$indicators$541660]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$541660, 
            System`TradingChartDump`$layoutData$541660, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$541660[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$541660["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$541660[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$541660[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$541660["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$541660[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$541660 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541660["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541660, 
                 System`TradingChartDump`$controlmax$541660}]]]; 
          System`TradingChartDump`$plotrangemax$541660 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541660["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541660, 
                 System`TradingChartDump`$controlmax$541660}]]]; {
            System`TradingChartDump`$plotrangemin$541660, 
             System`TradingChartDump`$plotrangemax$541660} = ReplaceAll[
             
             System`TradingChartDump`$sy$541660[{
              System`TradingChartDump`$plotrangemin$541660, 
               System`TradingChartDump`$plotrangemax$541660}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$541660[
                Min[System`TradingChartDump`$lows$541660]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$541660 == 
            System`TradingChartDump`$plotrangemax$541660, {
             System`TradingChartDump`$plotrangemin$541660, 
              System`TradingChartDump`$plotrangemax$541660} = {
             System`TradingChartDump`$plotrangemin$541660 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$541660], 
              System`TradingChartDump`$plotrangemax$541660 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$541660]}]; 
          System`TradingChartDump`$newgridlines$541660 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$541660, 
            Part[System`TradingChartDump`$newgridlines$541660, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$541660, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$541660], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$541660, 1]]; 
            Part[System`TradingChartDump`$newgridlines$541660, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$541660, 1] =!= None,
                 System`TradingChartDump`$length$541660 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$541660, 
                 Part[System`TradingChartDump`$newgridlines$541660, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$541660, 1]]; 
            System`TradingChartDump`$subpricegridlines$541660 = 
             Part[System`TradingChartDump`$gridlines$541660, 2]; 
            Part[System`TradingChartDump`$newgridlines$541660, 2] = 
             If[System`TradingChartDump`$sy$541660 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541660}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541660, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541660, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$541660, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$541660, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541660}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541660, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541660, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$541660 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$541660]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"GE\"", "\" with \"", 
           "\"FullStochastic\"", "\"(\"", "14", "\",\"", "3", "\",\"", "3", 
           "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {240., -502.20000000000005`}, 
      ImageScaled[{0.5, 0.5}], {450, 310}], InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$541676 = 
        "Full", System`TradingChartDump`$highlightposition$541676 = Automatic,
         System`TradingChartDump`$maxohlc$541676 = 24.95`4., 
        System`TradingChartDump`$timestampstyle$541676 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$541676 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$541676 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$541676, 
        System`TradingChartDump`$subplotpoint$541676, 
        System`TradingChartDump`$ndigits$541676 = 4, 
        System`TradingChartDump`$highlightstyle$541676 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$541676 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$541676 = True, 
        System`TradingChartDump`$timestampQ$541676 = True, 
        System`TradingChartDump`$data$541676 = {{{2012, 7, 26}, {
          19.55155642023346, 20.035505836575872`, 19.512840466926068`, 19.9, 
           57275600}}, {{2012, 7, 27}, {
          19.96928776290631, 20.327437858508603`, 19.901529636711278`, 20.25, 
           80268300}}, {{2012, 7, 30}, {
          20.120322115384614`, 20.236456730769227`, 20.023543269230768`, 
           20.13, 44993600}}, {{2012, 7, 31}, {
          20.08, 20.21547951807229, 20.08, 20.08, 38328400}}, {{2012, 8, 1}, {
          20.185798359864926`, 20.27288953207911, 20.040646406174623`, 20.06, 
           35734300}}, {{2012, 8, 2}, {
          19.860000000000003`, 20.03421052631579, 19.55029239766082, 19.86, 
           44000400}}, {{2012, 8, 3}, {
          20.144541984732825`, 20.318702290076335`, 20.096164122137402`, 
           20.28, 37891500}}, {{2012, 8, 6}, {
          20.29, 20.493190271816882`, 20.22226990939437, 20.29, 34159500}}, {{
          2012, 8, 7}, {
          20.459356060606062`, 20.507746212121216`, 20.410965909090912`, 
           20.44, 31115300}}, {{2012, 8, 8}, {
          20.36870537839124, 20.407410756782483`, 20.22356020942408, 20.33, 
           32345900}}, {{2012, 8, 9}, {
          20.263874643874647`, 20.43806267806268, 20.263874643874647`, 20.38, 
           31159700}}, {{2012, 8, 10}, {
          20.323222748815166`, 20.42, 20.265156398104267`, 20.42, 
           24419100}}, {{2012, 8, 13}, {
          20.358380181038587`, 20.377732253454024`, 20.2035636017151, 20.31, 
           26873600}}, {{2012, 8, 14}, {
          20.395453677172874`, 20.42447946513849, 20.22129894937918, 20.26, 
           30095000}}, {{2012, 8, 15}, {
          20.18324427480916, 20.34772900763359, 20.11551526717557, 20.28, 
           28870100}}, {{2012, 8, 16}, {
          20.195814726840858`, 20.457092636579574`, 20.147429928741094`, 
           20.37, 33598000}}, {{2012, 8, 17}, {
          20.33935238095238, 20.368380952380953`, 20.26194285714286, 20.32, 
           30032500}}, {{2012, 8, 20}, {
          20.269350215002387`, 20.33707596751075, 20.153248924988052`, 20.25, 
           27385500}}, {{2012, 8, 21}, {
          20.296143884892086`, 20.373573141486812`, 20.131606714628298`, 
           20.18, 30438800}}, {{2012, 8, 22}, {
          20.100322425409047`, 20.197098171318576`, 20.04225697786333, 20.11, 
           28016800}}, {{2012, 8, 23}, {
          20.06675387596899, 20.115130813953485`, 19.960324612403095`, 19.97, 
           36538800}}, {{2012, 8, 24}, {
          19.92676442307692, 20.22677884615384, 19.888052884615384`, 20.13, 
           29338200}}, {{2012, 8, 27}, {
          20.15096402877698, 20.276786570743404`, 20.121928057553955`, 20.18, 
           28775600}}, {{2012, 8, 28}, {
          20.09160980297934, 20.246458433445465`, 20.09160980297934, 20.14, 
           25912400}}, {{2012, 8, 29}, {
          20.15, 20.275816522574445`, 20.140321805955807`, 20.15, 
           19925800}}, {{2012, 8, 30}, {
          20.04740310077519, 20.10545542635659, 19.9506492248062, 19.97, 
           21237800}}, {{2012, 8, 31}, {
          20.08838242394978, 20.156117817479473`, 19.94323515210043, 20.04, 
           29679000}}, {{2012, 9, 4}, {
          19.966138469039493`, 20.024207703559238`, 19.820965382740127`, 
           19.85, 38173600}}, {{2012, 9, 5}, {
          19.883244552058112`, 20.096106537530268`, 19.84454237288136, 19.98, 
           33033500}}, {{2012, 9, 6}, {
          20.19424683247302, 20.629676208352887`, 20.17489441576725, 20.62, 
           53178600}}, {{2012, 9, 7}, {
          20.628754052802222`, 20.89, 20.609402501157945`, 20.89, 
           36379800}}, {{2012, 9, 10}, {
          20.79, 20.954539106145248`, 20.741606145251396`, 20.79, 
           33672300}}, {{2012, 9, 11}, {
          20.7932422417786, 20.9867577582214, 20.70616025937934, 20.89, 
           33593100}}, {{2012, 9, 12}, {
          20.967135678391962`, 21.218702603928733`, 20.957460027409777`, 
           21.18, 43006000}}, {{2012, 9, 13}, {
          21.0680608537693, 21.522906448683013`, 21.048705722070842`, 21.31, 
           111794200}}, {{2012, 9, 14}, {
          21.487109905020354`, 21.651650836725466`, 21.27417458163727, 21.4, 
           100148400}}, {{2012, 9, 17}, {
          21.22386394557823, 21.34, 21.194829931972787`, 21.34, 79283200}}, {{
          2012, 9, 18}, {
          21.278093525179855`, 21.52, 21.24906474820144, 21.52, 38831200}}, {{
          2012, 9, 19}, {
          21.584172982612575`, 21.768074008024968`, 21.535777975925104`, 
           21.71, 40462600}}, {{2012, 9, 20}, {
          21.63599197503344, 21.909001337494427`, 21.567739634418192`, 21.87, 
           43677000}}, {{2012, 9, 21}, {
          21.989502885042164`, 22.126023080337326`, 21.901739902352418`, 
           21.97, 66551700}}, {{2012, 9, 24}, {
          21.838998211091234`, 21.887745974955276`, 21.74150268336315, 21.8, 
           36799800}}, {{2012, 9, 25}, {
          21.8380277902286, 22.11112505602869, 21.750246526221428`, 21.76, 
           47039200}}, {{2012, 9, 26}, {
          21.608506787330317`, 21.69626696832579, 21.520746606334843`, 21.55, 
           41123300}}, {{2012, 9, 27}, {
          21.682287725472943`, 22.286739991201056`, 21.575046194456664`, 
           22.16, 67300400}}, {{2012, 9, 28}, {
          22.20852047556142, 22.393835314839276`, 22.062219286657857`, 22.15, 
           70926100}}, {{2012, 10, 1}, {
          22.161999123191585`, 22.42525208241999, 22.14249890398948, 22.24, 
           42550700}}, {{2012, 10, 2}, {
          22.3564984642387, 22.414997806055286`, 22.142000877577885`, 22.22, 
           45297400}}, {{2012, 10, 3}, {
          22.29124399825404, 22.40825840244435, 22.154727193365343`, 22.34, 
           32929400}}, {{2012, 10, 4}, {
          22.38, 22.477516339869283`, 22.204470588235292`, 22.38, 
           40344600}}, {{2012, 10, 5}, {
          22.46200692041522, 22.598494809688578`, 22.423010380622834`, 22.54, 
           38312500}}, {{2012, 10, 8}, {
          22.301243455497385`, 22.418259162303666`, 22.281740837696336`, 
           22.35, 24202200}}, {{2012, 10, 9}, {
          22.37207780725022, 22.401335101679926`, 22.04049513704686, 22.06, 
           39176000}}, {{2012, 10, 10}, {
          22.04550601872492, 22.17226036558181, 21.850499331252788`, 21.87, 
           32784100}}, {{2012, 10, 11}, {
          22.02800977343403, 22.14502443358507, 21.92074633496224, 21.95, 
           24161800}}, {{2012, 10, 12}, {
          22.017508896797153`, 22.144270462633454`, 21.851743772241996`, 
           21.92, 32954600}}, {{2012, 10, 15}, {
          21.98247349823321, 22.138515901060067`, 21.933710247349822`, 22.08, 
           29578600}}, {{2012, 10, 16}, {
          22.226289752650175`, 22.314063604240282`, 22.01173144876325, 22.08, 
           35668800}}, {{2012, 10, 17}, {
          22.203483195111303`, 22.349751200349196`, 22.154727193365343`, 
           22.34, 28272500}}, {{2012, 10, 18}, {
          22.24, 22.50325295922841, 22.230249890398948`, 22.24, 43140700}}, {{
          2012, 10, 19}, {
          21.9480163413527, 21.967517022242397`, 21.323994552882436`, 21.48, 
           107879900}}, {{2012, 10, 22}, {
          21.316018433179725`, 21.40377880184332, 20.72119815668203, 21.16, 
           86735100}}, {{2012, 10, 23}, {
          20.81825657894737, 20.867011278195488`, 20.671992481203006`, 20.75, 
           56297300}}, {{2012, 10, 24}, {
          20.8957619943556, 20.925014111006586`, 20.71049858889934, 20.73, 
           42295500}}, {{2012, 10, 25}, {
          20.964016933207905`, 21.032271872060207`, 20.505733772342428`, 
           20.73, 45769600}}, {{2012, 10, 26}, {
          20.657991473235434`, 20.862719090478446`, 20.541004263382284`, 
           20.58, 42827400}}, {{2012, 10, 31}, {
          20.735061728395063`, 20.79358024691358, 20.452222222222222`, 20.54, 
           39179300}}, {{2012, 11, 1}, {
          20.50769915651359, 20.858758200562324`, 20.497947516401123`, 20.81, 
           46231300}}, {{2012, 11, 2}, {
          20.994528390427032`, 21.14079774753637, 20.731243547630225`, 20.78, 
           47475200}}, {{2012, 11, 5}, {
          20.67519850537132, 20.938514712751047`, 20.67519850537132, 20.88, 
           30000100}}, {{2012, 11, 6}, {
          20.972000926354795`, 21.235247799907366`, 20.913501621120886`, 
           21.05, 32733200}}, {{2012, 11, 7}, {
          20.824230951254144`, 20.980217699952675`, 20.54150496923805, 20.6, 
           45253400}}, {{2012, 11, 8}, {
          20.633279080899953`, 20.66253231211106, 20.36024892292963, 20.37, 
           40770700}}, {{2012, 11, 9}, {
          20.245942857142857`, 20.77257142857143, 20.18742857142857, 20.48, 
           40306800}}, {{2012, 11, 12}, {
          20.51626615605553, 20.613776926759215`, 20.36024892292963, 20.37, 
           21816400}}, {{2012, 11, 13}, {
          20.091972920696332`, 20.433341392649908`, 20.06271276595745, 20.17, 
           41073300}}, {{2012, 11, 14}, {
          20.21200899550225, 20.231509245377314`, 19.451499250374813`, 19.51, 
           65539500}}, {{2012, 11, 15}, {
          19.403988035892322`, 19.72576271186441, 19.403988035892322`, 19.56, 
           51760300}}, {{2012, 11, 16}, {
          19.601240694789084`, 19.689007444168734`, 19.376947890818858`, 
           19.65, 45287500}}, {{2012, 11, 19}, {
          19.90617134559535, 20.208518877057113`, 19.88666505324298, 20.15, 
           38283400}}, {{2012, 11, 20}, {
          20.15876333656644, 20.178268671193017`, 19.8661833171678, 20.11, 
           26845900}}, {{2012, 11, 21}, {
          20.189506769825922`, 20.22852030947776, 20.06271276595745, 20.17, 
           41020400}}, {{2012, 11, 23}, {
          20.295684410646388`, 20.52, 20.217661596958177`, 20.52, 
           35456500}}, {{2012, 11, 26}, {
          20.364444444444445`, 20.549753086419752`, 20.35469135802469, 20.54, 
           47741300}}, {{2012, 11, 27}, {
          20.515764254911353`, 20.67177767129851, 20.330498322951605`, 20.35, 
           33001700}}, {{2012, 11, 28}, {
          20.229777672658468`, 20.619749290444656`, 19.9860454115421, 20.61, 
           34782700}}, {{2012, 11, 29}, {
          20.70724088973024, 20.824230951254144`, 20.42451490771415, 20.6, 
           27632800}}, {{2012, 11, 30}, {
          20.60974917179366, 20.726739233317563`, 20.512257453857078`, 20.6, 
           37857000}}, {{2012, 12, 3}, {
          20.651008645533143`, 20.699759846301635`, 20.280499519692604`, 20.3,
            29981900}}, {{2012, 12, 4}, {
          20.34975071907958, 20.486260786193675`, 20.19373921380633, 20.34, 
           36817200}}, {{2012, 12, 5}, {
          20.38798869524258, 20.8267545925577, 20.339236928874232`, 20.7, 
           46466500}}, {{2012, 12, 6}, {
          20.67421619092185, 20.859503977538605`, 20.557192325690217`, 20.84, 
           32751200}}, {{2012, 12, 7}, {
          20.910493942218082`, 20.94950605778192, 20.71543336439888, 20.93, 
           33548600}}, {{2012, 12, 10}, {
          20.899008882655444`, 20.967274427302478`, 20.830743338008414`, 
           20.86, 27604300}}, {{2012, 12, 11}, {
          20.940753138075312`, 21.203974895397486`, 20.823765690376565`, 
           20.97, 45757200}}, {{2012, 12, 12}, {
          21.074214876033054`, 21.40578512396694, 21.035206611570246`, 21.24, 
           42413600}}, {{2012, 12, 13}, {
          21.197002775208137`, 21.37250693802035, 21.011748381128584`, 21.08, 
           33966000}}, {{2012, 12, 14}, {
          21.07024976873265, 21.21650323774283, 21.011748381128584`, 21.08, 
           47536600}}, {{2012, 12, 17}, {
          21.146019151846783`, 21.399498404012764`, 21.146019151846783`, 
           21.38, 48483700}}, {{2012, 12, 18}, {
          21.30601659751037, 21.36452282157676, 20.876970954356842`, 21.15, 
           81119200}}, {{2012, 12, 19}, {
          21.104407425035696`, 21.123912422655877`, 20.450990004759635`, 
           20.49, 92330700}}, {{2012, 12, 20}, {
          20.57226128266033, 20.89693111638955, 20.532907363420428`, 20.71, 
           50831400}}, {{2012, 12, 21}, {
          20.510632183908047`, 20.658261494252873`, 20.235057471264366`, 
           20.55, 80833800}}, {{2012, 12, 24}, {
          20.460475504322766`, 20.62778097982709, 20.421109510086453`, 20.49, 
           15097200}}, {{2012, 12, 26}, {
          20.479364467982666`, 20.60729898892634, 20.380953298026, 20.44, 
           28557100}}, {{2012, 12, 27}, {
          20.468245529241177`, 20.537129047849202`, 20.094306428226197`, 
           20.36, 38330700}}, {{2012, 12, 28}, {
          20.119838551859097`, 20.375640900195695`, 20.1001614481409, 20.11, 
           32403400}}, {{2012, 12, 31}, {
          19.961338732729867`, 20.65983801810386, 19.931824678418295`, 20.65, 
           58785000}}, {{2013, 1, 2}, {
          21.167291471415183`, 21.196813495782568`, 20.8622305529522, 21., 
           46089500}}, {{2013, 1, 3}, {
          21.133876777251185`, 21.143715639810427`, 20.710805687203795`, 
           20.76, 48509100}}, {{2013, 1, 4}, {
          20.86983962264151, 20.91903773584906, 20.781283018867928`, 20.86, 
           29802600}}, {{2013, 1, 7}, {
          20.819517274017986`, 20.87855182205395, 20.622735447231427`, 20.79, 
           32746700}}, {{2013, 1, 8}, {
          20.766842105263162`, 20.786526315789477`, 20.353473684210527`, 
           20.57, 40045500}}, {{2013, 1, 9}, {
          20.708582338902147`, 20.738109785202866`, 20.600315035799525`, 
           20.62, 28540500}}, {{2013, 1, 10}, {
          20.702087860179493`, 20.88903637222484, 20.623372697213032`, 20.83, 
           33348200}}, {{2013, 1, 11}, {
          20.87855182205395, 20.898230004732607`, 20.68176999526739, 20.79, 
           41839700}}, {{2013, 1, 14}, {
          20.83903409090909, 20.898068181818182`, 20.730804924242427`, 20.78, 
           31715900}}, {{2013, 1, 15}, {
          20.70256603773585, 20.86983962264151, 20.673047169811323`, 20.86, 
           26551000}}, {{2013, 1, 16}, {
          20.809517045454545`, 20.858712121212122`, 20.72096590909091, 20.78, 
           38932100}}, {{2013, 1, 17}, {
          20.88127699530516, 21.196169014084504`, 20.78287323943662, 20.96, 
           63851700}}, {{2013, 1, 18}, {
          21.591588021778588`, 21.83761796733213, 21.247146098003633`, 21.69, 
           113079400}}, {{2013, 1, 22}, {
          21.82729668332576, 21.846978646069967`, 21.55174920490686, 21.66, 
           55165800}}, {{2013, 1, 23}, {
          21.629361896080216`, 21.67856426618049, 21.40303099361896, 21.59, 
           47228500}}, {{2013, 1, 24}, {
          21.611428571428572`, 21.837777777777777`, 21.6015873015873, 21.7, 
           46991100}}, {{2013, 1, 25}, {
          21.920161507402426`, 21.949676985195154`, 21.752907133243607`, 
           21.93, 41919800}}, {{2013, 1, 28}, {
          22.080960000000005`, 22.179360000000003`, 21.903840000000002`, 
           22.14, 49558400}}, {{2013, 1, 29}, {
          22.13016, 22.21872, 22.041600000000003`, 22.14, 34148000}}, {{2013, 
          1, 30}, {
          22.155303643724697`, 22.184817813765186`, 21.87, 21.87, 
           36200400}}, {{2013, 1, 31}, {
          21.85113105924596, 22.03806104129264, 21.8216157989228, 21.92, 
           34427700}}, {{2013, 2, 1}, {
          22.073023872679045`, 22.27968169761273, 21.964774535809017`, 22.26, 
           43840300}}, {{2013, 2, 4}, {
          22.0483863738234, 22.127095472882115`, 21.920484087852984`, 21.95, 
           35836600}}, {{2013, 2, 5}, {
          22.120958296362023`, 22.258722271517303`, 22.091437444543033`, 
           22.18, 30917700}}, {{2013, 2, 6}, {
          22.109518716577536`, 22.139037433155078`, 21.952085561497324`, 
           22.08, 42985800}}, {{2013, 2, 7}, {
          22.139679715302492`, 22.14951957295374, 21.913362989323847`, 22.12, 
           38325900}}, {{2013, 2, 8}, {
          22.14, 22.19904, 22.0908, 22.14, 24424600}}, {{2013, 2, 11}, {
          22.129358574610244`, 22.14903786191537, 21.99160356347439, 22.09, 
           19738700}}, {{2013, 2, 12}, {
          22.121594331266607`, 22.288883968113375`, 22.121594331266607`, 
           22.22, 34297500}}, {{2013, 2, 13}, {
          22.744429243266353`, 23.108576314664386`, 22.675536554082942`, 
           23.02, 84926900}}, {{2013, 2, 14}, {
          22.882528833831696`, 23.11873558308415, 22.74474156343443, 23.04, 
           53996500}}, {{2013, 2, 15}, {
          23.106981537140406`, 23.175869471876346`, 22.86095319879777, 22.92, 
           39283000}}, {{2013, 2, 19}, {
          23.04528, 23.37, 23.03544, 23.37, 41219000}}, {{2013, 2, 20}, {
          23.33525843656557, 23.374626228107648`, 22.980948312686888`, 23.04, 
           38107400}}, {{2013, 2, 21}, {
          23.000619088564054`, 23.169303525365432`, 22.9410834049871, 23.08, 
           47811200}}, {{2013, 2, 22}, {
          23.1603249251817, 23.259512612227446`, 23.041299700726807`, 23.2, 
           27836300}}, {{2013, 2, 25}, {
          23.314555019728193`, 23.344318281455507`, 22.630000000000003`, 
           22.63, 51619800}}, {{2013, 2, 26}, {
          22.790624728850325`, 22.96921908893709, 22.73109327548807, 22.87, 
           41316300}}, {{2013, 2, 27}, {
          22.83284552845528, 23.20975609756097, 22.813008130081297`, 23.18, 
           29676400}}, {{2013, 2, 28}, {
          23.188837209302328`, 23.27813953488372, 23.02015503875969, 23.04, 
           39714600}}, {{2013, 3, 1}, {
          22.841319534282018`, 23.158835705045277`, 22.821474773609314`, 
           23.01, 41226900}}, {{2013, 3, 4}, {
          22.970928233777396`, 23.09992264718522, 22.851856467554793`, 23.09, 
           25457800}}, {{2013, 3, 5}, {
          23.27104705383637, 23.519033488766425`, 23.251208139041967`, 23.4, 
           35728000}}, {{2013, 3, 6}, {
          23.648635403464297`, 23.648635403464297`, 23.48, 23.48, 
           31539100}}, {{2013, 3, 7}, {
          23.509839527027022`, 23.638796452702696`, 23.480080236486486`, 
           23.49, 22955700}}, {{2013, 3, 8}, {
          23.669280605805636`, 23.708960875052586`, 23.49071939419436, 23.58, 
           28952100}}, {{2013, 3, 11}, {
          23.499436917866216`, 23.558954276037255`, 23.261367485182046`, 
           23.43, 34947200}}, {{2013, 3, 12}, {
          23.39853908586074, 23.408457923964118`, 23.140649295173, 23.22, 
           36593000}}, {{2013, 3, 13}, {
          23.250404427415926`, 23.329757343550448`, 23.21072796934866, 23.3, 
           24152400}}, {{2013, 3, 14}, {
          23.361122836639932`, 23.569438581680036`, 23.321443647108484`, 23.5,
            34629800}}, {{2013, 3, 15}, {
          23.25, 23.527730375426618`, 23.17064846416382, 23.25, 58857200}}, {{
          2013, 3, 18}, {
          22.990619354838714`, 23.169225806451614`, 22.950929032258063`, 
           23.07, 33700000}}, {{2013, 3, 19}, {
          23.12015437392796, 23.17969125214408, 22.991157804459693`, 23.14, 
           36150200}}, {{2013, 3, 20}, {
          23.537813299232738`, 23.607246376811595`, 23.141052855924976`, 
           23.27, 39254000}}, {{2013, 3, 21}, {
          23.238995276942894`, 23.417604121940748`, 23.109999999999996`, 
           23.11, 38543900}}, {{2013, 3, 22}, {
          23.130406504065036`, 23.20975609756097, 23.090731707317072`, 23.18, 
           30606100}}, {{2013, 3, 25}, {
          23.268373493975904`, 23.298141135972465`, 22.87147160068847, 23.06, 
           41684400}}, {{2013, 3, 26}, {
          23.088832179930794`, 23.118598615916955`, 22.830856401384082`, 
           22.94, 32353500}}, {{2013, 3, 27}, {
          22.840623376623377`, 22.95968831168831, 22.671948051948053`, 22.92, 
           27492500}}, {{2013, 3, 28}, {
          22.95984429065744, 23.019377162629755`, 22.81101211072664, 22.94, 
           31151000}}, {{2013, 4, 1}, {
          22.85038994800693, 22.91984402079723, 22.79085788561525, 22.9, 
           27449700}}, {{2013, 4, 2}, {
          22.991311053984575`, 23.189768637532133`, 22.92185089974293, 23.16, 
           29180100}}, {{2013, 4, 3}, {
          23.19702608695652, 23.21686956521739, 22.740626086956524`, 22.82, 
           52570300}}, {{2013, 4, 4}, {
          22.830545927209705`, 22.949610051993066`, 22.780935875216638`, 22.9,
            30472100}}, {{2013, 4, 5}, {
          22.621020497165286`, 22.75992150021806, 22.58133449629307, 22.75, 
           31402200}}, {{2013, 4, 8}, {
          22.870544982698963`, 22.94, 22.652257785467125`, 22.94, 
           30493600}}, {{2013, 4, 9}, {
          23.068516912402426`, 23.068516912402426`, 22.721248915871637`, 
           22.88, 31668200}}, {{2013, 4, 10}, {
          22.913867684478376`, 23.45943596268024, 22.87418999151824, 23.39, 
           39772300}}, {{2013, 4, 11}, {
          23.36032217041119, 23.528952946163628`, 23.241288681644765`, 23.4, 
           27084400}}, {{2013, 4, 12}, {
          23.29975703324808, 23.39894714407502, 23.141052855924976`, 23.27, 
           27234300}}, {{2013, 4, 15}, {
          23.096291100394566`, 23.11613327487944, 22.630000000000003`, 22.63, 
           46453800}}, {{2013, 4, 16}, {
          22.890233766233766`, 22.92, 22.72155844155844, 22.92, 36016700}}, {{
          2013, 4, 17}, {
          22.778418277680135`, 22.847864674868188`, 22.470869947275915`, 
           22.58, 42672900}}, {{2013, 4, 18}, {
          22.579285399206, 22.668570798412, 22.39079400088222, 22.49, 
           41170900}}, {{2013, 4, 19}, {
          21.768514942528736`, 21.85781149425287, 21.44109425287356, 21.58, 
           108837900}}, {{2013, 4, 22}, {
          21.497451990632317`, 21.507372365339577`, 20.94191100702576, 21.18, 
           87828900}}, {{2013, 4, 23}, {
          21.37960465116279, 21.518497674418605`, 21.191106976744184`, 21.33, 
           65489600}}, {{2013, 4, 24}, {
          21.522090163934426`, 21.859458105646628`, 21.482399817850634`, 
           21.79, 51506700}}, {{2013, 4, 25}, {
          22.037986332574036`, 22.05783143507973, 21.74030979498861, 21.78, 
           41462900}}, {{2013, 4, 26}, {
          21.801864025213867`, 22.218460153084195`, 21.791945069788383`, 
           22.03, 47012500}}, {{2013, 4, 29}, {
          22.129676695105523`, 22.139595868881905`, 21.82218230803772, 22.09, 
           36531800}}, {{2013, 4, 30}, {
          22.11, 22.1992732166891, 22.03064602960969, 22.11, 34054800}}, {{
          2013, 5, 1}, {
          21.920406320541762`, 22.168374717832958`, 21.920406320541762`, 
           21.97, 39201600}}, {{2013, 5, 2}, {
          22.070564516129032`, 22.14, 21.971370967741933`, 22.14, 
           27651500}}, {{2013, 5, 3}, {
          22.39, 22.667766947275148`, 22.370159503766065`, 22.39, 
           45523300}}, {{2013, 5, 6}, {
          22.38015943312666, 22.45952170062002, 22.14207263064659, 22.4, 
           28563900}}, {{2013, 5, 7}, {
          22.509920634920633`, 22.60912698412698, 22.44047619047619, 22.5, 
           28211700}}, {{2013, 5, 8}, {
          22.502581486310298`, 22.83992177314211, 22.443050847457627`, 22.83, 
           39977300}}, {{2013, 5, 9}, {
          22.808340649692713`, 22.91747146619842, 22.510711150131694`, 22.6, 
           29974300}}, {{2013, 5, 10}, {
          22.591021834061134`, 22.729921397379915`, 22.412436681222708`, 
           22.72, 35117300}}, {{2013, 5, 13}, {
          22.67992122538293, 22.699763676148795`, 22.441811816192562`, 22.67, 
           30283800}}, {{2013, 5, 14}, {
          22.671251629726207`, 22.889530638852673`, 22.631564537157754`, 
           22.83, 39592300}}, {{2013, 5, 15}, {
          22.86154905335628, 23.069922547332187`, 22.732555938037866`, 23.06, 
           40153000}}, {{2013, 5, 16}, {
          22.921314997851315`, 23.16938117748174, 22.921314997851315`, 23.09, 
           33023300}}, {{2013, 5, 17}, {
          23.081538789428816`, 23.289838022165387`, 23.012105711849955`, 
           23.27, 41037700}}, {{2013, 5, 20}, {
          23.270886720407294`, 23.389919389053876`, 23.241128553245648`, 
           23.38, 32884800}}, {{2013, 5, 21}, {
          23.400562130177512`, 23.58903634826712, 23.400562130177512`, 23.47, 
           33815000}}, {{2013, 5, 22}, {
          23.590637049455157`, 23.937849958088854`, 23.56087594300084, 23.67, 
           68514400}}, {{2013, 5, 23}, {
          23.33112426035503, 23.559277261200336`, 23.261686390532542`, 23.47, 
           44383600}}, {{2013, 5, 24}, {
          23.3102422439439, 23.478869528261797`, 23.3003229919252, 23.34, 
           41015200}}, {{2013, 5, 28}, {
          23.578631355932202`, 23.648067796610167`, 23.39016101694915, 23.41, 
           47323000}}, {{2013, 5, 29}, {
          23.231768189509307`, 23.50951776649746, 23.21192893401015, 23.45, 
           39236500}}, {{2013, 5, 30}, {
          23.39016101694915, 23.56871186440678, 23.310805084745763`, 23.41, 
           29347100}}, {{2013, 5, 31}, {
          23.407915951972555`, 23.606372212692968`, 23.13007718696398, 23.14, 
           49247600}}, {{2013, 6, 3}, {
          23.18217005076142, 23.588874788494078`, 23.132571912013535`, 23.45, 
           45218400}}, {{2013, 6, 4}, {
          23.400562130177512`, 23.569196956889265`, 23.22200760777684, 23.47, 
           38701300}}, {{2013, 6, 5}, {
          23.368224699828474`, 23.397993138936535`, 23.030849056603774`, 
           23.14, 44756200}}, {{2013, 6, 6}, {
          23.06105645851155, 23.19991873396065, 22.9122754491018, 23.19, 
           42677500}}, {{2013, 6, 7}, {
          23.35254819782062, 23.759283319362954`, 23.28310561609388, 23.67, 
           49041200}}, {{2013, 6, 10}, {
          23.689201009251473`, 23.728881412952063`, 23.45111858704794, 23.59, 
           41626500}}, {{2013, 6, 11}, {
          23.300725190839696`, 23.49911365564038, 23.290805767599664`, 23.39, 
           36183000}}, {{2013, 6, 12}, {
          23.508382978723404`, 23.538140425531914`, 23.230646808510638`, 
           23.31, 33842000}}, {{2013, 6, 13}, {
          23.261845439189184`, 23.599117398648644`, 23.152728040540538`, 
           23.49, 34930500}}, {{2013, 6, 14}, {
          23.488707482993195`, 23.55814200680272, 23.27048469387755, 23.33, 
           27846000}}, {{2013, 6, 17}, {
          23.560159865376523`, 23.6593605384939, 23.460959192259146`, 23.58, 
           39278300}}, {{2013, 6, 18}, {
          23.64390464447185, 24.259062885326763`, 23.58437320180847, 24.14, 
           72766900}}, {{2013, 6, 19}, {
          24.008256880733942`, 24.15706839032527, 23.79, 23.79, 46082200}}, {{
          2013, 6, 20}, {23.63, 23.69, 23.2, 23.25, 62733200}}, {{2013, 6, 
          21}, {
          23.579999999999995`, 23.639999999999997`, 23.209999999999997`, 
           23.36, 65025200}}, {{2013, 6, 24}, {
          23.12, 23.15, 22.76, 22.93, 48760800}}, {{2013, 6, 25}, {
          23.169999999999998`, 23.249999999999996`, 22.939999999999998`, 
           23.11, 36569100}}, {{2013, 6, 26}, {
          23.43, 23.44, 23.02, 23.25, 32531700}}, {{2013, 6, 27}, {
          23.41, 23.48, 23.26, 23.32, 30867900}}, {{2013, 6, 28}, {
          23.32, 23.44, 23.16, 23.19, 45923200}}, {{2013, 7, 1}, {
          23.209999999999997`, 23.639999999999997`, 23.189999999999998`, 
           23.34, 35784800}}, {{2013, 7, 2}, {
          23.27, 23.34, 22.88, 22.9, 47571200}}, {{2013, 7, 3}, {
          22.83, 22.98, 22.76, 22.91, 21448500}}, {{2013, 7, 5}, {
          23.17, 23.24, 22.95, 23.24, 22688900}}, {{2013, 7, 8}, {
          23.36, 23.53, 23.27, 23.32, 35481100}}, {{2013, 7, 9}, {
          23.52, 23.8, 23.51, 23.62, 31541400}}, {{2013, 7, 10}, {
          23.719999999999995`, 23.729999999999997`, 23.359999999999996`, 
           23.54, 28457100}}, {{2013, 7, 11}, {
          23.91, 23.96, 23.63, 23.94, 32618400}}, {{2013, 7, 12}, {
          23.99, 24., 23.59, 23.76, 33257700}}, {{2013, 7, 15}, {
          23.73, 23.74, 23.56, 23.63, 35853500}}, {{2013, 7, 16}, {
          23.659999999999997`, 23.669999999999998`, 23.339999999999996`, 
           23.43, 38192400}}, {{2013, 7, 17}, {
          23.539999999999996`, 23.609999999999996`, 23.429999999999996`, 
           23.54, 26858500}}, {{2013, 7, 18}, {
          23.6, 23.94, 23.56, 23.63, 41438200}}, {{2013, 7, 19}, {
          24.21, 24.95, 24.1, 24.72, 103708900}}, {{2013, 7, 22}, {
          24.77, 24.92, 24.73, 24.86, 41560800}}, {{2013, 7, 23}, {
          24.87, 24.88, 24.63, 24.71, 32553000}}, {{2013, 7, 24}, {
          24.79, 24.84, 24.56, 24.62, 27485000}}, {{2013, 7, 25}, {
          24.61, 24.69, 24.52, 24.69, 29951700}}}, 
        System`TradingChartDump`$markerstyle$541676 = 1, 
        System`TradingChartDump`$controlmin$541676 = 0.5, 
        System`TradingChartDump`$controlmax$541676 = 250.5, 
        System`TradingChartDump`$datescope$541676 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$541676 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$541676, 
        System`TradingChartDump`$max$541676, 
        System`TradingChartDump`$ohlclabel$541676 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541676, 
              System`TradingChartDump`$opens$541676]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541676, 
              System`TradingChartDump`$highs$541676]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541676, 
              System`TradingChartDump`$lows$541676]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541676, 
              System`TradingChartDump`$closes$541676]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541676, 
              System`TradingChartDump`$visdates$541676]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$541676 = {}, 
        System`TradingChartDump`$subpricegridlines$541676 = Automatic, 
        System`TradingChartDump`$overlaypoint$541676, 
        System`TradingChartDump`$overlayvalue$541676, 
        System`TradingChartDump`$subplotvalue$541676, 
        System`TradingChartDump`$opts$541676 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "GE", " with ", 
            "ParabolicStopAndReversal", "(", 0.02, ",", 0.2, ",", Null, ",", 
            Null, ")"}], ImageSize -> {450, 310}, AlignmentPoint -> Center, 
         AspectRatio -> GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> 
         None, AxesOrigin -> Automatic, AxesStyle -> {}, Background -> None, 
         BaselinePosition -> Automatic, BaseStyle -> {}, ColorOutput -> 
         Automatic, ContentSelectable -> Automatic, CoordinatesToolOptions -> 
         Automatic, DisplayFunction :> $DisplayFunction, Epilog -> {}, 
         FormatType :> TraditionalForm, Frame -> True, FrameLabel -> None, 
         FrameStyle -> {}, FrameTicks -> Automatic, FrameTicksStyle -> {}, 
         GridLines -> Automatic, GridLinesStyle -> {}, ImageMargins -> 0., 
         ImagePadding -> All, ImageSize -> Automatic, ImageSizeRaw -> 
         Automatic, LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, 
         PlotRange -> All, PlotRangeClipping -> False, PlotRangePadding -> 
         Automatic, PlotRegion -> Automatic, PreserveImageOptions -> 
         Automatic, Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$541676 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmglczWkXx2/W7PuSl9RLZClS3WtQPcooqUkLiVT3tt5uC5ooBo09IVt6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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyFmndUVNcWxkfFhihRiF0CAoKABikjiOJRmgrCUJUqMDAgzUKMihKwRohi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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$541676 = 
        System`TradingChartDump`$staticindicatorpos$541676, 
        System`TradingChartDump`$length$541676 = 250, 
        System`TradingChartDump`$gridlinesflag$541676 = True, 
        System`TradingChartDump`$opens$541676 = 
        Dispatch[{
         1 -> 19.55`4., 2 -> 19.97`4., 3 -> 20.12`4., 4 -> 20.08`4., 5 -> 
          20.19`4., 6 -> 19.86`4., 7 -> 20.14`4., 8 -> 20.29`4., 9 -> 
          20.46`4., 10 -> 20.37`4., 11 -> 20.26`4., 12 -> 20.32`4., 13 -> 
          20.36`4., 14 -> 20.4`4., 15 -> 20.18`4., 16 -> 20.2`4., 17 -> 
          20.34`4., 18 -> 20.27`4., 19 -> 20.3`4., 20 -> 20.1`4., 21 -> 
          20.07`4., 22 -> 19.93`4., 23 -> 20.15`4., 24 -> 20.09`4., 25 -> 
          20.15`4., 26 -> 20.05`4., 27 -> 20.09`4., 28 -> 19.97`4., 29 -> 
          19.88`4., 30 -> 20.19`4., 31 -> 20.63`4., 32 -> 20.79`4., 33 -> 
          20.79`4., 34 -> 20.97`4., 35 -> 21.07`4., 36 -> 21.49`4., 37 -> 
          21.22`4., 38 -> 21.28`4., 39 -> 21.58`4., 40 -> 21.64`4., 41 -> 
          21.99`4., 42 -> 21.84`4., 43 -> 21.84`4., 44 -> 21.61`4., 45 -> 
          21.68`4., 46 -> 22.21`4., 47 -> 22.16`4., 48 -> 22.36`4., 49 -> 
          22.29`4., 50 -> 22.38`4., 51 -> 22.46`4., 52 -> 22.3`4., 53 -> 
          22.37`4., 54 -> 22.05`4., 55 -> 22.03`4., 56 -> 22.02`4., 57 -> 
          21.98`4., 58 -> 22.23`4., 59 -> 22.2`4., 60 -> 22.24`4., 61 -> 
          21.95`4., 62 -> 21.32`4., 63 -> 20.82`4., 64 -> 20.9`4., 65 -> 
          20.96`4., 66 -> 20.66`4., 67 -> 20.74`4., 68 -> 20.51`4., 69 -> 
          20.99`4., 70 -> 20.68`4., 71 -> 20.97`4., 72 -> 20.82`4., 73 -> 
          20.63`4., 74 -> 20.25`4., 75 -> 20.52`4., 76 -> 20.09`4., 77 -> 
          20.21`4., 78 -> 19.4`4., 79 -> 19.6`4., 80 -> 19.91`4., 81 -> 
          20.16`4., 82 -> 20.19`4., 83 -> 20.3`4., 84 -> 20.36`4., 85 -> 
          20.52`4., 86 -> 20.23`4., 87 -> 20.71`4., 88 -> 20.61`4., 89 -> 
          20.65`4., 90 -> 20.35`4., 91 -> 20.39`4., 92 -> 20.67`4., 93 -> 
          20.91`4., 94 -> 20.9`4., 95 -> 20.94`4., 96 -> 21.07`4., 97 -> 
          21.2`4., 98 -> 21.07`4., 99 -> 21.15`4., 100 -> 21.31`4., 101 -> 
          21.1`4., 102 -> 20.57`4., 103 -> 20.51`4., 104 -> 20.46`4., 105 -> 
          20.48`4., 106 -> 20.47`4., 107 -> 20.12`4., 108 -> 19.96`4., 109 -> 
          21.17`4., 110 -> 21.13`4., 111 -> 20.87`4., 112 -> 20.82`4., 113 -> 
          20.77`4., 114 -> 20.71`4., 115 -> 20.7`4., 116 -> 20.88`4., 117 -> 
          20.84`4., 118 -> 20.7`4., 119 -> 20.81`4., 120 -> 20.88`4., 121 -> 
          21.59`4., 122 -> 21.83`4., 123 -> 21.63`4., 124 -> 21.61`4., 125 -> 
          21.92`4., 126 -> 22.08`4., 127 -> 22.13`4., 128 -> 22.16`4., 129 -> 
          21.85`4., 130 -> 22.07`4., 131 -> 22.05`4., 132 -> 22.12`4., 133 -> 
          22.11`4., 134 -> 22.14`4., 135 -> 22.14`4., 136 -> 22.13`4., 137 -> 
          22.12`4., 138 -> 22.74`4., 139 -> 22.88`4., 140 -> 23.11`4., 141 -> 
          23.05`4., 142 -> 23.34`4., 143 -> 23.`4., 144 -> 23.16`4., 145 -> 
          23.31`4., 146 -> 22.79`4., 147 -> 22.83`4., 148 -> 23.19`4., 149 -> 
          22.84`4., 150 -> 22.97`4., 151 -> 23.27`4., 152 -> 23.65`4., 153 -> 
          23.51`4., 154 -> 23.67`4., 155 -> 23.5`4., 156 -> 23.4`4., 157 -> 
          23.25`4., 158 -> 23.36`4., 159 -> 23.25`4., 160 -> 22.99`4., 161 -> 
          23.12`4., 162 -> 23.54`4., 163 -> 23.24`4., 164 -> 23.13`4., 165 -> 
          23.27`4., 166 -> 23.09`4., 167 -> 22.84`4., 168 -> 22.96`4., 169 -> 
          22.85`4., 170 -> 22.99`4., 171 -> 23.2`4., 172 -> 22.83`4., 173 -> 
          22.62`4., 174 -> 22.87`4., 175 -> 23.07`4., 176 -> 22.91`4., 177 -> 
          23.36`4., 178 -> 23.3`4., 179 -> 23.1`4., 180 -> 22.89`4., 181 -> 
          22.78`4., 182 -> 22.58`4., 183 -> 21.77`4., 184 -> 21.5`4., 185 -> 
          21.38`4., 186 -> 21.52`4., 187 -> 22.04`4., 188 -> 21.8`4., 189 -> 
          22.13`4., 190 -> 22.11`4., 191 -> 21.92`4., 192 -> 22.07`4., 193 -> 
          22.39`4., 194 -> 22.38`4., 195 -> 22.51`4., 196 -> 22.5`4., 197 -> 
          22.81`4., 198 -> 22.59`4., 199 -> 22.68`4., 200 -> 22.67`4., 201 -> 
          22.86`4., 202 -> 22.92`4., 203 -> 23.08`4., 204 -> 23.27`4., 205 -> 
          23.4`4., 206 -> 23.59`4., 207 -> 23.33`4., 208 -> 23.31`4., 209 -> 
          23.58`4., 210 -> 23.23`4., 211 -> 23.39`4., 212 -> 23.41`4., 213 -> 
          23.18`4., 214 -> 23.4`4., 215 -> 23.37`4., 216 -> 23.06`4., 217 -> 
          23.35`4., 218 -> 23.69`4., 219 -> 23.3`4., 220 -> 23.51`4., 221 -> 
          23.26`4., 222 -> 23.49`4., 223 -> 23.56`4., 224 -> 23.64`4., 225 -> 
          24.01`4., 226 -> 23.63`4., 227 -> 23.58`4., 228 -> 23.12`4., 229 -> 
          23.17`4., 230 -> 23.43`4., 231 -> 23.41`4., 232 -> 23.32`4., 233 -> 
          23.21`4., 234 -> 23.27`4., 235 -> 22.83`4., 236 -> 23.17`4., 237 -> 
          23.36`4., 238 -> 23.52`4., 239 -> 23.72`4., 240 -> 23.91`4., 241 -> 
          23.99`4., 242 -> 23.73`4., 243 -> 23.66`4., 244 -> 23.54`4., 245 -> 
          23.6`4., 246 -> 24.21`4., 247 -> 24.77`4., 248 -> 24.87`4., 249 -> 
          24.79`4., 250 -> 24.61`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$541676 = 
        Dispatch[{
         1 -> 20.04`4., 2 -> 20.33`4., 3 -> 20.24`4., 4 -> 20.22`4., 5 -> 
          20.27`4., 6 -> 20.03`4., 7 -> 20.32`4., 8 -> 20.49`4., 9 -> 
          20.51`4., 10 -> 20.41`4., 11 -> 20.44`4., 12 -> 20.42`4., 13 -> 
          20.38`4., 14 -> 20.42`4., 15 -> 20.35`4., 16 -> 20.46`4., 17 -> 
          20.37`4., 18 -> 20.34`4., 19 -> 20.37`4., 20 -> 20.2`4., 21 -> 
          20.12`4., 22 -> 20.23`4., 23 -> 20.28`4., 24 -> 20.25`4., 25 -> 
          20.28`4., 26 -> 20.11`4., 27 -> 20.16`4., 28 -> 20.02`4., 29 -> 
          20.1`4., 30 -> 20.63`4., 31 -> 20.89`4., 32 -> 20.95`4., 33 -> 
          20.99`4., 34 -> 21.22`4., 35 -> 21.52`4., 36 -> 21.65`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.77`4., 40 -> 21.91`4., 41 -> 
          22.13`4., 42 -> 21.89`4., 43 -> 22.11`4., 44 -> 21.7`4., 45 -> 
          22.29`4., 46 -> 22.39`4., 47 -> 22.43`4., 48 -> 22.41`4., 49 -> 
          22.41`4., 50 -> 22.48`4., 51 -> 22.6`4., 52 -> 22.42`4., 53 -> 
          22.4`4., 54 -> 22.17`4., 55 -> 22.15`4., 56 -> 22.14`4., 57 -> 
          22.14`4., 58 -> 22.31`4., 59 -> 22.35`4., 60 -> 22.5`4., 61 -> 
          21.97`4., 62 -> 21.4`4., 63 -> 20.87`4., 64 -> 20.93`4., 65 -> 
          21.03`4., 66 -> 20.86`4., 67 -> 20.79`4., 68 -> 20.86`4., 69 -> 
          21.14`4., 70 -> 20.94`4., 71 -> 21.24`4., 72 -> 20.98`4., 73 -> 
          20.66`4., 74 -> 20.77`4., 75 -> 20.61`4., 76 -> 20.43`4., 77 -> 
          20.23`4., 78 -> 19.73`4., 79 -> 19.69`4., 80 -> 20.21`4., 81 -> 
          20.18`4., 82 -> 20.23`4., 83 -> 20.52`4., 84 -> 20.55`4., 85 -> 
          20.67`4., 86 -> 20.62`4., 87 -> 20.82`4., 88 -> 20.73`4., 89 -> 
          20.7`4., 90 -> 20.49`4., 91 -> 20.83`4., 92 -> 20.86`4., 93 -> 
          20.95`4., 94 -> 20.97`4., 95 -> 21.2`4., 96 -> 21.41`4., 97 -> 
          21.37`4., 98 -> 21.22`4., 99 -> 21.4`4., 100 -> 21.36`4., 101 -> 
          21.12`4., 102 -> 20.9`4., 103 -> 20.66`4., 104 -> 20.63`4., 105 -> 
          20.61`4., 106 -> 20.54`4., 107 -> 20.38`4., 108 -> 20.66`4., 109 -> 
          21.2`4., 110 -> 21.14`4., 111 -> 20.92`4., 112 -> 20.88`4., 113 -> 
          20.79`4., 114 -> 20.74`4., 115 -> 20.89`4., 116 -> 20.9`4., 117 -> 
          20.9`4., 118 -> 20.87`4., 119 -> 20.86`4., 120 -> 21.2`4., 121 -> 
          21.84`4., 122 -> 21.85`4., 123 -> 21.68`4., 124 -> 21.84`4., 125 -> 
          21.95`4., 126 -> 22.18`4., 127 -> 22.22`4., 128 -> 22.18`4., 129 -> 
          22.04`4., 130 -> 22.28`4., 131 -> 22.13`4., 132 -> 22.26`4., 133 -> 
          22.14`4., 134 -> 22.15`4., 135 -> 22.2`4., 136 -> 22.15`4., 137 -> 
          22.29`4., 138 -> 23.11`4., 139 -> 23.12`4., 140 -> 23.18`4., 141 -> 
          23.37`4., 142 -> 23.37`4., 143 -> 23.17`4., 144 -> 23.26`4., 145 -> 
          23.34`4., 146 -> 22.97`4., 147 -> 23.21`4., 148 -> 23.28`4., 149 -> 
          23.16`4., 150 -> 23.1`4., 151 -> 23.52`4., 152 -> 23.65`4., 153 -> 
          23.64`4., 154 -> 23.71`4., 155 -> 23.56`4., 156 -> 23.41`4., 157 -> 
          23.33`4., 158 -> 23.57`4., 159 -> 23.53`4., 160 -> 23.17`4., 161 -> 
          23.18`4., 162 -> 23.61`4., 163 -> 23.42`4., 164 -> 23.21`4., 165 -> 
          23.3`4., 166 -> 23.12`4., 167 -> 22.96`4., 168 -> 23.02`4., 169 -> 
          22.92`4., 170 -> 23.19`4., 171 -> 23.22`4., 172 -> 22.95`4., 173 -> 
          22.76`4., 174 -> 22.94`4., 175 -> 23.07`4., 176 -> 23.46`4., 177 -> 
          23.53`4., 178 -> 23.4`4., 179 -> 23.12`4., 180 -> 22.92`4., 181 -> 
          22.85`4., 182 -> 22.67`4., 183 -> 21.86`4., 184 -> 21.51`4., 185 -> 
          21.52`4., 186 -> 21.86`4., 187 -> 22.06`4., 188 -> 22.22`4., 189 -> 
          22.14`4., 190 -> 22.2`4., 191 -> 22.17`4., 192 -> 22.14`4., 193 -> 
          22.67`4., 194 -> 22.46`4., 195 -> 22.61`4., 196 -> 22.84`4., 197 -> 
          22.92`4., 198 -> 22.73`4., 199 -> 22.7`4., 200 -> 22.89`4., 201 -> 
          23.07`4., 202 -> 23.17`4., 203 -> 23.29`4., 204 -> 23.39`4., 205 -> 
          23.59`4., 206 -> 23.94`4., 207 -> 23.56`4., 208 -> 23.48`4., 209 -> 
          23.65`4., 210 -> 23.51`4., 211 -> 23.57`4., 212 -> 23.61`4., 213 -> 
          23.59`4., 214 -> 23.57`4., 215 -> 23.4`4., 216 -> 23.2`4., 217 -> 
          23.76`4., 218 -> 23.73`4., 219 -> 23.5`4., 220 -> 23.54`4., 221 -> 
          23.6`4., 222 -> 23.56`4., 223 -> 23.66`4., 224 -> 24.26`4., 225 -> 
          24.16`4., 226 -> 23.69`4., 227 -> 23.64`4., 228 -> 23.15`4., 229 -> 
          23.25`4., 230 -> 23.44`4., 231 -> 23.48`4., 232 -> 23.44`4., 233 -> 
          23.64`4., 234 -> 23.34`4., 235 -> 22.98`4., 236 -> 23.24`4., 237 -> 
          23.53`4., 238 -> 23.8`4., 239 -> 23.73`4., 240 -> 23.96`4., 241 -> 
          24.`4., 242 -> 23.74`4., 243 -> 23.67`4., 244 -> 23.61`4., 245 -> 
          23.94`4., 246 -> 24.95`4., 247 -> 24.92`4., 248 -> 24.88`4., 249 -> 
          24.84`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$541676 = 
        Dispatch[{
         1 -> 19.51`4., 2 -> 19.9`4., 3 -> 20.02`4., 4 -> 20.08`4., 5 -> 
          20.04`4., 6 -> 19.55`4., 7 -> 20.1`4., 8 -> 20.22`4., 9 -> 20.41`4.,
           10 -> 20.22`4., 11 -> 20.26`4., 12 -> 20.27`4., 13 -> 20.2`4., 14 -> 
          20.22`4., 15 -> 20.12`4., 16 -> 20.15`4., 17 -> 20.26`4., 18 -> 
          20.15`4., 19 -> 20.13`4., 20 -> 20.04`4., 21 -> 19.96`4., 22 -> 
          19.89`4., 23 -> 20.12`4., 24 -> 20.09`4., 25 -> 20.14`4., 26 -> 
          19.95`4., 27 -> 19.94`4., 28 -> 19.82`4., 29 -> 19.84`4., 30 -> 
          20.17`4., 31 -> 20.61`4., 32 -> 20.74`4., 33 -> 20.71`4., 34 -> 
          20.96`4., 35 -> 21.05`4., 36 -> 21.27`4., 37 -> 21.19`4., 38 -> 
          21.25`4., 39 -> 21.54`4., 40 -> 21.57`4., 41 -> 21.9`4., 42 -> 
          21.74`4., 43 -> 21.75`4., 44 -> 21.52`4., 45 -> 21.58`4., 46 -> 
          22.06`4., 47 -> 22.14`4., 48 -> 22.14`4., 49 -> 22.15`4., 50 -> 
          22.2`4., 51 -> 22.42`4., 52 -> 22.28`4., 53 -> 22.04`4., 54 -> 
          21.85`4., 55 -> 21.92`4., 56 -> 21.85`4., 57 -> 21.93`4., 58 -> 
          22.01`4., 59 -> 22.15`4., 60 -> 22.23`4., 61 -> 21.32`4., 62 -> 
          20.72`4., 63 -> 20.67`4., 64 -> 20.71`4., 65 -> 20.51`4., 66 -> 
          20.54`4., 67 -> 20.45`4., 68 -> 20.5`4., 69 -> 20.73`4., 70 -> 
          20.68`4., 71 -> 20.91`4., 72 -> 20.54`4., 73 -> 20.36`4., 74 -> 
          20.19`4., 75 -> 20.36`4., 76 -> 20.06`4., 77 -> 19.45`4., 78 -> 
          19.4`4., 79 -> 19.38`4., 80 -> 19.89`4., 81 -> 19.87`4., 82 -> 
          20.06`4., 83 -> 20.22`4., 84 -> 20.35`4., 85 -> 20.33`4., 86 -> 
          19.99`4., 87 -> 20.42`4., 88 -> 20.51`4., 89 -> 20.28`4., 90 -> 
          20.19`4., 91 -> 20.34`4., 92 -> 20.56`4., 93 -> 20.72`4., 94 -> 
          20.83`4., 95 -> 20.82`4., 96 -> 21.04`4., 97 -> 21.01`4., 98 -> 
          21.01`4., 99 -> 21.15`4., 100 -> 20.88`4., 101 -> 20.45`4., 102 -> 
          20.53`4., 103 -> 20.24`4., 104 -> 20.42`4., 105 -> 20.38`4., 106 -> 
          20.09`4., 107 -> 20.1`4., 108 -> 19.93`4., 109 -> 20.86`4., 110 -> 
          20.71`4., 111 -> 20.78`4., 112 -> 20.62`4., 113 -> 20.35`4., 114 -> 
          20.6`4., 115 -> 20.62`4., 116 -> 20.68`4., 117 -> 20.73`4., 118 -> 
          20.67`4., 119 -> 20.72`4., 120 -> 20.78`4., 121 -> 21.25`4., 122 -> 
          21.55`4., 123 -> 21.4`4., 124 -> 21.6`4., 125 -> 21.75`4., 126 -> 
          21.9`4., 127 -> 22.04`4., 128 -> 21.87`4., 129 -> 21.82`4., 130 -> 
          21.96`4., 131 -> 21.92`4., 132 -> 22.09`4., 133 -> 21.95`4., 134 -> 
          21.91`4., 135 -> 22.09`4., 136 -> 21.99`4., 137 -> 22.12`4., 138 -> 
          22.68`4., 139 -> 22.74`4., 140 -> 22.86`4., 141 -> 23.04`4., 142 -> 
          22.98`4., 143 -> 22.94`4., 144 -> 23.04`4., 145 -> 22.63`4., 146 -> 
          22.73`4., 147 -> 22.81`4., 148 -> 23.02`4., 149 -> 22.82`4., 150 -> 
          22.85`4., 151 -> 23.25`4., 152 -> 23.48`4., 153 -> 23.48`4., 154 -> 
          23.49`4., 155 -> 23.26`4., 156 -> 23.14`4., 157 -> 23.21`4., 158 -> 
          23.32`4., 159 -> 23.17`4., 160 -> 22.95`4., 161 -> 22.99`4., 162 -> 
          23.14`4., 163 -> 23.11`4., 164 -> 23.09`4., 165 -> 22.87`4., 166 -> 
          22.83`4., 167 -> 22.67`4., 168 -> 22.81`4., 169 -> 22.79`4., 170 -> 
          22.92`4., 171 -> 22.74`4., 172 -> 22.78`4., 173 -> 22.58`4., 174 -> 
          22.65`4., 175 -> 22.72`4., 176 -> 22.87`4., 177 -> 23.24`4., 178 -> 
          23.14`4., 179 -> 22.63`4., 180 -> 22.72`4., 181 -> 22.47`4., 182 -> 
          22.39`4., 183 -> 21.44`4., 184 -> 20.94`4., 185 -> 21.19`4., 186 -> 
          21.48`4., 187 -> 21.74`4., 188 -> 21.79`4., 189 -> 21.82`4., 190 -> 
          22.03`4., 191 -> 21.92`4., 192 -> 21.97`4., 193 -> 22.37`4., 194 -> 
          22.14`4., 195 -> 22.44`4., 196 -> 22.44`4., 197 -> 22.51`4., 198 -> 
          22.41`4., 199 -> 22.44`4., 200 -> 22.63`4., 201 -> 22.73`4., 202 -> 
          22.92`4., 203 -> 23.01`4., 204 -> 23.24`4., 205 -> 23.4`4., 206 -> 
          23.56`4., 207 -> 23.26`4., 208 -> 23.3`4., 209 -> 23.39`4., 210 -> 
          23.21`4., 211 -> 23.31`4., 212 -> 23.13`4., 213 -> 23.13`4., 214 -> 
          23.22`4., 215 -> 23.03`4., 216 -> 22.91`4., 217 -> 23.28`4., 218 -> 
          23.45`4., 219 -> 23.29`4., 220 -> 23.23`4., 221 -> 23.15`4., 222 -> 
          23.27`4., 223 -> 23.46`4., 224 -> 23.58`4., 225 -> 23.79`4., 226 -> 
          23.2`4., 227 -> 23.21`4., 228 -> 22.76`4., 229 -> 22.94`4., 230 -> 
          23.02`4., 231 -> 23.26`4., 232 -> 23.16`4., 233 -> 23.19`4., 234 -> 
          22.88`4., 235 -> 22.76`4., 236 -> 22.95`4., 237 -> 23.27`4., 238 -> 
          23.51`4., 239 -> 23.36`4., 240 -> 23.63`4., 241 -> 23.59`4., 242 -> 
          23.56`4., 243 -> 23.34`4., 244 -> 23.43`4., 245 -> 23.56`4., 246 -> 
          24.1`4., 247 -> 24.73`4., 248 -> 24.63`4., 249 -> 24.56`4., 250 -> 
          24.52`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$541676 = 
        Dispatch[{
         1 -> 19.9`4., 2 -> 20.25`4., 3 -> 20.13`4., 4 -> 20.08`4., 5 -> 
          20.06`4., 6 -> 19.86`4., 7 -> 20.28`4., 8 -> 20.29`4., 9 -> 
          20.44`4., 10 -> 20.33`4., 11 -> 20.38`4., 12 -> 20.42`4., 13 -> 
          20.31`4., 14 -> 20.26`4., 15 -> 20.28`4., 16 -> 20.37`4., 17 -> 
          20.32`4., 18 -> 20.25`4., 19 -> 20.18`4., 20 -> 20.11`4., 21 -> 
          19.97`4., 22 -> 20.13`4., 23 -> 20.18`4., 24 -> 20.14`4., 25 -> 
          20.15`4., 26 -> 19.97`4., 27 -> 20.04`4., 28 -> 19.85`4., 29 -> 
          19.98`4., 30 -> 20.62`4., 31 -> 20.89`4., 32 -> 20.79`4., 33 -> 
          20.89`4., 34 -> 21.18`4., 35 -> 21.31`4., 36 -> 21.4`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.71`4., 40 -> 21.87`4., 41 -> 
          21.97`4., 42 -> 21.8`4., 43 -> 21.76`4., 44 -> 21.55`4., 45 -> 
          22.16`4., 46 -> 22.15`4., 47 -> 22.24`4., 48 -> 22.22`4., 49 -> 
          22.34`4., 50 -> 22.38`4., 51 -> 22.54`4., 52 -> 22.35`4., 53 -> 
          22.06`4., 54 -> 21.87`4., 55 -> 21.95`4., 56 -> 21.92`4., 57 -> 
          22.08`4., 58 -> 22.08`4., 59 -> 22.34`4., 60 -> 22.24`4., 61 -> 
          21.48`4., 62 -> 21.16`4., 63 -> 20.75`4., 64 -> 20.73`4., 65 -> 
          20.73`4., 66 -> 20.58`4., 67 -> 20.54`4., 68 -> 20.81`4., 69 -> 
          20.78`4., 70 -> 20.88`4., 71 -> 21.05`4., 72 -> 20.6`4., 73 -> 
          20.37`4., 74 -> 20.48`4., 75 -> 20.37`4., 76 -> 20.17`4., 77 -> 
          19.51`4., 78 -> 19.56`4., 79 -> 19.65`4., 80 -> 20.15`4., 81 -> 
          20.11`4., 82 -> 20.17`4., 83 -> 20.52`4., 84 -> 20.54`4., 85 -> 
          20.35`4., 86 -> 20.61`4., 87 -> 20.6`4., 88 -> 20.6`4., 89 -> 
          20.3`4., 90 -> 20.34`4., 91 -> 20.7`4., 92 -> 20.84`4., 93 -> 
          20.93`4., 94 -> 20.86`4., 95 -> 20.97`4., 96 -> 21.24`4., 97 -> 
          21.08`4., 98 -> 21.08`4., 99 -> 21.38`4., 100 -> 21.15`4., 101 -> 
          20.49`4., 102 -> 20.71`4., 103 -> 20.55`4., 104 -> 20.49`4., 105 -> 
          20.44`4., 106 -> 20.36`4., 107 -> 20.11`4., 108 -> 20.65`4., 109 -> 
          21.`4., 110 -> 20.76`4., 111 -> 20.86`4., 112 -> 20.79`4., 113 -> 
          20.57`4., 114 -> 20.62`4., 115 -> 20.83`4., 116 -> 20.79`4., 117 -> 
          20.78`4., 118 -> 20.86`4., 119 -> 20.78`4., 120 -> 20.96`4., 121 -> 
          21.69`4., 122 -> 21.66`4., 123 -> 21.59`4., 124 -> 21.7`4., 125 -> 
          21.93`4., 126 -> 22.14`4., 127 -> 22.14`4., 128 -> 21.87`4., 129 -> 
          21.92`4., 130 -> 22.26`4., 131 -> 21.95`4., 132 -> 22.18`4., 133 -> 
          22.08`4., 134 -> 22.12`4., 135 -> 22.14`4., 136 -> 22.09`4., 137 -> 
          22.22`4., 138 -> 23.02`4., 139 -> 23.04`4., 140 -> 22.92`4., 141 -> 
          23.37`4., 142 -> 23.04`4., 143 -> 23.08`4., 144 -> 23.2`4., 145 -> 
          22.63`4., 146 -> 22.87`4., 147 -> 23.18`4., 148 -> 23.04`4., 149 -> 
          23.01`4., 150 -> 23.09`4., 151 -> 23.4`4., 152 -> 23.48`4., 153 -> 
          23.49`4., 154 -> 23.58`4., 155 -> 23.43`4., 156 -> 23.22`4., 157 -> 
          23.3`4., 158 -> 23.5`4., 159 -> 23.25`4., 160 -> 23.07`4., 161 -> 
          23.14`4., 162 -> 23.27`4., 163 -> 23.11`4., 164 -> 23.18`4., 165 -> 
          23.06`4., 166 -> 22.94`4., 167 -> 22.92`4., 168 -> 22.94`4., 169 -> 
          22.9`4., 170 -> 23.16`4., 171 -> 22.82`4., 172 -> 22.9`4., 173 -> 
          22.75`4., 174 -> 22.94`4., 175 -> 22.88`4., 176 -> 23.39`4., 177 -> 
          23.4`4., 178 -> 23.27`4., 179 -> 22.63`4., 180 -> 22.92`4., 181 -> 
          22.58`4., 182 -> 22.49`4., 183 -> 21.58`4., 184 -> 21.18`4., 185 -> 
          21.33`4., 186 -> 21.79`4., 187 -> 21.78`4., 188 -> 22.03`4., 189 -> 
          22.09`4., 190 -> 22.11`4., 191 -> 21.97`4., 192 -> 22.14`4., 193 -> 
          22.39`4., 194 -> 22.4`4., 195 -> 22.5`4., 196 -> 22.83`4., 197 -> 
          22.6`4., 198 -> 22.72`4., 199 -> 22.67`4., 200 -> 22.83`4., 201 -> 
          23.06`4., 202 -> 23.09`4., 203 -> 23.27`4., 204 -> 23.38`4., 205 -> 
          23.47`4., 206 -> 23.67`4., 207 -> 23.47`4., 208 -> 23.34`4., 209 -> 
          23.41`4., 210 -> 23.45`4., 211 -> 23.41`4., 212 -> 23.14`4., 213 -> 
          23.45`4., 214 -> 23.47`4., 215 -> 23.14`4., 216 -> 23.19`4., 217 -> 
          23.67`4., 218 -> 23.59`4., 219 -> 23.39`4., 220 -> 23.31`4., 221 -> 
          23.49`4., 222 -> 23.33`4., 223 -> 23.58`4., 224 -> 24.14`4., 225 -> 
          23.79`4., 226 -> 23.25`4., 227 -> 23.36`4., 228 -> 22.93`4., 229 -> 
          23.11`4., 230 -> 23.25`4., 231 -> 23.32`4., 232 -> 23.19`4., 233 -> 
          23.34`4., 234 -> 22.9`4., 235 -> 22.91`4., 236 -> 23.24`4., 237 -> 
          23.32`4., 238 -> 23.62`4., 239 -> 23.54`4., 240 -> 23.94`4., 241 -> 
          23.76`4., 242 -> 23.63`4., 243 -> 23.43`4., 244 -> 23.54`4., 245 -> 
          23.63`4., 246 -> 24.72`4., 247 -> 24.86`4., 248 -> 24.71`4., 249 -> 
          24.62`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$541676 = True, 
        System`TradingChartDump`$gridlines$541676 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$541676, 
        System`TradingChartDump`$plotrangemin$541676 = 19.0982952853598, 
        System`TradingChartDump`$plotrangemax$541676 = 25.507305210918112`, 
        System`TradingChartDump`$layoutData$541676, 
        System`TradingChartDump`$gridlinesscope$541676 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$541676 = {True, True}, 
        System`TradingChartDump`$indicators$541676 = {
         FinancialIndicator["ParabolicStopAndReversal", 0.02, 0.2]}, 
        System`TradingChartDump`$mouseQ$541676 = False, 
        System`TradingChartDump`$modelData$541676 = 
        System`TradingChartDump`modelData$539620, 
        System`TradingChartDump`$sy$541676 = Identity, 
        System`TradingChartDump`$isy$541676 = Identity, 
        System`TradingChartDump`$appearance$541676 = Automatic, 
        System`TradingChartDump`$perfgoal$541676 = "Quality", 
        System`TradingChartDump`$axesorigin$541676 = Automatic, 
        System`TradingChartDump`$framestyle$541676 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$541676 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$541676 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$541676 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$541676 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$541676, 
        System`TradingChartDump`$newgridlines$541676 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{19.0982952853598, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$541676 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$541676 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$541676 = "GraphicsFrame", 
        System`TradingChartDump`$frame$541676 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$541676 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$541676 = 
              Switch[System`TradingChartDump`$highlightposition$541676, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$541676], {
                 1, System`TradingChartDump`$length$541676}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$541676], {
                 1, System`TradingChartDump`$length$541676}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$541676, 
                   Charting`nearestDate[System`TradingChartDump`$dates$541676, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$541676]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$541676]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$541676, 
                    Floor[System`TradingChartDump`$controlmin$541676] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$541676, 
                    Floor[System`TradingChartDump`$controlmax$541676]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$541676 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$541676 = 
            If[System`TradingChartDump`$fastpos$541676 =!= True, 
              System`TradingChartDump`$fastpos$541676 = 
               Clip[System`TradingChartDump`$fastpos$541676, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$541676 = (
                  Floor[System`TradingChartDump`$controlmax$541676] - Floor[
                  System`TradingChartDump`$controlmin$541676]) (
                  System`TradingChartDump`$fastpos$541676/100) + 
                Floor[System`TradingChartDump`$controlmin$541676]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$541676], {
                Floor[System`TradingChartDump`$controlmin$541676] + 1, 
                 Floor[System`TradingChartDump`$controlmax$541676]}], 
              System`TradingChartDump`$staticindicatorpos$541676]; 
           System`TradingChartDump`$mouseQ$541676 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$541676]], 
              System`TradingChartDump`$highlightposition$541676 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$541676 = If[
              And[
              System`TradingChartDump`$bouncingballQ$541676, 
               System`TradingChartDump`$mouseQ$541676, 
               System`TradingChartDump`$appearance$541676 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$541676[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$541676]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$541676[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$541676, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$541676[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$541676]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$541676[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$541676[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541676, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541676[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541676, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541676, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541676[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541676[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$541676 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$541676, 
                 System`TradingChartDump`$defaultframeticksstyle$541676, 
                 System`TradingChartDump`$defaultlabelstyle$541676, 
                 System`TradingChartDump`$framestyle$541676, 
                 System`TradingChartDump`$frameticksstyle$541676, 
                 System`TradingChartDump`$labelstyle$541676}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541676 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$541676, 
                 System`TradingChartDump`$labelstyle$541676, 
                 System`TradingChartDump`$defaultframeticksstyle$541676, 
                 System`TradingChartDump`$defaultlabelstyle$541676}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541676 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541676, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$541676 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541676, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$541676 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541676, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$541676 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$541676 = 
             Part[System`TradingChartDump`$tickstextstyle$541676, 1], 
             System`TradingChartDump`$tickstextstyle$541676 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541676[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541676, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541676[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541676[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541676[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$541676[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541676, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$541676]], 
                    Style[":", System`TradingChartDump`$textstyle$541676]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$541676[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541676]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541676[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$541676[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$541676, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$541676]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$541676[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541676, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541676[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541676, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541676, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$541676[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541676[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541676[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$541676[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$541676[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$541676], 1], 
                   Floor[System`TradingChartDump`$controlmax$541676]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$541676[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$541676[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$541676[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$541676[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$541676[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541676[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$541676[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$541676[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$541676[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541676[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$541676[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$541676[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$541676[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$541676[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$541676[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$541676, 
                  System`TradingChartDump`$mouseQ$541676], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$541676 - 0.5, 
                   System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$541676 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$541676 + 0.5, 
                    System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541676, 1]}, {
                    System`TradingChartDump`$indicatorpos$541676 + 0.5, 
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$541676[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$541676, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$541676[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541676]]], {}]; 
              System`TradingChartDump`$subplotgridlines$541676[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$541676[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$541676[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541676[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$541676 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$541676, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541676, 
                   System`TradingChartDump`$opens$541676]], 12, 
                 System`TradingChartDump`$textstyle$541676, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$541676, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541676, 
                   System`TradingChartDump`$highs$541676]], 12, 
                 System`TradingChartDump`$textstyle$541676, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$541676, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541676, 
                   System`TradingChartDump`$lows$541676]], 12, 
                 System`TradingChartDump`$textstyle$541676, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$541676, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541676, 
                   System`TradingChartDump`$closes$541676]], 12, 
                 System`TradingChartDump`$textstyle$541676, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541676, 
                   System`TradingChartDump`$visdates$541676]], 12, 
                 System`TradingChartDump`$textstyle$541676, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$541676, 
                  System`TradingChartDump`$mouseQ$541676], {{
                  System`TradingChartDump`$timestampstyle$541676, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$541676 - 0.5, 
                    System`TradingChartDump`$plotrangemin$541676}, 
                    If[
                    System`TradingChartDump`$timestampdepth$541676 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$541676[1]}, {
                    System`TradingChartDump`$indicatorpos$541676 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541676}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541676, 1]}, {
                    System`TradingChartDump`$indicatorpos$541676 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541676}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$541676, {
               System`TradingChartDump`$highlightstyle$541676, 
                Dynamic[System`TradingChartDump`$ohlcpoint$541676]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$541676[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541676, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$541676[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$541676[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$541676, Length[
                    System`TradingChartDump`$layoutData$541676[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$541676}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$541676] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$541676] + 0.5}, {
                System`TradingChartDump`$plotrangemin$541676, 
                 System`TradingChartDump`$plotrangemax$541676}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$541676, Left, {
                 False, System`TradingChartDump`$frame$541676}, 
                 Blank[], {System`TradingChartDump`$frame$541676, False}], {
                False, System`TradingChartDump`$frame$541676}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$541676, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$541676]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$541676 100}], 
           StandardForm, Graphics],
          ImageSizeCache->{{5.252189972793673, 
           411.14299847591394`}, {-286.9271576880515, -36.072842311948435`}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541676 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541676, 1]], 
               Part[System`TradingChartDump`$framestyle$541676, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$541676]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$541676} -> 
                   System`TradingChartDump`$isy$541676[
                    System`TradingChartDump`$plotrangemin$541676], {
                    0, System`TradingChartDump`$plotrangemax$541676} -> 
                   System`TradingChartDump`$isy$541676[
                    System`TradingChartDump`$plotrangemax$541676]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$541676[
                   System`TradingChartDump`$plotrangemin$541676], 
                   System`TradingChartDump`$isy$541676[
                   System`TradingChartDump`$plotrangemax$541676]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$541676, 
                   System`TradingChartDump`$isy$541676}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541676, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541676 > 
                    System`TradingChartDump`$plotrangemin$541676, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541676 > 
                    System`TradingChartDump`$plotrangemin$541676, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541676, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541676 > 
                    System`TradingChartDump`$plotrangemin$541676, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541676 > 
                    System`TradingChartDump`$plotrangemin$541676, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541676, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541676, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541676 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541676,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541676], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541676 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541676, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541676]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 251.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$541676, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$541676[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$541676[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541676, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$541676[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$541676, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541676[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541676, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541676[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541676[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541676[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541676[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541676], 
                    Style[":", System`TradingChartDump`$textstyle$541676]], 
                    Style[":", System`TradingChartDump`$textstyle$541676]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$541676[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541676]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541676[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$541676}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$541676, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$541676 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$541676[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$541676, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$541676, Left, {
                    False, System`TradingChartDump`$frame$541676}, 
                    Blank[], {
                    System`TradingChartDump`$frame$541676, False}], {
                   System`TradingChartDump`$frame$541676, 
                    System`TradingChartDump`$frame$541676}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$541676, 
                    System`TradingChartDump`$controlmax$541676}] + 0.5, {
                   System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$541676]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$541676) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$541676 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$541676 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$541676, 1]], 
                   Part[System`TradingChartDump`$framestyle$541676, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$541676]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541676[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541676[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$541676[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541676, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541676, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$541676, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$541676, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$541676 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
541676, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$541676], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$541676 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$541676, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$541676]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$541676, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$541676) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$541676 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$541676[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$541676, 
              Dynamic[System`TradingChartDump`$ohlclabel$541676], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$541676}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541676 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541676, 2]], 
               Part[System`TradingChartDump`$framestyle$541676, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$541676]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$541676, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$541676, 
                    System`TradingChartDump`$controlmax$541676}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$541676] + 
                    0.5, System`TradingChartDump`$plotrangemin$541676}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$541676], 
                    System`TradingChartDump`$plotrangemin$541676}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$541676, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541676, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541676, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541676 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541676, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541676], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541676 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541676,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541676]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              406.4142135623731}, {-41.414213562373114`, \
-24.996705587314885`}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$overlaypoint$541676] = {
            HoldPattern[
               System`TradingChartDump`$overlaypoint$541676[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$overlayvalue$541676] = {
            HoldPattern[
               System`TradingChartDump`$overlayvalue$541676[1, 1]] :> {}}}, {
          DownValues[System`TradingChartDump`$layoutData$541676] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$541676["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541676["AllValues"]] :> {{
               19.512840466926068`, 20.035505836575872`, {19.513}}, {
               19.901529636711278`, 20.327437858508603`, {
                19.676000000000002`}}, {
               20.023543269230768`, 20.236456730769227`, {19.806}}, {
               20.08, 20.21547951807229, {19.91}}, {
               20.040646406174623`, 20.27288953207911, {20.327}}, {
               19.55029239766082, 20.03421052631579, {19.55}}, {
               20.096164122137402`, 20.318702290076335`, {19.566}}, {
               20.22226990939437, 20.493190271816882`, {19.603}}, {
               20.410965909090912`, 20.507746212121216`, {19.657}}, {
               20.22356020942408, 20.407410756782483`, {
                19.708000000000002`}}, {
               20.263874643874647`, 20.43806267806268, {19.756}}, {
               20.265156398104267`, 20.42, {19.801000000000002`}}, {
               20.2035636017151, 20.377732253454024`, {19.844}}, {
               20.22129894937918, 20.42447946513849, {19.883}}, {
               20.11551526717557, 20.34772900763359, {19.921}}, {
               20.147429928741094`, 20.457092636579574`, {19.956}}, {
               20.26194285714286, 20.368380952380953`, {19.989}}, {
               20.153248924988052`, 20.33707596751075, {20.02}}, {
               20.131606714628298`, 20.373573141486812`, {20.508}}, {
               20.04225697786333, 20.197098171318576`, {20.498}}, {
               19.960324612403095`, 20.115130813953485`, {20.477}}, {
               19.888052884615384`, 20.22677884615384, {20.442}}, {
               20.121928057553955`, 20.276786570743404`, {20.408}}, {
               20.09160980297934, 20.246458433445465`, {20.377}}, {
               20.140321805955807`, 20.275816522574445`, {20.348}}, {
               19.9506492248062, 20.10545542635659, {20.32}}, {
               19.94323515210043, 20.156117817479473`, {20.294}}, {
               19.820965382740127`, 20.024207703559238`, {20.256}}, {
               19.84454237288136, 20.096106537530268`, {19.821}}, {
               20.17489441576725, 20.629676208352887`, {19.837}}, {
               20.609402501157945`, 20.89, {19.879}}, {
               20.741606145251396`, 20.954539106145248`, {19.944}}, {
               20.70616025937934, 20.9867577582214, {20.027}}, {
               20.957460027409777`, 21.218702603928733`, {20.146}}, {
               21.048705722070842`, 21.522906448683013`, {20.312}}, {
               21.27417458163727, 21.651650836725466`, {20.499}}, {
               21.194829931972787`, 21.34, {20.661}}, {
               21.24906474820144, 21.52, {20.799}}, {
               21.535777975925104`, 21.768074008024968`, {20.954}}, {
               21.567739634418192`, 21.909001337494427`, {21.126}}, {
               21.901739902352418`, 22.126023080337326`, {21.326}}, {
               21.74150268336315, 21.887745974955276`, {21.486}}, {
               21.750246526221428`, 22.11112505602869, {22.126}}, {
               21.520746606334843`, 21.69626696832579, {21.521}}, {
               21.575046194456664`, 22.286739991201056`, {21.536}}, {
               22.062219286657857`, 22.393835314839276`, {21.57}}, {
               22.14249890398948, 22.42525208241999, {21.622}}, {
               22.142000877577885`, 22.414997806055286`, {21.67}}, {
               22.154727193365343`, 22.40825840244435, {21.715}}, {
               22.204470588235292`, 22.477516339869283`, {21.776}}, {
               22.423010380622834`, 22.598494809688578`, {21.858}}, {
               22.281740837696336`, 22.418259162303666`, {
                21.932000000000002`}}, {
               22.04049513704686, 22.401335101679926`, {22.598}}, {
               21.850499331252788`, 22.17226036558181, {22.584}}, {
               21.92074633496224, 22.14502443358507, {22.569}}, {
               21.851743772241996`, 22.144270462633454`, {22.555}}, {
               21.933710247349822`, 22.138515901060067`, {22.54}}, {
               22.01173144876325, 22.314063604240282`, {22.527}}, {
               22.154727193365343`, 22.349751200349196`, {22.513}}, {
               22.230249890398948`, 22.50325295922841, {22.23}}, {
               21.323994552882436`, 21.967517022242397`, {22.194}}, {
               20.72119815668203, 21.40377880184332, {22.106}}, {
               20.671992481203006`, 20.867011278195488`, {21.991}}, {
               20.71049858889934, 20.925014111006586`, {21.885}}, {
               20.505733772342428`, 21.032271872060207`, {21.747}}, {
               20.541004263382284`, 20.862719090478446`, {21.623}}, {
               20.452222222222222`, 20.79358024691358, {21.483}}, {
               20.497947516401123`, 20.858758200562324`, {21.359}}, {
               20.731243547630225`, 21.14079774753637, {21.25}}, {
               20.67519850537132, 20.938514712751047`, {20.452}}, {
               20.913501621120886`, 21.235247799907366`, {20.468}}, {
               20.54150496923805, 20.980217699952675`, {21.235}}, {
               20.36024892292963, 20.66253231211106, {21.218}}, {
               20.18742857142857, 20.77257142857143, {21.177}}, {
               20.36024892292963, 20.613776926759215`, {21.137}}, {
               20.06271276595745, 20.433341392649908`, {21.073}}, {
               19.451499250374813`, 20.231509245377314`, {20.943}}, {
               19.403988035892322`, 19.72576271186441, {20.789}}, {
               19.376947890818858`, 19.689007444168734`, {20.62}}, {
               19.88666505324298, 20.208518877057113`, {20.47}}, {
               19.8661833171678, 20.178268671193017`, {
                20.339000000000002`}}, {
               20.06271276595745, 20.22852030947776, {19.377}}, {
               20.217661596958177`, 20.52, {19.400000000000002`}}, {
               20.35469135802469, 20.549753086419752`, {19.446}}, {
               20.330498322951605`, 20.67177767129851, {
                19.519000000000002`}}, {
               19.9860454115421, 20.619749290444656`, {19.589}}, {
               20.42451490771415, 20.824230951254144`, {19.687}}, {
               20.512257453857078`, 20.726739233317563`, {19.778}}, {
               20.280499519692604`, 20.699759846301635`, {
                19.862000000000002`}}, {
               20.19373921380633, 20.486260786193675`, {19.939}}, {
               20.339236928874232`, 20.8267545925577, {20.028}}, {
               20.557192325690217`, 20.859503977538605`, {20.128}}, {
               20.71543336439888, 20.94950605778192, {20.243000000000002`}}, {
               20.830743338008414`, 20.967274427302478`, {20.359}}, {
               20.823765690376565`, 21.203974895397486`, {20.511}}, {
               21.035206611570246`, 21.40578512396694, {20.69}}, {
               21.011748381128584`, 21.37250693802035, {
                20.833000000000002`}}, {
               21.011748381128584`, 21.21650323774283, {20.948}}, {
               21.146019151846783`, 21.399498404012764`, {21.406}}, {
               20.876970954356842`, 21.36452282157676, {21.395}}, {
               20.450990004759635`, 21.123912422655877`, {21.357}}, {
               20.532907363420428`, 20.89693111638955, {21.321}}, {
               20.235057471264366`, 20.658261494252873`, {21.256}}, {
               20.421109510086453`, 20.62778097982709, {21.195}}, {
               20.380953298026, 20.60729898892634, {21.137}}, {
               20.094306428226197`, 20.537129047849202`, {
                21.054000000000002`}}, {
               20.1001614481409, 20.375640900195695`, {20.977}}, {
               19.931824678418295`, 20.65983801810386, {
                19.932000000000002`}}, {
               20.8622305529522, 21.196813495782568`, {19.957}}, {
               20.710805687203795`, 21.143715639810427`, {19.982}}, {
               20.781283018867928`, 20.91903773584906, {20.006}}, {
               20.622735447231427`, 20.87855182205395, {20.03}}, {
               20.353473684210527`, 20.786526315789477`, {20.053}}, {
               20.600315035799525`, 20.738109785202866`, {20.076}}, {
               20.623372697213032`, 20.88903637222484, {20.099}}, {
               20.68176999526739, 20.898230004732607`, {20.121}}, {
               20.730804924242427`, 20.898068181818182`, {20.142}}, {
               20.673047169811323`, 20.86983962264151, {20.163}}, {
               20.72096590909091, 20.858712121212122`, {20.184}}, {
               20.78287323943662, 21.196169014084504`, {20.204}}, {
               21.247146098003633`, 21.83761796733213, {
                20.269000000000002`}}, {
               21.55174920490686, 21.846978646069967`, {20.364}}, {
               21.40303099361896, 21.67856426618049, {20.453}}, {
               21.6015873015873, 21.837777777777777`, {20.537}}, {
               21.752907133243607`, 21.949676985195154`, {
                20.650000000000002`}}, {
               21.903840000000002`, 22.179360000000003`, {20.803}}, {
               22.041600000000003`, 22.21872, {20.973}}, {
               21.87, 22.184817813765186`, {21.122}}, {
               21.8216157989228, 22.03806104129264, {21.254}}, {
               21.964774535809017`, 22.27968169761273, {
                21.397000000000002`}}, {
               21.920484087852984`, 22.127095472882115`, {21.521}}, {
               22.091437444543033`, 22.258722271517303`, {21.627}}, {
               21.952085561497324`, 22.139037433155078`, {21.718}}, {
               21.913362989323847`, 22.14951957295374, {21.797}}, {
               22.0908, 22.19904, {21.865000000000002`}}, {
               21.99160356347439, 22.14903786191537, {21.923000000000002`}}, {
               22.121594331266607`, 22.288883968113375`, {21.981}}, {
               22.675536554082942`, 23.108576314664386`, {22.184}}, {
               22.74474156343443, 23.11873558308415, {22.371000000000002`}}, {
               22.86095319879777, 23.175869471876346`, {22.532}}, {
               23.03544, 23.37, {22.7}}, {
               22.980948312686888`, 23.374626228107648`, {22.835}}, {
               22.9410834049871, 23.169303525365432`, {22.941}}, {
               23.041299700726807`, 23.259512612227446`, {23.375}}, {
               22.630000000000003`, 23.344318281455507`, {23.36}}, {
               22.73109327548807, 22.96921908893709, {23.345}}, {
               22.813008130081297`, 23.20975609756097, {23.331}}, {
               23.02015503875969, 23.27813953488372, {23.317}}, {
               22.821474773609314`, 23.158835705045277`, {23.303}}, {
               22.851856467554793`, 23.09992264718522, {22.63}}, {
               23.251208139041967`, 23.519033488766425`, {22.648}}, {
               23.48, 23.648635403464297`, {22.688}}, {
               23.480080236486486`, 23.638796452702696`, {22.726}}, {
               23.49071939419436, 23.708960875052586`, {22.785}}, {
               23.261367485182046`, 23.558954276037255`, {22.841}}, {
               23.140649295173, 23.408457923964118`, {22.893}}, {
               23.21072796934866, 23.329757343550448`, {22.942}}, {
               23.321443647108484`, 23.569438581680036`, {22.988}}, {
               23.17064846416382, 23.527730375426618`, {23.709}}, {
               22.950929032258063`, 23.169225806451614`, {23.694}}, {
               22.991157804459693`, 23.17969125214408, {
                23.679000000000002`}}, {
               23.141052855924976`, 23.607246376811595`, {23.664}}, {
               23.109999999999996`, 23.417604121940748`, {
                23.650000000000002`}}, {
               23.090731707317072`, 23.20975609756097, {23.636}}, {
               22.87147160068847, 23.298141135972465`, {23.606}}, {
               22.830856401384082`, 23.118598615916955`, {23.559}}, {
               22.671948051948053`, 22.95968831168831, {23.488}}, {
               22.81101211072664, 23.019377162629755`, {
                23.423000000000002`}}, {
               22.79085788561525, 22.91984402079723, {23.363}}, {
               22.92185089974293, 23.189768637532133`, {
                23.307000000000002`}}, {
               22.740626086956524`, 23.21686956521739, {23.257}}, {
               22.780935875216638`, 22.949610051993066`, {23.21}}, {
               22.58133449629307, 22.75992150021806, {23.147000000000002`}}, {
               22.652257785467125`, 22.94, {23.09}}, {
               22.721248915871637`, 23.068516912402426`, {22.581}}, {
               22.87418999151824, 23.45943596268024, {22.599}}, {
               23.241288681644765`, 23.528952946163628`, {22.636}}, {
               23.141052855924976`, 23.39894714407502, {23.529}}, {
               22.630000000000003`, 23.11613327487944, {23.511}}, {
               22.72155844155844, 22.92, {23.493000000000002`}}, {
               22.470869947275915`, 22.847864674868188`, {23.452}}, {
               22.39079400088222, 22.668570798412, {23.389}}, {
               21.44109425287356, 21.85781149425287, {23.233}}, {
               20.94191100702576, 21.507372365339577`, {23.004}}, {
               21.191106976744184`, 21.518497674418605`, {
                22.798000000000002`}}, {
               21.482399817850634`, 21.859458105646628`, {
                22.612000000000002`}}, {
               21.74030979498861, 22.05783143507973, {22.445}}, {
               21.791945069788383`, 22.218460153084195`, {22.295}}, {
               21.82218230803772, 22.139595868881905`, {20.942}}, {
               22.03064602960969, 22.1992732166891, {20.967}}, {
               21.920406320541762`, 22.168374717832958`, {20.992}}, {
               21.971370967741933`, 22.14, {21.016000000000002`}}, {
               22.370159503766065`, 22.667766947275148`, {21.082}}, {
               22.14207263064659, 22.45952170062002, {21.145}}, {
               22.44047619047619, 22.60912698412698, {21.206}}, {
               22.443050847457627`, 22.83992177314211, {
                21.304000000000002`}}, {
               22.510711150131694`, 22.91747146619842, {21.433}}, {
               22.412436681222708`, 22.729921397379915`, {21.552}}, {
               22.441811816192562`, 22.699763676148795`, {21.661}}, {
               22.631564537157754`, 22.889530638852673`, {21.762}}, {
               22.732555938037866`, 23.069922547332187`, {21.893}}, {
               22.921314997851315`, 23.16938117748174, {22.046}}, {
               23.012105711849955`, 23.289838022165387`, {22.22}}, {
               23.241128553245648`, 23.389919389053876`, {22.407}}, {
               23.400562130177512`, 23.58903634826712, {22.62}}, {
               23.56087594300084, 23.937849958088854`, {22.883}}, {
               23.261686390532542`, 23.559277261200336`, {23.094}}, {
               23.3003229919252, 23.478869528261797`, {23.263}}, {
               23.39016101694915, 23.648067796610167`, {23.938}}, {
               23.21192893401015, 23.50951776649746, {23.923000000000002`}}, {
               23.310805084745763`, 23.56871186440678, {23.909}}, {
               23.13007718696398, 23.606372212692968`, {23.878}}, {
               23.132571912013535`, 23.588874788494078`, {23.848}}, {
               23.22200760777684, 23.569196956889265`, {23.819}}, {
               23.030849056603774`, 23.397993138936535`, {
                23.772000000000002`}}, {
               22.9122754491018, 23.19991873396065, {22.912}}, {
               23.28310561609388, 23.759283319362954`, {
                22.929000000000002`}}, {
               23.45111858704794, 23.728881412952063`, {22.946}}, {
               23.290805767599664`, 23.49911365564038, {22.962}}, {
               23.230646808510638`, 23.538140425531914`, {22.978}}, {
               23.152728040540538`, 23.599117398648644`, {22.994}}, {
               23.27048469387755, 23.55814200680272, {23.009}}, {
               23.460959192259146`, 23.6593605384939, {23.024}}, {
               23.58437320180847, 24.259062885326763`, {23.073}}, {
               23.79, 24.15706839032527, {23.121000000000002`}}, {
               23.2, 23.69, {23.166}}, {
               23.209999999999997`, 23.639999999999997`, {24.259}}, {
               22.76, 23.15, {24.229}}, {
               22.939999999999998`, 23.249999999999996`, {24.2}}, {
               23.02, 23.44, {24.171}}, {23.26, 23.48, {24.143}}, {
               23.16, 23.44, {24.115000000000002`}}, {
               23.189999999999998`, 23.639999999999997`, {24.088}}, {
               22.88, 23.34, {24.061}}, {22.76, 22.98, {24.035}}, {
               22.95, 23.24, {24.01}}, {23.27, 23.53, {23.985}}, {
               23.51, 23.8, {23.96}}, {
               23.359999999999996`, 23.729999999999997`, {22.76}}, {
               23.63, 23.96, {22.784}}, {23.59, 24., {22.833000000000002`}}, {
               23.56, 23.74, {22.879}}, {
               23.339999999999996`, 23.669999999999998`, {22.924}}, {
               23.429999999999996`, 23.609999999999996`, {22.967}}, {
               23.56, 23.94, {23.009}}, {24.1, 24.95, {23.125}}, {
               24.73, 24.92, {23.234}}, {24.63, 24.88, {23.337}}, {
               24.56, 24.84, {23.434}}, {
               24.52, 24.69, {23.525000000000002`}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541676["AppendedAdjust"]] :> 
             0.4882114994507905, HoldPattern[
               System`TradingChartDump`$layoutData$541676["AppendedBox"]] :> {
              16.47040570719603, 31.536781750924792`}, HoldPattern[
               System`TradingChartDump`$layoutData$541676["AppendedMin"]] :> 
             19.132842141093462`, HoldPattern[
               System`TradingChartDump`$layoutData$541676["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$541676["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$541676["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$541676["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541676["DataMax"]] :> 
             24.95, HoldPattern[
               System`TradingChartDump`$layoutData$541676["DataMin"]] :> 
             19.376947890818858`, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "MainChartAllValues"]] :> CompressedData["
1:eJxFVwk81csXp5Il0aKkJP4Rkcid38yVcCRRKUta9KToka2QVLRok6Wi5SFb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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "MainChartPoints"]] :> CompressedData["
1:eJxdV1toXFUUvRZFKYIKBf0ocapS6oNSTR/xEbubNk2apk1mMslkksnkztyZ
O487M6n4IxXhIuRHhFAoSEVkRBFBEEEKoV+X+CGIIoJQBJEpQhEiUpCK9MuZ
2Wt97HMhDOvuu886e+3HOTlQ3shU7/c8717/7z787fH43DkZDp7bo4IX+itH
gR+SW5f3fTV1gPhR6aP+K+J9srVz91DhEeInpDB48RvX2y/TwwVoT8nem59e
Gp8hfkreGB+8IX5G188SH1T+EvEh+Su9PbIZET+n/HPEL8i3fbg1QXzY4T8i
T27upreLxC9Kpr/cbpr4JSf+URmGe5j4qMa3n/iYDN3/Y7zHHb1OOP5j8tml
fsBPE78sQ/0PEr/irPeq6rWX9tfkw2v951fax+XtgWD3iF/X+D7m9yeV7w9i
0fW+B47FsZ/Cfo/Bfgr6AnsTut+Q9gkZbi9H+2kZ0I9s0n5a/u2nY+c67Wd0
f7/Tfgbx0j4pP/4weGif1Hzu0H5W7e/TflaeHSbkOOxT0BM4npJheY3TPq18
Y7RPY/+0n0O90X5O9XqP9hnVP0/7DOqf9vNOfOdldPD8w/3Pav3u0j6LfqL/
BYvjC87+Ltp44oua/8tcfw56cP05/U2Y33n9/gawODieV/6rwMk84qd/WuP9
if5p7a/v6J9W/W7RP635epj7y6h+1+ifsf0YZxAP/R27t6D6PU//Ba2Pd1H/
8YLubws4WdB6+Jz9kbX9Jlnbz3HWrp9kUc/kX7R6yCLqgf6Lut5H9F+08XpL
TvxLqs8s/ZeQb/ovaf18Q/+c2m/SP6f9+jf9c5i/9M+hv+i/jPpBPmQZ9cZ6
cXCyjH5g/vLQj/55Xe8d8ufR7+TPo1/Jv2K/lxU7/+MV3X+B/ivOvF1FPum/
ivfc/yrmBf1XrR5ewc4/Kej8v0L+gp2fSUH1+IX+a47/mlP/a47+jt0rqj53
6V/U+L/m/ovav19Q/6Lm+wPqv456oP7ryD/913G+YD4kDvZ8O59Svp1H4uP8
xPe+b+dX7ON8gL3r23mVYP0R4J7v8Jc0nseBUyU7j6Wk/fbACfCXcP4BxyXs
l/wlzAfYE+f7Xgn7A/bKGs8ocKqs9f0J+cvQh/GXES/5y3b9bln12kP+MuIj
fxnnJfkDzDfyB+gHYAkwfxl/oPwd8gfQi/wB5gf5A3xHfmAhf0Xr/THyV5Af
8ldU/0nyV9B/5K9YPboVnH/kr2g932H+KzZfXtXaU1XV5zb1r+L8In9V9/sz
zzvn+24VvKw/Z/1eFecR+UONN2D8oc2PhE78oa2POHTqL0S+yB8in+Snnf1b
s/erVA33XfZfDfMF2K9hfrD/gB8kf832U1JDvshfc+5XdduPKeCA+tehB+u/
Dl7GX8c8JH8d5xn568q3Tf666vUl9W9Y/1TD1o80bP/4DZuPuIHziPXXUL63
WH8N8LH+HbvXxPnK/De13urkb+p8eJP8jj1u2n7pOt8nTcvXc773Iq3PI+SP
7H4lwrwnf2TrNY5wHyd/ZOdHEqGeyB/ZeeK1sJ8x8LdQb+Rv4Zf8LZzH5G/h
vGH+W3Y+JI5/r4X/r8jfduJv23xI2/a331b9/2T9tXF/Yfxtu37SxvlN/jbu
a+TvYD6Qv4P7Avk76HfG33Hmb8eu13W+Tzqof+jb6+A+AOxt4H5E/TewX2DZ
wH1gTP4HLlcf7Q==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541676["NewOverlay"]] :> {
               FinancialIndicator["ParabolicStopAndReversal", 0.02, 0.2]}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "NewSubplot"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "OverlayIndicator"]] :> {{{{}, {Antialiasing -> False, 
                  GrayLevel[0.5], {{}}}, {{
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Point[CompressedData["
1:eJw9lQlUjfkbxysNmkpJi0F1G1qUpZI2Ld8sLS5t2te7d2+3BWHGVjd7SakR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                    "]]}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "OverlayIndicatorCount"]] :> 1, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "OverlayIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "PSAR"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "OverlayIndicatorNames"]] :> {
               FinancialIndicator["ParabolicStopAndReversal", 0.02, 0.2]}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "OverlayIndicatorParameters"]] :> {{{0.02, 0.2}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "OverlayIndicatorPoints"]] :> CompressedData["
1:eJxVVwlwDVYUjYxqRtGUTO0Ray1VTYnY3WyCiCw/iZ/973t+ailKqkHRVFPV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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "OverlayIndicatorValues"]] :> CompressedData["
1:eJxFlQtMlmUUx5HKmKmRuryjppjmnGPPeZ7n8/5HdFakJjhHZo5RphWTvISk
ZFNCIyOivKy8oDYvlBqZmjmniXkrNCXJGDlTszDBwFSSi+s873mc78Y+vnfv
d57zP//f/7w9UtISpt4XFhbWjP/q/Wf78pN1iVkKyzrcP7H1NoU3PuZ/Tir0
nZxXfLNS4eAP60ftTiScKOHrfQWbE5t8+UOFa5nD9ZRPFcoyrvSO2aLwSn51
5vBdCluOxNucg77eCYXrpWNSIn9V0FP2PtXyosKONf9sPnJVoeL2glf33VCY
u7+g04Amheyr4/dEPUDy3CLC7Olc8G3C4zERW7vMI9w5wwfNJKz+vnvRrOmE
3JUz2mQlE1qG91vy6HOEhD1RXIIQ3Xzh8rh4kj5iCR25jf6lClnfsZBfFDoP
ONer+QWFpal/NRTWKtxo4sLNCc84YdGErpNeGnx+HGHgzmPp+/n8ms1cqJDg
yi4tIYxNiUwaeINw1JXvrlHPMuYkavR0gjK1v2+kXraW3+do6S9fY2sXPqBA
o4rlZn+hcfaz14e2+EajfzAYjZ/qEi9trNAYcn5c7sprWvR9YuDaXrjcSN/5
BttHX5jX7gODFq7Ae0Z0LDYQPw3mt+MnBvnnYwxGJF8+9VhnAzeOHU0ah272
mZx30fdzQMu8C/z58zVWxPEvn9cIcxe0cDCbwN2Un5xLcHj0GaLlu9UIxtZf
41lnTE+NTavYqDYah51dtYSRrpHjhG7O6LWEwK4MwiNJPOmJd/1UmPayu5T4
NkvhAONx7h2FSPfcCiX+fKnAlIT3O6rwd28G5DeFz2sZtBp//0HChEsbuQPC
R4ylHkZeD8Hhe4r5mjmUJ1dEwm0ZSb/XCa2dEdO08DhVI8INiOcQ9JOgPVfe
z5h7eiuZptJWWnitJ++fwoZRu/9tYs6DOg0+H80IT7J927nPHjye/FYkHLUl
/MxxSepIYLcqbkcRXLlJvQhvcdz29iUcT3eB8RwSyXxGkuToBYKzo4594lPP
ZOSQzHOTP+eEz8ttEt+7ackD62nrAsJ673Ib+LHO+8t8vskxjyjRGOaAO6cR
BLVKC1cN2vdl8Kfre4qRvfCugXLX1wa3GLfiMiP7o8YIV8lWOJpshYckK3th
gpW8j7fS9xgLN67R6w0c3pc2GgT2Fhm44yu+NbKvjhms5RTFnzX4j59a9YeR
OrUGrkx1o8/RLiu5+MqKb9us8Flo/byscLLBir5VVvTlWamTaUV/qv/O/Qd+
j7VIa8ODjLWiV1uZa7SVnLf3+pYZ8ZlzLecYuPWSusSfu8gKtwusz51FEP8X
reRzsBXfmvk+SozkYLURLmca2S/xd/UTXDxz6wg/rndAEl7bN4c3vRY+23ne
o7X0R57nMRoOl/IZPt+5fp8Veu4PaT9nLXv9ISM+hrz/043Pu/H738j7oIOV
PRVnxccar6PKwmG9s9JKfn+3wmu59+u0n+dhK3xfMdJntZF8Xjey528ZeT/V
G7i1kX7HoNHJCbdY18kNzvr9ZIXXKIvT/LHgCSvPjQjBrf+CQSHhV4VEX7+Q
6O0Vkhx0DeHpoMEQ3Fpd83BIOIwIyX4NDwnfjZ6Hm1buFxvRybzK/jH+vWTk
PVNlvF/3+g7y0t3KHmP/A50TPZdpntvFFv8DMARjDg==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "OverlayState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$541676["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541676["PlotRangeMin"]] :> 
             19.132842141093462`, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$541676["Space"]] :> 2.495, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541676["Style"]] :> 
             RGBColor[0.24720000000000014`, 0.24, 0.6], HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "SubplotIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "SubplotIndicatorGridLines"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "SubplotIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "SubplotIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "SubplotIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "SubplotIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541676[
               "SubplotIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541676["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$541676["YRange"]] :> 24.95,
              HoldPattern[
               System`TradingChartDump`$layoutData$541676[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$541676[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$541676[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$541676[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$541676[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$541676 = 
           System`TradingChartDump`$length$541676; 
          System`TradingChartDump`$layoutData$541676["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$541676; 
          System`TradingChartDump`$modelData$541676["Data"] = 
           System`TradingChartDump`$data$541676; 
          System`TradingChartDump`$modelData$541676["Indicators"] = 
           System`TradingChartDump`$indicators$541676; 
          System`TradingChartDump`$layoutData$541676[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541676["ScalingFunctions"] = {
            System`TradingChartDump`$sy$541676, 
             System`TradingChartDump`$isy$541676}; 
          System`TradingChartDump`$layoutData$541676["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541676["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541676[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541676["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$541676["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$541676, 
            System`TradingChartDump`$layoutData$541676, 
            System`TradingChartDump`$indicators$541676]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$541676, 
            System`TradingChartDump`$layoutData$541676, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$541676[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$541676["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$541676[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$541676[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$541676["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$541676[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$541676 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541676["AllValues"], {1, 0} + 
              Map[
               IntegerPart, {
                System`TradingChartDump`$controlmin$541676, 
                 System`TradingChartDump`$controlmax$541676}]]]; 
          System`TradingChartDump`$plotrangemax$541676 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541676["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541676, 
                 System`TradingChartDump`$controlmax$541676}]]]; {
            System`TradingChartDump`$plotrangemin$541676, 
             System`TradingChartDump`$plotrangemax$541676} = ReplaceAll[
             
             System`TradingChartDump`$sy$541676[{
              System`TradingChartDump`$plotrangemin$541676, 
               System`TradingChartDump`$plotrangemax$541676}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$541676[
                Min[System`TradingChartDump`$lows$541676]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$541676 == 
            System`TradingChartDump`$plotrangemax$541676, {
             System`TradingChartDump`$plotrangemin$541676, 
              System`TradingChartDump`$plotrangemax$541676} = {
             System`TradingChartDump`$plotrangemin$541676 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$541676], 
              System`TradingChartDump`$plotrangemax$541676 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$541676]}]; 
          System`TradingChartDump`$newgridlines$541676 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$541676, 
            Part[System`TradingChartDump`$newgridlines$541676, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$541676, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$541676], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$541676, 1]]; 
            Part[System`TradingChartDump`$newgridlines$541676, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$541676, 1] =!= None,
                 System`TradingChartDump`$length$541676 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$541676, 
                 Part[System`TradingChartDump`$newgridlines$541676, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$541676, 1]]; 
            System`TradingChartDump`$subpricegridlines$541676 = 
             Part[System`TradingChartDump`$gridlines$541676, 2]; 
            Part[System`TradingChartDump`$newgridlines$541676, 2] = 
             If[System`TradingChartDump`$sy$541676 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541676}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541676, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541676, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$541676, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$541676, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541676}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541676, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541676, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$541676 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$541676]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"GE\"", "\" with \"", 
           "\"ParabolicStopAndReversal\"", "\"(\"", "0.02`", "\",\"", "0.2`", 
           "\",\"", "", "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {720., -502.20000000000005`}, 
      ImageScaled[{0.5, 0.5}], {450, 310}]}, {InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$541691 = 
        "Full", System`TradingChartDump`$highlightposition$541691 = Automatic,
         System`TradingChartDump`$maxohlc$541691 = 24.95`4., 
        System`TradingChartDump`$timestampstyle$541691 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$541691 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$541691 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$541691, 
        System`TradingChartDump`$subplotpoint$541691, 
        System`TradingChartDump`$ndigits$541691 = 4, 
        System`TradingChartDump`$highlightstyle$541691 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$541691 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$541691 = True, 
        System`TradingChartDump`$timestampQ$541691 = True, 
        System`TradingChartDump`$data$541691 = {{{2012, 7, 26}, {
          19.55155642023346, 20.035505836575872`, 19.512840466926068`, 19.9, 
           57275600}}, {{2012, 7, 27}, {
          19.96928776290631, 20.327437858508603`, 19.901529636711278`, 20.25, 
           80268300}}, {{2012, 7, 30}, {
          20.120322115384614`, 20.236456730769227`, 20.023543269230768`, 
           20.13, 44993600}}, {{2012, 7, 31}, {
          20.08, 20.21547951807229, 20.08, 20.08, 38328400}}, {{2012, 8, 1}, {
          20.185798359864926`, 20.27288953207911, 20.040646406174623`, 20.06, 
           35734300}}, {{2012, 8, 2}, {
          19.860000000000003`, 20.03421052631579, 19.55029239766082, 19.86, 
           44000400}}, {{2012, 8, 3}, {
          20.144541984732825`, 20.318702290076335`, 20.096164122137402`, 
           20.28, 37891500}}, {{2012, 8, 6}, {
          20.29, 20.493190271816882`, 20.22226990939437, 20.29, 34159500}}, {{
          2012, 8, 7}, {
          20.459356060606062`, 20.507746212121216`, 20.410965909090912`, 
           20.44, 31115300}}, {{2012, 8, 8}, {
          20.36870537839124, 20.407410756782483`, 20.22356020942408, 20.33, 
           32345900}}, {{2012, 8, 9}, {
          20.263874643874647`, 20.43806267806268, 20.263874643874647`, 20.38, 
           31159700}}, {{2012, 8, 10}, {
          20.323222748815166`, 20.42, 20.265156398104267`, 20.42, 
           24419100}}, {{2012, 8, 13}, {
          20.358380181038587`, 20.377732253454024`, 20.2035636017151, 20.31, 
           26873600}}, {{2012, 8, 14}, {
          20.395453677172874`, 20.42447946513849, 20.22129894937918, 20.26, 
           30095000}}, {{2012, 8, 15}, {
          20.18324427480916, 20.34772900763359, 20.11551526717557, 20.28, 
           28870100}}, {{2012, 8, 16}, {
          20.195814726840858`, 20.457092636579574`, 20.147429928741094`, 
           20.37, 33598000}}, {{2012, 8, 17}, {
          20.33935238095238, 20.368380952380953`, 20.26194285714286, 20.32, 
           30032500}}, {{2012, 8, 20}, {
          20.269350215002387`, 20.33707596751075, 20.153248924988052`, 20.25, 
           27385500}}, {{2012, 8, 21}, {
          20.296143884892086`, 20.373573141486812`, 20.131606714628298`, 
           20.18, 30438800}}, {{2012, 8, 22}, {
          20.100322425409047`, 20.197098171318576`, 20.04225697786333, 20.11, 
           28016800}}, {{2012, 8, 23}, {
          20.06675387596899, 20.115130813953485`, 19.960324612403095`, 19.97, 
           36538800}}, {{2012, 8, 24}, {
          19.92676442307692, 20.22677884615384, 19.888052884615384`, 20.13, 
           29338200}}, {{2012, 8, 27}, {
          20.15096402877698, 20.276786570743404`, 20.121928057553955`, 20.18, 
           28775600}}, {{2012, 8, 28}, {
          20.09160980297934, 20.246458433445465`, 20.09160980297934, 20.14, 
           25912400}}, {{2012, 8, 29}, {
          20.15, 20.275816522574445`, 20.140321805955807`, 20.15, 
           19925800}}, {{2012, 8, 30}, {
          20.04740310077519, 20.10545542635659, 19.9506492248062, 19.97, 
           21237800}}, {{2012, 8, 31}, {
          20.08838242394978, 20.156117817479473`, 19.94323515210043, 20.04, 
           29679000}}, {{2012, 9, 4}, {
          19.966138469039493`, 20.024207703559238`, 19.820965382740127`, 
           19.85, 38173600}}, {{2012, 9, 5}, {
          19.883244552058112`, 20.096106537530268`, 19.84454237288136, 19.98, 
           33033500}}, {{2012, 9, 6}, {
          20.19424683247302, 20.629676208352887`, 20.17489441576725, 20.62, 
           53178600}}, {{2012, 9, 7}, {
          20.628754052802222`, 20.89, 20.609402501157945`, 20.89, 
           36379800}}, {{2012, 9, 10}, {
          20.79, 20.954539106145248`, 20.741606145251396`, 20.79, 
           33672300}}, {{2012, 9, 11}, {
          20.7932422417786, 20.9867577582214, 20.70616025937934, 20.89, 
           33593100}}, {{2012, 9, 12}, {
          20.967135678391962`, 21.218702603928733`, 20.957460027409777`, 
           21.18, 43006000}}, {{2012, 9, 13}, {
          21.0680608537693, 21.522906448683013`, 21.048705722070842`, 21.31, 
           111794200}}, {{2012, 9, 14}, {
          21.487109905020354`, 21.651650836725466`, 21.27417458163727, 21.4, 
           100148400}}, {{2012, 9, 17}, {
          21.22386394557823, 21.34, 21.194829931972787`, 21.34, 79283200}}, {{
          2012, 9, 18}, {
          21.278093525179855`, 21.52, 21.24906474820144, 21.52, 38831200}}, {{
          2012, 9, 19}, {
          21.584172982612575`, 21.768074008024968`, 21.535777975925104`, 
           21.71, 40462600}}, {{2012, 9, 20}, {
          21.63599197503344, 21.909001337494427`, 21.567739634418192`, 21.87, 
           43677000}}, {{2012, 9, 21}, {
          21.989502885042164`, 22.126023080337326`, 21.901739902352418`, 
           21.97, 66551700}}, {{2012, 9, 24}, {
          21.838998211091234`, 21.887745974955276`, 21.74150268336315, 21.8, 
           36799800}}, {{2012, 9, 25}, {
          21.8380277902286, 22.11112505602869, 21.750246526221428`, 21.76, 
           47039200}}, {{2012, 9, 26}, {
          21.608506787330317`, 21.69626696832579, 21.520746606334843`, 21.55, 
           41123300}}, {{2012, 9, 27}, {
          21.682287725472943`, 22.286739991201056`, 21.575046194456664`, 
           22.16, 67300400}}, {{2012, 9, 28}, {
          22.20852047556142, 22.393835314839276`, 22.062219286657857`, 22.15, 
           70926100}}, {{2012, 10, 1}, {
          22.161999123191585`, 22.42525208241999, 22.14249890398948, 22.24, 
           42550700}}, {{2012, 10, 2}, {
          22.3564984642387, 22.414997806055286`, 22.142000877577885`, 22.22, 
           45297400}}, {{2012, 10, 3}, {
          22.29124399825404, 22.40825840244435, 22.154727193365343`, 22.34, 
           32929400}}, {{2012, 10, 4}, {
          22.38, 22.477516339869283`, 22.204470588235292`, 22.38, 
           40344600}}, {{2012, 10, 5}, {
          22.46200692041522, 22.598494809688578`, 22.423010380622834`, 22.54, 
           38312500}}, {{2012, 10, 8}, {
          22.301243455497385`, 22.418259162303666`, 22.281740837696336`, 
           22.35, 24202200}}, {{2012, 10, 9}, {
          22.37207780725022, 22.401335101679926`, 22.04049513704686, 22.06, 
           39176000}}, {{2012, 10, 10}, {
          22.04550601872492, 22.17226036558181, 21.850499331252788`, 21.87, 
           32784100}}, {{2012, 10, 11}, {
          22.02800977343403, 22.14502443358507, 21.92074633496224, 21.95, 
           24161800}}, {{2012, 10, 12}, {
          22.017508896797153`, 22.144270462633454`, 21.851743772241996`, 
           21.92, 32954600}}, {{2012, 10, 15}, {
          21.98247349823321, 22.138515901060067`, 21.933710247349822`, 22.08, 
           29578600}}, {{2012, 10, 16}, {
          22.226289752650175`, 22.314063604240282`, 22.01173144876325, 22.08, 
           35668800}}, {{2012, 10, 17}, {
          22.203483195111303`, 22.349751200349196`, 22.154727193365343`, 
           22.34, 28272500}}, {{2012, 10, 18}, {
          22.24, 22.50325295922841, 22.230249890398948`, 22.24, 43140700}}, {{
          2012, 10, 19}, {
          21.9480163413527, 21.967517022242397`, 21.323994552882436`, 21.48, 
           107879900}}, {{2012, 10, 22}, {
          21.316018433179725`, 21.40377880184332, 20.72119815668203, 21.16, 
           86735100}}, {{2012, 10, 23}, {
          20.81825657894737, 20.867011278195488`, 20.671992481203006`, 20.75, 
           56297300}}, {{2012, 10, 24}, {
          20.8957619943556, 20.925014111006586`, 20.71049858889934, 20.73, 
           42295500}}, {{2012, 10, 25}, {
          20.964016933207905`, 21.032271872060207`, 20.505733772342428`, 
           20.73, 45769600}}, {{2012, 10, 26}, {
          20.657991473235434`, 20.862719090478446`, 20.541004263382284`, 
           20.58, 42827400}}, {{2012, 10, 31}, {
          20.735061728395063`, 20.79358024691358, 20.452222222222222`, 20.54, 
           39179300}}, {{2012, 11, 1}, {
          20.50769915651359, 20.858758200562324`, 20.497947516401123`, 20.81, 
           46231300}}, {{2012, 11, 2}, {
          20.994528390427032`, 21.14079774753637, 20.731243547630225`, 20.78, 
           47475200}}, {{2012, 11, 5}, {
          20.67519850537132, 20.938514712751047`, 20.67519850537132, 20.88, 
           30000100}}, {{2012, 11, 6}, {
          20.972000926354795`, 21.235247799907366`, 20.913501621120886`, 
           21.05, 32733200}}, {{2012, 11, 7}, {
          20.824230951254144`, 20.980217699952675`, 20.54150496923805, 20.6, 
           45253400}}, {{2012, 11, 8}, {
          20.633279080899953`, 20.66253231211106, 20.36024892292963, 20.37, 
           40770700}}, {{2012, 11, 9}, {
          20.245942857142857`, 20.77257142857143, 20.18742857142857, 20.48, 
           40306800}}, {{2012, 11, 12}, {
          20.51626615605553, 20.613776926759215`, 20.36024892292963, 20.37, 
           21816400}}, {{2012, 11, 13}, {
          20.091972920696332`, 20.433341392649908`, 20.06271276595745, 20.17, 
           41073300}}, {{2012, 11, 14}, {
          20.21200899550225, 20.231509245377314`, 19.451499250374813`, 19.51, 
           65539500}}, {{2012, 11, 15}, {
          19.403988035892322`, 19.72576271186441, 19.403988035892322`, 19.56, 
           51760300}}, {{2012, 11, 16}, {
          19.601240694789084`, 19.689007444168734`, 19.376947890818858`, 
           19.65, 45287500}}, {{2012, 11, 19}, {
          19.90617134559535, 20.208518877057113`, 19.88666505324298, 20.15, 
           38283400}}, {{2012, 11, 20}, {
          20.15876333656644, 20.178268671193017`, 19.8661833171678, 20.11, 
           26845900}}, {{2012, 11, 21}, {
          20.189506769825922`, 20.22852030947776, 20.06271276595745, 20.17, 
           41020400}}, {{2012, 11, 23}, {
          20.295684410646388`, 20.52, 20.217661596958177`, 20.52, 
           35456500}}, {{2012, 11, 26}, {
          20.364444444444445`, 20.549753086419752`, 20.35469135802469, 20.54, 
           47741300}}, {{2012, 11, 27}, {
          20.515764254911353`, 20.67177767129851, 20.330498322951605`, 20.35, 
           33001700}}, {{2012, 11, 28}, {
          20.229777672658468`, 20.619749290444656`, 19.9860454115421, 20.61, 
           34782700}}, {{2012, 11, 29}, {
          20.70724088973024, 20.824230951254144`, 20.42451490771415, 20.6, 
           27632800}}, {{2012, 11, 30}, {
          20.60974917179366, 20.726739233317563`, 20.512257453857078`, 20.6, 
           37857000}}, {{2012, 12, 3}, {
          20.651008645533143`, 20.699759846301635`, 20.280499519692604`, 20.3,
            29981900}}, {{2012, 12, 4}, {
          20.34975071907958, 20.486260786193675`, 20.19373921380633, 20.34, 
           36817200}}, {{2012, 12, 5}, {
          20.38798869524258, 20.8267545925577, 20.339236928874232`, 20.7, 
           46466500}}, {{2012, 12, 6}, {
          20.67421619092185, 20.859503977538605`, 20.557192325690217`, 20.84, 
           32751200}}, {{2012, 12, 7}, {
          20.910493942218082`, 20.94950605778192, 20.71543336439888, 20.93, 
           33548600}}, {{2012, 12, 10}, {
          20.899008882655444`, 20.967274427302478`, 20.830743338008414`, 
           20.86, 27604300}}, {{2012, 12, 11}, {
          20.940753138075312`, 21.203974895397486`, 20.823765690376565`, 
           20.97, 45757200}}, {{2012, 12, 12}, {
          21.074214876033054`, 21.40578512396694, 21.035206611570246`, 21.24, 
           42413600}}, {{2012, 12, 13}, {
          21.197002775208137`, 21.37250693802035, 21.011748381128584`, 21.08, 
           33966000}}, {{2012, 12, 14}, {
          21.07024976873265, 21.21650323774283, 21.011748381128584`, 21.08, 
           47536600}}, {{2012, 12, 17}, {
          21.146019151846783`, 21.399498404012764`, 21.146019151846783`, 
           21.38, 48483700}}, {{2012, 12, 18}, {
          21.30601659751037, 21.36452282157676, 20.876970954356842`, 21.15, 
           81119200}}, {{2012, 12, 19}, {
          21.104407425035696`, 21.123912422655877`, 20.450990004759635`, 
           20.49, 92330700}}, {{2012, 12, 20}, {
          20.57226128266033, 20.89693111638955, 20.532907363420428`, 20.71, 
           50831400}}, {{2012, 12, 21}, {
          20.510632183908047`, 20.658261494252873`, 20.235057471264366`, 
           20.55, 80833800}}, {{2012, 12, 24}, {
          20.460475504322766`, 20.62778097982709, 20.421109510086453`, 20.49, 
           15097200}}, {{2012, 12, 26}, {
          20.479364467982666`, 20.60729898892634, 20.380953298026, 20.44, 
           28557100}}, {{2012, 12, 27}, {
          20.468245529241177`, 20.537129047849202`, 20.094306428226197`, 
           20.36, 38330700}}, {{2012, 12, 28}, {
          20.119838551859097`, 20.375640900195695`, 20.1001614481409, 20.11, 
           32403400}}, {{2012, 12, 31}, {
          19.961338732729867`, 20.65983801810386, 19.931824678418295`, 20.65, 
           58785000}}, {{2013, 1, 2}, {
          21.167291471415183`, 21.196813495782568`, 20.8622305529522, 21., 
           46089500}}, {{2013, 1, 3}, {
          21.133876777251185`, 21.143715639810427`, 20.710805687203795`, 
           20.76, 48509100}}, {{2013, 1, 4}, {
          20.86983962264151, 20.91903773584906, 20.781283018867928`, 20.86, 
           29802600}}, {{2013, 1, 7}, {
          20.819517274017986`, 20.87855182205395, 20.622735447231427`, 20.79, 
           32746700}}, {{2013, 1, 8}, {
          20.766842105263162`, 20.786526315789477`, 20.353473684210527`, 
           20.57, 40045500}}, {{2013, 1, 9}, {
          20.708582338902147`, 20.738109785202866`, 20.600315035799525`, 
           20.62, 28540500}}, {{2013, 1, 10}, {
          20.702087860179493`, 20.88903637222484, 20.623372697213032`, 20.83, 
           33348200}}, {{2013, 1, 11}, {
          20.87855182205395, 20.898230004732607`, 20.68176999526739, 20.79, 
           41839700}}, {{2013, 1, 14}, {
          20.83903409090909, 20.898068181818182`, 20.730804924242427`, 20.78, 
           31715900}}, {{2013, 1, 15}, {
          20.70256603773585, 20.86983962264151, 20.673047169811323`, 20.86, 
           26551000}}, {{2013, 1, 16}, {
          20.809517045454545`, 20.858712121212122`, 20.72096590909091, 20.78, 
           38932100}}, {{2013, 1, 17}, {
          20.88127699530516, 21.196169014084504`, 20.78287323943662, 20.96, 
           63851700}}, {{2013, 1, 18}, {
          21.591588021778588`, 21.83761796733213, 21.247146098003633`, 21.69, 
           113079400}}, {{2013, 1, 22}, {
          21.82729668332576, 21.846978646069967`, 21.55174920490686, 21.66, 
           55165800}}, {{2013, 1, 23}, {
          21.629361896080216`, 21.67856426618049, 21.40303099361896, 21.59, 
           47228500}}, {{2013, 1, 24}, {
          21.611428571428572`, 21.837777777777777`, 21.6015873015873, 21.7, 
           46991100}}, {{2013, 1, 25}, {
          21.920161507402426`, 21.949676985195154`, 21.752907133243607`, 
           21.93, 41919800}}, {{2013, 1, 28}, {
          22.080960000000005`, 22.179360000000003`, 21.903840000000002`, 
           22.14, 49558400}}, {{2013, 1, 29}, {
          22.13016, 22.21872, 22.041600000000003`, 22.14, 34148000}}, {{2013, 
          1, 30}, {
          22.155303643724697`, 22.184817813765186`, 21.87, 21.87, 
           36200400}}, {{2013, 1, 31}, {
          21.85113105924596, 22.03806104129264, 21.8216157989228, 21.92, 
           34427700}}, {{2013, 2, 1}, {
          22.073023872679045`, 22.27968169761273, 21.964774535809017`, 22.26, 
           43840300}}, {{2013, 2, 4}, {
          22.0483863738234, 22.127095472882115`, 21.920484087852984`, 21.95, 
           35836600}}, {{2013, 2, 5}, {
          22.120958296362023`, 22.258722271517303`, 22.091437444543033`, 
           22.18, 30917700}}, {{2013, 2, 6}, {
          22.109518716577536`, 22.139037433155078`, 21.952085561497324`, 
           22.08, 42985800}}, {{2013, 2, 7}, {
          22.139679715302492`, 22.14951957295374, 21.913362989323847`, 22.12, 
           38325900}}, {{2013, 2, 8}, {
          22.14, 22.19904, 22.0908, 22.14, 24424600}}, {{2013, 2, 11}, {
          22.129358574610244`, 22.14903786191537, 21.99160356347439, 22.09, 
           19738700}}, {{2013, 2, 12}, {
          22.121594331266607`, 22.288883968113375`, 22.121594331266607`, 
           22.22, 34297500}}, {{2013, 2, 13}, {
          22.744429243266353`, 23.108576314664386`, 22.675536554082942`, 
           23.02, 84926900}}, {{2013, 2, 14}, {
          22.882528833831696`, 23.11873558308415, 22.74474156343443, 23.04, 
           53996500}}, {{2013, 2, 15}, {
          23.106981537140406`, 23.175869471876346`, 22.86095319879777, 22.92, 
           39283000}}, {{2013, 2, 19}, {
          23.04528, 23.37, 23.03544, 23.37, 41219000}}, {{2013, 2, 20}, {
          23.33525843656557, 23.374626228107648`, 22.980948312686888`, 23.04, 
           38107400}}, {{2013, 2, 21}, {
          23.000619088564054`, 23.169303525365432`, 22.9410834049871, 23.08, 
           47811200}}, {{2013, 2, 22}, {
          23.1603249251817, 23.259512612227446`, 23.041299700726807`, 23.2, 
           27836300}}, {{2013, 2, 25}, {
          23.314555019728193`, 23.344318281455507`, 22.630000000000003`, 
           22.63, 51619800}}, {{2013, 2, 26}, {
          22.790624728850325`, 22.96921908893709, 22.73109327548807, 22.87, 
           41316300}}, {{2013, 2, 27}, {
          22.83284552845528, 23.20975609756097, 22.813008130081297`, 23.18, 
           29676400}}, {{2013, 2, 28}, {
          23.188837209302328`, 23.27813953488372, 23.02015503875969, 23.04, 
           39714600}}, {{2013, 3, 1}, {
          22.841319534282018`, 23.158835705045277`, 22.821474773609314`, 
           23.01, 41226900}}, {{2013, 3, 4}, {
          22.970928233777396`, 23.09992264718522, 22.851856467554793`, 23.09, 
           25457800}}, {{2013, 3, 5}, {
          23.27104705383637, 23.519033488766425`, 23.251208139041967`, 23.4, 
           35728000}}, {{2013, 3, 6}, {
          23.648635403464297`, 23.648635403464297`, 23.48, 23.48, 
           31539100}}, {{2013, 3, 7}, {
          23.509839527027022`, 23.638796452702696`, 23.480080236486486`, 
           23.49, 22955700}}, {{2013, 3, 8}, {
          23.669280605805636`, 23.708960875052586`, 23.49071939419436, 23.58, 
           28952100}}, {{2013, 3, 11}, {
          23.499436917866216`, 23.558954276037255`, 23.261367485182046`, 
           23.43, 34947200}}, {{2013, 3, 12}, {
          23.39853908586074, 23.408457923964118`, 23.140649295173, 23.22, 
           36593000}}, {{2013, 3, 13}, {
          23.250404427415926`, 23.329757343550448`, 23.21072796934866, 23.3, 
           24152400}}, {{2013, 3, 14}, {
          23.361122836639932`, 23.569438581680036`, 23.321443647108484`, 23.5,
            34629800}}, {{2013, 3, 15}, {
          23.25, 23.527730375426618`, 23.17064846416382, 23.25, 58857200}}, {{
          2013, 3, 18}, {
          22.990619354838714`, 23.169225806451614`, 22.950929032258063`, 
           23.07, 33700000}}, {{2013, 3, 19}, {
          23.12015437392796, 23.17969125214408, 22.991157804459693`, 23.14, 
           36150200}}, {{2013, 3, 20}, {
          23.537813299232738`, 23.607246376811595`, 23.141052855924976`, 
           23.27, 39254000}}, {{2013, 3, 21}, {
          23.238995276942894`, 23.417604121940748`, 23.109999999999996`, 
           23.11, 38543900}}, {{2013, 3, 22}, {
          23.130406504065036`, 23.20975609756097, 23.090731707317072`, 23.18, 
           30606100}}, {{2013, 3, 25}, {
          23.268373493975904`, 23.298141135972465`, 22.87147160068847, 23.06, 
           41684400}}, {{2013, 3, 26}, {
          23.088832179930794`, 23.118598615916955`, 22.830856401384082`, 
           22.94, 32353500}}, {{2013, 3, 27}, {
          22.840623376623377`, 22.95968831168831, 22.671948051948053`, 22.92, 
           27492500}}, {{2013, 3, 28}, {
          22.95984429065744, 23.019377162629755`, 22.81101211072664, 22.94, 
           31151000}}, {{2013, 4, 1}, {
          22.85038994800693, 22.91984402079723, 22.79085788561525, 22.9, 
           27449700}}, {{2013, 4, 2}, {
          22.991311053984575`, 23.189768637532133`, 22.92185089974293, 23.16, 
           29180100}}, {{2013, 4, 3}, {
          23.19702608695652, 23.21686956521739, 22.740626086956524`, 22.82, 
           52570300}}, {{2013, 4, 4}, {
          22.830545927209705`, 22.949610051993066`, 22.780935875216638`, 22.9,
            30472100}}, {{2013, 4, 5}, {
          22.621020497165286`, 22.75992150021806, 22.58133449629307, 22.75, 
           31402200}}, {{2013, 4, 8}, {
          22.870544982698963`, 22.94, 22.652257785467125`, 22.94, 
           30493600}}, {{2013, 4, 9}, {
          23.068516912402426`, 23.068516912402426`, 22.721248915871637`, 
           22.88, 31668200}}, {{2013, 4, 10}, {
          22.913867684478376`, 23.45943596268024, 22.87418999151824, 23.39, 
           39772300}}, {{2013, 4, 11}, {
          23.36032217041119, 23.528952946163628`, 23.241288681644765`, 23.4, 
           27084400}}, {{2013, 4, 12}, {
          23.29975703324808, 23.39894714407502, 23.141052855924976`, 23.27, 
           27234300}}, {{2013, 4, 15}, {
          23.096291100394566`, 23.11613327487944, 22.630000000000003`, 22.63, 
           46453800}}, {{2013, 4, 16}, {
          22.890233766233766`, 22.92, 22.72155844155844, 22.92, 36016700}}, {{
          2013, 4, 17}, {
          22.778418277680135`, 22.847864674868188`, 22.470869947275915`, 
           22.58, 42672900}}, {{2013, 4, 18}, {
          22.579285399206, 22.668570798412, 22.39079400088222, 22.49, 
           41170900}}, {{2013, 4, 19}, {
          21.768514942528736`, 21.85781149425287, 21.44109425287356, 21.58, 
           108837900}}, {{2013, 4, 22}, {
          21.497451990632317`, 21.507372365339577`, 20.94191100702576, 21.18, 
           87828900}}, {{2013, 4, 23}, {
          21.37960465116279, 21.518497674418605`, 21.191106976744184`, 21.33, 
           65489600}}, {{2013, 4, 24}, {
          21.522090163934426`, 21.859458105646628`, 21.482399817850634`, 
           21.79, 51506700}}, {{2013, 4, 25}, {
          22.037986332574036`, 22.05783143507973, 21.74030979498861, 21.78, 
           41462900}}, {{2013, 4, 26}, {
          21.801864025213867`, 22.218460153084195`, 21.791945069788383`, 
           22.03, 47012500}}, {{2013, 4, 29}, {
          22.129676695105523`, 22.139595868881905`, 21.82218230803772, 22.09, 
           36531800}}, {{2013, 4, 30}, {
          22.11, 22.1992732166891, 22.03064602960969, 22.11, 34054800}}, {{
          2013, 5, 1}, {
          21.920406320541762`, 22.168374717832958`, 21.920406320541762`, 
           21.97, 39201600}}, {{2013, 5, 2}, {
          22.070564516129032`, 22.14, 21.971370967741933`, 22.14, 
           27651500}}, {{2013, 5, 3}, {
          22.39, 22.667766947275148`, 22.370159503766065`, 22.39, 
           45523300}}, {{2013, 5, 6}, {
          22.38015943312666, 22.45952170062002, 22.14207263064659, 22.4, 
           28563900}}, {{2013, 5, 7}, {
          22.509920634920633`, 22.60912698412698, 22.44047619047619, 22.5, 
           28211700}}, {{2013, 5, 8}, {
          22.502581486310298`, 22.83992177314211, 22.443050847457627`, 22.83, 
           39977300}}, {{2013, 5, 9}, {
          22.808340649692713`, 22.91747146619842, 22.510711150131694`, 22.6, 
           29974300}}, {{2013, 5, 10}, {
          22.591021834061134`, 22.729921397379915`, 22.412436681222708`, 
           22.72, 35117300}}, {{2013, 5, 13}, {
          22.67992122538293, 22.699763676148795`, 22.441811816192562`, 22.67, 
           30283800}}, {{2013, 5, 14}, {
          22.671251629726207`, 22.889530638852673`, 22.631564537157754`, 
           22.83, 39592300}}, {{2013, 5, 15}, {
          22.86154905335628, 23.069922547332187`, 22.732555938037866`, 23.06, 
           40153000}}, {{2013, 5, 16}, {
          22.921314997851315`, 23.16938117748174, 22.921314997851315`, 23.09, 
           33023300}}, {{2013, 5, 17}, {
          23.081538789428816`, 23.289838022165387`, 23.012105711849955`, 
           23.27, 41037700}}, {{2013, 5, 20}, {
          23.270886720407294`, 23.389919389053876`, 23.241128553245648`, 
           23.38, 32884800}}, {{2013, 5, 21}, {
          23.400562130177512`, 23.58903634826712, 23.400562130177512`, 23.47, 
           33815000}}, {{2013, 5, 22}, {
          23.590637049455157`, 23.937849958088854`, 23.56087594300084, 23.67, 
           68514400}}, {{2013, 5, 23}, {
          23.33112426035503, 23.559277261200336`, 23.261686390532542`, 23.47, 
           44383600}}, {{2013, 5, 24}, {
          23.3102422439439, 23.478869528261797`, 23.3003229919252, 23.34, 
           41015200}}, {{2013, 5, 28}, {
          23.578631355932202`, 23.648067796610167`, 23.39016101694915, 23.41, 
           47323000}}, {{2013, 5, 29}, {
          23.231768189509307`, 23.50951776649746, 23.21192893401015, 23.45, 
           39236500}}, {{2013, 5, 30}, {
          23.39016101694915, 23.56871186440678, 23.310805084745763`, 23.41, 
           29347100}}, {{2013, 5, 31}, {
          23.407915951972555`, 23.606372212692968`, 23.13007718696398, 23.14, 
           49247600}}, {{2013, 6, 3}, {
          23.18217005076142, 23.588874788494078`, 23.132571912013535`, 23.45, 
           45218400}}, {{2013, 6, 4}, {
          23.400562130177512`, 23.569196956889265`, 23.22200760777684, 23.47, 
           38701300}}, {{2013, 6, 5}, {
          23.368224699828474`, 23.397993138936535`, 23.030849056603774`, 
           23.14, 44756200}}, {{2013, 6, 6}, {
          23.06105645851155, 23.19991873396065, 22.9122754491018, 23.19, 
           42677500}}, {{2013, 6, 7}, {
          23.35254819782062, 23.759283319362954`, 23.28310561609388, 23.67, 
           49041200}}, {{2013, 6, 10}, {
          23.689201009251473`, 23.728881412952063`, 23.45111858704794, 23.59, 
           41626500}}, {{2013, 6, 11}, {
          23.300725190839696`, 23.49911365564038, 23.290805767599664`, 23.39, 
           36183000}}, {{2013, 6, 12}, {
          23.508382978723404`, 23.538140425531914`, 23.230646808510638`, 
           23.31, 33842000}}, {{2013, 6, 13}, {
          23.261845439189184`, 23.599117398648644`, 23.152728040540538`, 
           23.49, 34930500}}, {{2013, 6, 14}, {
          23.488707482993195`, 23.55814200680272, 23.27048469387755, 23.33, 
           27846000}}, {{2013, 6, 17}, {
          23.560159865376523`, 23.6593605384939, 23.460959192259146`, 23.58, 
           39278300}}, {{2013, 6, 18}, {
          23.64390464447185, 24.259062885326763`, 23.58437320180847, 24.14, 
           72766900}}, {{2013, 6, 19}, {
          24.008256880733942`, 24.15706839032527, 23.79, 23.79, 46082200}}, {{
          2013, 6, 20}, {23.63, 23.69, 23.2, 23.25, 62733200}}, {{2013, 6, 
          21}, {23.579999999999995`, 23.639999999999997`, 23.209999999999997`,
            23.36, 65025200}}, {{2013, 6, 24}, {
          23.12, 23.15, 22.76, 22.93, 48760800}}, {{2013, 6, 25}, {
          23.169999999999998`, 23.249999999999996`, 22.939999999999998`, 
           23.11, 36569100}}, {{2013, 6, 26}, {
          23.43, 23.44, 23.02, 23.25, 32531700}}, {{2013, 6, 27}, {
          23.41, 23.48, 23.26, 23.32, 30867900}}, {{2013, 6, 28}, {
          23.32, 23.44, 23.16, 23.19, 45923200}}, {{2013, 7, 1}, {
          23.209999999999997`, 23.639999999999997`, 23.189999999999998`, 
           23.34, 35784800}}, {{2013, 7, 2}, {
          23.27, 23.34, 22.88, 22.9, 47571200}}, {{2013, 7, 3}, {
          22.83, 22.98, 22.76, 22.91, 21448500}}, {{2013, 7, 5}, {
          23.17, 23.24, 22.95, 23.24, 22688900}}, {{2013, 7, 8}, {
          23.36, 23.53, 23.27, 23.32, 35481100}}, {{2013, 7, 9}, {
          23.52, 23.8, 23.51, 23.62, 31541400}}, {{2013, 7, 10}, {
          23.719999999999995`, 23.729999999999997`, 23.359999999999996`, 
           23.54, 28457100}}, {{2013, 7, 11}, {
          23.91, 23.96, 23.63, 23.94, 32618400}}, {{2013, 7, 12}, {
          23.99, 24., 23.59, 23.76, 33257700}}, {{2013, 7, 15}, {
          23.73, 23.74, 23.56, 23.63, 35853500}}, {{2013, 7, 16}, {
          23.659999999999997`, 23.669999999999998`, 23.339999999999996`, 
           23.43, 38192400}}, {{2013, 7, 17}, {
          23.539999999999996`, 23.609999999999996`, 23.429999999999996`, 
           23.54, 26858500}}, {{2013, 7, 18}, {
          23.6, 23.94, 23.56, 23.63, 41438200}}, {{2013, 7, 19}, {
          24.21, 24.95, 24.1, 24.72, 103708900}}, {{2013, 7, 22}, {
          24.77, 24.92, 24.73, 24.86, 41560800}}, {{2013, 7, 23}, {
          24.87, 24.88, 24.63, 24.71, 32553000}}, {{2013, 7, 24}, {
          24.79, 24.84, 24.56, 24.62, 27485000}}, {{2013, 7, 25}, {
          24.61, 24.69, 24.52, 24.69, 29951700}}}, 
        System`TradingChartDump`$markerstyle$541691 = 1, 
        System`TradingChartDump`$controlmin$541691 = 0.5, 
        System`TradingChartDump`$controlmax$541691 = 250.5, 
        System`TradingChartDump`$datescope$541691 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$541691 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$541691, 
        System`TradingChartDump`$max$541691, 
        System`TradingChartDump`$ohlclabel$541691 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541691, 
              System`TradingChartDump`$opens$541691]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541691, 
              System`TradingChartDump`$highs$541691]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541691, 
              System`TradingChartDump`$lows$541691]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541691, 
              System`TradingChartDump`$closes$541691]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541691, 
              System`TradingChartDump`$visdates$541691]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$541691 = {}, 
        System`TradingChartDump`$subpricegridlines$541691 = Automatic, 
        System`TradingChartDump`$overlaypoint$541691, 
        System`TradingChartDump`$overlayvalue$541691, 
        System`TradingChartDump`$subplotvalue$541691, 
        System`TradingChartDump`$opts$541691 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "GE", " with ", 
            "PolarizedFractalEfficiency", "(", 10, ",", 5, ",", Null, ",", 
            Null, ")"}], ImageSize -> {450, 310}, AlignmentPoint -> Center, 
         AspectRatio -> GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> 
         None, AxesOrigin -> Automatic, AxesStyle -> {}, Background -> None, 
         BaselinePosition -> Automatic, BaseStyle -> {}, ColorOutput -> 
         Automatic, ContentSelectable -> Automatic, CoordinatesToolOptions -> 
         Automatic, DisplayFunction :> $DisplayFunction, Epilog -> {}, 
         FormatType :> TraditionalForm, Frame -> True, FrameLabel -> None, 
         FrameStyle -> {}, FrameTicks -> Automatic, FrameTicksStyle -> {}, 
         GridLines -> Automatic, GridLinesStyle -> {}, ImageMargins -> 0., 
         ImagePadding -> All, ImageSize -> Automatic, ImageSizeRaw -> 
         Automatic, LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, 
         PlotRange -> All, PlotRangeClipping -> False, PlotRangePadding -> 
         Automatic, PlotRegion -> Automatic, PreserveImageOptions -> 
         Automatic, Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$541691 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmglczWkXx2/W7PuSl9RLZClS3WtQPcooqUkLiVT3tt5uC5ooBo09IVt6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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyFmndUVNcWxkfFhihRiF0CAoKABikjiOJRmgrCUJUqMDAgzUKMihKwRohi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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$541691 = 
        System`TradingChartDump`$staticindicatorpos$541691, 
        System`TradingChartDump`$length$541691 = 250, 
        System`TradingChartDump`$gridlinesflag$541691 = True, 
        System`TradingChartDump`$opens$541691 = 
        Dispatch[{
         1 -> 19.55`4., 2 -> 19.97`4., 3 -> 20.12`4., 4 -> 20.08`4., 5 -> 
          20.19`4., 6 -> 19.86`4., 7 -> 20.14`4., 8 -> 20.29`4., 9 -> 
          20.46`4., 10 -> 20.37`4., 11 -> 20.26`4., 12 -> 20.32`4., 13 -> 
          20.36`4., 14 -> 20.4`4., 15 -> 20.18`4., 16 -> 20.2`4., 17 -> 
          20.34`4., 18 -> 20.27`4., 19 -> 20.3`4., 20 -> 20.1`4., 21 -> 
          20.07`4., 22 -> 19.93`4., 23 -> 20.15`4., 24 -> 20.09`4., 25 -> 
          20.15`4., 26 -> 20.05`4., 27 -> 20.09`4., 28 -> 19.97`4., 29 -> 
          19.88`4., 30 -> 20.19`4., 31 -> 20.63`4., 32 -> 20.79`4., 33 -> 
          20.79`4., 34 -> 20.97`4., 35 -> 21.07`4., 36 -> 21.49`4., 37 -> 
          21.22`4., 38 -> 21.28`4., 39 -> 21.58`4., 40 -> 21.64`4., 41 -> 
          21.99`4., 42 -> 21.84`4., 43 -> 21.84`4., 44 -> 21.61`4., 45 -> 
          21.68`4., 46 -> 22.21`4., 47 -> 22.16`4., 48 -> 22.36`4., 49 -> 
          22.29`4., 50 -> 22.38`4., 51 -> 22.46`4., 52 -> 22.3`4., 53 -> 
          22.37`4., 54 -> 22.05`4., 55 -> 22.03`4., 56 -> 22.02`4., 57 -> 
          21.98`4., 58 -> 22.23`4., 59 -> 22.2`4., 60 -> 22.24`4., 61 -> 
          21.95`4., 62 -> 21.32`4., 63 -> 20.82`4., 64 -> 20.9`4., 65 -> 
          20.96`4., 66 -> 20.66`4., 67 -> 20.74`4., 68 -> 20.51`4., 69 -> 
          20.99`4., 70 -> 20.68`4., 71 -> 20.97`4., 72 -> 20.82`4., 73 -> 
          20.63`4., 74 -> 20.25`4., 75 -> 20.52`4., 76 -> 20.09`4., 77 -> 
          20.21`4., 78 -> 19.4`4., 79 -> 19.6`4., 80 -> 19.91`4., 81 -> 
          20.16`4., 82 -> 20.19`4., 83 -> 20.3`4., 84 -> 20.36`4., 85 -> 
          20.52`4., 86 -> 20.23`4., 87 -> 20.71`4., 88 -> 20.61`4., 89 -> 
          20.65`4., 90 -> 20.35`4., 91 -> 20.39`4., 92 -> 20.67`4., 93 -> 
          20.91`4., 94 -> 20.9`4., 95 -> 20.94`4., 96 -> 21.07`4., 97 -> 
          21.2`4., 98 -> 21.07`4., 99 -> 21.15`4., 100 -> 21.31`4., 101 -> 
          21.1`4., 102 -> 20.57`4., 103 -> 20.51`4., 104 -> 20.46`4., 105 -> 
          20.48`4., 106 -> 20.47`4., 107 -> 20.12`4., 108 -> 19.96`4., 109 -> 
          21.17`4., 110 -> 21.13`4., 111 -> 20.87`4., 112 -> 20.82`4., 113 -> 
          20.77`4., 114 -> 20.71`4., 115 -> 20.7`4., 116 -> 20.88`4., 117 -> 
          20.84`4., 118 -> 20.7`4., 119 -> 20.81`4., 120 -> 20.88`4., 121 -> 
          21.59`4., 122 -> 21.83`4., 123 -> 21.63`4., 124 -> 21.61`4., 125 -> 
          21.92`4., 126 -> 22.08`4., 127 -> 22.13`4., 128 -> 22.16`4., 129 -> 
          21.85`4., 130 -> 22.07`4., 131 -> 22.05`4., 132 -> 22.12`4., 133 -> 
          22.11`4., 134 -> 22.14`4., 135 -> 22.14`4., 136 -> 22.13`4., 137 -> 
          22.12`4., 138 -> 22.74`4., 139 -> 22.88`4., 140 -> 23.11`4., 141 -> 
          23.05`4., 142 -> 23.34`4., 143 -> 23.`4., 144 -> 23.16`4., 145 -> 
          23.31`4., 146 -> 22.79`4., 147 -> 22.83`4., 148 -> 23.19`4., 149 -> 
          22.84`4., 150 -> 22.97`4., 151 -> 23.27`4., 152 -> 23.65`4., 153 -> 
          23.51`4., 154 -> 23.67`4., 155 -> 23.5`4., 156 -> 23.4`4., 157 -> 
          23.25`4., 158 -> 23.36`4., 159 -> 23.25`4., 160 -> 22.99`4., 161 -> 
          23.12`4., 162 -> 23.54`4., 163 -> 23.24`4., 164 -> 23.13`4., 165 -> 
          23.27`4., 166 -> 23.09`4., 167 -> 22.84`4., 168 -> 22.96`4., 169 -> 
          22.85`4., 170 -> 22.99`4., 171 -> 23.2`4., 172 -> 22.83`4., 173 -> 
          22.62`4., 174 -> 22.87`4., 175 -> 23.07`4., 176 -> 22.91`4., 177 -> 
          23.36`4., 178 -> 23.3`4., 179 -> 23.1`4., 180 -> 22.89`4., 181 -> 
          22.78`4., 182 -> 22.58`4., 183 -> 21.77`4., 184 -> 21.5`4., 185 -> 
          21.38`4., 186 -> 21.52`4., 187 -> 22.04`4., 188 -> 21.8`4., 189 -> 
          22.13`4., 190 -> 22.11`4., 191 -> 21.92`4., 192 -> 22.07`4., 193 -> 
          22.39`4., 194 -> 22.38`4., 195 -> 22.51`4., 196 -> 22.5`4., 197 -> 
          22.81`4., 198 -> 22.59`4., 199 -> 22.68`4., 200 -> 22.67`4., 201 -> 
          22.86`4., 202 -> 22.92`4., 203 -> 23.08`4., 204 -> 23.27`4., 205 -> 
          23.4`4., 206 -> 23.59`4., 207 -> 23.33`4., 208 -> 23.31`4., 209 -> 
          23.58`4., 210 -> 23.23`4., 211 -> 23.39`4., 212 -> 23.41`4., 213 -> 
          23.18`4., 214 -> 23.4`4., 215 -> 23.37`4., 216 -> 23.06`4., 217 -> 
          23.35`4., 218 -> 23.69`4., 219 -> 23.3`4., 220 -> 23.51`4., 221 -> 
          23.26`4., 222 -> 23.49`4., 223 -> 23.56`4., 224 -> 23.64`4., 225 -> 
          24.01`4., 226 -> 23.63`4., 227 -> 23.58`4., 228 -> 23.12`4., 229 -> 
          23.17`4., 230 -> 23.43`4., 231 -> 23.41`4., 232 -> 23.32`4., 233 -> 
          23.21`4., 234 -> 23.27`4., 235 -> 22.83`4., 236 -> 23.17`4., 237 -> 
          23.36`4., 238 -> 23.52`4., 239 -> 23.72`4., 240 -> 23.91`4., 241 -> 
          23.99`4., 242 -> 23.73`4., 243 -> 23.66`4., 244 -> 23.54`4., 245 -> 
          23.6`4., 246 -> 24.21`4., 247 -> 24.77`4., 248 -> 24.87`4., 249 -> 
          24.79`4., 250 -> 24.61`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$541691 = 
        Dispatch[{
         1 -> 20.04`4., 2 -> 20.33`4., 3 -> 20.24`4., 4 -> 20.22`4., 5 -> 
          20.27`4., 6 -> 20.03`4., 7 -> 20.32`4., 8 -> 20.49`4., 9 -> 
          20.51`4., 10 -> 20.41`4., 11 -> 20.44`4., 12 -> 20.42`4., 13 -> 
          20.38`4., 14 -> 20.42`4., 15 -> 20.35`4., 16 -> 20.46`4., 17 -> 
          20.37`4., 18 -> 20.34`4., 19 -> 20.37`4., 20 -> 20.2`4., 21 -> 
          20.12`4., 22 -> 20.23`4., 23 -> 20.28`4., 24 -> 20.25`4., 25 -> 
          20.28`4., 26 -> 20.11`4., 27 -> 20.16`4., 28 -> 20.02`4., 29 -> 
          20.1`4., 30 -> 20.63`4., 31 -> 20.89`4., 32 -> 20.95`4., 33 -> 
          20.99`4., 34 -> 21.22`4., 35 -> 21.52`4., 36 -> 21.65`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.77`4., 40 -> 21.91`4., 41 -> 
          22.13`4., 42 -> 21.89`4., 43 -> 22.11`4., 44 -> 21.7`4., 45 -> 
          22.29`4., 46 -> 22.39`4., 47 -> 22.43`4., 48 -> 22.41`4., 49 -> 
          22.41`4., 50 -> 22.48`4., 51 -> 22.6`4., 52 -> 22.42`4., 53 -> 
          22.4`4., 54 -> 22.17`4., 55 -> 22.15`4., 56 -> 22.14`4., 57 -> 
          22.14`4., 58 -> 22.31`4., 59 -> 22.35`4., 60 -> 22.5`4., 61 -> 
          21.97`4., 62 -> 21.4`4., 63 -> 20.87`4., 64 -> 20.93`4., 65 -> 
          21.03`4., 66 -> 20.86`4., 67 -> 20.79`4., 68 -> 20.86`4., 69 -> 
          21.14`4., 70 -> 20.94`4., 71 -> 21.24`4., 72 -> 20.98`4., 73 -> 
          20.66`4., 74 -> 20.77`4., 75 -> 20.61`4., 76 -> 20.43`4., 77 -> 
          20.23`4., 78 -> 19.73`4., 79 -> 19.69`4., 80 -> 20.21`4., 81 -> 
          20.18`4., 82 -> 20.23`4., 83 -> 20.52`4., 84 -> 20.55`4., 85 -> 
          20.67`4., 86 -> 20.62`4., 87 -> 20.82`4., 88 -> 20.73`4., 89 -> 
          20.7`4., 90 -> 20.49`4., 91 -> 20.83`4., 92 -> 20.86`4., 93 -> 
          20.95`4., 94 -> 20.97`4., 95 -> 21.2`4., 96 -> 21.41`4., 97 -> 
          21.37`4., 98 -> 21.22`4., 99 -> 21.4`4., 100 -> 21.36`4., 101 -> 
          21.12`4., 102 -> 20.9`4., 103 -> 20.66`4., 104 -> 20.63`4., 105 -> 
          20.61`4., 106 -> 20.54`4., 107 -> 20.38`4., 108 -> 20.66`4., 109 -> 
          21.2`4., 110 -> 21.14`4., 111 -> 20.92`4., 112 -> 20.88`4., 113 -> 
          20.79`4., 114 -> 20.74`4., 115 -> 20.89`4., 116 -> 20.9`4., 117 -> 
          20.9`4., 118 -> 20.87`4., 119 -> 20.86`4., 120 -> 21.2`4., 121 -> 
          21.84`4., 122 -> 21.85`4., 123 -> 21.68`4., 124 -> 21.84`4., 125 -> 
          21.95`4., 126 -> 22.18`4., 127 -> 22.22`4., 128 -> 22.18`4., 129 -> 
          22.04`4., 130 -> 22.28`4., 131 -> 22.13`4., 132 -> 22.26`4., 133 -> 
          22.14`4., 134 -> 22.15`4., 135 -> 22.2`4., 136 -> 22.15`4., 137 -> 
          22.29`4., 138 -> 23.11`4., 139 -> 23.12`4., 140 -> 23.18`4., 141 -> 
          23.37`4., 142 -> 23.37`4., 143 -> 23.17`4., 144 -> 23.26`4., 145 -> 
          23.34`4., 146 -> 22.97`4., 147 -> 23.21`4., 148 -> 23.28`4., 149 -> 
          23.16`4., 150 -> 23.1`4., 151 -> 23.52`4., 152 -> 23.65`4., 153 -> 
          23.64`4., 154 -> 23.71`4., 155 -> 23.56`4., 156 -> 23.41`4., 157 -> 
          23.33`4., 158 -> 23.57`4., 159 -> 23.53`4., 160 -> 23.17`4., 161 -> 
          23.18`4., 162 -> 23.61`4., 163 -> 23.42`4., 164 -> 23.21`4., 165 -> 
          23.3`4., 166 -> 23.12`4., 167 -> 22.96`4., 168 -> 23.02`4., 169 -> 
          22.92`4., 170 -> 23.19`4., 171 -> 23.22`4., 172 -> 22.95`4., 173 -> 
          22.76`4., 174 -> 22.94`4., 175 -> 23.07`4., 176 -> 23.46`4., 177 -> 
          23.53`4., 178 -> 23.4`4., 179 -> 23.12`4., 180 -> 22.92`4., 181 -> 
          22.85`4., 182 -> 22.67`4., 183 -> 21.86`4., 184 -> 21.51`4., 185 -> 
          21.52`4., 186 -> 21.86`4., 187 -> 22.06`4., 188 -> 22.22`4., 189 -> 
          22.14`4., 190 -> 22.2`4., 191 -> 22.17`4., 192 -> 22.14`4., 193 -> 
          22.67`4., 194 -> 22.46`4., 195 -> 22.61`4., 196 -> 22.84`4., 197 -> 
          22.92`4., 198 -> 22.73`4., 199 -> 22.7`4., 200 -> 22.89`4., 201 -> 
          23.07`4., 202 -> 23.17`4., 203 -> 23.29`4., 204 -> 23.39`4., 205 -> 
          23.59`4., 206 -> 23.94`4., 207 -> 23.56`4., 208 -> 23.48`4., 209 -> 
          23.65`4., 210 -> 23.51`4., 211 -> 23.57`4., 212 -> 23.61`4., 213 -> 
          23.59`4., 214 -> 23.57`4., 215 -> 23.4`4., 216 -> 23.2`4., 217 -> 
          23.76`4., 218 -> 23.73`4., 219 -> 23.5`4., 220 -> 23.54`4., 221 -> 
          23.6`4., 222 -> 23.56`4., 223 -> 23.66`4., 224 -> 24.26`4., 225 -> 
          24.16`4., 226 -> 23.69`4., 227 -> 23.64`4., 228 -> 23.15`4., 229 -> 
          23.25`4., 230 -> 23.44`4., 231 -> 23.48`4., 232 -> 23.44`4., 233 -> 
          23.64`4., 234 -> 23.34`4., 235 -> 22.98`4., 236 -> 23.24`4., 237 -> 
          23.53`4., 238 -> 23.8`4., 239 -> 23.73`4., 240 -> 23.96`4., 241 -> 
          24.`4., 242 -> 23.74`4., 243 -> 23.67`4., 244 -> 23.61`4., 245 -> 
          23.94`4., 246 -> 24.95`4., 247 -> 24.92`4., 248 -> 24.88`4., 249 -> 
          24.84`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$541691 = 
        Dispatch[{
         1 -> 19.51`4., 2 -> 19.9`4., 3 -> 20.02`4., 4 -> 20.08`4., 5 -> 
          20.04`4., 6 -> 19.55`4., 7 -> 20.1`4., 8 -> 20.22`4., 9 -> 20.41`4.,
           10 -> 20.22`4., 11 -> 20.26`4., 12 -> 20.27`4., 13 -> 20.2`4., 14 -> 
          20.22`4., 15 -> 20.12`4., 16 -> 20.15`4., 17 -> 20.26`4., 18 -> 
          20.15`4., 19 -> 20.13`4., 20 -> 20.04`4., 21 -> 19.96`4., 22 -> 
          19.89`4., 23 -> 20.12`4., 24 -> 20.09`4., 25 -> 20.14`4., 26 -> 
          19.95`4., 27 -> 19.94`4., 28 -> 19.82`4., 29 -> 19.84`4., 30 -> 
          20.17`4., 31 -> 20.61`4., 32 -> 20.74`4., 33 -> 20.71`4., 34 -> 
          20.96`4., 35 -> 21.05`4., 36 -> 21.27`4., 37 -> 21.19`4., 38 -> 
          21.25`4., 39 -> 21.54`4., 40 -> 21.57`4., 41 -> 21.9`4., 42 -> 
          21.74`4., 43 -> 21.75`4., 44 -> 21.52`4., 45 -> 21.58`4., 46 -> 
          22.06`4., 47 -> 22.14`4., 48 -> 22.14`4., 49 -> 22.15`4., 50 -> 
          22.2`4., 51 -> 22.42`4., 52 -> 22.28`4., 53 -> 22.04`4., 54 -> 
          21.85`4., 55 -> 21.92`4., 56 -> 21.85`4., 57 -> 21.93`4., 58 -> 
          22.01`4., 59 -> 22.15`4., 60 -> 22.23`4., 61 -> 21.32`4., 62 -> 
          20.72`4., 63 -> 20.67`4., 64 -> 20.71`4., 65 -> 20.51`4., 66 -> 
          20.54`4., 67 -> 20.45`4., 68 -> 20.5`4., 69 -> 20.73`4., 70 -> 
          20.68`4., 71 -> 20.91`4., 72 -> 20.54`4., 73 -> 20.36`4., 74 -> 
          20.19`4., 75 -> 20.36`4., 76 -> 20.06`4., 77 -> 19.45`4., 78 -> 
          19.4`4., 79 -> 19.38`4., 80 -> 19.89`4., 81 -> 19.87`4., 82 -> 
          20.06`4., 83 -> 20.22`4., 84 -> 20.35`4., 85 -> 20.33`4., 86 -> 
          19.99`4., 87 -> 20.42`4., 88 -> 20.51`4., 89 -> 20.28`4., 90 -> 
          20.19`4., 91 -> 20.34`4., 92 -> 20.56`4., 93 -> 20.72`4., 94 -> 
          20.83`4., 95 -> 20.82`4., 96 -> 21.04`4., 97 -> 21.01`4., 98 -> 
          21.01`4., 99 -> 21.15`4., 100 -> 20.88`4., 101 -> 20.45`4., 102 -> 
          20.53`4., 103 -> 20.24`4., 104 -> 20.42`4., 105 -> 20.38`4., 106 -> 
          20.09`4., 107 -> 20.1`4., 108 -> 19.93`4., 109 -> 20.86`4., 110 -> 
          20.71`4., 111 -> 20.78`4., 112 -> 20.62`4., 113 -> 20.35`4., 114 -> 
          20.6`4., 115 -> 20.62`4., 116 -> 20.68`4., 117 -> 20.73`4., 118 -> 
          20.67`4., 119 -> 20.72`4., 120 -> 20.78`4., 121 -> 21.25`4., 122 -> 
          21.55`4., 123 -> 21.4`4., 124 -> 21.6`4., 125 -> 21.75`4., 126 -> 
          21.9`4., 127 -> 22.04`4., 128 -> 21.87`4., 129 -> 21.82`4., 130 -> 
          21.96`4., 131 -> 21.92`4., 132 -> 22.09`4., 133 -> 21.95`4., 134 -> 
          21.91`4., 135 -> 22.09`4., 136 -> 21.99`4., 137 -> 22.12`4., 138 -> 
          22.68`4., 139 -> 22.74`4., 140 -> 22.86`4., 141 -> 23.04`4., 142 -> 
          22.98`4., 143 -> 22.94`4., 144 -> 23.04`4., 145 -> 22.63`4., 146 -> 
          22.73`4., 147 -> 22.81`4., 148 -> 23.02`4., 149 -> 22.82`4., 150 -> 
          22.85`4., 151 -> 23.25`4., 152 -> 23.48`4., 153 -> 23.48`4., 154 -> 
          23.49`4., 155 -> 23.26`4., 156 -> 23.14`4., 157 -> 23.21`4., 158 -> 
          23.32`4., 159 -> 23.17`4., 160 -> 22.95`4., 161 -> 22.99`4., 162 -> 
          23.14`4., 163 -> 23.11`4., 164 -> 23.09`4., 165 -> 22.87`4., 166 -> 
          22.83`4., 167 -> 22.67`4., 168 -> 22.81`4., 169 -> 22.79`4., 170 -> 
          22.92`4., 171 -> 22.74`4., 172 -> 22.78`4., 173 -> 22.58`4., 174 -> 
          22.65`4., 175 -> 22.72`4., 176 -> 22.87`4., 177 -> 23.24`4., 178 -> 
          23.14`4., 179 -> 22.63`4., 180 -> 22.72`4., 181 -> 22.47`4., 182 -> 
          22.39`4., 183 -> 21.44`4., 184 -> 20.94`4., 185 -> 21.19`4., 186 -> 
          21.48`4., 187 -> 21.74`4., 188 -> 21.79`4., 189 -> 21.82`4., 190 -> 
          22.03`4., 191 -> 21.92`4., 192 -> 21.97`4., 193 -> 22.37`4., 194 -> 
          22.14`4., 195 -> 22.44`4., 196 -> 22.44`4., 197 -> 22.51`4., 198 -> 
          22.41`4., 199 -> 22.44`4., 200 -> 22.63`4., 201 -> 22.73`4., 202 -> 
          22.92`4., 203 -> 23.01`4., 204 -> 23.24`4., 205 -> 23.4`4., 206 -> 
          23.56`4., 207 -> 23.26`4., 208 -> 23.3`4., 209 -> 23.39`4., 210 -> 
          23.21`4., 211 -> 23.31`4., 212 -> 23.13`4., 213 -> 23.13`4., 214 -> 
          23.22`4., 215 -> 23.03`4., 216 -> 22.91`4., 217 -> 23.28`4., 218 -> 
          23.45`4., 219 -> 23.29`4., 220 -> 23.23`4., 221 -> 23.15`4., 222 -> 
          23.27`4., 223 -> 23.46`4., 224 -> 23.58`4., 225 -> 23.79`4., 226 -> 
          23.2`4., 227 -> 23.21`4., 228 -> 22.76`4., 229 -> 22.94`4., 230 -> 
          23.02`4., 231 -> 23.26`4., 232 -> 23.16`4., 233 -> 23.19`4., 234 -> 
          22.88`4., 235 -> 22.76`4., 236 -> 22.95`4., 237 -> 23.27`4., 238 -> 
          23.51`4., 239 -> 23.36`4., 240 -> 23.63`4., 241 -> 23.59`4., 242 -> 
          23.56`4., 243 -> 23.34`4., 244 -> 23.43`4., 245 -> 23.56`4., 246 -> 
          24.1`4., 247 -> 24.73`4., 248 -> 24.63`4., 249 -> 24.56`4., 250 -> 
          24.52`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$541691 = 
        Dispatch[{
         1 -> 19.9`4., 2 -> 20.25`4., 3 -> 20.13`4., 4 -> 20.08`4., 5 -> 
          20.06`4., 6 -> 19.86`4., 7 -> 20.28`4., 8 -> 20.29`4., 9 -> 
          20.44`4., 10 -> 20.33`4., 11 -> 20.38`4., 12 -> 20.42`4., 13 -> 
          20.31`4., 14 -> 20.26`4., 15 -> 20.28`4., 16 -> 20.37`4., 17 -> 
          20.32`4., 18 -> 20.25`4., 19 -> 20.18`4., 20 -> 20.11`4., 21 -> 
          19.97`4., 22 -> 20.13`4., 23 -> 20.18`4., 24 -> 20.14`4., 25 -> 
          20.15`4., 26 -> 19.97`4., 27 -> 20.04`4., 28 -> 19.85`4., 29 -> 
          19.98`4., 30 -> 20.62`4., 31 -> 20.89`4., 32 -> 20.79`4., 33 -> 
          20.89`4., 34 -> 21.18`4., 35 -> 21.31`4., 36 -> 21.4`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.71`4., 40 -> 21.87`4., 41 -> 
          21.97`4., 42 -> 21.8`4., 43 -> 21.76`4., 44 -> 21.55`4., 45 -> 
          22.16`4., 46 -> 22.15`4., 47 -> 22.24`4., 48 -> 22.22`4., 49 -> 
          22.34`4., 50 -> 22.38`4., 51 -> 22.54`4., 52 -> 22.35`4., 53 -> 
          22.06`4., 54 -> 21.87`4., 55 -> 21.95`4., 56 -> 21.92`4., 57 -> 
          22.08`4., 58 -> 22.08`4., 59 -> 22.34`4., 60 -> 22.24`4., 61 -> 
          21.48`4., 62 -> 21.16`4., 63 -> 20.75`4., 64 -> 20.73`4., 65 -> 
          20.73`4., 66 -> 20.58`4., 67 -> 20.54`4., 68 -> 20.81`4., 69 -> 
          20.78`4., 70 -> 20.88`4., 71 -> 21.05`4., 72 -> 20.6`4., 73 -> 
          20.37`4., 74 -> 20.48`4., 75 -> 20.37`4., 76 -> 20.17`4., 77 -> 
          19.51`4., 78 -> 19.56`4., 79 -> 19.65`4., 80 -> 20.15`4., 81 -> 
          20.11`4., 82 -> 20.17`4., 83 -> 20.52`4., 84 -> 20.54`4., 85 -> 
          20.35`4., 86 -> 20.61`4., 87 -> 20.6`4., 88 -> 20.6`4., 89 -> 
          20.3`4., 90 -> 20.34`4., 91 -> 20.7`4., 92 -> 20.84`4., 93 -> 
          20.93`4., 94 -> 20.86`4., 95 -> 20.97`4., 96 -> 21.24`4., 97 -> 
          21.08`4., 98 -> 21.08`4., 99 -> 21.38`4., 100 -> 21.15`4., 101 -> 
          20.49`4., 102 -> 20.71`4., 103 -> 20.55`4., 104 -> 20.49`4., 105 -> 
          20.44`4., 106 -> 20.36`4., 107 -> 20.11`4., 108 -> 20.65`4., 109 -> 
          21.`4., 110 -> 20.76`4., 111 -> 20.86`4., 112 -> 20.79`4., 113 -> 
          20.57`4., 114 -> 20.62`4., 115 -> 20.83`4., 116 -> 20.79`4., 117 -> 
          20.78`4., 118 -> 20.86`4., 119 -> 20.78`4., 120 -> 20.96`4., 121 -> 
          21.69`4., 122 -> 21.66`4., 123 -> 21.59`4., 124 -> 21.7`4., 125 -> 
          21.93`4., 126 -> 22.14`4., 127 -> 22.14`4., 128 -> 21.87`4., 129 -> 
          21.92`4., 130 -> 22.26`4., 131 -> 21.95`4., 132 -> 22.18`4., 133 -> 
          22.08`4., 134 -> 22.12`4., 135 -> 22.14`4., 136 -> 22.09`4., 137 -> 
          22.22`4., 138 -> 23.02`4., 139 -> 23.04`4., 140 -> 22.92`4., 141 -> 
          23.37`4., 142 -> 23.04`4., 143 -> 23.08`4., 144 -> 23.2`4., 145 -> 
          22.63`4., 146 -> 22.87`4., 147 -> 23.18`4., 148 -> 23.04`4., 149 -> 
          23.01`4., 150 -> 23.09`4., 151 -> 23.4`4., 152 -> 23.48`4., 153 -> 
          23.49`4., 154 -> 23.58`4., 155 -> 23.43`4., 156 -> 23.22`4., 157 -> 
          23.3`4., 158 -> 23.5`4., 159 -> 23.25`4., 160 -> 23.07`4., 161 -> 
          23.14`4., 162 -> 23.27`4., 163 -> 23.11`4., 164 -> 23.18`4., 165 -> 
          23.06`4., 166 -> 22.94`4., 167 -> 22.92`4., 168 -> 22.94`4., 169 -> 
          22.9`4., 170 -> 23.16`4., 171 -> 22.82`4., 172 -> 22.9`4., 173 -> 
          22.75`4., 174 -> 22.94`4., 175 -> 22.88`4., 176 -> 23.39`4., 177 -> 
          23.4`4., 178 -> 23.27`4., 179 -> 22.63`4., 180 -> 22.92`4., 181 -> 
          22.58`4., 182 -> 22.49`4., 183 -> 21.58`4., 184 -> 21.18`4., 185 -> 
          21.33`4., 186 -> 21.79`4., 187 -> 21.78`4., 188 -> 22.03`4., 189 -> 
          22.09`4., 190 -> 22.11`4., 191 -> 21.97`4., 192 -> 22.14`4., 193 -> 
          22.39`4., 194 -> 22.4`4., 195 -> 22.5`4., 196 -> 22.83`4., 197 -> 
          22.6`4., 198 -> 22.72`4., 199 -> 22.67`4., 200 -> 22.83`4., 201 -> 
          23.06`4., 202 -> 23.09`4., 203 -> 23.27`4., 204 -> 23.38`4., 205 -> 
          23.47`4., 206 -> 23.67`4., 207 -> 23.47`4., 208 -> 23.34`4., 209 -> 
          23.41`4., 210 -> 23.45`4., 211 -> 23.41`4., 212 -> 23.14`4., 213 -> 
          23.45`4., 214 -> 23.47`4., 215 -> 23.14`4., 216 -> 23.19`4., 217 -> 
          23.67`4., 218 -> 23.59`4., 219 -> 23.39`4., 220 -> 23.31`4., 221 -> 
          23.49`4., 222 -> 23.33`4., 223 -> 23.58`4., 224 -> 24.14`4., 225 -> 
          23.79`4., 226 -> 23.25`4., 227 -> 23.36`4., 228 -> 22.93`4., 229 -> 
          23.11`4., 230 -> 23.25`4., 231 -> 23.32`4., 232 -> 23.19`4., 233 -> 
          23.34`4., 234 -> 22.9`4., 235 -> 22.91`4., 236 -> 23.24`4., 237 -> 
          23.32`4., 238 -> 23.62`4., 239 -> 23.54`4., 240 -> 23.94`4., 241 -> 
          23.76`4., 242 -> 23.63`4., 243 -> 23.43`4., 244 -> 23.54`4., 245 -> 
          23.63`4., 246 -> 24.72`4., 247 -> 24.86`4., 248 -> 24.71`4., 249 -> 
          24.62`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$541691 = True, 
        System`TradingChartDump`$gridlines$541691 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$541691, 
        System`TradingChartDump`$plotrangemin$541691 = 19.0982952853598, 
        System`TradingChartDump`$plotrangemax$541691 = 25.507305210918112`, 
        System`TradingChartDump`$layoutData$541691, 
        System`TradingChartDump`$gridlinesscope$541691 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$541691 = {True, True}, 
        System`TradingChartDump`$indicators$541691 = {
         FinancialIndicator["PolarizedFractalEfficiency", 10, 5]}, 
        System`TradingChartDump`$mouseQ$541691 = False, 
        System`TradingChartDump`$modelData$541691 = 
        System`TradingChartDump`modelData$539928, 
        System`TradingChartDump`$sy$541691 = Identity, 
        System`TradingChartDump`$isy$541691 = Identity, 
        System`TradingChartDump`$appearance$541691 = Automatic, 
        System`TradingChartDump`$perfgoal$541691 = "Quality", 
        System`TradingChartDump`$axesorigin$541691 = Automatic, 
        System`TradingChartDump`$framestyle$541691 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$541691 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$541691 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$541691 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$541691 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$541691, 
        System`TradingChartDump`$newgridlines$541691 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{19.0982952853598, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$541691 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$541691 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$541691 = "GraphicsFrame", 
        System`TradingChartDump`$frame$541691 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$541691 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$541691 = 
              Switch[System`TradingChartDump`$highlightposition$541691, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$541691], {
                 1, System`TradingChartDump`$length$541691}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$541691], {
                 1, System`TradingChartDump`$length$541691}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$541691, 
                   Charting`nearestDate[System`TradingChartDump`$dates$541691, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$541691]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$541691]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$541691, 
                    Floor[System`TradingChartDump`$controlmin$541691] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$541691, 
                    Floor[System`TradingChartDump`$controlmax$541691]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$541691 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$541691 = 
            If[System`TradingChartDump`$fastpos$541691 =!= True, 
              System`TradingChartDump`$fastpos$541691 = 
               Clip[System`TradingChartDump`$fastpos$541691, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$541691 = (
                  Floor[System`TradingChartDump`$controlmax$541691] - Floor[
                  System`TradingChartDump`$controlmin$541691]) (
                  System`TradingChartDump`$fastpos$541691/100) + 
                Floor[System`TradingChartDump`$controlmin$541691]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$541691], {
                Floor[System`TradingChartDump`$controlmin$541691] + 1, 
                 Floor[System`TradingChartDump`$controlmax$541691]}], 
              System`TradingChartDump`$staticindicatorpos$541691]; 
           System`TradingChartDump`$mouseQ$541691 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$541691]], 
              System`TradingChartDump`$highlightposition$541691 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$541691 = If[
              And[
              System`TradingChartDump`$bouncingballQ$541691, 
               System`TradingChartDump`$mouseQ$541691, 
               System`TradingChartDump`$appearance$541691 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$541691[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$541691]]], {}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$541691[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$541691, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$541691[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$541691]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$541691[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$541691[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541691, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541691[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541691, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541691, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541691[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541691[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$541691 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$541691, 
                 System`TradingChartDump`$defaultframeticksstyle$541691, 
                 System`TradingChartDump`$defaultlabelstyle$541691, 
                 System`TradingChartDump`$framestyle$541691, 
                 System`TradingChartDump`$frameticksstyle$541691, 
                 System`TradingChartDump`$labelstyle$541691}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541691 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$541691, 
                 System`TradingChartDump`$labelstyle$541691, 
                 System`TradingChartDump`$defaultframeticksstyle$541691, 
                 System`TradingChartDump`$defaultlabelstyle$541691}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541691 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541691, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$541691 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541691, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$541691 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541691, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$541691 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$541691 = 
             Part[System`TradingChartDump`$tickstextstyle$541691, 1], 
             System`TradingChartDump`$tickstextstyle$541691 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541691[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541691, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541691[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541691[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541691[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$541691[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541691, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$541691]], 
                    Style[":", System`TradingChartDump`$textstyle$541691]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$541691[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541691]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541691[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$541691[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$541691, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$541691]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$541691[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541691, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541691[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541691, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541691, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$541691[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541691[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541691[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$541691[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$541691[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$541691], 1], 
                   Floor[System`TradingChartDump`$controlmax$541691]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$541691[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$541691[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$541691[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$541691[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$541691[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541691[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$541691[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$541691[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$541691[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541691[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$541691[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$541691[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$541691[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$541691[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$541691[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$541691, 
                  System`TradingChartDump`$mouseQ$541691], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$541691 - 0.5, 
                   System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$541691 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$541691 + 0.5, 
                    System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541691, 1]}, {
                    System`TradingChartDump`$indicatorpos$541691 + 0.5, 
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$541691[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$541691, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$541691[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541691]]], {}]; 
              System`TradingChartDump`$subplotgridlines$541691[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$541691[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$541691[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541691[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$541691 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$541691, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541691, 
                   System`TradingChartDump`$opens$541691]], 12, 
                 System`TradingChartDump`$textstyle$541691, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$541691, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541691, 
                   System`TradingChartDump`$highs$541691]], 12, 
                 System`TradingChartDump`$textstyle$541691, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$541691, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541691, 
                   System`TradingChartDump`$lows$541691]], 12, 
                 System`TradingChartDump`$textstyle$541691, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$541691, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541691, 
                   System`TradingChartDump`$closes$541691]], 12, 
                 System`TradingChartDump`$textstyle$541691, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541691, 
                   System`TradingChartDump`$visdates$541691]], 12, 
                 System`TradingChartDump`$textstyle$541691, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$541691, 
                  System`TradingChartDump`$mouseQ$541691], {{
                  System`TradingChartDump`$timestampstyle$541691, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$541691 - 0.5, 
                    System`TradingChartDump`$plotrangemin$541691}, 
                    If[
                    System`TradingChartDump`$timestampdepth$541691 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$541691[1]}, {
                    System`TradingChartDump`$indicatorpos$541691 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541691}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541691, 1]}, {
                    System`TradingChartDump`$indicatorpos$541691 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541691}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$541691, {
               System`TradingChartDump`$highlightstyle$541691, 
                Dynamic[System`TradingChartDump`$ohlcpoint$541691]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$541691[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541691, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$541691[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$541691[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$541691, Length[
                    System`TradingChartDump`$layoutData$541691[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$541691}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$541691] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$541691] + 0.5}, {
                System`TradingChartDump`$plotrangemin$541691, 
                 System`TradingChartDump`$plotrangemax$541691}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$541691, Left, {
                 False, System`TradingChartDump`$frame$541691}, 
                 Blank[], {System`TradingChartDump`$frame$541691, False}], {
                False, System`TradingChartDump`$frame$541691}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$541691, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$541691]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$541691 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           387.0228610767757}, {-286.9226415094339, -65.7679245283018}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541691 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541691, 1]], 
               Part[System`TradingChartDump`$framestyle$541691, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$541691]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$541691} -> 
                   System`TradingChartDump`$isy$541691[
                    System`TradingChartDump`$plotrangemin$541691], {
                    0, System`TradingChartDump`$plotrangemax$541691} -> 
                   System`TradingChartDump`$isy$541691[
                    System`TradingChartDump`$plotrangemax$541691]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$541691[
                   System`TradingChartDump`$plotrangemin$541691], 
                   System`TradingChartDump`$isy$541691[
                   System`TradingChartDump`$plotrangemax$541691]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$541691, 
                   System`TradingChartDump`$isy$541691}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541691, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541691 > 
                    System`TradingChartDump`$plotrangemin$541691, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541691 > 
                    System`TradingChartDump`$plotrangemin$541691, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541691, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541691 > 
                    System`TradingChartDump`$plotrangemin$541691, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541691 > 
                    System`TradingChartDump`$plotrangemin$541691, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541691, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541691, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541691 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541691,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541691], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541691 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541691, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541691]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$541691, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$541691[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$541691[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541691, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$541691[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$541691, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541691[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541691, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541691[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541691[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541691[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541691[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541691], 
                    Style[":", System`TradingChartDump`$textstyle$541691]], 
                    Style[":", System`TradingChartDump`$textstyle$541691]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$541691[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541691]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541691[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$541691}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$541691, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$541691 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$541691[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$541691, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$541691, Left, {
                    False, System`TradingChartDump`$frame$541691}, 
                    Blank[], {
                    System`TradingChartDump`$frame$541691, False}], {
                   System`TradingChartDump`$frame$541691, 
                    System`TradingChartDump`$frame$541691}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$541691, 
                    System`TradingChartDump`$controlmax$541691}] + 0.5, {
                   System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$541691]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$541691) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$541691 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$541691 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$541691, 1]], 
                   Part[System`TradingChartDump`$framestyle$541691, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$541691]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541691[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541691[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$541691[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541691, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541691, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$541691, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$541691, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$541691 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
541691, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$541691], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$541691 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$541691, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$541691]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$541691, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$541691) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$541691 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$541691[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           475.9407855006933}, {-55.98962264150938, -0.70094339622635}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$541691, 
              Dynamic[System`TradingChartDump`$ohlclabel$541691], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$541691}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541691 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541691, 2]], 
               Part[System`TradingChartDump`$framestyle$541691, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$541691]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$541691, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$541691, 
                    System`TradingChartDump`$controlmax$541691}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$541691] + 
                    0.5, System`TradingChartDump`$plotrangemin$541691}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$541691], 
                    System`TradingChartDump`$plotrangemin$541691}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$541691, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541691, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541691, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541691 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541691, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541691], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541691 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541691,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541691]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$541691] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$541691[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$541691] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$541691[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$541691] = {HoldPattern[
               System`TradingChartDump`$min$541691[1]] :> -108.76}}, {
          DownValues[System`TradingChartDump`$max$541691] = {HoldPattern[
               System`TradingChartDump`$max$541691[1]] :> 
             110.21000000000001`}}, {
          DownValues[System`TradingChartDump`$subplotvalue$541691] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$541691[1, 1]] :> 
             Invisible[104.65]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$541691] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$541691[1]] :> {-100, 
              0, 100}}}, {
          DownValues[System`TradingChartDump`$layoutData$541691] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$541691["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "AllValues"]] :> CompressedData["
1:eJxFVwk4lVsXppIh0aCkJH7kIJGzv72PhCUVlTKkQVcqXSKKkooGqWSoaLjI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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541691["AppendedAdjust"]] :> 
             21.896885216855722`, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "AppendedBox"]] :> {-125.07018207258393`, 143.27582373707298`},
              HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "AppendedMin"]] :> -119.70512267154433`, HoldPattern[
               System`TradingChartDump`$layoutData$541691["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$541691["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$541691["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$541691["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541691["DataMax"]] :> 
             24.95, HoldPattern[
               System`TradingChartDump`$layoutData$541691["DataMin"]] :> 
             19.376947890818858`, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "MainChartAllValues"]] :> CompressedData["
1:eJxFVwk81csXp5Il0aKkJP4Rkcid38yVcCRRKUta9KToka2QVLRok6Wi5SFb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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "MainChartPoints"]] :> CompressedData["
1:eJxdV1toXFUUvRZFKYIKBf0ocapS6oNSTR/xEbubNk2apk1mMslkksnkztyZ
O487M6n4IxXhIuRHhFAoSEVkRBFBEEEKoV+X+CGIIoJQBJEpQhEiUpCK9MuZ
2Wt97HMhDOvuu886e+3HOTlQ3shU7/c8717/7z787fH43DkZDp7bo4IX+itH
gR+SW5f3fTV1gPhR6aP+K+J9srVz91DhEeInpDB48RvX2y/TwwVoT8nem59e
Gp8hfkreGB+8IX5G188SH1T+EvEh+Su9PbIZET+n/HPEL8i3fbg1QXzY4T8i
T27upreLxC9Kpr/cbpr4JSf+URmGe5j4qMa3n/iYDN3/Y7zHHb1OOP5j8tml
fsBPE78sQ/0PEr/irPeq6rWX9tfkw2v951fax+XtgWD3iF/X+D7m9yeV7w9i
0fW+B47FsZ/Cfo/Bfgr6AnsTut+Q9gkZbi9H+2kZ0I9s0n5a/u2nY+c67Wd0
f7/Tfgbx0j4pP/4weGif1Hzu0H5W7e/TflaeHSbkOOxT0BM4npJheY3TPq18
Y7RPY/+0n0O90X5O9XqP9hnVP0/7DOqf9vNOfOdldPD8w/3Pav3u0j6LfqL/
BYvjC87+Ltp44oua/8tcfw56cP05/U2Y33n9/gawODieV/6rwMk84qd/WuP9
if5p7a/v6J9W/W7RP635epj7y6h+1+ifsf0YZxAP/R27t6D6PU//Ba2Pd1H/
8YLubws4WdB6+Jz9kbX9Jlnbz3HWrp9kUc/kX7R6yCLqgf6Lut5H9F+08XpL
TvxLqs8s/ZeQb/ovaf18Q/+c2m/SP6f9+jf9c5i/9M+hv+i/jPpBPmQZ9cZ6
cXCyjH5g/vLQj/55Xe8d8ufR7+TPo1/Jv2K/lxU7/+MV3X+B/ivOvF1FPum/
ivfc/yrmBf1XrR5ewc4/Kej8v0L+gp2fSUH1+IX+a47/mlP/a47+jt0rqj53
6V/U+L/m/ovav19Q/6Lm+wPqv456oP7ryD/913G+YD4kDvZ8O59Svp1H4uP8
xPe+b+dX7ON8gL3r23mVYP0R4J7v8Jc0nseBUyU7j6Wk/fbACfCXcP4BxyXs
l/wlzAfYE+f7Xgn7A/bKGs8ocKqs9f0J+cvQh/GXES/5y3b9bln12kP+MuIj
fxnnJfkDzDfyB+gHYAkwfxl/oPwd8gfQi/wB5gf5A3xHfmAhf0Xr/THyV5Af
8ldU/0nyV9B/5K9YPboVnH/kr2g932H+KzZfXtXaU1XV5zb1r+L8In9V9/sz
zzvn+24VvKw/Z/1eFecR+UONN2D8oc2PhE78oa2POHTqL0S+yB8in+Snnf1b
s/erVA33XfZfDfMF2K9hfrD/gB8kf832U1JDvshfc+5XdduPKeCA+tehB+u/
Dl7GX8c8JH8d5xn568q3Tf666vUl9W9Y/1TD1o80bP/4DZuPuIHziPXXUL63
WH8N8LH+HbvXxPnK/De13urkb+p8eJP8jj1u2n7pOt8nTcvXc773Iq3PI+SP
7H4lwrwnf2TrNY5wHyd/ZOdHEqGeyB/ZeeK1sJ8x8LdQb+Rv4Zf8LZzH5G/h
vGH+W3Y+JI5/r4X/r8jfduJv23xI2/a331b9/2T9tXF/Yfxtu37SxvlN/jbu
a+TvYD6Qv4P7Avk76HfG33Hmb8eu13W+Tzqof+jb6+A+AOxt4H5E/TewX2DZ
wH1gTP4HLlcf7Q==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541691["NewSubplot"]] :> {
               FinancialIndicator["PolarizedFractalEfficiency", 10, 5]}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541691["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "PlotRangeMin"]] :> -119.70512267154433`, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$541691["Space"]] :> 2.495, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541691["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, -50}, {250., -50}}], 
                    Line[{{0, 0}, {250., 0}}], 
                    Line[{{0, 50}, {250., 50}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJw9lws4FGgXx6c+pWyErsoypGSppMJK/N0vkdsY18mMYYYZl9ImbcnIstml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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "SubplotIndicatorGridLines"]] :> {{-100, 0, 100}}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "PFE"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["PolarizedFractalEfficiency", 10, 5]}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "SubplotIndicatorParameters"]] :> {{{10, 5}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "SubplotIndicatorPoints"]] :> {{{}, {}, {}, {}, {}, {}, {}, \
{}, {}, {{10., 108.92}}, {{11., 109.12}}, {{12., 109.29}}, {{13., 109.38}}, {{
                14., 109.43}}, {{15., 109.57000000000001`}}, {{16., 
                109.96000000000001`}}, {{17., 110.21000000000001`}}, {{18., 
                36.53}}, {{19., -12.61}}, {{20., -45.37}}, {{21., -67.2}}, {{
                22., -81.69}}, {{23., -91.35000000000001}}, {{
                24., -97.79}}, {{25., -102.10000000000001`}}, {{
                26., -104.93}}, {{27., -106.8}}, {{28., -108.}}, {{
                29., -108.76}}, {{30., -36.38}}, {{31., 11.81}}, {{32., 
                43.88}}, {{33., 65.28}}, {{34., 79.48}}, {{35., 89.11}}, {{
                36., 95.53}}, {{37., 99.93}}, {{38., 102.87}}, {{39., 
                105.28}}, {{40., 106.95}}, {{41., 108.13}}, {{42., 
                108.78}}, {{43., 109.29}}, {{44., 109.52}}, {{45., 
                109.11}}, {{46., 108.85000000000001`}}, {{47., 
                108.71000000000001`}}, {{48., 108.63}}, {{49., 
                108.60000000000001`}}, {{50., 108.58}}, {{51., 108.64}}, {{
                52., 108.58}}, {{53., 108.45}}, {{54., 
                35.660000000000004`}}, {{55., -12.84}}, {{56., -45.2}}, {{
                57., -66.71000000000001}}, {{58., -81.09}}, {{
                59., -90.53}}, {{60., -96.88}}, {{61., -100.29}}, {{
                62., -102.55}}, {{63., -103.89}}, {{64., -104.84}}, {{
                65., -105.46000000000001`}}, {{66., -106.03}}, {{
                67., -106.42}}, {{68., -106.67}}, {{
                69., -106.82000000000001`}}, {{70., -107.57000000000001`}}, {{
                71., -108.15}}, {{72., -108.48}}, {{73., -108.61}}, {{
                74., -108.67}}, {{75., -108.72}}, {{76., -108.7}}, {{
                77., -108.33}}, {{78., -108.04}}, {{79., -107.86}}, {{
                80., -107.23}}, {{81., -107.06}}, {{82., -107.01}}, {{
                83., -35.910000000000004`}}, {{84., 11.51}}, {{85., 
                43.13}}, {{86., 65.06}}, {{87., 79.66}}, {{88., 89.38}}, {{
                89., 95.99000000000001}}, {{90., 100.4}}, {{91., 103.15}}, {{
                92., 105.14}}, {{93., 106.46000000000001`}}, {{94., 
                107.42}}, {{95., 108.15}}, {{96., 108.54}}, {{97., 
                108.72}}, {{98., 109.08}}, {{99., 109.24000000000001`}}, {{
                100., 109.33}}, {{101., 37.13}}, {{102., -10.91}}, {{
                103., -42.9}}, {{104., -64.27}}, {{105., -78.73}}, {{
                106., -88.38}}, {{107., -94.77}}, {{
                108., -98.60000000000001}}, {{109., -100.95}}, {{
                110., -31.43}}, {{111., 14.97}}, {{112., 45.95}}, {{113., 
                66.51}}, {{114., 80.23}}, {{115., 89.33}}, {{116., 95.56}}, {{
                117., 100.16}}, {{118., 30.09}}, {{119., 56.85}}, {{120., 
                74.64}}, {{121., 85.71000000000001}}, {{122., 93.26}}, {{123.,
                 98.23}}, {{124., 101.58}}, {{125., 103.81}}, {{126., 
                105.31}}, {{127., 106.29}}, {{128., 106.73}}, {{129., 
                107.04}}, {{130., 107.85000000000001`}}, {{131., 108.16}}, {{
                132., 108.32000000000001`}}, {{133., 108.4}}, {{134., 
                108.53}}, {{135., 72.35000000000001}}, {{136., 11.9}}, {{137.,
                 44.4}}, {{138., 65.18}}, {{139., 79.14}}, {{140., 88.65}}, {{
                141., 94.81}}, {{142., 98.65}}, {{143., 
                101.21000000000001`}}, {{144., 102.92}}, {{145., 103.37}}, {{
                146., 103.62}}, {{147., 104.58}}, {{148., 69.72}}, {{149., 
                81.96000000000001}}, {{150., 18.79}}, {{151., 
                48.410000000000004`}}, {{152., 68.16}}, {{153., 81.33}}, {{
                154., 90.84}}, {{155., 97.15}}, {{156., 101.39}}, {{157., 
                104.26}}, {{158., 106.13}}, {{159., 107.22}}, {{160., 
                34.87}}, {{161., -13.370000000000001`}}, {{
                162., -45.480000000000004`}}, {{163., -66.88}}, {{
                164., -81.16}}, {{165., -90.73}}, {{166., -97.11}}, {{
                167., -101.48}}, {{168., -104.48}}, {{169., -106.52}}, {{
                170., -34.27}}, {{171., -59.44}}, {{172., -76.22}}, {{
                173., -87.4}}, {{174., -94.78}}, {{175., -99.72}}, {{
                176., -30.39}}, {{177., 15.83}}, {{178., 46.59}}, {{
                179., -4.42}}, {{180., 32.54}}, {{181., -13.61}}, {{
                182., -44.4}}, {{183., -64.02}}, {{184., -77.01}}, {{
                185., -86.29}}, {{186., -91.84}}, {{187., -95.51}}, {{
                188., -98.2}}, {{189., -100.18}}, {{190., -101.63}}, {{
                191., -102.58}}, {{192., -32.28}}, {{193., 14.98}}, {{194., 
                46.47}}, {{195., 67.73}}, {{196., 81.8}}, {{197., 91.06}}, {{
                198., 97.22}}, {{199., 101.31}}, {{200., 
                104.10000000000001`}}, {{201., 105.94}}, {{202., 107.22}}, {{
                203., 108.05}}, {{204., 108.61}}, {{205., 109.11}}, {{206., 
                109.61}}, {{207., 109.78}}, {{208., 109.84}}, {{209., 
                109.91}}, {{210., 110.02}}, {{211., 110.08}}, {{212., 
                36.75}}, {{213., 60.97}}, {{214., 40.65}}, {{215., -9.31}}, {{
                216., -42.65}}, {{217., 7.62}}, {{218., 41.12}}, {{
                219., -8.55}}, {{220., -41.65}}, {{221., 8.28}}, {{
                222., -30.64}}, {{223., 15.610000000000001`}}, {{224., 
                46.27}}, {{225., 66.37}}, {{226., 8.86}}, {{227., -29.45}}, {{
                228., -54.76}}, {{229., -71.56}}, {{230., -82.78}}, {{
                231., -90.29}}, {{232., -95.41}}, {{233., -99.41}}, {{
                234., -101.99000000000001`}}, {{235., -104.11}}, {{
                236., -105.32000000000001`}}, {{237., -33.94}}, {{238., 
                13.56}}, {{239., 45.21}}, {{240., 66.08}}, {{241., 79.95}}, {{
                242., 89.17}}, {{243., 95.63}}, {{244., 99.94}}, {{245., 
                102.96000000000001`}}, {{246., 103.49000000000001`}}, {{247., 
                103.89}}, {{248., 104.11}}, {{249., 104.36}}, {{250., 
                104.65}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "SubplotIndicatorValues"]] :> {{{""}, {""}, {""}, {""}, {""}, {
                ""}, {""}, {""}, {""}, {108.92}, {109.12}, {109.29}, {
                109.38}, {109.43}, {109.57000000000001`}, {
                109.96000000000001`}, {110.21000000000001`}, {
                36.53}, {-12.61}, {-45.37}, {-67.2}, {-81.69}, \
{-91.35000000000001}, {-97.79}, {-102.10000000000001`}, {-104.93}, {-106.8}, \
{-108.}, {-108.76}, {-36.38}, {11.81}, {43.88}, {65.28}, {79.48}, {89.11}, {
                95.53}, {99.93}, {102.87}, {105.28}, {106.95}, {108.13}, {
                108.78}, {109.29}, {109.52}, {109.11}, {
                108.85000000000001`}, {108.71000000000001`}, {108.63}, {
                108.60000000000001`}, {108.58}, {108.64}, {108.58}, {
                108.45}, {
                35.660000000000004`}, {-12.84}, {-45.2}, \
{-66.71000000000001}, {-81.09}, {-90.53}, {-96.88}, {-100.29}, {-102.55}, \
{-103.89}, {-104.84}, {-105.46000000000001`}, {-106.03}, {-106.42}, \
{-106.67}, {-106.82000000000001`}, {-107.57000000000001`}, {-108.15}, \
{-108.48}, {-108.61}, {-108.67}, {-108.72}, {-108.7}, {-108.33}, {-108.04}, \
{-107.86}, {-107.23}, {-107.06}, {-107.01}, {-35.910000000000004`}, {11.51}, {
                43.13}, {65.06}, {79.66}, {89.38}, {95.99000000000001}, {
                100.4}, {103.15}, {105.14}, {106.46000000000001`}, {107.42}, {
                108.15}, {108.54}, {108.72}, {109.08}, {
                109.24000000000001`}, {109.33}, {
                37.13}, {-10.91}, {-42.9}, {-64.27}, {-78.73}, {-88.38}, \
{-94.77}, {-98.60000000000001}, {-100.95}, {-31.43}, {14.97}, {45.95}, {
                66.51}, {80.23}, {89.33}, {95.56}, {100.16}, {30.09}, {
                56.85}, {74.64}, {85.71000000000001}, {93.26}, {98.23}, {
                101.58}, {103.81}, {105.31}, {106.29}, {106.73}, {107.04}, {
                107.85000000000001`}, {108.16}, {108.32000000000001`}, {
                108.4}, {108.53}, {72.35000000000001}, {11.9}, {44.4}, {
                65.18}, {79.14}, {88.65}, {94.81}, {98.65}, {
                101.21000000000001`}, {102.92}, {103.37}, {103.62}, {
                104.58}, {69.72}, {81.96000000000001}, {18.79}, {
                48.410000000000004`}, {68.16}, {81.33}, {90.84}, {97.15}, {
                101.39}, {104.26}, {106.13}, {107.22}, {
                34.87}, {-13.370000000000001`}, {-45.480000000000004`}, \
{-66.88}, {-81.16}, {-90.73}, {-97.11}, {-101.48}, {-104.48}, {-106.52}, \
{-34.27}, {-59.44}, {-76.22}, {-87.4}, {-94.78}, {-99.72}, {-30.39}, {
                15.83}, {46.59}, {-4.42}, {
                32.54}, {-13.61}, {-44.4}, {-64.02}, {-77.01}, {-86.29}, \
{-91.84}, {-95.51}, {-98.2}, {-100.18}, {-101.63}, {-102.58}, {-32.28}, {
                14.98}, {46.47}, {67.73}, {81.8}, {91.06}, {97.22}, {
                101.31}, {104.10000000000001`}, {105.94}, {107.22}, {
                108.05}, {108.61}, {109.11}, {109.61}, {109.78}, {109.84}, {
                109.91}, {110.02}, {110.08}, {36.75}, {60.97}, {
                40.65}, {-9.31}, {-42.65}, {7.62}, {
                41.12}, {-8.55}, {-41.65}, {8.28}, {-30.64}, {
                15.610000000000001`}, {46.27}, {66.37}, {
                8.86}, {-29.45}, {-54.76}, {-71.56}, {-82.78}, {-90.29}, \
{-95.41}, {-99.41}, {-101.99000000000001`}, {-104.11}, \
{-105.32000000000001`}, {-33.94}, {13.56}, {45.21}, {66.08}, {79.95}, {
                89.17}, {95.63}, {99.94}, {102.96000000000001`}, {
                103.49000000000001`}, {103.89}, {104.11}, {104.36}, {
                104.65}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$541691["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$541691["YRange"]] :> 24.95,
              HoldPattern[
               System`TradingChartDump`$layoutData$541691[
               "SubplotPoints", {
                1}]] :> {{}, {}, {}, {}, {}, {}, {}, {}, {}, {108.92}, {
               109.12}, {109.29}, {109.38}, {109.43}, {109.57000000000001`}, {
               109.96000000000001`}, {110.21000000000001`}, {
               36.53}, {-12.61}, {-45.37}, {-67.2}, {-81.69}, \
{-91.35000000000001}, {-97.79}, {-102.10000000000001`}, {-104.93}, {-106.8}, \
{-108.}, {-108.76}, {-36.38}, {11.81}, {43.88}, {65.28}, {79.48}, {89.11}, {
               95.53}, {99.93}, {102.87}, {105.28}, {106.95}, {108.13}, {
               108.78}, {109.29}, {109.52}, {109.11}, {108.85000000000001`}, {
               108.71000000000001`}, {108.63}, {108.60000000000001`}, {
               108.58}, {108.64}, {108.58}, {108.45}, {
               35.660000000000004`}, {-12.84}, {-45.2}, {-66.71000000000001}, \
{-81.09}, {-90.53}, {-96.88}, {-100.29}, {-102.55}, {-103.89}, {-104.84}, \
{-105.46000000000001`}, {-106.03}, {-106.42}, {-106.67}, \
{-106.82000000000001`}, {-107.57000000000001`}, {-108.15}, {-108.48}, \
{-108.61}, {-108.67}, {-108.72}, {-108.7}, {-108.33}, {-108.04}, {-107.86}, \
{-107.23}, {-107.06}, {-107.01}, {-35.910000000000004`}, {11.51}, {43.13}, {
               65.06}, {79.66}, {89.38}, {95.99000000000001}, {100.4}, {
               103.15}, {105.14}, {106.46000000000001`}, {107.42}, {108.15}, {
               108.54}, {108.72}, {109.08}, {109.24000000000001`}, {109.33}, {
               37.13}, {-10.91}, {-42.9}, {-64.27}, {-78.73}, {-88.38}, \
{-94.77}, {-98.60000000000001}, {-100.95}, {-31.43}, {14.97}, {45.95}, {
               66.51}, {80.23}, {89.33}, {95.56}, {100.16}, {30.09}, {
               56.85}, {74.64}, {85.71000000000001}, {93.26}, {98.23}, {
               101.58}, {103.81}, {105.31}, {106.29}, {106.73}, {107.04}, {
               107.85000000000001`}, {108.16}, {108.32000000000001`}, {
               108.4}, {108.53}, {72.35000000000001}, {11.9}, {44.4}, {
               65.18}, {79.14}, {88.65}, {94.81}, {98.65}, {
               101.21000000000001`}, {102.92}, {103.37}, {103.62}, {104.58}, {
               69.72}, {81.96000000000001}, {18.79}, {48.410000000000004`}, {
               68.16}, {81.33}, {90.84}, {97.15}, {101.39}, {104.26}, {
               106.13}, {107.22}, {
               34.87}, {-13.370000000000001`}, {-45.480000000000004`}, \
{-66.88}, {-81.16}, {-90.73}, {-97.11}, {-101.48}, {-104.48}, {-106.52}, \
{-34.27}, {-59.44}, {-76.22}, {-87.4}, {-94.78}, {-99.72}, {-30.39}, {
               15.83}, {46.59}, {-4.42}, {
               32.54}, {-13.61}, {-44.4}, {-64.02}, {-77.01}, {-86.29}, \
{-91.84}, {-95.51}, {-98.2}, {-100.18}, {-101.63}, {-102.58}, {-32.28}, {
               14.98}, {46.47}, {67.73}, {81.8}, {91.06}, {97.22}, {101.31}, {
               104.10000000000001`}, {105.94}, {107.22}, {108.05}, {108.61}, {
               109.11}, {109.61}, {109.78}, {109.84}, {109.91}, {110.02}, {
               110.08}, {36.75}, {60.97}, {40.65}, {-9.31}, {-42.65}, {
               7.62}, {41.12}, {-8.55}, {-41.65}, {8.28}, {-30.64}, {
               15.610000000000001`}, {46.27}, {66.37}, {
               8.86}, {-29.45}, {-54.76}, {-71.56}, {-82.78}, {-90.29}, \
{-95.41}, {-99.41}, {-101.99000000000001`}, {-104.11}, \
{-105.32000000000001`}, {-33.94}, {13.56}, {45.21}, {66.08}, {79.95}, {
               89.17}, {95.63}, {99.94}, {102.96000000000001`}, {
               103.49000000000001`}, {103.89}, {104.11}, {104.36}, {104.65}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541691[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$541691[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$541691[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$541691[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$541691[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$541691 = 
           System`TradingChartDump`$length$541691; 
          System`TradingChartDump`$layoutData$541691["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$541691; 
          System`TradingChartDump`$modelData$541691["Data"] = 
           System`TradingChartDump`$data$541691; 
          System`TradingChartDump`$modelData$541691["Indicators"] = 
           System`TradingChartDump`$indicators$541691; 
          System`TradingChartDump`$layoutData$541691[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541691["ScalingFunctions"] = {
            System`TradingChartDump`$sy$541691, 
             System`TradingChartDump`$isy$541691}; 
          System`TradingChartDump`$layoutData$541691["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541691["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541691[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541691["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$541691["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$541691, 
            System`TradingChartDump`$layoutData$541691, 
            System`TradingChartDump`$indicators$541691]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$541691, 
            System`TradingChartDump`$layoutData$541691, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$541691[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$541691["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$541691[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$541691[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$541691["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$541691[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$541691 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541691["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541691, 
                 System`TradingChartDump`$controlmax$541691}]]]; 
          System`TradingChartDump`$plotrangemax$541691 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541691["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541691, 
                 System`TradingChartDump`$controlmax$541691}]]]; {
            System`TradingChartDump`$plotrangemin$541691, 
             System`TradingChartDump`$plotrangemax$541691} = ReplaceAll[
             
             System`TradingChartDump`$sy$541691[{
              System`TradingChartDump`$plotrangemin$541691, 
               System`TradingChartDump`$plotrangemax$541691}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$541691[
                Min[System`TradingChartDump`$lows$541691]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$541691 == 
            System`TradingChartDump`$plotrangemax$541691, {
             System`TradingChartDump`$plotrangemin$541691, 
              System`TradingChartDump`$plotrangemax$541691} = {
             System`TradingChartDump`$plotrangemin$541691 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$541691], 
              System`TradingChartDump`$plotrangemax$541691 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$541691]}]; 
          System`TradingChartDump`$newgridlines$541691 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$541691, 
            Part[System`TradingChartDump`$newgridlines$541691, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$541691, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$541691], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$541691, 1]]; 
            Part[System`TradingChartDump`$newgridlines$541691, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$541691, 1] =!= None,
                 System`TradingChartDump`$length$541691 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$541691, 
                 Part[System`TradingChartDump`$newgridlines$541691, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$541691, 1]]; 
            System`TradingChartDump`$subpricegridlines$541691 = 
             Part[System`TradingChartDump`$gridlines$541691, 2]; 
            Part[System`TradingChartDump`$newgridlines$541691, 2] = 
             If[System`TradingChartDump`$sy$541691 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541691}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541691, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541691, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$541691, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$541691, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541691}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541691, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541691, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$541691 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$541691]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"GE\"", "\" with \"", 
           "\"PolarizedFractalEfficiency\"", "\"(\"", "10", "\",\"", "5", 
           "\",\"", "", "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {240., -837.}, ImageScaled[{0.5, 0.5}], {450, 310}], 
     InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$541706 = 
        "Full", System`TradingChartDump`$highlightposition$541706 = Automatic,
         System`TradingChartDump`$maxohlc$541706 = 24.95`4., 
        System`TradingChartDump`$timestampstyle$541706 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$541706 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$541706 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$541706, 
        System`TradingChartDump`$subplotpoint$541706, 
        System`TradingChartDump`$ndigits$541706 = 4, 
        System`TradingChartDump`$highlightstyle$541706 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$541706 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$541706 = True, 
        System`TradingChartDump`$timestampQ$541706 = True, 
        System`TradingChartDump`$data$541706 = {{{2012, 7, 26}, {
          19.55155642023346, 20.035505836575872`, 19.512840466926068`, 19.9, 
           57275600}}, {{2012, 7, 27}, {
          19.96928776290631, 20.327437858508603`, 19.901529636711278`, 20.25, 
           80268300}}, {{2012, 7, 30}, {
          20.120322115384614`, 20.236456730769227`, 20.023543269230768`, 
           20.13, 44993600}}, {{2012, 7, 31}, {
          20.08, 20.21547951807229, 20.08, 20.08, 38328400}}, {{2012, 8, 1}, {
          20.185798359864926`, 20.27288953207911, 20.040646406174623`, 20.06, 
           35734300}}, {{2012, 8, 2}, {
          19.860000000000003`, 20.03421052631579, 19.55029239766082, 19.86, 
           44000400}}, {{2012, 8, 3}, {
          20.144541984732825`, 20.318702290076335`, 20.096164122137402`, 
           20.28, 37891500}}, {{2012, 8, 6}, {
          20.29, 20.493190271816882`, 20.22226990939437, 20.29, 34159500}}, {{
          2012, 8, 7}, {
          20.459356060606062`, 20.507746212121216`, 20.410965909090912`, 
           20.44, 31115300}}, {{2012, 8, 8}, {
          20.36870537839124, 20.407410756782483`, 20.22356020942408, 20.33, 
           32345900}}, {{2012, 8, 9}, {
          20.263874643874647`, 20.43806267806268, 20.263874643874647`, 20.38, 
           31159700}}, {{2012, 8, 10}, {
          20.323222748815166`, 20.42, 20.265156398104267`, 20.42, 
           24419100}}, {{2012, 8, 13}, {
          20.358380181038587`, 20.377732253454024`, 20.2035636017151, 20.31, 
           26873600}}, {{2012, 8, 14}, {
          20.395453677172874`, 20.42447946513849, 20.22129894937918, 20.26, 
           30095000}}, {{2012, 8, 15}, {
          20.18324427480916, 20.34772900763359, 20.11551526717557, 20.28, 
           28870100}}, {{2012, 8, 16}, {
          20.195814726840858`, 20.457092636579574`, 20.147429928741094`, 
           20.37, 33598000}}, {{2012, 8, 17}, {
          20.33935238095238, 20.368380952380953`, 20.26194285714286, 20.32, 
           30032500}}, {{2012, 8, 20}, {
          20.269350215002387`, 20.33707596751075, 20.153248924988052`, 20.25, 
           27385500}}, {{2012, 8, 21}, {
          20.296143884892086`, 20.373573141486812`, 20.131606714628298`, 
           20.18, 30438800}}, {{2012, 8, 22}, {
          20.100322425409047`, 20.197098171318576`, 20.04225697786333, 20.11, 
           28016800}}, {{2012, 8, 23}, {
          20.06675387596899, 20.115130813953485`, 19.960324612403095`, 19.97, 
           36538800}}, {{2012, 8, 24}, {
          19.92676442307692, 20.22677884615384, 19.888052884615384`, 20.13, 
           29338200}}, {{2012, 8, 27}, {
          20.15096402877698, 20.276786570743404`, 20.121928057553955`, 20.18, 
           28775600}}, {{2012, 8, 28}, {
          20.09160980297934, 20.246458433445465`, 20.09160980297934, 20.14, 
           25912400}}, {{2012, 8, 29}, {
          20.15, 20.275816522574445`, 20.140321805955807`, 20.15, 
           19925800}}, {{2012, 8, 30}, {
          20.04740310077519, 20.10545542635659, 19.9506492248062, 19.97, 
           21237800}}, {{2012, 8, 31}, {
          20.08838242394978, 20.156117817479473`, 19.94323515210043, 20.04, 
           29679000}}, {{2012, 9, 4}, {
          19.966138469039493`, 20.024207703559238`, 19.820965382740127`, 
           19.85, 38173600}}, {{2012, 9, 5}, {
          19.883244552058112`, 20.096106537530268`, 19.84454237288136, 19.98, 
           33033500}}, {{2012, 9, 6}, {
          20.19424683247302, 20.629676208352887`, 20.17489441576725, 20.62, 
           53178600}}, {{2012, 9, 7}, {
          20.628754052802222`, 20.89, 20.609402501157945`, 20.89, 
           36379800}}, {{2012, 9, 10}, {
          20.79, 20.954539106145248`, 20.741606145251396`, 20.79, 
           33672300}}, {{2012, 9, 11}, {
          20.7932422417786, 20.9867577582214, 20.70616025937934, 20.89, 
           33593100}}, {{2012, 9, 12}, {
          20.967135678391962`, 21.218702603928733`, 20.957460027409777`, 
           21.18, 43006000}}, {{2012, 9, 13}, {
          21.0680608537693, 21.522906448683013`, 21.048705722070842`, 21.31, 
           111794200}}, {{2012, 9, 14}, {
          21.487109905020354`, 21.651650836725466`, 21.27417458163727, 21.4, 
           100148400}}, {{2012, 9, 17}, {
          21.22386394557823, 21.34, 21.194829931972787`, 21.34, 79283200}}, {{
          2012, 9, 18}, {
          21.278093525179855`, 21.52, 21.24906474820144, 21.52, 38831200}}, {{
          2012, 9, 19}, {
          21.584172982612575`, 21.768074008024968`, 21.535777975925104`, 
           21.71, 40462600}}, {{2012, 9, 20}, {
          21.63599197503344, 21.909001337494427`, 21.567739634418192`, 21.87, 
           43677000}}, {{2012, 9, 21}, {
          21.989502885042164`, 22.126023080337326`, 21.901739902352418`, 
           21.97, 66551700}}, {{2012, 9, 24}, {
          21.838998211091234`, 21.887745974955276`, 21.74150268336315, 21.8, 
           36799800}}, {{2012, 9, 25}, {
          21.8380277902286, 22.11112505602869, 21.750246526221428`, 21.76, 
           47039200}}, {{2012, 9, 26}, {
          21.608506787330317`, 21.69626696832579, 21.520746606334843`, 21.55, 
           41123300}}, {{2012, 9, 27}, {
          21.682287725472943`, 22.286739991201056`, 21.575046194456664`, 
           22.16, 67300400}}, {{2012, 9, 28}, {
          22.20852047556142, 22.393835314839276`, 22.062219286657857`, 22.15, 
           70926100}}, {{2012, 10, 1}, {
          22.161999123191585`, 22.42525208241999, 22.14249890398948, 22.24, 
           42550700}}, {{2012, 10, 2}, {
          22.3564984642387, 22.414997806055286`, 22.142000877577885`, 22.22, 
           45297400}}, {{2012, 10, 3}, {
          22.29124399825404, 22.40825840244435, 22.154727193365343`, 22.34, 
           32929400}}, {{2012, 10, 4}, {
          22.38, 22.477516339869283`, 22.204470588235292`, 22.38, 
           40344600}}, {{2012, 10, 5}, {
          22.46200692041522, 22.598494809688578`, 22.423010380622834`, 22.54, 
           38312500}}, {{2012, 10, 8}, {
          22.301243455497385`, 22.418259162303666`, 22.281740837696336`, 
           22.35, 24202200}}, {{2012, 10, 9}, {
          22.37207780725022, 22.401335101679926`, 22.04049513704686, 22.06, 
           39176000}}, {{2012, 10, 10}, {
          22.04550601872492, 22.17226036558181, 21.850499331252788`, 21.87, 
           32784100}}, {{2012, 10, 11}, {
          22.02800977343403, 22.14502443358507, 21.92074633496224, 21.95, 
           24161800}}, {{2012, 10, 12}, {
          22.017508896797153`, 22.144270462633454`, 21.851743772241996`, 
           21.92, 32954600}}, {{2012, 10, 15}, {
          21.98247349823321, 22.138515901060067`, 21.933710247349822`, 22.08, 
           29578600}}, {{2012, 10, 16}, {
          22.226289752650175`, 22.314063604240282`, 22.01173144876325, 22.08, 
           35668800}}, {{2012, 10, 17}, {
          22.203483195111303`, 22.349751200349196`, 22.154727193365343`, 
           22.34, 28272500}}, {{2012, 10, 18}, {
          22.24, 22.50325295922841, 22.230249890398948`, 22.24, 43140700}}, {{
          2012, 10, 19}, {
          21.9480163413527, 21.967517022242397`, 21.323994552882436`, 21.48, 
           107879900}}, {{2012, 10, 22}, {
          21.316018433179725`, 21.40377880184332, 20.72119815668203, 21.16, 
           86735100}}, {{2012, 10, 23}, {
          20.81825657894737, 20.867011278195488`, 20.671992481203006`, 20.75, 
           56297300}}, {{2012, 10, 24}, {
          20.8957619943556, 20.925014111006586`, 20.71049858889934, 20.73, 
           42295500}}, {{2012, 10, 25}, {
          20.964016933207905`, 21.032271872060207`, 20.505733772342428`, 
           20.73, 45769600}}, {{2012, 10, 26}, {
          20.657991473235434`, 20.862719090478446`, 20.541004263382284`, 
           20.58, 42827400}}, {{2012, 10, 31}, {
          20.735061728395063`, 20.79358024691358, 20.452222222222222`, 20.54, 
           39179300}}, {{2012, 11, 1}, {
          20.50769915651359, 20.858758200562324`, 20.497947516401123`, 20.81, 
           46231300}}, {{2012, 11, 2}, {
          20.994528390427032`, 21.14079774753637, 20.731243547630225`, 20.78, 
           47475200}}, {{2012, 11, 5}, {
          20.67519850537132, 20.938514712751047`, 20.67519850537132, 20.88, 
           30000100}}, {{2012, 11, 6}, {
          20.972000926354795`, 21.235247799907366`, 20.913501621120886`, 
           21.05, 32733200}}, {{2012, 11, 7}, {
          20.824230951254144`, 20.980217699952675`, 20.54150496923805, 20.6, 
           45253400}}, {{2012, 11, 8}, {
          20.633279080899953`, 20.66253231211106, 20.36024892292963, 20.37, 
           40770700}}, {{2012, 11, 9}, {
          20.245942857142857`, 20.77257142857143, 20.18742857142857, 20.48, 
           40306800}}, {{2012, 11, 12}, {
          20.51626615605553, 20.613776926759215`, 20.36024892292963, 20.37, 
           21816400}}, {{2012, 11, 13}, {
          20.091972920696332`, 20.433341392649908`, 20.06271276595745, 20.17, 
           41073300}}, {{2012, 11, 14}, {
          20.21200899550225, 20.231509245377314`, 19.451499250374813`, 19.51, 
           65539500}}, {{2012, 11, 15}, {
          19.403988035892322`, 19.72576271186441, 19.403988035892322`, 19.56, 
           51760300}}, {{2012, 11, 16}, {
          19.601240694789084`, 19.689007444168734`, 19.376947890818858`, 
           19.65, 45287500}}, {{2012, 11, 19}, {
          19.90617134559535, 20.208518877057113`, 19.88666505324298, 20.15, 
           38283400}}, {{2012, 11, 20}, {
          20.15876333656644, 20.178268671193017`, 19.8661833171678, 20.11, 
           26845900}}, {{2012, 11, 21}, {
          20.189506769825922`, 20.22852030947776, 20.06271276595745, 20.17, 
           41020400}}, {{2012, 11, 23}, {
          20.295684410646388`, 20.52, 20.217661596958177`, 20.52, 
           35456500}}, {{2012, 11, 26}, {
          20.364444444444445`, 20.549753086419752`, 20.35469135802469, 20.54, 
           47741300}}, {{2012, 11, 27}, {
          20.515764254911353`, 20.67177767129851, 20.330498322951605`, 20.35, 
           33001700}}, {{2012, 11, 28}, {
          20.229777672658468`, 20.619749290444656`, 19.9860454115421, 20.61, 
           34782700}}, {{2012, 11, 29}, {
          20.70724088973024, 20.824230951254144`, 20.42451490771415, 20.6, 
           27632800}}, {{2012, 11, 30}, {
          20.60974917179366, 20.726739233317563`, 20.512257453857078`, 20.6, 
           37857000}}, {{2012, 12, 3}, {
          20.651008645533143`, 20.699759846301635`, 20.280499519692604`, 20.3,
            29981900}}, {{2012, 12, 4}, {
          20.34975071907958, 20.486260786193675`, 20.19373921380633, 20.34, 
           36817200}}, {{2012, 12, 5}, {
          20.38798869524258, 20.8267545925577, 20.339236928874232`, 20.7, 
           46466500}}, {{2012, 12, 6}, {
          20.67421619092185, 20.859503977538605`, 20.557192325690217`, 20.84, 
           32751200}}, {{2012, 12, 7}, {
          20.910493942218082`, 20.94950605778192, 20.71543336439888, 20.93, 
           33548600}}, {{2012, 12, 10}, {
          20.899008882655444`, 20.967274427302478`, 20.830743338008414`, 
           20.86, 27604300}}, {{2012, 12, 11}, {
          20.940753138075312`, 21.203974895397486`, 20.823765690376565`, 
           20.97, 45757200}}, {{2012, 12, 12}, {
          21.074214876033054`, 21.40578512396694, 21.035206611570246`, 21.24, 
           42413600}}, {{2012, 12, 13}, {
          21.197002775208137`, 21.37250693802035, 21.011748381128584`, 21.08, 
           33966000}}, {{2012, 12, 14}, {
          21.07024976873265, 21.21650323774283, 21.011748381128584`, 21.08, 
           47536600}}, {{2012, 12, 17}, {
          21.146019151846783`, 21.399498404012764`, 21.146019151846783`, 
           21.38, 48483700}}, {{2012, 12, 18}, {
          21.30601659751037, 21.36452282157676, 20.876970954356842`, 21.15, 
           81119200}}, {{2012, 12, 19}, {
          21.104407425035696`, 21.123912422655877`, 20.450990004759635`, 
           20.49, 92330700}}, {{2012, 12, 20}, {
          20.57226128266033, 20.89693111638955, 20.532907363420428`, 20.71, 
           50831400}}, {{2012, 12, 21}, {
          20.510632183908047`, 20.658261494252873`, 20.235057471264366`, 
           20.55, 80833800}}, {{2012, 12, 24}, {
          20.460475504322766`, 20.62778097982709, 20.421109510086453`, 20.49, 
           15097200}}, {{2012, 12, 26}, {
          20.479364467982666`, 20.60729898892634, 20.380953298026, 20.44, 
           28557100}}, {{2012, 12, 27}, {
          20.468245529241177`, 20.537129047849202`, 20.094306428226197`, 
           20.36, 38330700}}, {{2012, 12, 28}, {
          20.119838551859097`, 20.375640900195695`, 20.1001614481409, 20.11, 
           32403400}}, {{2012, 12, 31}, {
          19.961338732729867`, 20.65983801810386, 19.931824678418295`, 20.65, 
           58785000}}, {{2013, 1, 2}, {
          21.167291471415183`, 21.196813495782568`, 20.8622305529522, 21., 
           46089500}}, {{2013, 1, 3}, {
          21.133876777251185`, 21.143715639810427`, 20.710805687203795`, 
           20.76, 48509100}}, {{2013, 1, 4}, {
          20.86983962264151, 20.91903773584906, 20.781283018867928`, 20.86, 
           29802600}}, {{2013, 1, 7}, {
          20.819517274017986`, 20.87855182205395, 20.622735447231427`, 20.79, 
           32746700}}, {{2013, 1, 8}, {
          20.766842105263162`, 20.786526315789477`, 20.353473684210527`, 
           20.57, 40045500}}, {{2013, 1, 9}, {
          20.708582338902147`, 20.738109785202866`, 20.600315035799525`, 
           20.62, 28540500}}, {{2013, 1, 10}, {
          20.702087860179493`, 20.88903637222484, 20.623372697213032`, 20.83, 
           33348200}}, {{2013, 1, 11}, {
          20.87855182205395, 20.898230004732607`, 20.68176999526739, 20.79, 
           41839700}}, {{2013, 1, 14}, {
          20.83903409090909, 20.898068181818182`, 20.730804924242427`, 20.78, 
           31715900}}, {{2013, 1, 15}, {
          20.70256603773585, 20.86983962264151, 20.673047169811323`, 20.86, 
           26551000}}, {{2013, 1, 16}, {
          20.809517045454545`, 20.858712121212122`, 20.72096590909091, 20.78, 
           38932100}}, {{2013, 1, 17}, {
          20.88127699530516, 21.196169014084504`, 20.78287323943662, 20.96, 
           63851700}}, {{2013, 1, 18}, {
          21.591588021778588`, 21.83761796733213, 21.247146098003633`, 21.69, 
           113079400}}, {{2013, 1, 22}, {
          21.82729668332576, 21.846978646069967`, 21.55174920490686, 21.66, 
           55165800}}, {{2013, 1, 23}, {
          21.629361896080216`, 21.67856426618049, 21.40303099361896, 21.59, 
           47228500}}, {{2013, 1, 24}, {
          21.611428571428572`, 21.837777777777777`, 21.6015873015873, 21.7, 
           46991100}}, {{2013, 1, 25}, {
          21.920161507402426`, 21.949676985195154`, 21.752907133243607`, 
           21.93, 41919800}}, {{2013, 1, 28}, {
          22.080960000000005`, 22.179360000000003`, 21.903840000000002`, 
           22.14, 49558400}}, {{2013, 1, 29}, {
          22.13016, 22.21872, 22.041600000000003`, 22.14, 34148000}}, {{2013, 
          1, 30}, {
          22.155303643724697`, 22.184817813765186`, 21.87, 21.87, 
           36200400}}, {{2013, 1, 31}, {
          21.85113105924596, 22.03806104129264, 21.8216157989228, 21.92, 
           34427700}}, {{2013, 2, 1}, {
          22.073023872679045`, 22.27968169761273, 21.964774535809017`, 22.26, 
           43840300}}, {{2013, 2, 4}, {
          22.0483863738234, 22.127095472882115`, 21.920484087852984`, 21.95, 
           35836600}}, {{2013, 2, 5}, {
          22.120958296362023`, 22.258722271517303`, 22.091437444543033`, 
           22.18, 30917700}}, {{2013, 2, 6}, {
          22.109518716577536`, 22.139037433155078`, 21.952085561497324`, 
           22.08, 42985800}}, {{2013, 2, 7}, {
          22.139679715302492`, 22.14951957295374, 21.913362989323847`, 22.12, 
           38325900}}, {{2013, 2, 8}, {
          22.14, 22.19904, 22.0908, 22.14, 24424600}}, {{2013, 2, 11}, {
          22.129358574610244`, 22.14903786191537, 21.99160356347439, 22.09, 
           19738700}}, {{2013, 2, 12}, {
          22.121594331266607`, 22.288883968113375`, 22.121594331266607`, 
           22.22, 34297500}}, {{2013, 2, 13}, {
          22.744429243266353`, 23.108576314664386`, 22.675536554082942`, 
           23.02, 84926900}}, {{2013, 2, 14}, {
          22.882528833831696`, 23.11873558308415, 22.74474156343443, 23.04, 
           53996500}}, {{2013, 2, 15}, {
          23.106981537140406`, 23.175869471876346`, 22.86095319879777, 22.92, 
           39283000}}, {{2013, 2, 19}, {
          23.04528, 23.37, 23.03544, 23.37, 41219000}}, {{2013, 2, 20}, {
          23.33525843656557, 23.374626228107648`, 22.980948312686888`, 23.04, 
           38107400}}, {{2013, 2, 21}, {
          23.000619088564054`, 23.169303525365432`, 22.9410834049871, 23.08, 
           47811200}}, {{2013, 2, 22}, {
          23.1603249251817, 23.259512612227446`, 23.041299700726807`, 23.2, 
           27836300}}, {{2013, 2, 25}, {
          23.314555019728193`, 23.344318281455507`, 22.630000000000003`, 
           22.63, 51619800}}, {{2013, 2, 26}, {
          22.790624728850325`, 22.96921908893709, 22.73109327548807, 22.87, 
           41316300}}, {{2013, 2, 27}, {
          22.83284552845528, 23.20975609756097, 22.813008130081297`, 23.18, 
           29676400}}, {{2013, 2, 28}, {
          23.188837209302328`, 23.27813953488372, 23.02015503875969, 23.04, 
           39714600}}, {{2013, 3, 1}, {
          22.841319534282018`, 23.158835705045277`, 22.821474773609314`, 
           23.01, 41226900}}, {{2013, 3, 4}, {
          22.970928233777396`, 23.09992264718522, 22.851856467554793`, 23.09, 
           25457800}}, {{2013, 3, 5}, {
          23.27104705383637, 23.519033488766425`, 23.251208139041967`, 23.4, 
           35728000}}, {{2013, 3, 6}, {
          23.648635403464297`, 23.648635403464297`, 23.48, 23.48, 
           31539100}}, {{2013, 3, 7}, {
          23.509839527027022`, 23.638796452702696`, 23.480080236486486`, 
           23.49, 22955700}}, {{2013, 3, 8}, {
          23.669280605805636`, 23.708960875052586`, 23.49071939419436, 23.58, 
           28952100}}, {{2013, 3, 11}, {
          23.499436917866216`, 23.558954276037255`, 23.261367485182046`, 
           23.43, 34947200}}, {{2013, 3, 12}, {
          23.39853908586074, 23.408457923964118`, 23.140649295173, 23.22, 
           36593000}}, {{2013, 3, 13}, {
          23.250404427415926`, 23.329757343550448`, 23.21072796934866, 23.3, 
           24152400}}, {{2013, 3, 14}, {
          23.361122836639932`, 23.569438581680036`, 23.321443647108484`, 23.5,
            34629800}}, {{2013, 3, 15}, {
          23.25, 23.527730375426618`, 23.17064846416382, 23.25, 58857200}}, {{
          2013, 3, 18}, {
          22.990619354838714`, 23.169225806451614`, 22.950929032258063`, 
           23.07, 33700000}}, {{2013, 3, 19}, {
          23.12015437392796, 23.17969125214408, 22.991157804459693`, 23.14, 
           36150200}}, {{2013, 3, 20}, {
          23.537813299232738`, 23.607246376811595`, 23.141052855924976`, 
           23.27, 39254000}}, {{2013, 3, 21}, {
          23.238995276942894`, 23.417604121940748`, 23.109999999999996`, 
           23.11, 38543900}}, {{2013, 3, 22}, {
          23.130406504065036`, 23.20975609756097, 23.090731707317072`, 23.18, 
           30606100}}, {{2013, 3, 25}, {
          23.268373493975904`, 23.298141135972465`, 22.87147160068847, 23.06, 
           41684400}}, {{2013, 3, 26}, {
          23.088832179930794`, 23.118598615916955`, 22.830856401384082`, 
           22.94, 32353500}}, {{2013, 3, 27}, {
          22.840623376623377`, 22.95968831168831, 22.671948051948053`, 22.92, 
           27492500}}, {{2013, 3, 28}, {
          22.95984429065744, 23.019377162629755`, 22.81101211072664, 22.94, 
           31151000}}, {{2013, 4, 1}, {
          22.85038994800693, 22.91984402079723, 22.79085788561525, 22.9, 
           27449700}}, {{2013, 4, 2}, {
          22.991311053984575`, 23.189768637532133`, 22.92185089974293, 23.16, 
           29180100}}, {{2013, 4, 3}, {
          23.19702608695652, 23.21686956521739, 22.740626086956524`, 22.82, 
           52570300}}, {{2013, 4, 4}, {
          22.830545927209705`, 22.949610051993066`, 22.780935875216638`, 22.9,
            30472100}}, {{2013, 4, 5}, {
          22.621020497165286`, 22.75992150021806, 22.58133449629307, 22.75, 
           31402200}}, {{2013, 4, 8}, {
          22.870544982698963`, 22.94, 22.652257785467125`, 22.94, 
           30493600}}, {{2013, 4, 9}, {
          23.068516912402426`, 23.068516912402426`, 22.721248915871637`, 
           22.88, 31668200}}, {{2013, 4, 10}, {
          22.913867684478376`, 23.45943596268024, 22.87418999151824, 23.39, 
           39772300}}, {{2013, 4, 11}, {
          23.36032217041119, 23.528952946163628`, 23.241288681644765`, 23.4, 
           27084400}}, {{2013, 4, 12}, {
          23.29975703324808, 23.39894714407502, 23.141052855924976`, 23.27, 
           27234300}}, {{2013, 4, 15}, {
          23.096291100394566`, 23.11613327487944, 22.630000000000003`, 22.63, 
           46453800}}, {{2013, 4, 16}, {
          22.890233766233766`, 22.92, 22.72155844155844, 22.92, 36016700}}, {{
          2013, 4, 17}, {
          22.778418277680135`, 22.847864674868188`, 22.470869947275915`, 
           22.58, 42672900}}, {{2013, 4, 18}, {
          22.579285399206, 22.668570798412, 22.39079400088222, 22.49, 
           41170900}}, {{2013, 4, 19}, {
          21.768514942528736`, 21.85781149425287, 21.44109425287356, 21.58, 
           108837900}}, {{2013, 4, 22}, {
          21.497451990632317`, 21.507372365339577`, 20.94191100702576, 21.18, 
           87828900}}, {{2013, 4, 23}, {
          21.37960465116279, 21.518497674418605`, 21.191106976744184`, 21.33, 
           65489600}}, {{2013, 4, 24}, {
          21.522090163934426`, 21.859458105646628`, 21.482399817850634`, 
           21.79, 51506700}}, {{2013, 4, 25}, {
          22.037986332574036`, 22.05783143507973, 21.74030979498861, 21.78, 
           41462900}}, {{2013, 4, 26}, {
          21.801864025213867`, 22.218460153084195`, 21.791945069788383`, 
           22.03, 47012500}}, {{2013, 4, 29}, {
          22.129676695105523`, 22.139595868881905`, 21.82218230803772, 22.09, 
           36531800}}, {{2013, 4, 30}, {
          22.11, 22.1992732166891, 22.03064602960969, 22.11, 34054800}}, {{
          2013, 5, 1}, {
          21.920406320541762`, 22.168374717832958`, 21.920406320541762`, 
           21.97, 39201600}}, {{2013, 5, 2}, {
          22.070564516129032`, 22.14, 21.971370967741933`, 22.14, 
           27651500}}, {{2013, 5, 3}, {
          22.39, 22.667766947275148`, 22.370159503766065`, 22.39, 
           45523300}}, {{2013, 5, 6}, {
          22.38015943312666, 22.45952170062002, 22.14207263064659, 22.4, 
           28563900}}, {{2013, 5, 7}, {
          22.509920634920633`, 22.60912698412698, 22.44047619047619, 22.5, 
           28211700}}, {{2013, 5, 8}, {
          22.502581486310298`, 22.83992177314211, 22.443050847457627`, 22.83, 
           39977300}}, {{2013, 5, 9}, {
          22.808340649692713`, 22.91747146619842, 22.510711150131694`, 22.6, 
           29974300}}, {{2013, 5, 10}, {
          22.591021834061134`, 22.729921397379915`, 22.412436681222708`, 
           22.72, 35117300}}, {{2013, 5, 13}, {
          22.67992122538293, 22.699763676148795`, 22.441811816192562`, 22.67, 
           30283800}}, {{2013, 5, 14}, {
          22.671251629726207`, 22.889530638852673`, 22.631564537157754`, 
           22.83, 39592300}}, {{2013, 5, 15}, {
          22.86154905335628, 23.069922547332187`, 22.732555938037866`, 23.06, 
           40153000}}, {{2013, 5, 16}, {
          22.921314997851315`, 23.16938117748174, 22.921314997851315`, 23.09, 
           33023300}}, {{2013, 5, 17}, {
          23.081538789428816`, 23.289838022165387`, 23.012105711849955`, 
           23.27, 41037700}}, {{2013, 5, 20}, {
          23.270886720407294`, 23.389919389053876`, 23.241128553245648`, 
           23.38, 32884800}}, {{2013, 5, 21}, {
          23.400562130177512`, 23.58903634826712, 23.400562130177512`, 23.47, 
           33815000}}, {{2013, 5, 22}, {
          23.590637049455157`, 23.937849958088854`, 23.56087594300084, 23.67, 
           68514400}}, {{2013, 5, 23}, {
          23.33112426035503, 23.559277261200336`, 23.261686390532542`, 23.47, 
           44383600}}, {{2013, 5, 24}, {
          23.3102422439439, 23.478869528261797`, 23.3003229919252, 23.34, 
           41015200}}, {{2013, 5, 28}, {
          23.578631355932202`, 23.648067796610167`, 23.39016101694915, 23.41, 
           47323000}}, {{2013, 5, 29}, {
          23.231768189509307`, 23.50951776649746, 23.21192893401015, 23.45, 
           39236500}}, {{2013, 5, 30}, {
          23.39016101694915, 23.56871186440678, 23.310805084745763`, 23.41, 
           29347100}}, {{2013, 5, 31}, {
          23.407915951972555`, 23.606372212692968`, 23.13007718696398, 23.14, 
           49247600}}, {{2013, 6, 3}, {
          23.18217005076142, 23.588874788494078`, 23.132571912013535`, 23.45, 
           45218400}}, {{2013, 6, 4}, {
          23.400562130177512`, 23.569196956889265`, 23.22200760777684, 23.47, 
           38701300}}, {{2013, 6, 5}, {
          23.368224699828474`, 23.397993138936535`, 23.030849056603774`, 
           23.14, 44756200}}, {{2013, 6, 6}, {
          23.06105645851155, 23.19991873396065, 22.9122754491018, 23.19, 
           42677500}}, {{2013, 6, 7}, {
          23.35254819782062, 23.759283319362954`, 23.28310561609388, 23.67, 
           49041200}}, {{2013, 6, 10}, {
          23.689201009251473`, 23.728881412952063`, 23.45111858704794, 23.59, 
           41626500}}, {{2013, 6, 11}, {
          23.300725190839696`, 23.49911365564038, 23.290805767599664`, 23.39, 
           36183000}}, {{2013, 6, 12}, {
          23.508382978723404`, 23.538140425531914`, 23.230646808510638`, 
           23.31, 33842000}}, {{2013, 6, 13}, {
          23.261845439189184`, 23.599117398648644`, 23.152728040540538`, 
           23.49, 34930500}}, {{2013, 6, 14}, {
          23.488707482993195`, 23.55814200680272, 23.27048469387755, 23.33, 
           27846000}}, {{2013, 6, 17}, {
          23.560159865376523`, 23.6593605384939, 23.460959192259146`, 23.58, 
           39278300}}, {{2013, 6, 18}, {
          23.64390464447185, 24.259062885326763`, 23.58437320180847, 24.14, 
           72766900}}, {{2013, 6, 19}, {
          24.008256880733942`, 24.15706839032527, 23.79, 23.79, 46082200}}, {{
          2013, 6, 20}, {23.63, 23.69, 23.2, 23.25, 62733200}}, {{2013, 6, 
          21}, {
          23.579999999999995`, 23.639999999999997`, 23.209999999999997`, 
           23.36, 65025200}}, {{2013, 6, 24}, {
          23.12, 23.15, 22.76, 22.93, 48760800}}, {{2013, 6, 25}, {
          23.169999999999998`, 23.249999999999996`, 22.939999999999998`, 
           23.11, 36569100}}, {{2013, 6, 26}, {
          23.43, 23.44, 23.02, 23.25, 32531700}}, {{2013, 6, 27}, {
          23.41, 23.48, 23.26, 23.32, 30867900}}, {{2013, 6, 28}, {
          23.32, 23.44, 23.16, 23.19, 45923200}}, {{2013, 7, 1}, {
          23.209999999999997`, 23.639999999999997`, 23.189999999999998`, 
           23.34, 35784800}}, {{2013, 7, 2}, {
          23.27, 23.34, 22.88, 22.9, 47571200}}, {{2013, 7, 3}, {
          22.83, 22.98, 22.76, 22.91, 21448500}}, {{2013, 7, 5}, {
          23.17, 23.24, 22.95, 23.24, 22688900}}, {{2013, 7, 8}, {
          23.36, 23.53, 23.27, 23.32, 35481100}}, {{2013, 7, 9}, {
          23.52, 23.8, 23.51, 23.62, 31541400}}, {{2013, 7, 10}, {
          23.719999999999995`, 23.729999999999997`, 23.359999999999996`, 
           23.54, 28457100}}, {{2013, 7, 11}, {
          23.91, 23.96, 23.63, 23.94, 32618400}}, {{2013, 7, 12}, {
          23.99, 24., 23.59, 23.76, 33257700}}, {{2013, 7, 15}, {
          23.73, 23.74, 23.56, 23.63, 35853500}}, {{2013, 7, 16}, {
          23.659999999999997`, 23.669999999999998`, 23.339999999999996`, 
           23.43, 38192400}}, {{2013, 7, 17}, {
          23.539999999999996`, 23.609999999999996`, 23.429999999999996`, 
           23.54, 26858500}}, {{2013, 7, 18}, {
          23.6, 23.94, 23.56, 23.63, 41438200}}, {{2013, 7, 19}, {
          24.21, 24.95, 24.1, 24.72, 103708900}}, {{2013, 7, 22}, {
          24.77, 24.92, 24.73, 24.86, 41560800}}, {{2013, 7, 23}, {
          24.87, 24.88, 24.63, 24.71, 32553000}}, {{2013, 7, 24}, {
          24.79, 24.84, 24.56, 24.62, 27485000}}, {{2013, 7, 25}, {
          24.61, 24.69, 24.52, 24.69, 29951700}}}, 
        System`TradingChartDump`$markerstyle$541706 = 1, 
        System`TradingChartDump`$controlmin$541706 = 0.5, 
        System`TradingChartDump`$controlmax$541706 = 250.5, 
        System`TradingChartDump`$datescope$541706 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$541706 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$541706, 
        System`TradingChartDump`$max$541706, 
        System`TradingChartDump`$ohlclabel$541706 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541706, 
              System`TradingChartDump`$opens$541706]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541706, 
              System`TradingChartDump`$highs$541706]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541706, 
              System`TradingChartDump`$lows$541706]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541706, 
              System`TradingChartDump`$closes$541706]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541706, 
              System`TradingChartDump`$visdates$541706]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$541706 = {}, 
        System`TradingChartDump`$subpricegridlines$541706 = Automatic, 
        System`TradingChartDump`$overlaypoint$541706, 
        System`TradingChartDump`$overlayvalue$541706, 
        System`TradingChartDump`$subplotvalue$541706, 
        System`TradingChartDump`$opts$541706 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "GE", " with ", 
            "RelativeStrengthIndex", "(", 14, ",", Null, ",", Null, ",", Null,
             ")"}], ImageSize -> {450, 310}, AlignmentPoint -> Center, 
         AspectRatio -> GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> 
         None, AxesOrigin -> Automatic, AxesStyle -> {}, Background -> None, 
         BaselinePosition -> Automatic, BaseStyle -> {}, ColorOutput -> 
         Automatic, ContentSelectable -> Automatic, CoordinatesToolOptions -> 
         Automatic, DisplayFunction :> $DisplayFunction, Epilog -> {}, 
         FormatType :> TraditionalForm, Frame -> True, FrameLabel -> None, 
         FrameStyle -> {}, FrameTicks -> Automatic, FrameTicksStyle -> {}, 
         GridLines -> Automatic, GridLinesStyle -> {}, ImageMargins -> 0., 
         ImagePadding -> All, ImageSize -> Automatic, ImageSizeRaw -> 
         Automatic, LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, 
         PlotRange -> All, PlotRangeClipping -> False, PlotRangePadding -> 
         Automatic, PlotRegion -> Automatic, PreserveImageOptions -> 
         Automatic, Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$541706 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmglczWkXx2/W7PuSl9RLZClS3WtQPcooqUkLiVT3tt5uC5ooBo09IVt6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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyFmndUVNcWxkfFhihRiF0CAoKABikjiOJRmgrCUJUqMDAgzUKMihKwRohi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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$541706 = 
        System`TradingChartDump`$staticindicatorpos$541706, 
        System`TradingChartDump`$length$541706 = 250, 
        System`TradingChartDump`$gridlinesflag$541706 = True, 
        System`TradingChartDump`$opens$541706 = 
        Dispatch[{
         1 -> 19.55`4., 2 -> 19.97`4., 3 -> 20.12`4., 4 -> 20.08`4., 5 -> 
          20.19`4., 6 -> 19.86`4., 7 -> 20.14`4., 8 -> 20.29`4., 9 -> 
          20.46`4., 10 -> 20.37`4., 11 -> 20.26`4., 12 -> 20.32`4., 13 -> 
          20.36`4., 14 -> 20.4`4., 15 -> 20.18`4., 16 -> 20.2`4., 17 -> 
          20.34`4., 18 -> 20.27`4., 19 -> 20.3`4., 20 -> 20.1`4., 21 -> 
          20.07`4., 22 -> 19.93`4., 23 -> 20.15`4., 24 -> 20.09`4., 25 -> 
          20.15`4., 26 -> 20.05`4., 27 -> 20.09`4., 28 -> 19.97`4., 29 -> 
          19.88`4., 30 -> 20.19`4., 31 -> 20.63`4., 32 -> 20.79`4., 33 -> 
          20.79`4., 34 -> 20.97`4., 35 -> 21.07`4., 36 -> 21.49`4., 37 -> 
          21.22`4., 38 -> 21.28`4., 39 -> 21.58`4., 40 -> 21.64`4., 41 -> 
          21.99`4., 42 -> 21.84`4., 43 -> 21.84`4., 44 -> 21.61`4., 45 -> 
          21.68`4., 46 -> 22.21`4., 47 -> 22.16`4., 48 -> 22.36`4., 49 -> 
          22.29`4., 50 -> 22.38`4., 51 -> 22.46`4., 52 -> 22.3`4., 53 -> 
          22.37`4., 54 -> 22.05`4., 55 -> 22.03`4., 56 -> 22.02`4., 57 -> 
          21.98`4., 58 -> 22.23`4., 59 -> 22.2`4., 60 -> 22.24`4., 61 -> 
          21.95`4., 62 -> 21.32`4., 63 -> 20.82`4., 64 -> 20.9`4., 65 -> 
          20.96`4., 66 -> 20.66`4., 67 -> 20.74`4., 68 -> 20.51`4., 69 -> 
          20.99`4., 70 -> 20.68`4., 71 -> 20.97`4., 72 -> 20.82`4., 73 -> 
          20.63`4., 74 -> 20.25`4., 75 -> 20.52`4., 76 -> 20.09`4., 77 -> 
          20.21`4., 78 -> 19.4`4., 79 -> 19.6`4., 80 -> 19.91`4., 81 -> 
          20.16`4., 82 -> 20.19`4., 83 -> 20.3`4., 84 -> 20.36`4., 85 -> 
          20.52`4., 86 -> 20.23`4., 87 -> 20.71`4., 88 -> 20.61`4., 89 -> 
          20.65`4., 90 -> 20.35`4., 91 -> 20.39`4., 92 -> 20.67`4., 93 -> 
          20.91`4., 94 -> 20.9`4., 95 -> 20.94`4., 96 -> 21.07`4., 97 -> 
          21.2`4., 98 -> 21.07`4., 99 -> 21.15`4., 100 -> 21.31`4., 101 -> 
          21.1`4., 102 -> 20.57`4., 103 -> 20.51`4., 104 -> 20.46`4., 105 -> 
          20.48`4., 106 -> 20.47`4., 107 -> 20.12`4., 108 -> 19.96`4., 109 -> 
          21.17`4., 110 -> 21.13`4., 111 -> 20.87`4., 112 -> 20.82`4., 113 -> 
          20.77`4., 114 -> 20.71`4., 115 -> 20.7`4., 116 -> 20.88`4., 117 -> 
          20.84`4., 118 -> 20.7`4., 119 -> 20.81`4., 120 -> 20.88`4., 121 -> 
          21.59`4., 122 -> 21.83`4., 123 -> 21.63`4., 124 -> 21.61`4., 125 -> 
          21.92`4., 126 -> 22.08`4., 127 -> 22.13`4., 128 -> 22.16`4., 129 -> 
          21.85`4., 130 -> 22.07`4., 131 -> 22.05`4., 132 -> 22.12`4., 133 -> 
          22.11`4., 134 -> 22.14`4., 135 -> 22.14`4., 136 -> 22.13`4., 137 -> 
          22.12`4., 138 -> 22.74`4., 139 -> 22.88`4., 140 -> 23.11`4., 141 -> 
          23.05`4., 142 -> 23.34`4., 143 -> 23.`4., 144 -> 23.16`4., 145 -> 
          23.31`4., 146 -> 22.79`4., 147 -> 22.83`4., 148 -> 23.19`4., 149 -> 
          22.84`4., 150 -> 22.97`4., 151 -> 23.27`4., 152 -> 23.65`4., 153 -> 
          23.51`4., 154 -> 23.67`4., 155 -> 23.5`4., 156 -> 23.4`4., 157 -> 
          23.25`4., 158 -> 23.36`4., 159 -> 23.25`4., 160 -> 22.99`4., 161 -> 
          23.12`4., 162 -> 23.54`4., 163 -> 23.24`4., 164 -> 23.13`4., 165 -> 
          23.27`4., 166 -> 23.09`4., 167 -> 22.84`4., 168 -> 22.96`4., 169 -> 
          22.85`4., 170 -> 22.99`4., 171 -> 23.2`4., 172 -> 22.83`4., 173 -> 
          22.62`4., 174 -> 22.87`4., 175 -> 23.07`4., 176 -> 22.91`4., 177 -> 
          23.36`4., 178 -> 23.3`4., 179 -> 23.1`4., 180 -> 22.89`4., 181 -> 
          22.78`4., 182 -> 22.58`4., 183 -> 21.77`4., 184 -> 21.5`4., 185 -> 
          21.38`4., 186 -> 21.52`4., 187 -> 22.04`4., 188 -> 21.8`4., 189 -> 
          22.13`4., 190 -> 22.11`4., 191 -> 21.92`4., 192 -> 22.07`4., 193 -> 
          22.39`4., 194 -> 22.38`4., 195 -> 22.51`4., 196 -> 22.5`4., 197 -> 
          22.81`4., 198 -> 22.59`4., 199 -> 22.68`4., 200 -> 22.67`4., 201 -> 
          22.86`4., 202 -> 22.92`4., 203 -> 23.08`4., 204 -> 23.27`4., 205 -> 
          23.4`4., 206 -> 23.59`4., 207 -> 23.33`4., 208 -> 23.31`4., 209 -> 
          23.58`4., 210 -> 23.23`4., 211 -> 23.39`4., 212 -> 23.41`4., 213 -> 
          23.18`4., 214 -> 23.4`4., 215 -> 23.37`4., 216 -> 23.06`4., 217 -> 
          23.35`4., 218 -> 23.69`4., 219 -> 23.3`4., 220 -> 23.51`4., 221 -> 
          23.26`4., 222 -> 23.49`4., 223 -> 23.56`4., 224 -> 23.64`4., 225 -> 
          24.01`4., 226 -> 23.63`4., 227 -> 23.58`4., 228 -> 23.12`4., 229 -> 
          23.17`4., 230 -> 23.43`4., 231 -> 23.41`4., 232 -> 23.32`4., 233 -> 
          23.21`4., 234 -> 23.27`4., 235 -> 22.83`4., 236 -> 23.17`4., 237 -> 
          23.36`4., 238 -> 23.52`4., 239 -> 23.72`4., 240 -> 23.91`4., 241 -> 
          23.99`4., 242 -> 23.73`4., 243 -> 23.66`4., 244 -> 23.54`4., 245 -> 
          23.6`4., 246 -> 24.21`4., 247 -> 24.77`4., 248 -> 24.87`4., 249 -> 
          24.79`4., 250 -> 24.61`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$541706 = 
        Dispatch[{
         1 -> 20.04`4., 2 -> 20.33`4., 3 -> 20.24`4., 4 -> 20.22`4., 5 -> 
          20.27`4., 6 -> 20.03`4., 7 -> 20.32`4., 8 -> 20.49`4., 9 -> 
          20.51`4., 10 -> 20.41`4., 11 -> 20.44`4., 12 -> 20.42`4., 13 -> 
          20.38`4., 14 -> 20.42`4., 15 -> 20.35`4., 16 -> 20.46`4., 17 -> 
          20.37`4., 18 -> 20.34`4., 19 -> 20.37`4., 20 -> 20.2`4., 21 -> 
          20.12`4., 22 -> 20.23`4., 23 -> 20.28`4., 24 -> 20.25`4., 25 -> 
          20.28`4., 26 -> 20.11`4., 27 -> 20.16`4., 28 -> 20.02`4., 29 -> 
          20.1`4., 30 -> 20.63`4., 31 -> 20.89`4., 32 -> 20.95`4., 33 -> 
          20.99`4., 34 -> 21.22`4., 35 -> 21.52`4., 36 -> 21.65`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.77`4., 40 -> 21.91`4., 41 -> 
          22.13`4., 42 -> 21.89`4., 43 -> 22.11`4., 44 -> 21.7`4., 45 -> 
          22.29`4., 46 -> 22.39`4., 47 -> 22.43`4., 48 -> 22.41`4., 49 -> 
          22.41`4., 50 -> 22.48`4., 51 -> 22.6`4., 52 -> 22.42`4., 53 -> 
          22.4`4., 54 -> 22.17`4., 55 -> 22.15`4., 56 -> 22.14`4., 57 -> 
          22.14`4., 58 -> 22.31`4., 59 -> 22.35`4., 60 -> 22.5`4., 61 -> 
          21.97`4., 62 -> 21.4`4., 63 -> 20.87`4., 64 -> 20.93`4., 65 -> 
          21.03`4., 66 -> 20.86`4., 67 -> 20.79`4., 68 -> 20.86`4., 69 -> 
          21.14`4., 70 -> 20.94`4., 71 -> 21.24`4., 72 -> 20.98`4., 73 -> 
          20.66`4., 74 -> 20.77`4., 75 -> 20.61`4., 76 -> 20.43`4., 77 -> 
          20.23`4., 78 -> 19.73`4., 79 -> 19.69`4., 80 -> 20.21`4., 81 -> 
          20.18`4., 82 -> 20.23`4., 83 -> 20.52`4., 84 -> 20.55`4., 85 -> 
          20.67`4., 86 -> 20.62`4., 87 -> 20.82`4., 88 -> 20.73`4., 89 -> 
          20.7`4., 90 -> 20.49`4., 91 -> 20.83`4., 92 -> 20.86`4., 93 -> 
          20.95`4., 94 -> 20.97`4., 95 -> 21.2`4., 96 -> 21.41`4., 97 -> 
          21.37`4., 98 -> 21.22`4., 99 -> 21.4`4., 100 -> 21.36`4., 101 -> 
          21.12`4., 102 -> 20.9`4., 103 -> 20.66`4., 104 -> 20.63`4., 105 -> 
          20.61`4., 106 -> 20.54`4., 107 -> 20.38`4., 108 -> 20.66`4., 109 -> 
          21.2`4., 110 -> 21.14`4., 111 -> 20.92`4., 112 -> 20.88`4., 113 -> 
          20.79`4., 114 -> 20.74`4., 115 -> 20.89`4., 116 -> 20.9`4., 117 -> 
          20.9`4., 118 -> 20.87`4., 119 -> 20.86`4., 120 -> 21.2`4., 121 -> 
          21.84`4., 122 -> 21.85`4., 123 -> 21.68`4., 124 -> 21.84`4., 125 -> 
          21.95`4., 126 -> 22.18`4., 127 -> 22.22`4., 128 -> 22.18`4., 129 -> 
          22.04`4., 130 -> 22.28`4., 131 -> 22.13`4., 132 -> 22.26`4., 133 -> 
          22.14`4., 134 -> 22.15`4., 135 -> 22.2`4., 136 -> 22.15`4., 137 -> 
          22.29`4., 138 -> 23.11`4., 139 -> 23.12`4., 140 -> 23.18`4., 141 -> 
          23.37`4., 142 -> 23.37`4., 143 -> 23.17`4., 144 -> 23.26`4., 145 -> 
          23.34`4., 146 -> 22.97`4., 147 -> 23.21`4., 148 -> 23.28`4., 149 -> 
          23.16`4., 150 -> 23.1`4., 151 -> 23.52`4., 152 -> 23.65`4., 153 -> 
          23.64`4., 154 -> 23.71`4., 155 -> 23.56`4., 156 -> 23.41`4., 157 -> 
          23.33`4., 158 -> 23.57`4., 159 -> 23.53`4., 160 -> 23.17`4., 161 -> 
          23.18`4., 162 -> 23.61`4., 163 -> 23.42`4., 164 -> 23.21`4., 165 -> 
          23.3`4., 166 -> 23.12`4., 167 -> 22.96`4., 168 -> 23.02`4., 169 -> 
          22.92`4., 170 -> 23.19`4., 171 -> 23.22`4., 172 -> 22.95`4., 173 -> 
          22.76`4., 174 -> 22.94`4., 175 -> 23.07`4., 176 -> 23.46`4., 177 -> 
          23.53`4., 178 -> 23.4`4., 179 -> 23.12`4., 180 -> 22.92`4., 181 -> 
          22.85`4., 182 -> 22.67`4., 183 -> 21.86`4., 184 -> 21.51`4., 185 -> 
          21.52`4., 186 -> 21.86`4., 187 -> 22.06`4., 188 -> 22.22`4., 189 -> 
          22.14`4., 190 -> 22.2`4., 191 -> 22.17`4., 192 -> 22.14`4., 193 -> 
          22.67`4., 194 -> 22.46`4., 195 -> 22.61`4., 196 -> 22.84`4., 197 -> 
          22.92`4., 198 -> 22.73`4., 199 -> 22.7`4., 200 -> 22.89`4., 201 -> 
          23.07`4., 202 -> 23.17`4., 203 -> 23.29`4., 204 -> 23.39`4., 205 -> 
          23.59`4., 206 -> 23.94`4., 207 -> 23.56`4., 208 -> 23.48`4., 209 -> 
          23.65`4., 210 -> 23.51`4., 211 -> 23.57`4., 212 -> 23.61`4., 213 -> 
          23.59`4., 214 -> 23.57`4., 215 -> 23.4`4., 216 -> 23.2`4., 217 -> 
          23.76`4., 218 -> 23.73`4., 219 -> 23.5`4., 220 -> 23.54`4., 221 -> 
          23.6`4., 222 -> 23.56`4., 223 -> 23.66`4., 224 -> 24.26`4., 225 -> 
          24.16`4., 226 -> 23.69`4., 227 -> 23.64`4., 228 -> 23.15`4., 229 -> 
          23.25`4., 230 -> 23.44`4., 231 -> 23.48`4., 232 -> 23.44`4., 233 -> 
          23.64`4., 234 -> 23.34`4., 235 -> 22.98`4., 236 -> 23.24`4., 237 -> 
          23.53`4., 238 -> 23.8`4., 239 -> 23.73`4., 240 -> 23.96`4., 241 -> 
          24.`4., 242 -> 23.74`4., 243 -> 23.67`4., 244 -> 23.61`4., 245 -> 
          23.94`4., 246 -> 24.95`4., 247 -> 24.92`4., 248 -> 24.88`4., 249 -> 
          24.84`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$541706 = 
        Dispatch[{
         1 -> 19.51`4., 2 -> 19.9`4., 3 -> 20.02`4., 4 -> 20.08`4., 5 -> 
          20.04`4., 6 -> 19.55`4., 7 -> 20.1`4., 8 -> 20.22`4., 9 -> 20.41`4.,
           10 -> 20.22`4., 11 -> 20.26`4., 12 -> 20.27`4., 13 -> 20.2`4., 14 -> 
          20.22`4., 15 -> 20.12`4., 16 -> 20.15`4., 17 -> 20.26`4., 18 -> 
          20.15`4., 19 -> 20.13`4., 20 -> 20.04`4., 21 -> 19.96`4., 22 -> 
          19.89`4., 23 -> 20.12`4., 24 -> 20.09`4., 25 -> 20.14`4., 26 -> 
          19.95`4., 27 -> 19.94`4., 28 -> 19.82`4., 29 -> 19.84`4., 30 -> 
          20.17`4., 31 -> 20.61`4., 32 -> 20.74`4., 33 -> 20.71`4., 34 -> 
          20.96`4., 35 -> 21.05`4., 36 -> 21.27`4., 37 -> 21.19`4., 38 -> 
          21.25`4., 39 -> 21.54`4., 40 -> 21.57`4., 41 -> 21.9`4., 42 -> 
          21.74`4., 43 -> 21.75`4., 44 -> 21.52`4., 45 -> 21.58`4., 46 -> 
          22.06`4., 47 -> 22.14`4., 48 -> 22.14`4., 49 -> 22.15`4., 50 -> 
          22.2`4., 51 -> 22.42`4., 52 -> 22.28`4., 53 -> 22.04`4., 54 -> 
          21.85`4., 55 -> 21.92`4., 56 -> 21.85`4., 57 -> 21.93`4., 58 -> 
          22.01`4., 59 -> 22.15`4., 60 -> 22.23`4., 61 -> 21.32`4., 62 -> 
          20.72`4., 63 -> 20.67`4., 64 -> 20.71`4., 65 -> 20.51`4., 66 -> 
          20.54`4., 67 -> 20.45`4., 68 -> 20.5`4., 69 -> 20.73`4., 70 -> 
          20.68`4., 71 -> 20.91`4., 72 -> 20.54`4., 73 -> 20.36`4., 74 -> 
          20.19`4., 75 -> 20.36`4., 76 -> 20.06`4., 77 -> 19.45`4., 78 -> 
          19.4`4., 79 -> 19.38`4., 80 -> 19.89`4., 81 -> 19.87`4., 82 -> 
          20.06`4., 83 -> 20.22`4., 84 -> 20.35`4., 85 -> 20.33`4., 86 -> 
          19.99`4., 87 -> 20.42`4., 88 -> 20.51`4., 89 -> 20.28`4., 90 -> 
          20.19`4., 91 -> 20.34`4., 92 -> 20.56`4., 93 -> 20.72`4., 94 -> 
          20.83`4., 95 -> 20.82`4., 96 -> 21.04`4., 97 -> 21.01`4., 98 -> 
          21.01`4., 99 -> 21.15`4., 100 -> 20.88`4., 101 -> 20.45`4., 102 -> 
          20.53`4., 103 -> 20.24`4., 104 -> 20.42`4., 105 -> 20.38`4., 106 -> 
          20.09`4., 107 -> 20.1`4., 108 -> 19.93`4., 109 -> 20.86`4., 110 -> 
          20.71`4., 111 -> 20.78`4., 112 -> 20.62`4., 113 -> 20.35`4., 114 -> 
          20.6`4., 115 -> 20.62`4., 116 -> 20.68`4., 117 -> 20.73`4., 118 -> 
          20.67`4., 119 -> 20.72`4., 120 -> 20.78`4., 121 -> 21.25`4., 122 -> 
          21.55`4., 123 -> 21.4`4., 124 -> 21.6`4., 125 -> 21.75`4., 126 -> 
          21.9`4., 127 -> 22.04`4., 128 -> 21.87`4., 129 -> 21.82`4., 130 -> 
          21.96`4., 131 -> 21.92`4., 132 -> 22.09`4., 133 -> 21.95`4., 134 -> 
          21.91`4., 135 -> 22.09`4., 136 -> 21.99`4., 137 -> 22.12`4., 138 -> 
          22.68`4., 139 -> 22.74`4., 140 -> 22.86`4., 141 -> 23.04`4., 142 -> 
          22.98`4., 143 -> 22.94`4., 144 -> 23.04`4., 145 -> 22.63`4., 146 -> 
          22.73`4., 147 -> 22.81`4., 148 -> 23.02`4., 149 -> 22.82`4., 150 -> 
          22.85`4., 151 -> 23.25`4., 152 -> 23.48`4., 153 -> 23.48`4., 154 -> 
          23.49`4., 155 -> 23.26`4., 156 -> 23.14`4., 157 -> 23.21`4., 158 -> 
          23.32`4., 159 -> 23.17`4., 160 -> 22.95`4., 161 -> 22.99`4., 162 -> 
          23.14`4., 163 -> 23.11`4., 164 -> 23.09`4., 165 -> 22.87`4., 166 -> 
          22.83`4., 167 -> 22.67`4., 168 -> 22.81`4., 169 -> 22.79`4., 170 -> 
          22.92`4., 171 -> 22.74`4., 172 -> 22.78`4., 173 -> 22.58`4., 174 -> 
          22.65`4., 175 -> 22.72`4., 176 -> 22.87`4., 177 -> 23.24`4., 178 -> 
          23.14`4., 179 -> 22.63`4., 180 -> 22.72`4., 181 -> 22.47`4., 182 -> 
          22.39`4., 183 -> 21.44`4., 184 -> 20.94`4., 185 -> 21.19`4., 186 -> 
          21.48`4., 187 -> 21.74`4., 188 -> 21.79`4., 189 -> 21.82`4., 190 -> 
          22.03`4., 191 -> 21.92`4., 192 -> 21.97`4., 193 -> 22.37`4., 194 -> 
          22.14`4., 195 -> 22.44`4., 196 -> 22.44`4., 197 -> 22.51`4., 198 -> 
          22.41`4., 199 -> 22.44`4., 200 -> 22.63`4., 201 -> 22.73`4., 202 -> 
          22.92`4., 203 -> 23.01`4., 204 -> 23.24`4., 205 -> 23.4`4., 206 -> 
          23.56`4., 207 -> 23.26`4., 208 -> 23.3`4., 209 -> 23.39`4., 210 -> 
          23.21`4., 211 -> 23.31`4., 212 -> 23.13`4., 213 -> 23.13`4., 214 -> 
          23.22`4., 215 -> 23.03`4., 216 -> 22.91`4., 217 -> 23.28`4., 218 -> 
          23.45`4., 219 -> 23.29`4., 220 -> 23.23`4., 221 -> 23.15`4., 222 -> 
          23.27`4., 223 -> 23.46`4., 224 -> 23.58`4., 225 -> 23.79`4., 226 -> 
          23.2`4., 227 -> 23.21`4., 228 -> 22.76`4., 229 -> 22.94`4., 230 -> 
          23.02`4., 231 -> 23.26`4., 232 -> 23.16`4., 233 -> 23.19`4., 234 -> 
          22.88`4., 235 -> 22.76`4., 236 -> 22.95`4., 237 -> 23.27`4., 238 -> 
          23.51`4., 239 -> 23.36`4., 240 -> 23.63`4., 241 -> 23.59`4., 242 -> 
          23.56`4., 243 -> 23.34`4., 244 -> 23.43`4., 245 -> 23.56`4., 246 -> 
          24.1`4., 247 -> 24.73`4., 248 -> 24.63`4., 249 -> 24.56`4., 250 -> 
          24.52`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$541706 = 
        Dispatch[{
         1 -> 19.9`4., 2 -> 20.25`4., 3 -> 20.13`4., 4 -> 20.08`4., 5 -> 
          20.06`4., 6 -> 19.86`4., 7 -> 20.28`4., 8 -> 20.29`4., 9 -> 
          20.44`4., 10 -> 20.33`4., 11 -> 20.38`4., 12 -> 20.42`4., 13 -> 
          20.31`4., 14 -> 20.26`4., 15 -> 20.28`4., 16 -> 20.37`4., 17 -> 
          20.32`4., 18 -> 20.25`4., 19 -> 20.18`4., 20 -> 20.11`4., 21 -> 
          19.97`4., 22 -> 20.13`4., 23 -> 20.18`4., 24 -> 20.14`4., 25 -> 
          20.15`4., 26 -> 19.97`4., 27 -> 20.04`4., 28 -> 19.85`4., 29 -> 
          19.98`4., 30 -> 20.62`4., 31 -> 20.89`4., 32 -> 20.79`4., 33 -> 
          20.89`4., 34 -> 21.18`4., 35 -> 21.31`4., 36 -> 21.4`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.71`4., 40 -> 21.87`4., 41 -> 
          21.97`4., 42 -> 21.8`4., 43 -> 21.76`4., 44 -> 21.55`4., 45 -> 
          22.16`4., 46 -> 22.15`4., 47 -> 22.24`4., 48 -> 22.22`4., 49 -> 
          22.34`4., 50 -> 22.38`4., 51 -> 22.54`4., 52 -> 22.35`4., 53 -> 
          22.06`4., 54 -> 21.87`4., 55 -> 21.95`4., 56 -> 21.92`4., 57 -> 
          22.08`4., 58 -> 22.08`4., 59 -> 22.34`4., 60 -> 22.24`4., 61 -> 
          21.48`4., 62 -> 21.16`4., 63 -> 20.75`4., 64 -> 20.73`4., 65 -> 
          20.73`4., 66 -> 20.58`4., 67 -> 20.54`4., 68 -> 20.81`4., 69 -> 
          20.78`4., 70 -> 20.88`4., 71 -> 21.05`4., 72 -> 20.6`4., 73 -> 
          20.37`4., 74 -> 20.48`4., 75 -> 20.37`4., 76 -> 20.17`4., 77 -> 
          19.51`4., 78 -> 19.56`4., 79 -> 19.65`4., 80 -> 20.15`4., 81 -> 
          20.11`4., 82 -> 20.17`4., 83 -> 20.52`4., 84 -> 20.54`4., 85 -> 
          20.35`4., 86 -> 20.61`4., 87 -> 20.6`4., 88 -> 20.6`4., 89 -> 
          20.3`4., 90 -> 20.34`4., 91 -> 20.7`4., 92 -> 20.84`4., 93 -> 
          20.93`4., 94 -> 20.86`4., 95 -> 20.97`4., 96 -> 21.24`4., 97 -> 
          21.08`4., 98 -> 21.08`4., 99 -> 21.38`4., 100 -> 21.15`4., 101 -> 
          20.49`4., 102 -> 20.71`4., 103 -> 20.55`4., 104 -> 20.49`4., 105 -> 
          20.44`4., 106 -> 20.36`4., 107 -> 20.11`4., 108 -> 20.65`4., 109 -> 
          21.`4., 110 -> 20.76`4., 111 -> 20.86`4., 112 -> 20.79`4., 113 -> 
          20.57`4., 114 -> 20.62`4., 115 -> 20.83`4., 116 -> 20.79`4., 117 -> 
          20.78`4., 118 -> 20.86`4., 119 -> 20.78`4., 120 -> 20.96`4., 121 -> 
          21.69`4., 122 -> 21.66`4., 123 -> 21.59`4., 124 -> 21.7`4., 125 -> 
          21.93`4., 126 -> 22.14`4., 127 -> 22.14`4., 128 -> 21.87`4., 129 -> 
          21.92`4., 130 -> 22.26`4., 131 -> 21.95`4., 132 -> 22.18`4., 133 -> 
          22.08`4., 134 -> 22.12`4., 135 -> 22.14`4., 136 -> 22.09`4., 137 -> 
          22.22`4., 138 -> 23.02`4., 139 -> 23.04`4., 140 -> 22.92`4., 141 -> 
          23.37`4., 142 -> 23.04`4., 143 -> 23.08`4., 144 -> 23.2`4., 145 -> 
          22.63`4., 146 -> 22.87`4., 147 -> 23.18`4., 148 -> 23.04`4., 149 -> 
          23.01`4., 150 -> 23.09`4., 151 -> 23.4`4., 152 -> 23.48`4., 153 -> 
          23.49`4., 154 -> 23.58`4., 155 -> 23.43`4., 156 -> 23.22`4., 157 -> 
          23.3`4., 158 -> 23.5`4., 159 -> 23.25`4., 160 -> 23.07`4., 161 -> 
          23.14`4., 162 -> 23.27`4., 163 -> 23.11`4., 164 -> 23.18`4., 165 -> 
          23.06`4., 166 -> 22.94`4., 167 -> 22.92`4., 168 -> 22.94`4., 169 -> 
          22.9`4., 170 -> 23.16`4., 171 -> 22.82`4., 172 -> 22.9`4., 173 -> 
          22.75`4., 174 -> 22.94`4., 175 -> 22.88`4., 176 -> 23.39`4., 177 -> 
          23.4`4., 178 -> 23.27`4., 179 -> 22.63`4., 180 -> 22.92`4., 181 -> 
          22.58`4., 182 -> 22.49`4., 183 -> 21.58`4., 184 -> 21.18`4., 185 -> 
          21.33`4., 186 -> 21.79`4., 187 -> 21.78`4., 188 -> 22.03`4., 189 -> 
          22.09`4., 190 -> 22.11`4., 191 -> 21.97`4., 192 -> 22.14`4., 193 -> 
          22.39`4., 194 -> 22.4`4., 195 -> 22.5`4., 196 -> 22.83`4., 197 -> 
          22.6`4., 198 -> 22.72`4., 199 -> 22.67`4., 200 -> 22.83`4., 201 -> 
          23.06`4., 202 -> 23.09`4., 203 -> 23.27`4., 204 -> 23.38`4., 205 -> 
          23.47`4., 206 -> 23.67`4., 207 -> 23.47`4., 208 -> 23.34`4., 209 -> 
          23.41`4., 210 -> 23.45`4., 211 -> 23.41`4., 212 -> 23.14`4., 213 -> 
          23.45`4., 214 -> 23.47`4., 215 -> 23.14`4., 216 -> 23.19`4., 217 -> 
          23.67`4., 218 -> 23.59`4., 219 -> 23.39`4., 220 -> 23.31`4., 221 -> 
          23.49`4., 222 -> 23.33`4., 223 -> 23.58`4., 224 -> 24.14`4., 225 -> 
          23.79`4., 226 -> 23.25`4., 227 -> 23.36`4., 228 -> 22.93`4., 229 -> 
          23.11`4., 230 -> 23.25`4., 231 -> 23.32`4., 232 -> 23.19`4., 233 -> 
          23.34`4., 234 -> 22.9`4., 235 -> 22.91`4., 236 -> 23.24`4., 237 -> 
          23.32`4., 238 -> 23.62`4., 239 -> 23.54`4., 240 -> 23.94`4., 241 -> 
          23.76`4., 242 -> 23.63`4., 243 -> 23.43`4., 244 -> 23.54`4., 245 -> 
          23.63`4., 246 -> 24.72`4., 247 -> 24.86`4., 248 -> 24.71`4., 249 -> 
          24.62`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$541706 = True, 
        System`TradingChartDump`$gridlines$541706 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$541706, 
        System`TradingChartDump`$plotrangemin$541706 = 19.0982952853598, 
        System`TradingChartDump`$plotrangemax$541706 = 25.507305210918112`, 
        System`TradingChartDump`$layoutData$541706, 
        System`TradingChartDump`$gridlinesscope$541706 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$541706 = {True, True}, 
        System`TradingChartDump`$indicators$541706 = {
         FinancialIndicator["RelativeStrengthIndex", 14]}, 
        System`TradingChartDump`$mouseQ$541706 = False, 
        System`TradingChartDump`$modelData$541706 = 
        System`TradingChartDump`modelData$540236, 
        System`TradingChartDump`$sy$541706 = Identity, 
        System`TradingChartDump`$isy$541706 = Identity, 
        System`TradingChartDump`$appearance$541706 = Automatic, 
        System`TradingChartDump`$perfgoal$541706 = "Quality", 
        System`TradingChartDump`$axesorigin$541706 = Automatic, 
        System`TradingChartDump`$framestyle$541706 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$541706 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$541706 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$541706 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$541706 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$541706, 
        System`TradingChartDump`$newgridlines$541706 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{19.0982952853598, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$541706 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$541706 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$541706 = "GraphicsFrame", 
        System`TradingChartDump`$frame$541706 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$541706 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$541706 = 
              Switch[System`TradingChartDump`$highlightposition$541706, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$541706], {
                 1, System`TradingChartDump`$length$541706}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$541706], {
                 1, System`TradingChartDump`$length$541706}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$541706, 
                   Charting`nearestDate[System`TradingChartDump`$dates$541706, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$541706]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$541706]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$541706, 
                    Floor[System`TradingChartDump`$controlmin$541706] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$541706, 
                    Floor[System`TradingChartDump`$controlmax$541706]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$541706 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$541706 = 
            If[System`TradingChartDump`$fastpos$541706 =!= True, 
              System`TradingChartDump`$fastpos$541706 = 
               Clip[System`TradingChartDump`$fastpos$541706, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$541706 = (
                  Floor[System`TradingChartDump`$controlmax$541706] - Floor[
                  System`TradingChartDump`$controlmin$541706]) (
                  System`TradingChartDump`$fastpos$541706/100) + 
                Floor[System`TradingChartDump`$controlmin$541706]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$541706], {
                Floor[System`TradingChartDump`$controlmin$541706] + 1, 
                 Floor[System`TradingChartDump`$controlmax$541706]}], 
              System`TradingChartDump`$staticindicatorpos$541706]; 
           System`TradingChartDump`$mouseQ$541706 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$541706]], 
              System`TradingChartDump`$highlightposition$541706 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$541706 = If[
              And[
              System`TradingChartDump`$bouncingballQ$541706, 
               System`TradingChartDump`$mouseQ$541706, 
               System`TradingChartDump`$appearance$541706 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$541706[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$541706]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$541706[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$541706, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$541706[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$541706]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$541706[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$541706[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541706, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541706[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541706, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541706, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541706[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541706[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$541706 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$541706, 
                 System`TradingChartDump`$defaultframeticksstyle$541706, 
                 System`TradingChartDump`$defaultlabelstyle$541706, 
                 System`TradingChartDump`$framestyle$541706, 
                 System`TradingChartDump`$frameticksstyle$541706, 
                 System`TradingChartDump`$labelstyle$541706}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541706 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$541706, 
                 System`TradingChartDump`$labelstyle$541706, 
                 System`TradingChartDump`$defaultframeticksstyle$541706, 
                 System`TradingChartDump`$defaultlabelstyle$541706}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541706 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541706, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$541706 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541706, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$541706 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541706, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$541706 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$541706 = 
             Part[System`TradingChartDump`$tickstextstyle$541706, 1], 
             System`TradingChartDump`$tickstextstyle$541706 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541706[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541706, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541706[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541706[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541706[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$541706[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541706, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$541706]], 
                    Style[":", System`TradingChartDump`$textstyle$541706]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$541706[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541706]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541706[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$541706[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$541706, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$541706]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$541706[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541706, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541706[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541706, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541706, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$541706[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541706[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541706[
               "SubplotIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$541706[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$541706[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$541706], 1], 
                   Floor[System`TradingChartDump`$controlmax$541706]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$541706[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$541706[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$541706[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$541706[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$541706[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541706[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$541706[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$541706[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$541706[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541706[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$541706[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$541706[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$541706[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$541706[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$541706[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$541706, 
                  System`TradingChartDump`$mouseQ$541706], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$541706 - 0.5, 
                   System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$541706 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$541706 + 0.5, 
                    System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541706, 1]}, {
                    System`TradingChartDump`$indicatorpos$541706 + 0.5, 
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$541706[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$541706, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$541706[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541706]]], {}]; 
              System`TradingChartDump`$subplotgridlines$541706[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$541706[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$541706[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541706[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$541706 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$541706, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541706, 
                   System`TradingChartDump`$opens$541706]], 12, 
                 System`TradingChartDump`$textstyle$541706, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$541706, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541706, 
                   System`TradingChartDump`$highs$541706]], 12, 
                 System`TradingChartDump`$textstyle$541706, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$541706, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541706, 
                   System`TradingChartDump`$lows$541706]], 12, 
                 System`TradingChartDump`$textstyle$541706, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$541706, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541706, 
                   System`TradingChartDump`$closes$541706]], 12, 
                 System`TradingChartDump`$textstyle$541706, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541706, 
                   System`TradingChartDump`$visdates$541706]], 12, 
                 System`TradingChartDump`$textstyle$541706, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$541706, 
                  System`TradingChartDump`$mouseQ$541706], {{
                  System`TradingChartDump`$timestampstyle$541706, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$541706 - 0.5, 
                    System`TradingChartDump`$plotrangemin$541706}, 
                    If[
                    System`TradingChartDump`$timestampdepth$541706 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$541706[1]}, {
                    System`TradingChartDump`$indicatorpos$541706 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541706}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541706, 1]}, {
                    System`TradingChartDump`$indicatorpos$541706 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541706}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$541706, {
               System`TradingChartDump`$highlightstyle$541706, 
                Dynamic[System`TradingChartDump`$ohlcpoint$541706]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$541706[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541706, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$541706[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$541706[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$541706, Length[
                    System`TradingChartDump`$layoutData$541706[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$541706}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$541706] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$541706] + 0.5}, {
                System`TradingChartDump`$plotrangemin$541706, 
                 System`TradingChartDump`$plotrangemax$541706}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$541706, Left, {
                 False, System`TradingChartDump`$frame$541706}, 
                 Blank[], {System`TradingChartDump`$frame$541706, False}], {
                False, System`TradingChartDump`$frame$541706}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$541706, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$541706]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$541706 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           387.02286107677577`}, {-286.9226415094339, -65.7679245283018}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541706 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541706, 1]], 
               Part[System`TradingChartDump`$framestyle$541706, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$541706]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$541706} -> 
                   System`TradingChartDump`$isy$541706[
                    System`TradingChartDump`$plotrangemin$541706], {
                    0, System`TradingChartDump`$plotrangemax$541706} -> 
                   System`TradingChartDump`$isy$541706[
                    System`TradingChartDump`$plotrangemax$541706]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$541706[
                   System`TradingChartDump`$plotrangemin$541706], 
                   System`TradingChartDump`$isy$541706[
                   System`TradingChartDump`$plotrangemax$541706]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$541706, 
                   System`TradingChartDump`$isy$541706}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541706, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541706 > 
                    System`TradingChartDump`$plotrangemin$541706, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541706 > 
                    System`TradingChartDump`$plotrangemin$541706, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541706, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541706 > 
                    System`TradingChartDump`$plotrangemin$541706, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541706 > 
                    System`TradingChartDump`$plotrangemin$541706, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541706, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541706, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541706 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541706,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541706], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541706 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541706, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541706]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$541706, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$541706[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$541706[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541706, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$541706[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$541706, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541706[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541706, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541706[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541706[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541706[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541706[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541706], 
                    Style[":", System`TradingChartDump`$textstyle$541706]], 
                    Style[":", System`TradingChartDump`$textstyle$541706]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$541706[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541706]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541706[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$541706}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$541706, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$541706 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$541706[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$541706, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$541706, Left, {
                    False, System`TradingChartDump`$frame$541706}, 
                    Blank[], {
                    System`TradingChartDump`$frame$541706, False}], {
                   System`TradingChartDump`$frame$541706, 
                    System`TradingChartDump`$frame$541706}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$541706, 
                    System`TradingChartDump`$controlmax$541706}] + 0.5, {
                   System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$541706]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$541706) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$541706 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$541706 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$541706, 1]], 
                   Part[System`TradingChartDump`$framestyle$541706, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$541706]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541706[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541706[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$541706[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541706, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541706, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$541706, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$541706, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$541706 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
541706, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$541706], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$541706 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$541706, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$541706]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$541706, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$541706) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$541706 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$541706[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           475.9407855006933}, {-55.98962264150938, -0.70094339622635}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$541706, 
              Dynamic[System`TradingChartDump`$ohlclabel$541706], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$541706}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541706 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541706, 2]], 
               Part[System`TradingChartDump`$framestyle$541706, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$541706]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$541706, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$541706, 
                    System`TradingChartDump`$controlmax$541706}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$541706] + 
                    0.5, System`TradingChartDump`$plotrangemin$541706}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$541706], 
                    System`TradingChartDump`$plotrangemin$541706}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$541706, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541706, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541706, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541706 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541706, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541706], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541706 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541706,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541706]]]}, 
              StandardForm, Graphics],
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$541706] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$541706[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$541706] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$541706[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$541706] = {HoldPattern[
               System`TradingChartDump`$min$541706[1]] :> 24.92}}, {
          DownValues[System`TradingChartDump`$max$541706] = {HoldPattern[
               System`TradingChartDump`$max$541706[1]] :> 79.75}}, {
          DownValues[System`TradingChartDump`$subplotvalue$541706] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$541706[1, 1]] :> 
             Invisible[65.24]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$541706] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$541706[1]] :> {
              50}}}, {DownValues[
            System`TradingChartDump`$layoutData$541706] = {HoldPattern[
               System`TradingChartDump`$layoutData$541706["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "AllValues"]] :> CompressedData["
1:eJxFVwk4lVsXppIh0aCkJH7kIJGzv72PhCUVlTKkQVcqXSKKkooGqWSoaLjI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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541706["AppendedAdjust"]] :> 
             5.483017890748525, HoldPattern[
               System`TradingChartDump`$layoutData$541706["AppendedBox"]] :> {
              21.185262121527728`, 103.68022170677322`}, HoldPattern[
               System`TradingChartDump`$layoutData$541706["AppendedMin"]] :> 
             22.182328844658358`, HoldPattern[
               System`TradingChartDump`$layoutData$541706["AppendedRatio"]] :> 
             0.9999999999999999, HoldPattern[
               System`TradingChartDump`$layoutData$541706["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$541706["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$541706["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541706["DataMax"]] :> 
             24.95, HoldPattern[
               System`TradingChartDump`$layoutData$541706["DataMin"]] :> 
             19.376947890818858`, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "MainChartAllValues"]] :> CompressedData["
1:eJxFVwk81csXp5Il0aKkJP4Rkcid38yVcCRRKUta9KToka2QVLRok6Wi5SFb
tCuhUrL3EhXabGkXskUJWdv+x9Jr7ud+5s6ZM2dmzjnz/Z6rYO9u6TBMQECg
/9uH30UH+j88yBDfcqGongfSGw58HjmSgFSycbWvFIFl/KDHG8UIPNF07ao6
woP2eH16ehKB8izj5Ho+gZ/mZZKcM4FnM1t0dbQJbEqpW3TUkMCL2aqLq7G/
LXQwV5YQENJeKH4J9efcCnc6MRXHDnndOUoEPF9+SJFAvaAec0sdZQLU0Ljv
mgIBpw7PNSW4b8ozr4rKTh6cDR7jvqqWB7cT/kqi0whIFHnleEkT+LJHX6Fl
OoGE/fZ31nbwYPetmtfb23iwekRIoWopDyJinn7iveDB7N4N1QWzUP/E348F
YwiI2+6qf5lDoCGf13z/JoEHHddkZDsJyLm59m0X5+DRIfVlmgs5qJ38at37
ORyEy0rdytPnoO1Aea5KEAcyO3ztVx3nQGqy3KYX9Rx8+JIsV5bDwXDJkSpj
/uVgdNqSi2b+HHhW07n0JAd6652jPklSKLD+8MRXkYIJz0FtDfarlh3mxShT
aNimrbGaUMg7f8hpsRsFn1e1qvImFJwML9euFaOgLPDDMvMlB3InFUXSmjl4
Z61XPeoVB9nL9p4VbuXgVYF4hcDwP/aK1ZQS2uZSWJ52almbJQf7a8AzPp3A
vy2CqcJXCSxQXzKv9hYB/+vZ+dv3od+17Q38ggmI9tRX5HsRYGPFdvv4EYje
2X5fK4tA7nvVpy9x3fmQ4Xqvmwhk+FWMjUf9JsefRto2BFTi4i2+afwZ0/LT
baPHEDAI2LI1zIsHvxSC81w38qDXRiPBbz0PTDTkdn6v4UHYyWjN3Le8//Sf
BsQnpjPsaw+NfryGQJ73v0HRVgTS2l7t2PSdB91Llg5LciNQuKVj6fQDBKLi
hEueGBPQg3MfTs0hoCuro/NiJYF2VwGV8yEEfEInnp9xm0DqVLdTieUEOrOa
l9WUYn6bfjIdLsqBW6Z8m+DwP31Awcv9dkocqO6TV9v3nkCvYYbUVvQHvdYW
6xZIoDivO2PWPAKyr7mKx64EyPJ85UN2BDJFLLYr4rt4PAFmn5chcMS5QfLI
Zx4kBc9VzHpDoMb6iE03+lu7s2vmsId43uYpEa5xBEyTrWE33nO1xEj95EgC
JXc2rAlD+aKxPr6ByQT2rx8rMhH9byx4p8QU/X90fCH/OMZx7hIPOxe0s23+
ju4FmJcGieHu+kc5mPlOREx9IwfxgpPjBaM4qCRR/rmYj2NKGiXsGzjYdUDD
9CLm0zT/Zov0dxxMhEznFaUccOYPtn3r4kCxZO2L85hfmm13PZ2kKXTETa3O
6uCgxF9FpbQJ7fjSRD2Uc+lqWS9/cGCiZvNEfhqFT6IpXa1XKcxrGWd/KZeC
tPbDTRvfULDvCTw1TpTBTonMTdO+UbCeG1r58Qvm59dfsSfEGNT4ItKcodB3
+NEnlSwKT6WGLVV4RiHE0qNaRYiBjOJtNdNSCikinYbjX1GIvcqpmwHaGwAo
BqtVy4Lqsa87aVQYt5uBzqS7fY3zGdDeqAhBRQa+NxMWtHMM9j33U1hsyWDe
DcXTKWoM/Nfen+DRQWGt1cmD2T8oHCI6YrKo/1doXqeKLAPpc15z5kozCLI2
uTepikJLrJlgajkFi8zowhF4Txkdm92nn1Iw23visncR+lPjiuvPZgpfxJ4n
Rubg2OqNc/MDCkGxzitL/6EQoHh3bd9FCqltL/PPpVO4JWn+sQjtzgy1mlSg
y/7b/7c/3C+Uj05HPUX+s8/BOyhMMVw7ftTfFC4eDjna7MHByGYXKYU2AtbK
whtaNBGvDNuO7tnJwRb7lW0HEYdIz56m7CIONNbNCvbF+I78JOH6QpjCnLwL
d+IwvibZwfmJPRyE9bUX5NlSuGRCq2wRj8TvaYrf86BwdUn+A1dPlB807s7Z
TyHNf5FXmDPGJdDon8kob96YQJPxnD9sSGEgxq1tQobpa7x/4G5FG5nhDBws
SyMz8V718na6hx0ZGCx9cSwslIGhkkz1D4zPvJCb3dWmDPb2XIqo3sBgxcW9
vUAZVDmLtRwzY7C4WzLHVIGB3fYonS/Y274N313BZ1CgvSijTpiBwPP5NcFN
FJrcx8X4mGC8fvTu2+XFQMVKXX/LYrTjuzxxlA6D/KXLNWSUGTwy+t8uPSMG
qodbXQW3MZiyafPOyDAGYpXnPHSLGPAGGoNOFZvQPMyXewM/KHjoogbma/9z
kRMakuP5Z9r0JwobnNdkUN0ft2r637oBcx1D64yG1u0fyi+bIf0zDPq3F4tg
MCBG/zzvH69ikNRPv5v/yKMiscnwB/M+kz+0nj80zx/cx58PE5vwI0rAJD+p
u3Q5gSsnLmwKRLwaLeV6ZSbi6orUuIlvjBCfbm4QyhMhUCA60yfcgkCiSvpt
gz0E/DKrLn1DPrBxXTDO1IlAzHu194oeBFr6zSPeZc2NlkxdT6Ax4mrKFcRh
xYTE/BHWBETW1AmN8EZebn9Cl9kS+JhhHrMYcTjUetHus+sIzPwYMdJbi8Cs
64HUB/n//qUUdYm5BE6bT9j1eiGBOzvW1UvrIw4qr2+KxrHShu3yvyYTuO6w
emU31gXTZap8tLAuKY2b7hGFONvQdtdb6wzyUX8AavGcF+5dtfmK/VlxlZjv
BALdyj58ZxwId7lrvUUejlF6EV56kRv09ypuyF8c9KwL8ovP50Ay9KHZzUYO
xCI8xA3lKSSG91oY1nLwxGns9S2yFI7qWR7Vu8FBx+X8oo2LKETrKf1diu8x
54iY5Vvka4vm8iW6LhRKnjnGHXCiYD7qwX49XwrqHje+0kgKWavNRMa7Usj1
ulaX40hB6YSNgcwsCi62+pbySvi+i9IaP+P7cxGe88B7OoXN4z/tcDTH9zbP
fUmQNdrfG6lRsZdC5qsxWindHMzJniVuizhfJbvb6+tbAnGyhzMetyCfSKn1
zBfhYINugMpr5J0KPTZepZiAUXjpycrXyM8jtC1HKXJwRkpi7/wvBKoklHna
8zh4ZiB1pLWPwGbJW7ejLyOPBWXpPiggsH7H+F3ysQT47krbWjcTEDwdq7lA
B+M59WFYcQYP7my8XWR/DevGUN09dhyB+qsCI86pE8hPili2F+M76GcChuLG
p7OPEPjlNCmuN5FAmXpa7aXTWFd+T30kUEYgqUQ6bFQmAYfmidumpxLYIqwX
vnMXAcdX6zUv4ryrWY2XCN6n95B2+bgOnPf/tSSum8Dn1vc3GOFA/fzVwGr0
R4yVTazNOg4cwsLuumH8f4iOCDBy5GCtxVRbi7UciLz3zUifxoFrwnjj2Dqs
F0QWlh1IwLx3kjFIi8f6b4V5+/ZoAl56Eov3BRFwtvMXUMV8f+v8VbEZ9dQf
Bdjaa3FQ0Wh1pAj92DM/WmJhM9YDx1IKGrFesM6rLbQuJPBoqem9r9nor8v6
tRGYn8UxTxzbcb/cXe+KG7A/M2ze06R3+K5MckLKMS4LvjUr8NHufZ1jCpuf
c9BgfD2i7AUHOb6GG9KSOBCsyo7agXIr9SZhOeTjRm5b0Ed1CmrfkkV+Mgpd
z+345hqIN1FmtrmiFKyCgB9pTOGkH88qCPO5rmlznM58CtMtxTsjML9y2tU+
LpyB/HRq3KKvWhTKihxXK+M40z7L9Cvmd2iUSULxFAaF7NBWBzkG78bJPRRS
Z4N1gy0D7XalfQ3rENeCn/msQj6Ncpnh6o64OHvBbD2l1QyKzwvmyvVQIDP/
OnkD8fSNuIQyMWZgEv1562XETbOiioB/ZBiUP+hYX3WQwazGBT3iFxH3VMaq
Bp5jcHxPtveeWwykguPipRH/ilnJjWNODPRUZ/e5WDHwcZiQef844vAxv5Uy
AQwsrRvtLPEc4is79ARmM9ASOuO3NRrx3TlkcqML++8c407N67NE3qlIO+Vr
g/caISHzv+ROChkPK+s7RzB4mFta54s8ViTolvQP4rr+lOB7BxkDa8PO8zKI
5zldM1gw4rvnEC88+CG6PHgsA3sL+1Ox3ni/unJvZzzPgbNOjgrIe5fCRJsy
p7JB/ES70j8LE0a/pOCre2OrciLWC+0ZgZGv8X+EcL5y7T4OxiX7GmYf5OCx
iMkWoTccTLf2FXsiQeFR7yzBTxjnGftGhWRj/H5eeHR8OI9C5bFh0ZPV6CAO
onx/ndn99isUpnaX0XPeiDet33Jboyl8rxw2VaiSwpsVXU5VH/G+Du3ybzIp
VH9flTY9FeuTy1eM02speI9K9qzH+xyrjDxmg/70XDm5TAv5dPSYZ3dLkKed
u0ZNLA5n8PmwZevELwx2gUvxLIzP1tb9cyKwDhst4lTQcIGBy/O4u+7Id24+
RTIRGKfZ6eGcDsZjndAhv39x/bbSxR/SUF507/X7GgcGP9nDKnXk30+SBn+v
z2NwanFDT0Qm+rUruqnAj8EVc5UT94IYTLosmLcukkFpjqBDTQiDa5PVXxUn
MOib8L3NYj4fbiSbneVU+IPxucbg3ABBM3DsbzMY/Opv+mxw3uNPHfl7/Fu/
coiHB+b7KAxMYz1j0k+8GN/Hj/ob1pcDfMygq5/2O7EuGWj8Qf0cBgPwlzjE
+zFD+3wZqjc6+EN5McTn1fzBfSt/n58P/wdya6kS
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "MainChartPoints"]] :> CompressedData["
1:eJxdV1toXFUUvRZFKYIKBf0ocapS6oNSTR/xEbubNk2apk1mMslkksnkztyZ
O487M6n4IxXhIuRHhFAoSEVkRBFBEEEKoV+X+CGIIoJQBJEpQhEiUpCK9MuZ
2Wt97HMhDOvuu886e+3HOTlQ3shU7/c8717/7z787fH43DkZDp7bo4IX+itH
gR+SW5f3fTV1gPhR6aP+K+J9srVz91DhEeInpDB48RvX2y/TwwVoT8nem59e
Gp8hfkreGB+8IX5G188SH1T+EvEh+Su9PbIZET+n/HPEL8i3fbg1QXzY4T8i
T27upreLxC9Kpr/cbpr4JSf+URmGe5j4qMa3n/iYDN3/Y7zHHb1OOP5j8tml
fsBPE78sQ/0PEr/irPeq6rWX9tfkw2v951fax+XtgWD3iF/X+D7m9yeV7w9i
0fW+B47FsZ/Cfo/Bfgr6AnsTut+Q9gkZbi9H+2kZ0I9s0n5a/u2nY+c67Wd0
f7/Tfgbx0j4pP/4weGif1Hzu0H5W7e/TflaeHSbkOOxT0BM4npJheY3TPq18
Y7RPY/+0n0O90X5O9XqP9hnVP0/7DOqf9vNOfOdldPD8w/3Pav3u0j6LfqL/
BYvjC87+Ltp44oua/8tcfw56cP05/U2Y33n9/gawODieV/6rwMk84qd/WuP9
if5p7a/v6J9W/W7RP635epj7y6h+1+ifsf0YZxAP/R27t6D6PU//Ba2Pd1H/
8YLubws4WdB6+Jz9kbX9Jlnbz3HWrp9kUc/kX7R6yCLqgf6Lut5H9F+08XpL
TvxLqs8s/ZeQb/ovaf18Q/+c2m/SP6f9+jf9c5i/9M+hv+i/jPpBPmQZ9cZ6
cXCyjH5g/vLQj/55Xe8d8ufR7+TPo1/Jv2K/lxU7/+MV3X+B/ivOvF1FPum/
ivfc/yrmBf1XrR5ewc4/Kej8v0L+gp2fSUH1+IX+a47/mlP/a47+jt0rqj53
6V/U+L/m/ovav19Q/6Lm+wPqv456oP7ryD/913G+YD4kDvZ8O59Svp1H4uP8
xPe+b+dX7ON8gL3r23mVYP0R4J7v8Jc0nseBUyU7j6Wk/fbACfCXcP4BxyXs
l/wlzAfYE+f7Xgn7A/bKGs8ocKqs9f0J+cvQh/GXES/5y3b9bln12kP+MuIj
fxnnJfkDzDfyB+gHYAkwfxl/oPwd8gfQi/wB5gf5A3xHfmAhf0Xr/THyV5Af
8ldU/0nyV9B/5K9YPboVnH/kr2g932H+KzZfXtXaU1XV5zb1r+L8In9V9/sz
zzvn+24VvKw/Z/1eFecR+UONN2D8oc2PhE78oa2POHTqL0S+yB8in+Snnf1b
s/erVA33XfZfDfMF2K9hfrD/gB8kf832U1JDvshfc+5XdduPKeCA+tehB+u/
Dl7GX8c8JH8d5xn568q3Tf666vUl9W9Y/1TD1o80bP/4DZuPuIHziPXXUL63
WH8N8LH+HbvXxPnK/De13urkb+p8eJP8jj1u2n7pOt8nTcvXc773Iq3PI+SP
7H4lwrwnf2TrNY5wHyd/ZOdHEqGeyB/ZeeK1sJ8x8LdQb+Rv4Zf8LZzH5G/h
vGH+W3Y+JI5/r4X/r8jfduJv23xI2/a331b9/2T9tXF/Yfxtu37SxvlN/jbu
a+TvYD6Qv4P7Avk76HfG33Hmb8eu13W+Tzqof+jb6+A+AOxt4H5E/TewX2DZ
wH1gTP4HLlcf7Q==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541706["NewSubplot"]] :> {
               FinancialIndicator["RelativeStrengthIndex", 14]}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541706["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541706["PlotRangeMin"]] :> 
             22.182328844658358`, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$541706["Space"]] :> 2.495, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541706["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, 30}, {250., 30}}], 
                    Line[{{0, 50}, {250., 50}}], 
                    Line[{{0, 70}, {250., 70}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJxdVgdUk1kWjoplAfso2INdUVGxIAp8ICC9J1ThT0gIgQA6sIg6jrGxdsdB
pVjIqMxYEJWxY8kKOLIiiIMNFYNd+rhjV9zZ473n7Mo5OZzvfO9797777v3e
byFPClC2F4lEtX/9/vv/y58dmvevsBUPdcMXbI/n9Z3Fm4f4EXaAUWdRcruZ
/oSBW6N6X36lJl4LNHZ7XHO0mtc7Yk5l5dE+z2m91hFHzLybc4MCiHfCBmlO
zwU7CWudkHJi2IBb3ZmfDcuIF5J5B5mfDe9cYfkU+0DinXFj6lTXHgWEtc5Y
OxiVjq3Mu+C89krDRF/Wu+DyqxuNA1s5f1c8csnxzjPj/F1xuCJ5r8GJ48/B
w8GNM2snsH4OInR/ZshSmHeDsUdVSOkc5t2Q/36x+9EDzLtjnJflo8VXmHdH
5u+r5v3Lg/PzQKc3oy3yl3J9PKB2inpaFu5DvCfeFE0LG1jsSbwnGk4NN92b
6UW8F8IXPitoHEtY64XA/TVD7B56E+/9/1jrjX3y02Oldnw/Psif3l+oraZ4
Wh+MtfltulWZC/G+uNOaIg+2nU28L26PnjSw+3oQ74ddt6ztnBII4yus9YPu
36+ezHpq/wXr/TAu+0VfuYywyB817tdnub93Ir0/ll4Kv327iLDWH57L0rJu
DnQmvT9Ubnu6JIW4kj4AWiEytZeG9QFwbqtOSyvn+AFwMKxZpbUjXh+Ax+Ne
JjVoHEkfiKxeVhkWnTj/QOg/j9ytbbQhfSDmTfedctfJlvSBMN3iObPh1CzS
B2GXyHKSuSflhyA4D5l8Ia8dYW0QHI5af+x7iPMPwoL7hvR0N54vCXZYz6j8
uJAwJMg6uKC56AydTytB+oudpycGupNeguJuNd8VzSAskqLkfzGkuDbokWTZ
JNZL8TZp0Ea3A4T1Ulx6MOVJeroH6YORMfxow4Cb1F8IhjhqjbHXfu6nYJy2
7NYv9Qrx+mCUqww/jTJw/4WgyqwiabebL+lDkCva8HTFGO63r7A+BJ2qPwSb
36L1olCMPFtoP6qM9kMoLJ4Xt/WewvmHom7FfHWdL9VHH4pey2c8v/GS7z8M
1mMujDgzjzDCYBy5ddIlEevD4NPyq+ySO/WzPgz3NReL8yZSP4vCUWaafq6g
hesfjuRNZtf+eZ3nLRxrFg4S5Hu5/uEwrzlf5JrG9YvAdeM9Vp0ruf4R2Bdx
y6hL+RzSR+BMx+NGO9w5/whUNZW9SfVk/Vx8XuJbFlnH+rmwrh5uJpQS1s7F
QVHzA7tcWq+fi259T9fe/JnvPxL2RdkJ+3R8f5F45fk66Mg59rNIePdSnM1d
T1gfibRZU7qN6svzH4V2x75/6LiEMKKwr7vXmFRX9qMo3BwWNrxPA2H9V1gk
IGKbjbdFHd2nWMD8uV5la4fyfgKkJfIfbgbTekGAlUHVlpfJfiMg+sDnmqcW
tF4noFWibv9tB9pPL0Af0ZruH0jYIKBw2oAqhyXcPzIMjTmf4FZM+4ll8K3J
nNe3mftRhivuve/N3Uj+K8jwLtVyc7vt7McymCh+Dw44Q/npZDCuisqyfUy8
XgbLcNUfu0opP4MMtTlXFZ0ec/3ksK33L1wF0ovlaLVw8fm+H/ezHEH1GT+d
Laf+F+QIz05JOV9C+WnlUPXZZDgcRPnr5IjIeFaRaERYL8cE+6lnn3C9DHLU
GK0rKpBy/Gg4F9i6t2wjLI6GRhLw2SuX6x8N9YT1bcOaCAvRuJJ4R+10meNH
49iNC+ER/Sg/XTSCDjVfXcT56qPxrUOWtUka1z8aY89Zfj/Ln+dfgYiJ9VX3
Xak/xQp895tV5KW3hKGAPqiLtKsDrRcUWFxStf2OH/FaBcJbsz0/d6X+1Skg
F5ntrt7C86ZAXU7zZZOxND8GBTzTzS8Ob6L5EikxyCa0xNKaeLESkoTVi10P
EA8lLpR4uygm0f6CEjqzPyatNbA/KOHYOXf6x0Zar1PiuCyvPpn9U6/EtrbB
z1RHOb4SKKy5/+AVx49BySdJyMpVVC9xDHLlxilddxJGDKpsOm29cI/jx+Dc
qNsXHKeRH2ljUOa+2dh8Ou2vi8Evh3vuzVSyX8Vgv2n7PUeO0/thiMF6j7Ye
9kf4/VTBEJi0vE0yk+KrYBTZwe+zinio0GNRQPXtVPI7QYVTil6OObH8nqvw
4cPmoS5ZFE+nwvv928ePHMjnV0HpkFwc5EHYoMIv5nkLOjny90Es/rai49by
p8SLY3HXaaZPn9HsZ3/xJ5wqy+0JC7GYuGGy6doxfP+xaEhNLY9rof7QxWJ3
/uuUzB3sd7EYUVEY2zuX6meIxcWL88f9ak5YpEb/nuu+6bOM9GI1Hpr4FE6O
onmBGmrT5dsubycsqLElZES9Rzv2RzWe5dQ61/D3q06NyVHj4+POs1+qsema
PDx7Hs23QY2T9kEOovfsP3HQj92KgOnsP3Eof5lS2J6/pxCHB2ahh49Z0Xoh
DmunnXhm9yP7Xxze35gTYjhL59XFIdO/7gHu8fzFoWlPaeljE57/OMz8MPiH
nvzeiOLR6jS+RQjj+YvHdS9Vx6xrHD8eV+osXCZWsP/Ew/RUU25FNL9v8chI
LTBxXcDx41Hjd3HPSnuqpz4eOLm0tkxKvCEeHbsYZ9vqef41SH5zL6Upjf1H
g8q3Ctm9b7j/NahwCHx5S0r9LWgg6r9Qepq/V7QanI07rv/UkfpHp8EAqyzv
n9fQfOk1WJjss/rvh3n+NHAolklDZ/P5E9CltN6m2xie/wREReesli3h/kuA
Zd6rlsFN1K9CAjKWSp/oOJ42AS2vFwRcNaH1ugTclTzOHlLE/pOAd/H2nzqM
ovMaEnDjx/w+syO5/xJhW2oib/Tn+0+E05BFWLyS/T8R63zavG468vwn4v0I
m2nFSj5/ImKDR0iUfH+6RDSLNe9ODuXvrUQMyy+8eqQD918idm13s/qHhN/f
JOwpiBy4fTPXPwnVsTWH/hzA/p+EjXtnSHb7+uE/IPboVA==
                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "SubplotIndicatorGridLines"]] :> {{25, 50, 75, 100}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "RSI"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["RelativeStrengthIndex", 14]}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "SubplotIndicatorParameters"]] :> {{{14}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "SubplotIndicatorPoints"]] :> {{{}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {{29., 48.27}}, {{30., 64.49}}, {{31., 68.92}}, {{32., 65.66}}, {{33.,
                 67.32000000000001}}, {{34., 71.63}}, {{35., 
                73.32000000000001}}, {{36., 74.46000000000001}}, {{37., 
                72.25}}, {{38., 74.68}}, {{39., 76.97}}, {{40., 78.72}}, {{
                41., 79.75}}, {{42., 73.24}}, {{43., 71.75}}, {{44., 
                64.37}}, {{45., 73.04}}, {{46., 72.73}}, {{47., 
                73.82000000000001}}, {{48., 73.12}}, {{49., 74.67}}, {{50., 
                75.18}}, {{51., 77.17}}, {{52., 69.99}}, {{53., 60.72}}, {{
                54., 55.52}}, {{55., 57.18}}, {{56., 56.34}}, {{57., 
                59.77}}, {{58., 59.77}}, {{59., 64.96000000000001}}, {{60., 
                61.660000000000004`}}, {{61., 43.57}}, {{62., 38.46}}, {{63., 
                33.09}}, {{64., 32.85}}, {{65., 32.85}}, {{66., 
                30.900000000000002`}}, {{67., 30.38}}, {{68., 37.96}}, {{69., 
                37.47}}, {{70., 40.230000000000004`}}, {{71., 44.69}}, {{72., 
                36.84}}, {{73., 33.6}}, {{74., 36.480000000000004`}}, {{75., 
                34.85}}, {{76., 32.05}}, {{77., 24.92}}, {{78., 26.26}}, {{
                79., 28.72}}, {{80., 40.59}}, {{81., 40.01}}, {{82., 
                41.35}}, {{83., 48.57}}, {{84., 48.95}}, {{85., 45.46}}, {{
                86., 50.65}}, {{87., 50.45}}, {{88., 50.45}}, {{89., 
                44.39}}, {{90., 45.33}}, {{91., 53.050000000000004`}}, {{92., 
                55.67}}, {{93., 57.32}}, {{94., 55.59}}, {{95., 57.75}}, {{
                96., 62.57}}, {{97., 58.32}}, {{98., 58.32}}, {{99., 
                63.68}}, {{100., 57.57}}, {{101., 44.410000000000004`}}, {{
                102., 48.620000000000005`}}, {{103., 45.9}}, {{104., 
                44.88}}, {{105., 44.01}}, {{106., 42.58}}, {{107., 38.38}}, {{
                108., 49.870000000000005`}}, {{109., 55.65}}, {{110., 
                51.28}}, {{111., 52.94}}, {{112., 51.620000000000005`}}, {{
                113., 47.59}}, {{114., 48.58}}, {{115., 52.59}}, {{116., 
                51.76}}, {{117., 51.54}}, {{118., 53.24}}, {{119., 
                51.300000000000004`}}, {{120., 55.26}}, {{121., 
                66.96000000000001}}, {{122., 66.2}}, {{123., 64.35}}, {{124., 
                65.96000000000001}}, {{125., 69.10000000000001}}, {{126., 
                71.67}}, {{127., 71.67}}, {{128., 63.76}}, {{129., 64.54}}, {{
                130., 69.37}}, {{131., 61.18}}, {{132., 64.53}}, {{133., 
                62.03}}, {{134., 62.65}}, {{135., 62.980000000000004`}}, {{
                136., 61.53}}, {{137., 63.86}}, {{138., 74.22}}, {{139., 
                74.42}}, {{140., 70.91}}, {{141., 75.57000000000001}}, {{142.,
                 67.09}}, {{143., 67.56}}, {{144., 69.01}}, {{145., 56.2}}, {{
                146., 59.6}}, {{147., 63.54}}, {{148., 
                60.660000000000004`}}, {{149., 60.03}}, {{150., 61.19}}, {{
                151., 65.35}}, {{152., 66.36}}, {{153., 66.49}}, {{154., 
                67.71000000000001}}, {{155., 63.56}}, {{156., 58.2}}, {{157., 
                59.6}}, {{158., 62.940000000000005`}}, {{159., 56.63}}, {{
                160., 52.550000000000004`}}, {{161., 53.94}}, {{162., 
                56.49}}, {{163., 52.63}}, {{164., 54.11}}, {{165., 
                51.160000000000004`}}, {{166., 48.33}}, {{167., 47.85}}, {{
                168., 48.4}}, {{169., 47.33}}, {{170., 54.39}}, {{171., 
                45.75}}, {{172., 47.85}}, {{173., 44.39}}, {{174., 49.39}}, {{
                175., 47.92}}, {{176., 59.04}}, {{177., 
                59.230000000000004`}}, {{178., 55.72}}, {{179., 42.42}}, {{
                180., 48.43}}, {{181., 42.79}}, {{182., 41.42}}, {{183., 
                30.69}}, {{184., 27.34}}, {{185., 30.41}}, {{186., 38.93}}, {{
                187., 38.82}}, {{188., 43.19}}, {{189., 44.22}}, {{190., 
                44.58}}, {{191., 42.51}}, {{192., 45.800000000000004`}}, {{
                193., 50.31}}, {{194., 50.49}}, {{195., 52.32}}, {{196., 
                57.870000000000005`}}, {{197., 53.22}}, {{198., 55.24}}, {{
                199., 54.19}}, {{200., 57.01}}, {{201., 60.74}}, {{202., 
                61.22}}, {{203., 64.02}}, {{204., 65.65}}, {{205., 66.98}}, {{
                206., 69.76}}, {{207., 63.95}}, {{208., 60.43}}, {{209., 
                61.660000000000004`}}, {{210., 62.370000000000005`}}, {{211., 
                61.14}}, {{212., 53.480000000000004`}}, {{213., 59.72}}, {{
                214., 60.09}}, {{215., 51.620000000000005`}}, {{216., 
                52.71}}, {{217., 61.63}}, {{218., 59.61}}, {{219., 54.78}}, {{
                220., 52.93}}, {{221., 56.49}}, {{222., 52.68}}, {{223., 
                57.5}}, {{224., 65.89}}, {{225., 58.160000000000004`}}, {{
                226., 48.68}}, {{227., 50.45}}, {{228., 
                44.050000000000004`}}, {{229., 47.08}}, {{230., 
                49.370000000000005`}}, {{231., 50.53}}, {{232., 48.32}}, {{
                233., 50.980000000000004`}}, {{234., 43.85}}, {{235., 
                44.04}}, {{236., 50.09}}, {{237., 51.46}}, {{238., 
                56.300000000000004`}}, {{239., 54.74}}, {{240., 60.64}}, {{
                241., 57.04}}, {{242., 54.51}}, {{243., 
                50.800000000000004`}}, {{244., 52.71}}, {{245., 54.27}}, {{
                246., 68.06}}, {{247., 69.34}}, {{248., 66.28}}, {{249., 
                64.44}}, {{250., 65.24}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "SubplotIndicatorValues"]] :> {{{""}, {""}, {""}, {""}, {""}, {
                ""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {
                ""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {
                ""}, {""}, {""}, {48.27}, {64.49}, {68.92}, {65.66}, {
                67.32000000000001}, {71.63}, {73.32000000000001}, {
                74.46000000000001}, {72.25}, {74.68}, {76.97}, {78.72}, {
                79.75}, {73.24}, {71.75}, {64.37}, {73.04}, {72.73}, {
                73.82000000000001}, {73.12}, {74.67}, {75.18}, {77.17}, {
                69.99}, {60.72}, {55.52}, {57.18}, {56.34}, {59.77}, {
                59.77}, {64.96000000000001}, {61.660000000000004`}, {43.57}, {
                38.46}, {33.09}, {32.85}, {32.85}, {30.900000000000002`}, {
                30.38}, {37.96}, {37.47}, {40.230000000000004`}, {44.69}, {
                36.84}, {33.6}, {36.480000000000004`}, {34.85}, {32.05}, {
                24.92}, {26.26}, {28.72}, {40.59}, {40.01}, {41.35}, {
                48.57}, {48.95}, {45.46}, {50.65}, {50.45}, {50.45}, {
                44.39}, {45.33}, {53.050000000000004`}, {55.67}, {57.32}, {
                55.59}, {57.75}, {62.57}, {58.32}, {58.32}, {63.68}, {
                57.57}, {44.410000000000004`}, {48.620000000000005`}, {
                45.9}, {44.88}, {44.01}, {42.58}, {38.38}, {
                49.870000000000005`}, {55.65}, {51.28}, {52.94}, {
                51.620000000000005`}, {47.59}, {48.58}, {52.59}, {51.76}, {
                51.54}, {53.24}, {51.300000000000004`}, {55.26}, {
                66.96000000000001}, {66.2}, {64.35}, {65.96000000000001}, {
                69.10000000000001}, {71.67}, {71.67}, {63.76}, {64.54}, {
                69.37}, {61.18}, {64.53}, {62.03}, {62.65}, {
                62.980000000000004`}, {61.53}, {63.86}, {74.22}, {74.42}, {
                70.91}, {75.57000000000001}, {67.09}, {67.56}, {69.01}, {
                56.2}, {59.6}, {63.54}, {60.660000000000004`}, {60.03}, {
                61.19}, {65.35}, {66.36}, {66.49}, {67.71000000000001}, {
                63.56}, {58.2}, {59.6}, {62.940000000000005`}, {56.63}, {
                52.550000000000004`}, {53.94}, {56.49}, {52.63}, {54.11}, {
                51.160000000000004`}, {48.33}, {47.85}, {48.4}, {47.33}, {
                54.39}, {45.75}, {47.85}, {44.39}, {49.39}, {47.92}, {
                59.04}, {59.230000000000004`}, {55.72}, {42.42}, {48.43}, {
                42.79}, {41.42}, {30.69}, {27.34}, {30.41}, {38.93}, {
                38.82}, {43.19}, {44.22}, {44.58}, {42.51}, {
                45.800000000000004`}, {50.31}, {50.49}, {52.32}, {
                57.870000000000005`}, {53.22}, {55.24}, {54.19}, {57.01}, {
                60.74}, {61.22}, {64.02}, {65.65}, {66.98}, {69.76}, {
                63.95}, {60.43}, {61.660000000000004`}, {
                62.370000000000005`}, {61.14}, {53.480000000000004`}, {
                59.72}, {60.09}, {51.620000000000005`}, {52.71}, {61.63}, {
                59.61}, {54.78}, {52.93}, {56.49}, {52.68}, {57.5}, {65.89}, {
                58.160000000000004`}, {48.68}, {50.45}, {
                44.050000000000004`}, {47.08}, {49.370000000000005`}, {
                50.53}, {48.32}, {50.980000000000004`}, {43.85}, {44.04}, {
                50.09}, {51.46}, {56.300000000000004`}, {54.74}, {60.64}, {
                57.04}, {54.51}, {50.800000000000004`}, {52.71}, {54.27}, {
                68.06}, {69.34}, {66.28}, {64.44}, {65.24}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$541706["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$541706["YRange"]] :> 24.95,
              HoldPattern[
               System`TradingChartDump`$layoutData$541706[
               "SubplotPoints", {
                1}]] :> {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {48.27}, {
               64.49}, {68.92}, {65.66}, {67.32000000000001}, {71.63}, {
               73.32000000000001}, {74.46000000000001}, {72.25}, {74.68}, {
               76.97}, {78.72}, {79.75}, {73.24}, {71.75}, {64.37}, {73.04}, {
               72.73}, {73.82000000000001}, {73.12}, {74.67}, {75.18}, {
               77.17}, {69.99}, {60.72}, {55.52}, {57.18}, {56.34}, {59.77}, {
               59.77}, {64.96000000000001}, {61.660000000000004`}, {43.57}, {
               38.46}, {33.09}, {32.85}, {32.85}, {30.900000000000002`}, {
               30.38}, {37.96}, {37.47}, {40.230000000000004`}, {44.69}, {
               36.84}, {33.6}, {36.480000000000004`}, {34.85}, {32.05}, {
               24.92}, {26.26}, {28.72}, {40.59}, {40.01}, {41.35}, {48.57}, {
               48.95}, {45.46}, {50.65}, {50.45}, {50.45}, {44.39}, {45.33}, {
               53.050000000000004`}, {55.67}, {57.32}, {55.59}, {57.75}, {
               62.57}, {58.32}, {58.32}, {63.68}, {57.57}, {
               44.410000000000004`}, {48.620000000000005`}, {45.9}, {44.88}, {
               44.01}, {42.58}, {38.38}, {49.870000000000005`}, {55.65}, {
               51.28}, {52.94}, {51.620000000000005`}, {47.59}, {48.58}, {
               52.59}, {51.76}, {51.54}, {53.24}, {51.300000000000004`}, {
               55.26}, {66.96000000000001}, {66.2}, {64.35}, {
               65.96000000000001}, {69.10000000000001}, {71.67}, {71.67}, {
               63.76}, {64.54}, {69.37}, {61.18}, {64.53}, {62.03}, {62.65}, {
               62.980000000000004`}, {61.53}, {63.86}, {74.22}, {74.42}, {
               70.91}, {75.57000000000001}, {67.09}, {67.56}, {69.01}, {
               56.2}, {59.6}, {63.54}, {60.660000000000004`}, {60.03}, {
               61.19}, {65.35}, {66.36}, {66.49}, {67.71000000000001}, {
               63.56}, {58.2}, {59.6}, {62.940000000000005`}, {56.63}, {
               52.550000000000004`}, {53.94}, {56.49}, {52.63}, {54.11}, {
               51.160000000000004`}, {48.33}, {47.85}, {48.4}, {47.33}, {
               54.39}, {45.75}, {47.85}, {44.39}, {49.39}, {47.92}, {59.04}, {
               59.230000000000004`}, {55.72}, {42.42}, {48.43}, {42.79}, {
               41.42}, {30.69}, {27.34}, {30.41}, {38.93}, {38.82}, {43.19}, {
               44.22}, {44.58}, {42.51}, {45.800000000000004`}, {50.31}, {
               50.49}, {52.32}, {57.870000000000005`}, {53.22}, {55.24}, {
               54.19}, {57.01}, {60.74}, {61.22}, {64.02}, {65.65}, {66.98}, {
               69.76}, {63.95}, {60.43}, {61.660000000000004`}, {
               62.370000000000005`}, {61.14}, {53.480000000000004`}, {
               59.72}, {60.09}, {51.620000000000005`}, {52.71}, {61.63}, {
               59.61}, {54.78}, {52.93}, {56.49}, {52.68}, {57.5}, {65.89}, {
               58.160000000000004`}, {48.68}, {50.45}, {
               44.050000000000004`}, {47.08}, {49.370000000000005`}, {
               50.53}, {48.32}, {50.980000000000004`}, {43.85}, {44.04}, {
               50.09}, {51.46}, {56.300000000000004`}, {54.74}, {60.64}, {
               57.04}, {54.51}, {50.800000000000004`}, {52.71}, {54.27}, {
               68.06}, {69.34}, {66.28}, {64.44}, {65.24}}, HoldPattern[
               System`TradingChartDump`$layoutData$541706[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$541706[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$541706[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$541706[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$541706[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$541706 = 
           System`TradingChartDump`$length$541706; 
          System`TradingChartDump`$layoutData$541706["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$541706; 
          System`TradingChartDump`$modelData$541706["Data"] = 
           System`TradingChartDump`$data$541706; 
          System`TradingChartDump`$modelData$541706["Indicators"] = 
           System`TradingChartDump`$indicators$541706; 
          System`TradingChartDump`$layoutData$541706[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541706["ScalingFunctions"] = {
            System`TradingChartDump`$sy$541706, 
             System`TradingChartDump`$isy$541706}; 
          System`TradingChartDump`$layoutData$541706["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541706["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541706[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541706["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$541706["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$541706, 
            System`TradingChartDump`$layoutData$541706, 
            System`TradingChartDump`$indicators$541706]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$541706, 
            System`TradingChartDump`$layoutData$541706, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$541706[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$541706["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$541706[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$541706[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$541706["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$541706[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$541706 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541706["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541706, 
                 System`TradingChartDump`$controlmax$541706}]]]; 
          System`TradingChartDump`$plotrangemax$541706 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541706["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541706, 
                 System`TradingChartDump`$controlmax$541706}]]]; {
            System`TradingChartDump`$plotrangemin$541706, 
             System`TradingChartDump`$plotrangemax$541706} = ReplaceAll[
             System`TradingChartDump`$sy$541706[{
              System`TradingChartDump`$plotrangemin$541706, 
               System`TradingChartDump`$plotrangemax$541706}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$541706[
                Min[System`TradingChartDump`$lows$541706]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$541706 == 
            System`TradingChartDump`$plotrangemax$541706, {
             System`TradingChartDump`$plotrangemin$541706, 
              System`TradingChartDump`$plotrangemax$541706} = {
             System`TradingChartDump`$plotrangemin$541706 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$541706], 
              System`TradingChartDump`$plotrangemax$541706 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$541706]}]; 
          System`TradingChartDump`$newgridlines$541706 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$541706, 
            Part[System`TradingChartDump`$newgridlines$541706, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$541706, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$541706], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$541706, 1]]; 
            Part[System`TradingChartDump`$newgridlines$541706, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$541706, 1] =!= None,
                 System`TradingChartDump`$length$541706 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$541706, 
                 Part[System`TradingChartDump`$newgridlines$541706, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$541706, 1]]; 
            System`TradingChartDump`$subpricegridlines$541706 = 
             Part[System`TradingChartDump`$gridlines$541706, 2]; 
            Part[System`TradingChartDump`$newgridlines$541706, 2] = 
             If[System`TradingChartDump`$sy$541706 === Identity, 
               With[{
                System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541706}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541706, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541706, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$541706, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$541706, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541706}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541706, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541706, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$541706 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$541706]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"GE\"", "\" with \"", 
           "\"RelativeStrengthIndex\"", "\"(\"", "14", "\",\"", "", "\",\"", 
           "", "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {720., -837.}, 
      ImageScaled[{0.5, 0.5}], {450, 310}]}, {InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$541720 = 
        "Full", System`TradingChartDump`$highlightposition$541720 = Automatic,
         System`TradingChartDump`$maxohlc$541720 = 24.95`4., 
        System`TradingChartDump`$timestampstyle$541720 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$541720 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$541720 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$541720, 
        System`TradingChartDump`$subplotpoint$541720, 
        System`TradingChartDump`$ndigits$541720 = 4, 
        System`TradingChartDump`$highlightstyle$541720 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$541720 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$541720 = True, 
        System`TradingChartDump`$timestampQ$541720 = True, 
        System`TradingChartDump`$data$541720 = {{{2012, 7, 26}, {
          19.55155642023346, 20.035505836575872`, 19.512840466926068`, 19.9, 
           57275600}}, {{2012, 7, 27}, {
          19.96928776290631, 20.327437858508603`, 19.901529636711278`, 20.25, 
           80268300}}, {{2012, 7, 30}, {
          20.120322115384614`, 20.236456730769227`, 20.023543269230768`, 
           20.13, 44993600}}, {{2012, 7, 31}, {
          20.08, 20.21547951807229, 20.08, 20.08, 38328400}}, {{2012, 8, 1}, {
          20.185798359864926`, 20.27288953207911, 20.040646406174623`, 20.06, 
           35734300}}, {{2012, 8, 2}, {
          19.860000000000003`, 20.03421052631579, 19.55029239766082, 19.86, 
           44000400}}, {{2012, 8, 3}, {
          20.144541984732825`, 20.318702290076335`, 20.096164122137402`, 
           20.28, 37891500}}, {{2012, 8, 6}, {
          20.29, 20.493190271816882`, 20.22226990939437, 20.29, 34159500}}, {{
          2012, 8, 7}, {
          20.459356060606062`, 20.507746212121216`, 20.410965909090912`, 
           20.44, 31115300}}, {{2012, 8, 8}, {
          20.36870537839124, 20.407410756782483`, 20.22356020942408, 20.33, 
           32345900}}, {{2012, 8, 9}, {
          20.263874643874647`, 20.43806267806268, 20.263874643874647`, 20.38, 
           31159700}}, {{2012, 8, 10}, {
          20.323222748815166`, 20.42, 20.265156398104267`, 20.42, 
           24419100}}, {{2012, 8, 13}, {
          20.358380181038587`, 20.377732253454024`, 20.2035636017151, 20.31, 
           26873600}}, {{2012, 8, 14}, {
          20.395453677172874`, 20.42447946513849, 20.22129894937918, 20.26, 
           30095000}}, {{2012, 8, 15}, {
          20.18324427480916, 20.34772900763359, 20.11551526717557, 20.28, 
           28870100}}, {{2012, 8, 16}, {
          20.195814726840858`, 20.457092636579574`, 20.147429928741094`, 
           20.37, 33598000}}, {{2012, 8, 17}, {
          20.33935238095238, 20.368380952380953`, 20.26194285714286, 20.32, 
           30032500}}, {{2012, 8, 20}, {
          20.269350215002387`, 20.33707596751075, 20.153248924988052`, 20.25, 
           27385500}}, {{2012, 8, 21}, {
          20.296143884892086`, 20.373573141486812`, 20.131606714628298`, 
           20.18, 30438800}}, {{2012, 8, 22}, {
          20.100322425409047`, 20.197098171318576`, 20.04225697786333, 20.11, 
           28016800}}, {{2012, 8, 23}, {
          20.06675387596899, 20.115130813953485`, 19.960324612403095`, 19.97, 
           36538800}}, {{2012, 8, 24}, {
          19.92676442307692, 20.22677884615384, 19.888052884615384`, 20.13, 
           29338200}}, {{2012, 8, 27}, {
          20.15096402877698, 20.276786570743404`, 20.121928057553955`, 20.18, 
           28775600}}, {{2012, 8, 28}, {
          20.09160980297934, 20.246458433445465`, 20.09160980297934, 20.14, 
           25912400}}, {{2012, 8, 29}, {
          20.15, 20.275816522574445`, 20.140321805955807`, 20.15, 
           19925800}}, {{2012, 8, 30}, {
          20.04740310077519, 20.10545542635659, 19.9506492248062, 19.97, 
           21237800}}, {{2012, 8, 31}, {
          20.08838242394978, 20.156117817479473`, 19.94323515210043, 20.04, 
           29679000}}, {{2012, 9, 4}, {
          19.966138469039493`, 20.024207703559238`, 19.820965382740127`, 
           19.85, 38173600}}, {{2012, 9, 5}, {
          19.883244552058112`, 20.096106537530268`, 19.84454237288136, 19.98, 
           33033500}}, {{2012, 9, 6}, {
          20.19424683247302, 20.629676208352887`, 20.17489441576725, 20.62, 
           53178600}}, {{2012, 9, 7}, {
          20.628754052802222`, 20.89, 20.609402501157945`, 20.89, 
           36379800}}, {{2012, 9, 10}, {
          20.79, 20.954539106145248`, 20.741606145251396`, 20.79, 
           33672300}}, {{2012, 9, 11}, {
          20.7932422417786, 20.9867577582214, 20.70616025937934, 20.89, 
           33593100}}, {{2012, 9, 12}, {
          20.967135678391962`, 21.218702603928733`, 20.957460027409777`, 
           21.18, 43006000}}, {{2012, 9, 13}, {
          21.0680608537693, 21.522906448683013`, 21.048705722070842`, 21.31, 
           111794200}}, {{2012, 9, 14}, {
          21.487109905020354`, 21.651650836725466`, 21.27417458163727, 21.4, 
           100148400}}, {{2012, 9, 17}, {
          21.22386394557823, 21.34, 21.194829931972787`, 21.34, 79283200}}, {{
          2012, 9, 18}, {
          21.278093525179855`, 21.52, 21.24906474820144, 21.52, 38831200}}, {{
          2012, 9, 19}, {
          21.584172982612575`, 21.768074008024968`, 21.535777975925104`, 
           21.71, 40462600}}, {{2012, 9, 20}, {
          21.63599197503344, 21.909001337494427`, 21.567739634418192`, 21.87, 
           43677000}}, {{2012, 9, 21}, {
          21.989502885042164`, 22.126023080337326`, 21.901739902352418`, 
           21.97, 66551700}}, {{2012, 9, 24}, {
          21.838998211091234`, 21.887745974955276`, 21.74150268336315, 21.8, 
           36799800}}, {{2012, 9, 25}, {
          21.8380277902286, 22.11112505602869, 21.750246526221428`, 21.76, 
           47039200}}, {{2012, 9, 26}, {
          21.608506787330317`, 21.69626696832579, 21.520746606334843`, 21.55, 
           41123300}}, {{2012, 9, 27}, {
          21.682287725472943`, 22.286739991201056`, 21.575046194456664`, 
           22.16, 67300400}}, {{2012, 9, 28}, {
          22.20852047556142, 22.393835314839276`, 22.062219286657857`, 22.15, 
           70926100}}, {{2012, 10, 1}, {
          22.161999123191585`, 22.42525208241999, 22.14249890398948, 22.24, 
           42550700}}, {{2012, 10, 2}, {
          22.3564984642387, 22.414997806055286`, 22.142000877577885`, 22.22, 
           45297400}}, {{2012, 10, 3}, {
          22.29124399825404, 22.40825840244435, 22.154727193365343`, 22.34, 
           32929400}}, {{2012, 10, 4}, {
          22.38, 22.477516339869283`, 22.204470588235292`, 22.38, 
           40344600}}, {{2012, 10, 5}, {
          22.46200692041522, 22.598494809688578`, 22.423010380622834`, 22.54, 
           38312500}}, {{2012, 10, 8}, {
          22.301243455497385`, 22.418259162303666`, 22.281740837696336`, 
           22.35, 24202200}}, {{2012, 10, 9}, {
          22.37207780725022, 22.401335101679926`, 22.04049513704686, 22.06, 
           39176000}}, {{2012, 10, 10}, {
          22.04550601872492, 22.17226036558181, 21.850499331252788`, 21.87, 
           32784100}}, {{2012, 10, 11}, {
          22.02800977343403, 22.14502443358507, 21.92074633496224, 21.95, 
           24161800}}, {{2012, 10, 12}, {
          22.017508896797153`, 22.144270462633454`, 21.851743772241996`, 
           21.92, 32954600}}, {{2012, 10, 15}, {
          21.98247349823321, 22.138515901060067`, 21.933710247349822`, 22.08, 
           29578600}}, {{2012, 10, 16}, {
          22.226289752650175`, 22.314063604240282`, 22.01173144876325, 22.08, 
           35668800}}, {{2012, 10, 17}, {
          22.203483195111303`, 22.349751200349196`, 22.154727193365343`, 
           22.34, 28272500}}, {{2012, 10, 18}, {
          22.24, 22.50325295922841, 22.230249890398948`, 22.24, 43140700}}, {{
          2012, 10, 19}, {
          21.9480163413527, 21.967517022242397`, 21.323994552882436`, 21.48, 
           107879900}}, {{2012, 10, 22}, {
          21.316018433179725`, 21.40377880184332, 20.72119815668203, 21.16, 
           86735100}}, {{2012, 10, 23}, {
          20.81825657894737, 20.867011278195488`, 20.671992481203006`, 20.75, 
           56297300}}, {{2012, 10, 24}, {
          20.8957619943556, 20.925014111006586`, 20.71049858889934, 20.73, 
           42295500}}, {{2012, 10, 25}, {
          20.964016933207905`, 21.032271872060207`, 20.505733772342428`, 
           20.73, 45769600}}, {{2012, 10, 26}, {
          20.657991473235434`, 20.862719090478446`, 20.541004263382284`, 
           20.58, 42827400}}, {{2012, 10, 31}, {
          20.735061728395063`, 20.79358024691358, 20.452222222222222`, 20.54, 
           39179300}}, {{2012, 11, 1}, {
          20.50769915651359, 20.858758200562324`, 20.497947516401123`, 20.81, 
           46231300}}, {{2012, 11, 2}, {
          20.994528390427032`, 21.14079774753637, 20.731243547630225`, 20.78, 
           47475200}}, {{2012, 11, 5}, {
          20.67519850537132, 20.938514712751047`, 20.67519850537132, 20.88, 
           30000100}}, {{2012, 11, 6}, {
          20.972000926354795`, 21.235247799907366`, 20.913501621120886`, 
           21.05, 32733200}}, {{2012, 11, 7}, {
          20.824230951254144`, 20.980217699952675`, 20.54150496923805, 20.6, 
           45253400}}, {{2012, 11, 8}, {
          20.633279080899953`, 20.66253231211106, 20.36024892292963, 20.37, 
           40770700}}, {{2012, 11, 9}, {
          20.245942857142857`, 20.77257142857143, 20.18742857142857, 20.48, 
           40306800}}, {{2012, 11, 12}, {
          20.51626615605553, 20.613776926759215`, 20.36024892292963, 20.37, 
           21816400}}, {{2012, 11, 13}, {
          20.091972920696332`, 20.433341392649908`, 20.06271276595745, 20.17, 
           41073300}}, {{2012, 11, 14}, {
          20.21200899550225, 20.231509245377314`, 19.451499250374813`, 19.51, 
           65539500}}, {{2012, 11, 15}, {
          19.403988035892322`, 19.72576271186441, 19.403988035892322`, 19.56, 
           51760300}}, {{2012, 11, 16}, {
          19.601240694789084`, 19.689007444168734`, 19.376947890818858`, 
           19.65, 45287500}}, {{2012, 11, 19}, {
          19.90617134559535, 20.208518877057113`, 19.88666505324298, 20.15, 
           38283400}}, {{2012, 11, 20}, {
          20.15876333656644, 20.178268671193017`, 19.8661833171678, 20.11, 
           26845900}}, {{2012, 11, 21}, {
          20.189506769825922`, 20.22852030947776, 20.06271276595745, 20.17, 
           41020400}}, {{2012, 11, 23}, {
          20.295684410646388`, 20.52, 20.217661596958177`, 20.52, 
           35456500}}, {{2012, 11, 26}, {
          20.364444444444445`, 20.549753086419752`, 20.35469135802469, 20.54, 
           47741300}}, {{2012, 11, 27}, {
          20.515764254911353`, 20.67177767129851, 20.330498322951605`, 20.35, 
           33001700}}, {{2012, 11, 28}, {
          20.229777672658468`, 20.619749290444656`, 19.9860454115421, 20.61, 
           34782700}}, {{2012, 11, 29}, {
          20.70724088973024, 20.824230951254144`, 20.42451490771415, 20.6, 
           27632800}}, {{2012, 11, 30}, {
          20.60974917179366, 20.726739233317563`, 20.512257453857078`, 20.6, 
           37857000}}, {{2012, 12, 3}, {
          20.651008645533143`, 20.699759846301635`, 20.280499519692604`, 20.3,
            29981900}}, {{2012, 12, 4}, {
          20.34975071907958, 20.486260786193675`, 20.19373921380633, 20.34, 
           36817200}}, {{2012, 12, 5}, {
          20.38798869524258, 20.8267545925577, 20.339236928874232`, 20.7, 
           46466500}}, {{2012, 12, 6}, {
          20.67421619092185, 20.859503977538605`, 20.557192325690217`, 20.84, 
           32751200}}, {{2012, 12, 7}, {
          20.910493942218082`, 20.94950605778192, 20.71543336439888, 20.93, 
           33548600}}, {{2012, 12, 10}, {
          20.899008882655444`, 20.967274427302478`, 20.830743338008414`, 
           20.86, 27604300}}, {{2012, 12, 11}, {
          20.940753138075312`, 21.203974895397486`, 20.823765690376565`, 
           20.97, 45757200}}, {{2012, 12, 12}, {
          21.074214876033054`, 21.40578512396694, 21.035206611570246`, 21.24, 
           42413600}}, {{2012, 12, 13}, {
          21.197002775208137`, 21.37250693802035, 21.011748381128584`, 21.08, 
           33966000}}, {{2012, 12, 14}, {
          21.07024976873265, 21.21650323774283, 21.011748381128584`, 21.08, 
           47536600}}, {{2012, 12, 17}, {
          21.146019151846783`, 21.399498404012764`, 21.146019151846783`, 
           21.38, 48483700}}, {{2012, 12, 18}, {
          21.30601659751037, 21.36452282157676, 20.876970954356842`, 21.15, 
           81119200}}, {{2012, 12, 19}, {
          21.104407425035696`, 21.123912422655877`, 20.450990004759635`, 
           20.49, 92330700}}, {{2012, 12, 20}, {
          20.57226128266033, 20.89693111638955, 20.532907363420428`, 20.71, 
           50831400}}, {{2012, 12, 21}, {
          20.510632183908047`, 20.658261494252873`, 20.235057471264366`, 
           20.55, 80833800}}, {{2012, 12, 24}, {
          20.460475504322766`, 20.62778097982709, 20.421109510086453`, 20.49, 
           15097200}}, {{2012, 12, 26}, {
          20.479364467982666`, 20.60729898892634, 20.380953298026, 20.44, 
           28557100}}, {{2012, 12, 27}, {
          20.468245529241177`, 20.537129047849202`, 20.094306428226197`, 
           20.36, 38330700}}, {{2012, 12, 28}, {
          20.119838551859097`, 20.375640900195695`, 20.1001614481409, 20.11, 
           32403400}}, {{2012, 12, 31}, {
          19.961338732729867`, 20.65983801810386, 19.931824678418295`, 20.65, 
           58785000}}, {{2013, 1, 2}, {
          21.167291471415183`, 21.196813495782568`, 20.8622305529522, 21., 
           46089500}}, {{2013, 1, 3}, {
          21.133876777251185`, 21.143715639810427`, 20.710805687203795`, 
           20.76, 48509100}}, {{2013, 1, 4}, {
          20.86983962264151, 20.91903773584906, 20.781283018867928`, 20.86, 
           29802600}}, {{2013, 1, 7}, {
          20.819517274017986`, 20.87855182205395, 20.622735447231427`, 20.79, 
           32746700}}, {{2013, 1, 8}, {
          20.766842105263162`, 20.786526315789477`, 20.353473684210527`, 
           20.57, 40045500}}, {{2013, 1, 9}, {
          20.708582338902147`, 20.738109785202866`, 20.600315035799525`, 
           20.62, 28540500}}, {{2013, 1, 10}, {
          20.702087860179493`, 20.88903637222484, 20.623372697213032`, 20.83, 
           33348200}}, {{2013, 1, 11}, {
          20.87855182205395, 20.898230004732607`, 20.68176999526739, 20.79, 
           41839700}}, {{2013, 1, 14}, {
          20.83903409090909, 20.898068181818182`, 20.730804924242427`, 20.78, 
           31715900}}, {{2013, 1, 15}, {
          20.70256603773585, 20.86983962264151, 20.673047169811323`, 20.86, 
           26551000}}, {{2013, 1, 16}, {
          20.809517045454545`, 20.858712121212122`, 20.72096590909091, 20.78, 
           38932100}}, {{2013, 1, 17}, {
          20.88127699530516, 21.196169014084504`, 20.78287323943662, 20.96, 
           63851700}}, {{2013, 1, 18}, {
          21.591588021778588`, 21.83761796733213, 21.247146098003633`, 21.69, 
           113079400}}, {{2013, 1, 22}, {
          21.82729668332576, 21.846978646069967`, 21.55174920490686, 21.66, 
           55165800}}, {{2013, 1, 23}, {
          21.629361896080216`, 21.67856426618049, 21.40303099361896, 21.59, 
           47228500}}, {{2013, 1, 24}, {
          21.611428571428572`, 21.837777777777777`, 21.6015873015873, 21.7, 
           46991100}}, {{2013, 1, 25}, {
          21.920161507402426`, 21.949676985195154`, 21.752907133243607`, 
           21.93, 41919800}}, {{2013, 1, 28}, {
          22.080960000000005`, 22.179360000000003`, 21.903840000000002`, 
           22.14, 49558400}}, {{2013, 1, 29}, {
          22.13016, 22.21872, 22.041600000000003`, 22.14, 34148000}}, {{2013, 
          1, 30}, {
          22.155303643724697`, 22.184817813765186`, 21.87, 21.87, 
           36200400}}, {{2013, 1, 31}, {
          21.85113105924596, 22.03806104129264, 21.8216157989228, 21.92, 
           34427700}}, {{2013, 2, 1}, {
          22.073023872679045`, 22.27968169761273, 21.964774535809017`, 22.26, 
           43840300}}, {{2013, 2, 4}, {
          22.0483863738234, 22.127095472882115`, 21.920484087852984`, 21.95, 
           35836600}}, {{2013, 2, 5}, {
          22.120958296362023`, 22.258722271517303`, 22.091437444543033`, 
           22.18, 30917700}}, {{2013, 2, 6}, {
          22.109518716577536`, 22.139037433155078`, 21.952085561497324`, 
           22.08, 42985800}}, {{2013, 2, 7}, {
          22.139679715302492`, 22.14951957295374, 21.913362989323847`, 22.12, 
           38325900}}, {{2013, 2, 8}, {
          22.14, 22.19904, 22.0908, 22.14, 24424600}}, {{2013, 2, 11}, {
          22.129358574610244`, 22.14903786191537, 21.99160356347439, 22.09, 
           19738700}}, {{2013, 2, 12}, {
          22.121594331266607`, 22.288883968113375`, 22.121594331266607`, 
           22.22, 34297500}}, {{2013, 2, 13}, {
          22.744429243266353`, 23.108576314664386`, 22.675536554082942`, 
           23.02, 84926900}}, {{2013, 2, 14}, {
          22.882528833831696`, 23.11873558308415, 22.74474156343443, 23.04, 
           53996500}}, {{2013, 2, 15}, {
          23.106981537140406`, 23.175869471876346`, 22.86095319879777, 22.92, 
           39283000}}, {{2013, 2, 19}, {
          23.04528, 23.37, 23.03544, 23.37, 41219000}}, {{2013, 2, 20}, {
          23.33525843656557, 23.374626228107648`, 22.980948312686888`, 23.04, 
           38107400}}, {{2013, 2, 21}, {
          23.000619088564054`, 23.169303525365432`, 22.9410834049871, 23.08, 
           47811200}}, {{2013, 2, 22}, {
          23.1603249251817, 23.259512612227446`, 23.041299700726807`, 23.2, 
           27836300}}, {{2013, 2, 25}, {
          23.314555019728193`, 23.344318281455507`, 22.630000000000003`, 
           22.63, 51619800}}, {{2013, 2, 26}, {
          22.790624728850325`, 22.96921908893709, 22.73109327548807, 22.87, 
           41316300}}, {{2013, 2, 27}, {
          22.83284552845528, 23.20975609756097, 22.813008130081297`, 23.18, 
           29676400}}, {{2013, 2, 28}, {
          23.188837209302328`, 23.27813953488372, 23.02015503875969, 23.04, 
           39714600}}, {{2013, 3, 1}, {
          22.841319534282018`, 23.158835705045277`, 22.821474773609314`, 
           23.01, 41226900}}, {{2013, 3, 4}, {
          22.970928233777396`, 23.09992264718522, 22.851856467554793`, 23.09, 
           25457800}}, {{2013, 3, 5}, {
          23.27104705383637, 23.519033488766425`, 23.251208139041967`, 23.4, 
           35728000}}, {{2013, 3, 6}, {
          23.648635403464297`, 23.648635403464297`, 23.48, 23.48, 
           31539100}}, {{2013, 3, 7}, {
          23.509839527027022`, 23.638796452702696`, 23.480080236486486`, 
           23.49, 22955700}}, {{2013, 3, 8}, {
          23.669280605805636`, 23.708960875052586`, 23.49071939419436, 23.58, 
           28952100}}, {{2013, 3, 11}, {
          23.499436917866216`, 23.558954276037255`, 23.261367485182046`, 
           23.43, 34947200}}, {{2013, 3, 12}, {
          23.39853908586074, 23.408457923964118`, 23.140649295173, 23.22, 
           36593000}}, {{2013, 3, 13}, {
          23.250404427415926`, 23.329757343550448`, 23.21072796934866, 23.3, 
           24152400}}, {{2013, 3, 14}, {
          23.361122836639932`, 23.569438581680036`, 23.321443647108484`, 23.5,
            34629800}}, {{2013, 3, 15}, {
          23.25, 23.527730375426618`, 23.17064846416382, 23.25, 58857200}}, {{
          2013, 3, 18}, {
          22.990619354838714`, 23.169225806451614`, 22.950929032258063`, 
           23.07, 33700000}}, {{2013, 3, 19}, {
          23.12015437392796, 23.17969125214408, 22.991157804459693`, 23.14, 
           36150200}}, {{2013, 3, 20}, {
          23.537813299232738`, 23.607246376811595`, 23.141052855924976`, 
           23.27, 39254000}}, {{2013, 3, 21}, {
          23.238995276942894`, 23.417604121940748`, 23.109999999999996`, 
           23.11, 38543900}}, {{2013, 3, 22}, {
          23.130406504065036`, 23.20975609756097, 23.090731707317072`, 23.18, 
           30606100}}, {{2013, 3, 25}, {
          23.268373493975904`, 23.298141135972465`, 22.87147160068847, 23.06, 
           41684400}}, {{2013, 3, 26}, {
          23.088832179930794`, 23.118598615916955`, 22.830856401384082`, 
           22.94, 32353500}}, {{2013, 3, 27}, {
          22.840623376623377`, 22.95968831168831, 22.671948051948053`, 22.92, 
           27492500}}, {{2013, 3, 28}, {
          22.95984429065744, 23.019377162629755`, 22.81101211072664, 22.94, 
           31151000}}, {{2013, 4, 1}, {
          22.85038994800693, 22.91984402079723, 22.79085788561525, 22.9, 
           27449700}}, {{2013, 4, 2}, {
          22.991311053984575`, 23.189768637532133`, 22.92185089974293, 23.16, 
           29180100}}, {{2013, 4, 3}, {
          23.19702608695652, 23.21686956521739, 22.740626086956524`, 22.82, 
           52570300}}, {{2013, 4, 4}, {
          22.830545927209705`, 22.949610051993066`, 22.780935875216638`, 22.9,
            30472100}}, {{2013, 4, 5}, {
          22.621020497165286`, 22.75992150021806, 22.58133449629307, 22.75, 
           31402200}}, {{2013, 4, 8}, {
          22.870544982698963`, 22.94, 22.652257785467125`, 22.94, 
           30493600}}, {{2013, 4, 9}, {
          23.068516912402426`, 23.068516912402426`, 22.721248915871637`, 
           22.88, 31668200}}, {{2013, 4, 10}, {
          22.913867684478376`, 23.45943596268024, 22.87418999151824, 23.39, 
           39772300}}, {{2013, 4, 11}, {
          23.36032217041119, 23.528952946163628`, 23.241288681644765`, 23.4, 
           27084400}}, {{2013, 4, 12}, {
          23.29975703324808, 23.39894714407502, 23.141052855924976`, 23.27, 
           27234300}}, {{2013, 4, 15}, {
          23.096291100394566`, 23.11613327487944, 22.630000000000003`, 22.63, 
           46453800}}, {{2013, 4, 16}, {
          22.890233766233766`, 22.92, 22.72155844155844, 22.92, 36016700}}, {{
          2013, 4, 17}, {
          22.778418277680135`, 22.847864674868188`, 22.470869947275915`, 
           22.58, 42672900}}, {{2013, 4, 18}, {
          22.579285399206, 22.668570798412, 22.39079400088222, 22.49, 
           41170900}}, {{2013, 4, 19}, {
          21.768514942528736`, 21.85781149425287, 21.44109425287356, 21.58, 
           108837900}}, {{2013, 4, 22}, {
          21.497451990632317`, 21.507372365339577`, 20.94191100702576, 21.18, 
           87828900}}, {{2013, 4, 23}, {
          21.37960465116279, 21.518497674418605`, 21.191106976744184`, 21.33, 
           65489600}}, {{2013, 4, 24}, {
          21.522090163934426`, 21.859458105646628`, 21.482399817850634`, 
           21.79, 51506700}}, {{2013, 4, 25}, {
          22.037986332574036`, 22.05783143507973, 21.74030979498861, 21.78, 
           41462900}}, {{2013, 4, 26}, {
          21.801864025213867`, 22.218460153084195`, 21.791945069788383`, 
           22.03, 47012500}}, {{2013, 4, 29}, {
          22.129676695105523`, 22.139595868881905`, 21.82218230803772, 22.09, 
           36531800}}, {{2013, 4, 30}, {
          22.11, 22.1992732166891, 22.03064602960969, 22.11, 34054800}}, {{
          2013, 5, 1}, {
          21.920406320541762`, 22.168374717832958`, 21.920406320541762`, 
           21.97, 39201600}}, {{2013, 5, 2}, {
          22.070564516129032`, 22.14, 21.971370967741933`, 22.14, 
           27651500}}, {{2013, 5, 3}, {
          22.39, 22.667766947275148`, 22.370159503766065`, 22.39, 
           45523300}}, {{2013, 5, 6}, {
          22.38015943312666, 22.45952170062002, 22.14207263064659, 22.4, 
           28563900}}, {{2013, 5, 7}, {
          22.509920634920633`, 22.60912698412698, 22.44047619047619, 22.5, 
           28211700}}, {{2013, 5, 8}, {
          22.502581486310298`, 22.83992177314211, 22.443050847457627`, 22.83, 
           39977300}}, {{2013, 5, 9}, {
          22.808340649692713`, 22.91747146619842, 22.510711150131694`, 22.6, 
           29974300}}, {{2013, 5, 10}, {
          22.591021834061134`, 22.729921397379915`, 22.412436681222708`, 
           22.72, 35117300}}, {{2013, 5, 13}, {
          22.67992122538293, 22.699763676148795`, 22.441811816192562`, 22.67, 
           30283800}}, {{2013, 5, 14}, {
          22.671251629726207`, 22.889530638852673`, 22.631564537157754`, 
           22.83, 39592300}}, {{2013, 5, 15}, {
          22.86154905335628, 23.069922547332187`, 22.732555938037866`, 23.06, 
           40153000}}, {{2013, 5, 16}, {
          22.921314997851315`, 23.16938117748174, 22.921314997851315`, 23.09, 
           33023300}}, {{2013, 5, 17}, {
          23.081538789428816`, 23.289838022165387`, 23.012105711849955`, 
           23.27, 41037700}}, {{2013, 5, 20}, {
          23.270886720407294`, 23.389919389053876`, 23.241128553245648`, 
           23.38, 32884800}}, {{2013, 5, 21}, {
          23.400562130177512`, 23.58903634826712, 23.400562130177512`, 23.47, 
           33815000}}, {{2013, 5, 22}, {
          23.590637049455157`, 23.937849958088854`, 23.56087594300084, 23.67, 
           68514400}}, {{2013, 5, 23}, {
          23.33112426035503, 23.559277261200336`, 23.261686390532542`, 23.47, 
           44383600}}, {{2013, 5, 24}, {
          23.3102422439439, 23.478869528261797`, 23.3003229919252, 23.34, 
           41015200}}, {{2013, 5, 28}, {
          23.578631355932202`, 23.648067796610167`, 23.39016101694915, 23.41, 
           47323000}}, {{2013, 5, 29}, {
          23.231768189509307`, 23.50951776649746, 23.21192893401015, 23.45, 
           39236500}}, {{2013, 5, 30}, {
          23.39016101694915, 23.56871186440678, 23.310805084745763`, 23.41, 
           29347100}}, {{2013, 5, 31}, {
          23.407915951972555`, 23.606372212692968`, 23.13007718696398, 23.14, 
           49247600}}, {{2013, 6, 3}, {
          23.18217005076142, 23.588874788494078`, 23.132571912013535`, 23.45, 
           45218400}}, {{2013, 6, 4}, {
          23.400562130177512`, 23.569196956889265`, 23.22200760777684, 23.47, 
           38701300}}, {{2013, 6, 5}, {
          23.368224699828474`, 23.397993138936535`, 23.030849056603774`, 
           23.14, 44756200}}, {{2013, 6, 6}, {
          23.06105645851155, 23.19991873396065, 22.9122754491018, 23.19, 
           42677500}}, {{2013, 6, 7}, {
          23.35254819782062, 23.759283319362954`, 23.28310561609388, 23.67, 
           49041200}}, {{2013, 6, 10}, {
          23.689201009251473`, 23.728881412952063`, 23.45111858704794, 23.59, 
           41626500}}, {{2013, 6, 11}, {
          23.300725190839696`, 23.49911365564038, 23.290805767599664`, 23.39, 
           36183000}}, {{2013, 6, 12}, {
          23.508382978723404`, 23.538140425531914`, 23.230646808510638`, 
           23.31, 33842000}}, {{2013, 6, 13}, {
          23.261845439189184`, 23.599117398648644`, 23.152728040540538`, 
           23.49, 34930500}}, {{2013, 6, 14}, {
          23.488707482993195`, 23.55814200680272, 23.27048469387755, 23.33, 
           27846000}}, {{2013, 6, 17}, {
          23.560159865376523`, 23.6593605384939, 23.460959192259146`, 23.58, 
           39278300}}, {{2013, 6, 18}, {
          23.64390464447185, 24.259062885326763`, 23.58437320180847, 24.14, 
           72766900}}, {{2013, 6, 19}, {
          24.008256880733942`, 24.15706839032527, 23.79, 23.79, 46082200}}, {{
          2013, 6, 20}, {23.63, 23.69, 23.2, 23.25, 62733200}}, {{2013, 6, 
          21}, {23.579999999999995`, 23.639999999999997`, 23.209999999999997`,
            23.36, 65025200}}, {{2013, 6, 24}, {
          23.12, 23.15, 22.76, 22.93, 48760800}}, {{2013, 6, 25}, {
          23.169999999999998`, 23.249999999999996`, 22.939999999999998`, 
           23.11, 36569100}}, {{2013, 6, 26}, {
          23.43, 23.44, 23.02, 23.25, 32531700}}, {{2013, 6, 27}, {
          23.41, 23.48, 23.26, 23.32, 30867900}}, {{2013, 6, 28}, {
          23.32, 23.44, 23.16, 23.19, 45923200}}, {{2013, 7, 1}, {
          23.209999999999997`, 23.639999999999997`, 23.189999999999998`, 
           23.34, 35784800}}, {{2013, 7, 2}, {
          23.27, 23.34, 22.88, 22.9, 47571200}}, {{2013, 7, 3}, {
          22.83, 22.98, 22.76, 22.91, 21448500}}, {{2013, 7, 5}, {
          23.17, 23.24, 22.95, 23.24, 22688900}}, {{2013, 7, 8}, {
          23.36, 23.53, 23.27, 23.32, 35481100}}, {{2013, 7, 9}, {
          23.52, 23.8, 23.51, 23.62, 31541400}}, {{2013, 7, 10}, {
          23.719999999999995`, 23.729999999999997`, 23.359999999999996`, 
           23.54, 28457100}}, {{2013, 7, 11}, {
          23.91, 23.96, 23.63, 23.94, 32618400}}, {{2013, 7, 12}, {
          23.99, 24., 23.59, 23.76, 33257700}}, {{2013, 7, 15}, {
          23.73, 23.74, 23.56, 23.63, 35853500}}, {{2013, 7, 16}, {
          23.659999999999997`, 23.669999999999998`, 23.339999999999996`, 
           23.43, 38192400}}, {{2013, 7, 17}, {
          23.539999999999996`, 23.609999999999996`, 23.429999999999996`, 
           23.54, 26858500}}, {{2013, 7, 18}, {
          23.6, 23.94, 23.56, 23.63, 41438200}}, {{2013, 7, 19}, {
          24.21, 24.95, 24.1, 24.72, 103708900}}, {{2013, 7, 22}, {
          24.77, 24.92, 24.73, 24.86, 41560800}}, {{2013, 7, 23}, {
          24.87, 24.88, 24.63, 24.71, 32553000}}, {{2013, 7, 24}, {
          24.79, 24.84, 24.56, 24.62, 27485000}}, {{2013, 7, 25}, {
          24.61, 24.69, 24.52, 24.69, 29951700}}}, 
        System`TradingChartDump`$markerstyle$541720 = 1, 
        System`TradingChartDump`$controlmin$541720 = 0.5, 
        System`TradingChartDump`$controlmax$541720 = 250.5, 
        System`TradingChartDump`$datescope$541720 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$541720 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$541720, 
        System`TradingChartDump`$max$541720, 
        System`TradingChartDump`$ohlclabel$541720 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541720, 
              System`TradingChartDump`$opens$541720]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541720, 
              System`TradingChartDump`$highs$541720]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541720, 
              System`TradingChartDump`$lows$541720]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541720, 
              System`TradingChartDump`$closes$541720]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541720, 
              System`TradingChartDump`$visdates$541720]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$541720 = {}, 
        System`TradingChartDump`$subpricegridlines$541720 = Automatic, 
        System`TradingChartDump`$overlaypoint$541720, 
        System`TradingChartDump`$overlayvalue$541720, 
        System`TradingChartDump`$subplotvalue$541720, 
        System`TradingChartDump`$opts$541720 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "GE", " with ", "TRIX", "(", 15, ",",
             Null, ",", Null, ",", Null, ")"}], ImageSize -> {450, 310}, 
         AlignmentPoint -> Center, AspectRatio -> GoldenRatio^(-1), Axes -> 
         Automatic, AxesLabel -> None, AxesOrigin -> Automatic, 
         AxesStyle -> {}, Background -> None, BaselinePosition -> Automatic, 
         BaseStyle -> {}, ColorOutput -> Automatic, ContentSelectable -> 
         Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$541720 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmglczWkXx2/W7PuSl9RLZClS3WtQPcooqUkLiVT3tt5uC5ooBo09IVt6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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyFmndUVNcWxkfFhihRiF0CAoKABikjiOJRmgrCUJUqMDAgzUKMihKwRohi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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$541720 = 
        System`TradingChartDump`$staticindicatorpos$541720, 
        System`TradingChartDump`$length$541720 = 250, 
        System`TradingChartDump`$gridlinesflag$541720 = True, 
        System`TradingChartDump`$opens$541720 = 
        Dispatch[{
         1 -> 19.55`4., 2 -> 19.97`4., 3 -> 20.12`4., 4 -> 20.08`4., 5 -> 
          20.19`4., 6 -> 19.86`4., 7 -> 20.14`4., 8 -> 20.29`4., 9 -> 
          20.46`4., 10 -> 20.37`4., 11 -> 20.26`4., 12 -> 20.32`4., 13 -> 
          20.36`4., 14 -> 20.4`4., 15 -> 20.18`4., 16 -> 20.2`4., 17 -> 
          20.34`4., 18 -> 20.27`4., 19 -> 20.3`4., 20 -> 20.1`4., 21 -> 
          20.07`4., 22 -> 19.93`4., 23 -> 20.15`4., 24 -> 20.09`4., 25 -> 
          20.15`4., 26 -> 20.05`4., 27 -> 20.09`4., 28 -> 19.97`4., 29 -> 
          19.88`4., 30 -> 20.19`4., 31 -> 20.63`4., 32 -> 20.79`4., 33 -> 
          20.79`4., 34 -> 20.97`4., 35 -> 21.07`4., 36 -> 21.49`4., 37 -> 
          21.22`4., 38 -> 21.28`4., 39 -> 21.58`4., 40 -> 21.64`4., 41 -> 
          21.99`4., 42 -> 21.84`4., 43 -> 21.84`4., 44 -> 21.61`4., 45 -> 
          21.68`4., 46 -> 22.21`4., 47 -> 22.16`4., 48 -> 22.36`4., 49 -> 
          22.29`4., 50 -> 22.38`4., 51 -> 22.46`4., 52 -> 22.3`4., 53 -> 
          22.37`4., 54 -> 22.05`4., 55 -> 22.03`4., 56 -> 22.02`4., 57 -> 
          21.98`4., 58 -> 22.23`4., 59 -> 22.2`4., 60 -> 22.24`4., 61 -> 
          21.95`4., 62 -> 21.32`4., 63 -> 20.82`4., 64 -> 20.9`4., 65 -> 
          20.96`4., 66 -> 20.66`4., 67 -> 20.74`4., 68 -> 20.51`4., 69 -> 
          20.99`4., 70 -> 20.68`4., 71 -> 20.97`4., 72 -> 20.82`4., 73 -> 
          20.63`4., 74 -> 20.25`4., 75 -> 20.52`4., 76 -> 20.09`4., 77 -> 
          20.21`4., 78 -> 19.4`4., 79 -> 19.6`4., 80 -> 19.91`4., 81 -> 
          20.16`4., 82 -> 20.19`4., 83 -> 20.3`4., 84 -> 20.36`4., 85 -> 
          20.52`4., 86 -> 20.23`4., 87 -> 20.71`4., 88 -> 20.61`4., 89 -> 
          20.65`4., 90 -> 20.35`4., 91 -> 20.39`4., 92 -> 20.67`4., 93 -> 
          20.91`4., 94 -> 20.9`4., 95 -> 20.94`4., 96 -> 21.07`4., 97 -> 
          21.2`4., 98 -> 21.07`4., 99 -> 21.15`4., 100 -> 21.31`4., 101 -> 
          21.1`4., 102 -> 20.57`4., 103 -> 20.51`4., 104 -> 20.46`4., 105 -> 
          20.48`4., 106 -> 20.47`4., 107 -> 20.12`4., 108 -> 19.96`4., 109 -> 
          21.17`4., 110 -> 21.13`4., 111 -> 20.87`4., 112 -> 20.82`4., 113 -> 
          20.77`4., 114 -> 20.71`4., 115 -> 20.7`4., 116 -> 20.88`4., 117 -> 
          20.84`4., 118 -> 20.7`4., 119 -> 20.81`4., 120 -> 20.88`4., 121 -> 
          21.59`4., 122 -> 21.83`4., 123 -> 21.63`4., 124 -> 21.61`4., 125 -> 
          21.92`4., 126 -> 22.08`4., 127 -> 22.13`4., 128 -> 22.16`4., 129 -> 
          21.85`4., 130 -> 22.07`4., 131 -> 22.05`4., 132 -> 22.12`4., 133 -> 
          22.11`4., 134 -> 22.14`4., 135 -> 22.14`4., 136 -> 22.13`4., 137 -> 
          22.12`4., 138 -> 22.74`4., 139 -> 22.88`4., 140 -> 23.11`4., 141 -> 
          23.05`4., 142 -> 23.34`4., 143 -> 23.`4., 144 -> 23.16`4., 145 -> 
          23.31`4., 146 -> 22.79`4., 147 -> 22.83`4., 148 -> 23.19`4., 149 -> 
          22.84`4., 150 -> 22.97`4., 151 -> 23.27`4., 152 -> 23.65`4., 153 -> 
          23.51`4., 154 -> 23.67`4., 155 -> 23.5`4., 156 -> 23.4`4., 157 -> 
          23.25`4., 158 -> 23.36`4., 159 -> 23.25`4., 160 -> 22.99`4., 161 -> 
          23.12`4., 162 -> 23.54`4., 163 -> 23.24`4., 164 -> 23.13`4., 165 -> 
          23.27`4., 166 -> 23.09`4., 167 -> 22.84`4., 168 -> 22.96`4., 169 -> 
          22.85`4., 170 -> 22.99`4., 171 -> 23.2`4., 172 -> 22.83`4., 173 -> 
          22.62`4., 174 -> 22.87`4., 175 -> 23.07`4., 176 -> 22.91`4., 177 -> 
          23.36`4., 178 -> 23.3`4., 179 -> 23.1`4., 180 -> 22.89`4., 181 -> 
          22.78`4., 182 -> 22.58`4., 183 -> 21.77`4., 184 -> 21.5`4., 185 -> 
          21.38`4., 186 -> 21.52`4., 187 -> 22.04`4., 188 -> 21.8`4., 189 -> 
          22.13`4., 190 -> 22.11`4., 191 -> 21.92`4., 192 -> 22.07`4., 193 -> 
          22.39`4., 194 -> 22.38`4., 195 -> 22.51`4., 196 -> 22.5`4., 197 -> 
          22.81`4., 198 -> 22.59`4., 199 -> 22.68`4., 200 -> 22.67`4., 201 -> 
          22.86`4., 202 -> 22.92`4., 203 -> 23.08`4., 204 -> 23.27`4., 205 -> 
          23.4`4., 206 -> 23.59`4., 207 -> 23.33`4., 208 -> 23.31`4., 209 -> 
          23.58`4., 210 -> 23.23`4., 211 -> 23.39`4., 212 -> 23.41`4., 213 -> 
          23.18`4., 214 -> 23.4`4., 215 -> 23.37`4., 216 -> 23.06`4., 217 -> 
          23.35`4., 218 -> 23.69`4., 219 -> 23.3`4., 220 -> 23.51`4., 221 -> 
          23.26`4., 222 -> 23.49`4., 223 -> 23.56`4., 224 -> 23.64`4., 225 -> 
          24.01`4., 226 -> 23.63`4., 227 -> 23.58`4., 228 -> 23.12`4., 229 -> 
          23.17`4., 230 -> 23.43`4., 231 -> 23.41`4., 232 -> 23.32`4., 233 -> 
          23.21`4., 234 -> 23.27`4., 235 -> 22.83`4., 236 -> 23.17`4., 237 -> 
          23.36`4., 238 -> 23.52`4., 239 -> 23.72`4., 240 -> 23.91`4., 241 -> 
          23.99`4., 242 -> 23.73`4., 243 -> 23.66`4., 244 -> 23.54`4., 245 -> 
          23.6`4., 246 -> 24.21`4., 247 -> 24.77`4., 248 -> 24.87`4., 249 -> 
          24.79`4., 250 -> 24.61`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$541720 = 
        Dispatch[{
         1 -> 20.04`4., 2 -> 20.33`4., 3 -> 20.24`4., 4 -> 20.22`4., 5 -> 
          20.27`4., 6 -> 20.03`4., 7 -> 20.32`4., 8 -> 20.49`4., 9 -> 
          20.51`4., 10 -> 20.41`4., 11 -> 20.44`4., 12 -> 20.42`4., 13 -> 
          20.38`4., 14 -> 20.42`4., 15 -> 20.35`4., 16 -> 20.46`4., 17 -> 
          20.37`4., 18 -> 20.34`4., 19 -> 20.37`4., 20 -> 20.2`4., 21 -> 
          20.12`4., 22 -> 20.23`4., 23 -> 20.28`4., 24 -> 20.25`4., 25 -> 
          20.28`4., 26 -> 20.11`4., 27 -> 20.16`4., 28 -> 20.02`4., 29 -> 
          20.1`4., 30 -> 20.63`4., 31 -> 20.89`4., 32 -> 20.95`4., 33 -> 
          20.99`4., 34 -> 21.22`4., 35 -> 21.52`4., 36 -> 21.65`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.77`4., 40 -> 21.91`4., 41 -> 
          22.13`4., 42 -> 21.89`4., 43 -> 22.11`4., 44 -> 21.7`4., 45 -> 
          22.29`4., 46 -> 22.39`4., 47 -> 22.43`4., 48 -> 22.41`4., 49 -> 
          22.41`4., 50 -> 22.48`4., 51 -> 22.6`4., 52 -> 22.42`4., 53 -> 
          22.4`4., 54 -> 22.17`4., 55 -> 22.15`4., 56 -> 22.14`4., 57 -> 
          22.14`4., 58 -> 22.31`4., 59 -> 22.35`4., 60 -> 22.5`4., 61 -> 
          21.97`4., 62 -> 21.4`4., 63 -> 20.87`4., 64 -> 20.93`4., 65 -> 
          21.03`4., 66 -> 20.86`4., 67 -> 20.79`4., 68 -> 20.86`4., 69 -> 
          21.14`4., 70 -> 20.94`4., 71 -> 21.24`4., 72 -> 20.98`4., 73 -> 
          20.66`4., 74 -> 20.77`4., 75 -> 20.61`4., 76 -> 20.43`4., 77 -> 
          20.23`4., 78 -> 19.73`4., 79 -> 19.69`4., 80 -> 20.21`4., 81 -> 
          20.18`4., 82 -> 20.23`4., 83 -> 20.52`4., 84 -> 20.55`4., 85 -> 
          20.67`4., 86 -> 20.62`4., 87 -> 20.82`4., 88 -> 20.73`4., 89 -> 
          20.7`4., 90 -> 20.49`4., 91 -> 20.83`4., 92 -> 20.86`4., 93 -> 
          20.95`4., 94 -> 20.97`4., 95 -> 21.2`4., 96 -> 21.41`4., 97 -> 
          21.37`4., 98 -> 21.22`4., 99 -> 21.4`4., 100 -> 21.36`4., 101 -> 
          21.12`4., 102 -> 20.9`4., 103 -> 20.66`4., 104 -> 20.63`4., 105 -> 
          20.61`4., 106 -> 20.54`4., 107 -> 20.38`4., 108 -> 20.66`4., 109 -> 
          21.2`4., 110 -> 21.14`4., 111 -> 20.92`4., 112 -> 20.88`4., 113 -> 
          20.79`4., 114 -> 20.74`4., 115 -> 20.89`4., 116 -> 20.9`4., 117 -> 
          20.9`4., 118 -> 20.87`4., 119 -> 20.86`4., 120 -> 21.2`4., 121 -> 
          21.84`4., 122 -> 21.85`4., 123 -> 21.68`4., 124 -> 21.84`4., 125 -> 
          21.95`4., 126 -> 22.18`4., 127 -> 22.22`4., 128 -> 22.18`4., 129 -> 
          22.04`4., 130 -> 22.28`4., 131 -> 22.13`4., 132 -> 22.26`4., 133 -> 
          22.14`4., 134 -> 22.15`4., 135 -> 22.2`4., 136 -> 22.15`4., 137 -> 
          22.29`4., 138 -> 23.11`4., 139 -> 23.12`4., 140 -> 23.18`4., 141 -> 
          23.37`4., 142 -> 23.37`4., 143 -> 23.17`4., 144 -> 23.26`4., 145 -> 
          23.34`4., 146 -> 22.97`4., 147 -> 23.21`4., 148 -> 23.28`4., 149 -> 
          23.16`4., 150 -> 23.1`4., 151 -> 23.52`4., 152 -> 23.65`4., 153 -> 
          23.64`4., 154 -> 23.71`4., 155 -> 23.56`4., 156 -> 23.41`4., 157 -> 
          23.33`4., 158 -> 23.57`4., 159 -> 23.53`4., 160 -> 23.17`4., 161 -> 
          23.18`4., 162 -> 23.61`4., 163 -> 23.42`4., 164 -> 23.21`4., 165 -> 
          23.3`4., 166 -> 23.12`4., 167 -> 22.96`4., 168 -> 23.02`4., 169 -> 
          22.92`4., 170 -> 23.19`4., 171 -> 23.22`4., 172 -> 22.95`4., 173 -> 
          22.76`4., 174 -> 22.94`4., 175 -> 23.07`4., 176 -> 23.46`4., 177 -> 
          23.53`4., 178 -> 23.4`4., 179 -> 23.12`4., 180 -> 22.92`4., 181 -> 
          22.85`4., 182 -> 22.67`4., 183 -> 21.86`4., 184 -> 21.51`4., 185 -> 
          21.52`4., 186 -> 21.86`4., 187 -> 22.06`4., 188 -> 22.22`4., 189 -> 
          22.14`4., 190 -> 22.2`4., 191 -> 22.17`4., 192 -> 22.14`4., 193 -> 
          22.67`4., 194 -> 22.46`4., 195 -> 22.61`4., 196 -> 22.84`4., 197 -> 
          22.92`4., 198 -> 22.73`4., 199 -> 22.7`4., 200 -> 22.89`4., 201 -> 
          23.07`4., 202 -> 23.17`4., 203 -> 23.29`4., 204 -> 23.39`4., 205 -> 
          23.59`4., 206 -> 23.94`4., 207 -> 23.56`4., 208 -> 23.48`4., 209 -> 
          23.65`4., 210 -> 23.51`4., 211 -> 23.57`4., 212 -> 23.61`4., 213 -> 
          23.59`4., 214 -> 23.57`4., 215 -> 23.4`4., 216 -> 23.2`4., 217 -> 
          23.76`4., 218 -> 23.73`4., 219 -> 23.5`4., 220 -> 23.54`4., 221 -> 
          23.6`4., 222 -> 23.56`4., 223 -> 23.66`4., 224 -> 24.26`4., 225 -> 
          24.16`4., 226 -> 23.69`4., 227 -> 23.64`4., 228 -> 23.15`4., 229 -> 
          23.25`4., 230 -> 23.44`4., 231 -> 23.48`4., 232 -> 23.44`4., 233 -> 
          23.64`4., 234 -> 23.34`4., 235 -> 22.98`4., 236 -> 23.24`4., 237 -> 
          23.53`4., 238 -> 23.8`4., 239 -> 23.73`4., 240 -> 23.96`4., 241 -> 
          24.`4., 242 -> 23.74`4., 243 -> 23.67`4., 244 -> 23.61`4., 245 -> 
          23.94`4., 246 -> 24.95`4., 247 -> 24.92`4., 248 -> 24.88`4., 249 -> 
          24.84`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$541720 = 
        Dispatch[{
         1 -> 19.51`4., 2 -> 19.9`4., 3 -> 20.02`4., 4 -> 20.08`4., 5 -> 
          20.04`4., 6 -> 19.55`4., 7 -> 20.1`4., 8 -> 20.22`4., 9 -> 20.41`4.,
           10 -> 20.22`4., 11 -> 20.26`4., 12 -> 20.27`4., 13 -> 20.2`4., 14 -> 
          20.22`4., 15 -> 20.12`4., 16 -> 20.15`4., 17 -> 20.26`4., 18 -> 
          20.15`4., 19 -> 20.13`4., 20 -> 20.04`4., 21 -> 19.96`4., 22 -> 
          19.89`4., 23 -> 20.12`4., 24 -> 20.09`4., 25 -> 20.14`4., 26 -> 
          19.95`4., 27 -> 19.94`4., 28 -> 19.82`4., 29 -> 19.84`4., 30 -> 
          20.17`4., 31 -> 20.61`4., 32 -> 20.74`4., 33 -> 20.71`4., 34 -> 
          20.96`4., 35 -> 21.05`4., 36 -> 21.27`4., 37 -> 21.19`4., 38 -> 
          21.25`4., 39 -> 21.54`4., 40 -> 21.57`4., 41 -> 21.9`4., 42 -> 
          21.74`4., 43 -> 21.75`4., 44 -> 21.52`4., 45 -> 21.58`4., 46 -> 
          22.06`4., 47 -> 22.14`4., 48 -> 22.14`4., 49 -> 22.15`4., 50 -> 
          22.2`4., 51 -> 22.42`4., 52 -> 22.28`4., 53 -> 22.04`4., 54 -> 
          21.85`4., 55 -> 21.92`4., 56 -> 21.85`4., 57 -> 21.93`4., 58 -> 
          22.01`4., 59 -> 22.15`4., 60 -> 22.23`4., 61 -> 21.32`4., 62 -> 
          20.72`4., 63 -> 20.67`4., 64 -> 20.71`4., 65 -> 20.51`4., 66 -> 
          20.54`4., 67 -> 20.45`4., 68 -> 20.5`4., 69 -> 20.73`4., 70 -> 
          20.68`4., 71 -> 20.91`4., 72 -> 20.54`4., 73 -> 20.36`4., 74 -> 
          20.19`4., 75 -> 20.36`4., 76 -> 20.06`4., 77 -> 19.45`4., 78 -> 
          19.4`4., 79 -> 19.38`4., 80 -> 19.89`4., 81 -> 19.87`4., 82 -> 
          20.06`4., 83 -> 20.22`4., 84 -> 20.35`4., 85 -> 20.33`4., 86 -> 
          19.99`4., 87 -> 20.42`4., 88 -> 20.51`4., 89 -> 20.28`4., 90 -> 
          20.19`4., 91 -> 20.34`4., 92 -> 20.56`4., 93 -> 20.72`4., 94 -> 
          20.83`4., 95 -> 20.82`4., 96 -> 21.04`4., 97 -> 21.01`4., 98 -> 
          21.01`4., 99 -> 21.15`4., 100 -> 20.88`4., 101 -> 20.45`4., 102 -> 
          20.53`4., 103 -> 20.24`4., 104 -> 20.42`4., 105 -> 20.38`4., 106 -> 
          20.09`4., 107 -> 20.1`4., 108 -> 19.93`4., 109 -> 20.86`4., 110 -> 
          20.71`4., 111 -> 20.78`4., 112 -> 20.62`4., 113 -> 20.35`4., 114 -> 
          20.6`4., 115 -> 20.62`4., 116 -> 20.68`4., 117 -> 20.73`4., 118 -> 
          20.67`4., 119 -> 20.72`4., 120 -> 20.78`4., 121 -> 21.25`4., 122 -> 
          21.55`4., 123 -> 21.4`4., 124 -> 21.6`4., 125 -> 21.75`4., 126 -> 
          21.9`4., 127 -> 22.04`4., 128 -> 21.87`4., 129 -> 21.82`4., 130 -> 
          21.96`4., 131 -> 21.92`4., 132 -> 22.09`4., 133 -> 21.95`4., 134 -> 
          21.91`4., 135 -> 22.09`4., 136 -> 21.99`4., 137 -> 22.12`4., 138 -> 
          22.68`4., 139 -> 22.74`4., 140 -> 22.86`4., 141 -> 23.04`4., 142 -> 
          22.98`4., 143 -> 22.94`4., 144 -> 23.04`4., 145 -> 22.63`4., 146 -> 
          22.73`4., 147 -> 22.81`4., 148 -> 23.02`4., 149 -> 22.82`4., 150 -> 
          22.85`4., 151 -> 23.25`4., 152 -> 23.48`4., 153 -> 23.48`4., 154 -> 
          23.49`4., 155 -> 23.26`4., 156 -> 23.14`4., 157 -> 23.21`4., 158 -> 
          23.32`4., 159 -> 23.17`4., 160 -> 22.95`4., 161 -> 22.99`4., 162 -> 
          23.14`4., 163 -> 23.11`4., 164 -> 23.09`4., 165 -> 22.87`4., 166 -> 
          22.83`4., 167 -> 22.67`4., 168 -> 22.81`4., 169 -> 22.79`4., 170 -> 
          22.92`4., 171 -> 22.74`4., 172 -> 22.78`4., 173 -> 22.58`4., 174 -> 
          22.65`4., 175 -> 22.72`4., 176 -> 22.87`4., 177 -> 23.24`4., 178 -> 
          23.14`4., 179 -> 22.63`4., 180 -> 22.72`4., 181 -> 22.47`4., 182 -> 
          22.39`4., 183 -> 21.44`4., 184 -> 20.94`4., 185 -> 21.19`4., 186 -> 
          21.48`4., 187 -> 21.74`4., 188 -> 21.79`4., 189 -> 21.82`4., 190 -> 
          22.03`4., 191 -> 21.92`4., 192 -> 21.97`4., 193 -> 22.37`4., 194 -> 
          22.14`4., 195 -> 22.44`4., 196 -> 22.44`4., 197 -> 22.51`4., 198 -> 
          22.41`4., 199 -> 22.44`4., 200 -> 22.63`4., 201 -> 22.73`4., 202 -> 
          22.92`4., 203 -> 23.01`4., 204 -> 23.24`4., 205 -> 23.4`4., 206 -> 
          23.56`4., 207 -> 23.26`4., 208 -> 23.3`4., 209 -> 23.39`4., 210 -> 
          23.21`4., 211 -> 23.31`4., 212 -> 23.13`4., 213 -> 23.13`4., 214 -> 
          23.22`4., 215 -> 23.03`4., 216 -> 22.91`4., 217 -> 23.28`4., 218 -> 
          23.45`4., 219 -> 23.29`4., 220 -> 23.23`4., 221 -> 23.15`4., 222 -> 
          23.27`4., 223 -> 23.46`4., 224 -> 23.58`4., 225 -> 23.79`4., 226 -> 
          23.2`4., 227 -> 23.21`4., 228 -> 22.76`4., 229 -> 22.94`4., 230 -> 
          23.02`4., 231 -> 23.26`4., 232 -> 23.16`4., 233 -> 23.19`4., 234 -> 
          22.88`4., 235 -> 22.76`4., 236 -> 22.95`4., 237 -> 23.27`4., 238 -> 
          23.51`4., 239 -> 23.36`4., 240 -> 23.63`4., 241 -> 23.59`4., 242 -> 
          23.56`4., 243 -> 23.34`4., 244 -> 23.43`4., 245 -> 23.56`4., 246 -> 
          24.1`4., 247 -> 24.73`4., 248 -> 24.63`4., 249 -> 24.56`4., 250 -> 
          24.52`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$541720 = 
        Dispatch[{
         1 -> 19.9`4., 2 -> 20.25`4., 3 -> 20.13`4., 4 -> 20.08`4., 5 -> 
          20.06`4., 6 -> 19.86`4., 7 -> 20.28`4., 8 -> 20.29`4., 9 -> 
          20.44`4., 10 -> 20.33`4., 11 -> 20.38`4., 12 -> 20.42`4., 13 -> 
          20.31`4., 14 -> 20.26`4., 15 -> 20.28`4., 16 -> 20.37`4., 17 -> 
          20.32`4., 18 -> 20.25`4., 19 -> 20.18`4., 20 -> 20.11`4., 21 -> 
          19.97`4., 22 -> 20.13`4., 23 -> 20.18`4., 24 -> 20.14`4., 25 -> 
          20.15`4., 26 -> 19.97`4., 27 -> 20.04`4., 28 -> 19.85`4., 29 -> 
          19.98`4., 30 -> 20.62`4., 31 -> 20.89`4., 32 -> 20.79`4., 33 -> 
          20.89`4., 34 -> 21.18`4., 35 -> 21.31`4., 36 -> 21.4`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.71`4., 40 -> 21.87`4., 41 -> 
          21.97`4., 42 -> 21.8`4., 43 -> 21.76`4., 44 -> 21.55`4., 45 -> 
          22.16`4., 46 -> 22.15`4., 47 -> 22.24`4., 48 -> 22.22`4., 49 -> 
          22.34`4., 50 -> 22.38`4., 51 -> 22.54`4., 52 -> 22.35`4., 53 -> 
          22.06`4., 54 -> 21.87`4., 55 -> 21.95`4., 56 -> 21.92`4., 57 -> 
          22.08`4., 58 -> 22.08`4., 59 -> 22.34`4., 60 -> 22.24`4., 61 -> 
          21.48`4., 62 -> 21.16`4., 63 -> 20.75`4., 64 -> 20.73`4., 65 -> 
          20.73`4., 66 -> 20.58`4., 67 -> 20.54`4., 68 -> 20.81`4., 69 -> 
          20.78`4., 70 -> 20.88`4., 71 -> 21.05`4., 72 -> 20.6`4., 73 -> 
          20.37`4., 74 -> 20.48`4., 75 -> 20.37`4., 76 -> 20.17`4., 77 -> 
          19.51`4., 78 -> 19.56`4., 79 -> 19.65`4., 80 -> 20.15`4., 81 -> 
          20.11`4., 82 -> 20.17`4., 83 -> 20.52`4., 84 -> 20.54`4., 85 -> 
          20.35`4., 86 -> 20.61`4., 87 -> 20.6`4., 88 -> 20.6`4., 89 -> 
          20.3`4., 90 -> 20.34`4., 91 -> 20.7`4., 92 -> 20.84`4., 93 -> 
          20.93`4., 94 -> 20.86`4., 95 -> 20.97`4., 96 -> 21.24`4., 97 -> 
          21.08`4., 98 -> 21.08`4., 99 -> 21.38`4., 100 -> 21.15`4., 101 -> 
          20.49`4., 102 -> 20.71`4., 103 -> 20.55`4., 104 -> 20.49`4., 105 -> 
          20.44`4., 106 -> 20.36`4., 107 -> 20.11`4., 108 -> 20.65`4., 109 -> 
          21.`4., 110 -> 20.76`4., 111 -> 20.86`4., 112 -> 20.79`4., 113 -> 
          20.57`4., 114 -> 20.62`4., 115 -> 20.83`4., 116 -> 20.79`4., 117 -> 
          20.78`4., 118 -> 20.86`4., 119 -> 20.78`4., 120 -> 20.96`4., 121 -> 
          21.69`4., 122 -> 21.66`4., 123 -> 21.59`4., 124 -> 21.7`4., 125 -> 
          21.93`4., 126 -> 22.14`4., 127 -> 22.14`4., 128 -> 21.87`4., 129 -> 
          21.92`4., 130 -> 22.26`4., 131 -> 21.95`4., 132 -> 22.18`4., 133 -> 
          22.08`4., 134 -> 22.12`4., 135 -> 22.14`4., 136 -> 22.09`4., 137 -> 
          22.22`4., 138 -> 23.02`4., 139 -> 23.04`4., 140 -> 22.92`4., 141 -> 
          23.37`4., 142 -> 23.04`4., 143 -> 23.08`4., 144 -> 23.2`4., 145 -> 
          22.63`4., 146 -> 22.87`4., 147 -> 23.18`4., 148 -> 23.04`4., 149 -> 
          23.01`4., 150 -> 23.09`4., 151 -> 23.4`4., 152 -> 23.48`4., 153 -> 
          23.49`4., 154 -> 23.58`4., 155 -> 23.43`4., 156 -> 23.22`4., 157 -> 
          23.3`4., 158 -> 23.5`4., 159 -> 23.25`4., 160 -> 23.07`4., 161 -> 
          23.14`4., 162 -> 23.27`4., 163 -> 23.11`4., 164 -> 23.18`4., 165 -> 
          23.06`4., 166 -> 22.94`4., 167 -> 22.92`4., 168 -> 22.94`4., 169 -> 
          22.9`4., 170 -> 23.16`4., 171 -> 22.82`4., 172 -> 22.9`4., 173 -> 
          22.75`4., 174 -> 22.94`4., 175 -> 22.88`4., 176 -> 23.39`4., 177 -> 
          23.4`4., 178 -> 23.27`4., 179 -> 22.63`4., 180 -> 22.92`4., 181 -> 
          22.58`4., 182 -> 22.49`4., 183 -> 21.58`4., 184 -> 21.18`4., 185 -> 
          21.33`4., 186 -> 21.79`4., 187 -> 21.78`4., 188 -> 22.03`4., 189 -> 
          22.09`4., 190 -> 22.11`4., 191 -> 21.97`4., 192 -> 22.14`4., 193 -> 
          22.39`4., 194 -> 22.4`4., 195 -> 22.5`4., 196 -> 22.83`4., 197 -> 
          22.6`4., 198 -> 22.72`4., 199 -> 22.67`4., 200 -> 22.83`4., 201 -> 
          23.06`4., 202 -> 23.09`4., 203 -> 23.27`4., 204 -> 23.38`4., 205 -> 
          23.47`4., 206 -> 23.67`4., 207 -> 23.47`4., 208 -> 23.34`4., 209 -> 
          23.41`4., 210 -> 23.45`4., 211 -> 23.41`4., 212 -> 23.14`4., 213 -> 
          23.45`4., 214 -> 23.47`4., 215 -> 23.14`4., 216 -> 23.19`4., 217 -> 
          23.67`4., 218 -> 23.59`4., 219 -> 23.39`4., 220 -> 23.31`4., 221 -> 
          23.49`4., 222 -> 23.33`4., 223 -> 23.58`4., 224 -> 24.14`4., 225 -> 
          23.79`4., 226 -> 23.25`4., 227 -> 23.36`4., 228 -> 22.93`4., 229 -> 
          23.11`4., 230 -> 23.25`4., 231 -> 23.32`4., 232 -> 23.19`4., 233 -> 
          23.34`4., 234 -> 22.9`4., 235 -> 22.91`4., 236 -> 23.24`4., 237 -> 
          23.32`4., 238 -> 23.62`4., 239 -> 23.54`4., 240 -> 23.94`4., 241 -> 
          23.76`4., 242 -> 23.63`4., 243 -> 23.43`4., 244 -> 23.54`4., 245 -> 
          23.63`4., 246 -> 24.72`4., 247 -> 24.86`4., 248 -> 24.71`4., 249 -> 
          24.62`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$541720 = True, 
        System`TradingChartDump`$gridlines$541720 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$541720, 
        System`TradingChartDump`$plotrangemin$541720 = 19.0982952853598, 
        System`TradingChartDump`$plotrangemax$541720 = 25.507305210918112`, 
        System`TradingChartDump`$layoutData$541720, 
        System`TradingChartDump`$gridlinesscope$541720 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$541720 = {True, True}, 
        System`TradingChartDump`$indicators$541720 = {
         FinancialIndicator["TRIX", 15]}, 
        System`TradingChartDump`$mouseQ$541720 = False, 
        System`TradingChartDump`$modelData$541720 = 
        System`TradingChartDump`modelData$540640, 
        System`TradingChartDump`$sy$541720 = Identity, 
        System`TradingChartDump`$isy$541720 = Identity, 
        System`TradingChartDump`$appearance$541720 = Automatic, 
        System`TradingChartDump`$perfgoal$541720 = "Quality", 
        System`TradingChartDump`$axesorigin$541720 = Automatic, 
        System`TradingChartDump`$framestyle$541720 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$541720 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$541720 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$541720 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$541720 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$541720, 
        System`TradingChartDump`$newgridlines$541720 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{19.0982952853598, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$541720 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$541720 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$541720 = "GraphicsFrame", 
        System`TradingChartDump`$frame$541720 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$541720 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$541720 = 
              Switch[System`TradingChartDump`$highlightposition$541720, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$541720], {
                 1, System`TradingChartDump`$length$541720}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$541720], {
                 1, System`TradingChartDump`$length$541720}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$541720, 
                   Charting`nearestDate[System`TradingChartDump`$dates$541720, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$541720]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$541720]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$541720, 
                    Floor[System`TradingChartDump`$controlmin$541720] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$541720, 
                    Floor[System`TradingChartDump`$controlmax$541720]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$541720 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$541720 = 
            If[System`TradingChartDump`$fastpos$541720 =!= True, 
              System`TradingChartDump`$fastpos$541720 = 
               Clip[System`TradingChartDump`$fastpos$541720, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$541720 = (
                  Floor[System`TradingChartDump`$controlmax$541720] - Floor[
                  System`TradingChartDump`$controlmin$541720]) (
                  System`TradingChartDump`$fastpos$541720/100) + 
                Floor[System`TradingChartDump`$controlmin$541720]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$541720], {
                Floor[System`TradingChartDump`$controlmin$541720] + 1, 
                 Floor[System`TradingChartDump`$controlmax$541720]}], 
              System`TradingChartDump`$staticindicatorpos$541720]; 
           System`TradingChartDump`$mouseQ$541720 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$541720]], 
              System`TradingChartDump`$highlightposition$541720 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$541720 = If[
              And[
              System`TradingChartDump`$bouncingballQ$541720, 
               System`TradingChartDump`$mouseQ$541720, 
               System`TradingChartDump`$appearance$541720 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$541720[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$541720]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$541720[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$541720, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$541720[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$541720]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$541720[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$541720[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541720, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541720[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541720, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541720, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541720[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541720[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$541720 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$541720, 
                 System`TradingChartDump`$defaultframeticksstyle$541720, 
                 System`TradingChartDump`$defaultlabelstyle$541720, 
                 System`TradingChartDump`$framestyle$541720, 
                 System`TradingChartDump`$frameticksstyle$541720, 
                 System`TradingChartDump`$labelstyle$541720}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541720 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$541720, 
                 System`TradingChartDump`$labelstyle$541720, 
                 System`TradingChartDump`$defaultframeticksstyle$541720, 
                 System`TradingChartDump`$defaultlabelstyle$541720}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541720 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541720, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$541720 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541720, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$541720 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541720, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$541720 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$541720 = 
             Part[System`TradingChartDump`$tickstextstyle$541720, 1], 
             System`TradingChartDump`$tickstextstyle$541720 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541720[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541720, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541720[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541720[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541720[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$541720[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541720, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$541720]], 
                    Style[":", System`TradingChartDump`$textstyle$541720]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$541720[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541720]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541720[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$541720[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$541720, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$541720]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$541720[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541720, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541720[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541720, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541720, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$541720[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541720[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541720[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$541720[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$541720[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$541720], 1], 
                   Floor[System`TradingChartDump`$controlmax$541720]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$541720[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$541720[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$541720[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$541720[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$541720[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541720[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$541720[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$541720[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$541720[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541720[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$541720[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$541720[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$541720[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$541720[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$541720[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$541720, 
                  System`TradingChartDump`$mouseQ$541720], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$541720 - 0.5, 
                   System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$541720 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$541720 + 0.5, 
                    System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541720, 1]}, {
                    System`TradingChartDump`$indicatorpos$541720 + 0.5, 
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$541720[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$541720, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$541720[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541720]]], {}]; 
              System`TradingChartDump`$subplotgridlines$541720[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$541720[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$541720[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541720[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$541720 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$541720, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541720, 
                   System`TradingChartDump`$opens$541720]], 12, 
                 System`TradingChartDump`$textstyle$541720, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$541720, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541720, 
                   System`TradingChartDump`$highs$541720]], 12, 
                 System`TradingChartDump`$textstyle$541720, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$541720, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541720, 
                   System`TradingChartDump`$lows$541720]], 12, 
                 System`TradingChartDump`$textstyle$541720, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$541720, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541720, 
                   System`TradingChartDump`$closes$541720]], 12, 
                 System`TradingChartDump`$textstyle$541720, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541720, 
                   System`TradingChartDump`$visdates$541720]], 12, 
                 System`TradingChartDump`$textstyle$541720, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$541720, 
                  System`TradingChartDump`$mouseQ$541720], {{
                  System`TradingChartDump`$timestampstyle$541720, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$541720 - 0.5, 
                    System`TradingChartDump`$plotrangemin$541720}, 
                    If[
                    System`TradingChartDump`$timestampdepth$541720 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$541720[1]}, {
                    System`TradingChartDump`$indicatorpos$541720 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541720}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541720, 1]}, {
                    System`TradingChartDump`$indicatorpos$541720 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541720}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$541720, {
               System`TradingChartDump`$highlightstyle$541720, 
                Dynamic[System`TradingChartDump`$ohlcpoint$541720]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$541720[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541720, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$541720[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$541720[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$541720, Length[
                    System`TradingChartDump`$layoutData$541720[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$541720}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$541720] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$541720] + 0.5}, {
                System`TradingChartDump`$plotrangemin$541720, 
                 System`TradingChartDump`$plotrangemax$541720}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$541720, Left, {
                 False, System`TradingChartDump`$frame$541720}, 
                 Blank[], {System`TradingChartDump`$frame$541720, False}], {
                False, System`TradingChartDump`$frame$541720}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$541720, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$541720]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$541720 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           387.0228610767757}, {-286.92264150943396`, -65.76792452830186}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541720 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541720, 1]], 
               Part[System`TradingChartDump`$framestyle$541720, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$541720]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$541720} -> 
                   System`TradingChartDump`$isy$541720[
                    System`TradingChartDump`$plotrangemin$541720], {
                    0, System`TradingChartDump`$plotrangemax$541720} -> 
                   System`TradingChartDump`$isy$541720[
                    System`TradingChartDump`$plotrangemax$541720]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$541720[
                   System`TradingChartDump`$plotrangemin$541720], 
                   System`TradingChartDump`$isy$541720[
                   System`TradingChartDump`$plotrangemax$541720]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$541720, 
                   System`TradingChartDump`$isy$541720}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541720, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541720 > 
                    System`TradingChartDump`$plotrangemin$541720, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541720 > 
                    System`TradingChartDump`$plotrangemin$541720, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541720, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541720 > 
                    System`TradingChartDump`$plotrangemin$541720, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541720 > 
                    System`TradingChartDump`$plotrangemin$541720, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541720, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541720, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541720 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541720,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541720], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541720 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541720, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541720]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$541720, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$541720[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$541720[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541720, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$541720[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$541720, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541720[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541720, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541720[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541720[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541720[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541720[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541720], 
                    Style[":", System`TradingChartDump`$textstyle$541720]], 
                    Style[":", System`TradingChartDump`$textstyle$541720]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$541720[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541720]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541720[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$541720}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$541720, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$541720 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$541720[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$541720, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$541720, Left, {
                    False, System`TradingChartDump`$frame$541720}, 
                    Blank[], {
                    System`TradingChartDump`$frame$541720, False}], {
                   System`TradingChartDump`$frame$541720, 
                    System`TradingChartDump`$frame$541720}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$541720, 
                    System`TradingChartDump`$controlmax$541720}] + 0.5, {
                   System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$541720]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$541720) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$541720 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$541720 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$541720, 1]], 
                   Part[System`TradingChartDump`$framestyle$541720, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$541720]]], {}, 
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541720[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541720[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$541720[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541720, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541720, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$541720, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$541720, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$541720 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
541720, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$541720], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$541720 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$541720, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$541720]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$541720, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$541720) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$541720 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$541720[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           475.9407855006933}, {-55.989622641509435`, -0.7009433962264069}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$541720, 
              Dynamic[System`TradingChartDump`$ohlclabel$541720], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$541720}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541720 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541720, 2]], 
               Part[System`TradingChartDump`$framestyle$541720, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$541720]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$541720, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$541720, 
                    System`TradingChartDump`$controlmax$541720}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$541720] + 
                    0.5, System`TradingChartDump`$plotrangemin$541720}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$541720], 
                    System`TradingChartDump`$plotrangemin$541720}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$541720, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541720, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541720, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541720 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541720, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541720], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541720 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541720,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541720]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$541720] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$541720[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$541720] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$541720[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$541720] = {HoldPattern[
               System`TradingChartDump`$min$541720[1]] :> -0.4}}, {
          DownValues[System`TradingChartDump`$max$541720] = {HoldPattern[
               System`TradingChartDump`$max$541720[1]] :> 0.42}}, {
          DownValues[System`TradingChartDump`$subplotvalue$541720] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$541720[1, 1]] :> 
             Invisible[0.01], HoldPattern[
               System`TradingChartDump`$subplotvalue$541720[1, 2]] :> 
             Invisible[-0.01]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$541720] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$541720[1]] :> {0, 
               Rational[1, 2]}}}, {
          DownValues[System`TradingChartDump`$layoutData$541720] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$541720["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "AllValues"]] :> CompressedData["
1:eJxFVwk4lVsXppIh0aCkJH7kIJGzv72PhCUVlTKkQVcqXSKKkooGqWSoaLjI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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541720["AppendedAdjust"]] :> 
             0.08150428019768745, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "AppendedBox"]] :> {-0.4553597773574395, 0.5448011116441356}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "AppendedMin"]] :> -0.43671716388792153`, HoldPattern[
               System`TradingChartDump`$layoutData$541720["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$541720["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$541720["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$541720["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541720["DataMax"]] :> 
             24.95, HoldPattern[
               System`TradingChartDump`$layoutData$541720["DataMin"]] :> 
             19.376947890818858`, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "MainChartAllValues"]] :> CompressedData["
1:eJxFVwk81csXp5Il0aKkJP4Rkcid38yVcCRRKUta9KToka2QVLRok6Wi5SFb
tCuhUrL3EhXabGkXskUJWdv+x9Jr7ud+5s6ZM2dmzjnz/Z6rYO9u6TBMQECg
/9uH30UH+j88yBDfcqGongfSGw58HjmSgFSycbWvFIFl/KDHG8UIPNF07ao6
woP2eH16ehKB8izj5Ho+gZ/mZZKcM4FnM1t0dbQJbEqpW3TUkMCL2aqLq7G/
LXQwV5YQENJeKH4J9efcCnc6MRXHDnndOUoEPF9+SJFAvaAec0sdZQLU0Ljv
mgIBpw7PNSW4b8ozr4rKTh6cDR7jvqqWB7cT/kqi0whIFHnleEkT+LJHX6Fl
OoGE/fZ31nbwYPetmtfb23iwekRIoWopDyJinn7iveDB7N4N1QWzUP/E348F
YwiI2+6qf5lDoCGf13z/JoEHHddkZDsJyLm59m0X5+DRIfVlmgs5qJ38at37
ORyEy0rdytPnoO1Aea5KEAcyO3ztVx3nQGqy3KYX9Rx8+JIsV5bDwXDJkSpj
/uVgdNqSi2b+HHhW07n0JAd6652jPklSKLD+8MRXkYIJz0FtDfarlh3mxShT
aNimrbGaUMg7f8hpsRsFn1e1qvImFJwML9euFaOgLPDDMvMlB3InFUXSmjl4
Z61XPeoVB9nL9p4VbuXgVYF4hcDwP/aK1ZQS2uZSWJ52almbJQf7a8AzPp3A
vy2CqcJXCSxQXzKv9hYB/+vZ+dv3od+17Q38ggmI9tRX5HsRYGPFdvv4EYje
2X5fK4tA7nvVpy9x3fmQ4Xqvmwhk+FWMjUf9JsefRto2BFTi4i2+afwZ0/LT
baPHEDAI2LI1zIsHvxSC81w38qDXRiPBbz0PTDTkdn6v4UHYyWjN3Le8//Sf
BsQnpjPsaw+NfryGQJ73v0HRVgTS2l7t2PSdB91Llg5LciNQuKVj6fQDBKLi
hEueGBPQg3MfTs0hoCuro/NiJYF2VwGV8yEEfEInnp9xm0DqVLdTieUEOrOa
l9WUYn6bfjIdLsqBW6Z8m+DwP31Awcv9dkocqO6TV9v3nkCvYYbUVvQHvdYW
6xZIoDivO2PWPAKyr7mKx64EyPJ85UN2BDJFLLYr4rt4PAFmn5chcMS5QfLI
Zx4kBc9VzHpDoMb6iE03+lu7s2vmsId43uYpEa5xBEyTrWE33nO1xEj95EgC
JXc2rAlD+aKxPr6ByQT2rx8rMhH9byx4p8QU/X90fCH/OMZx7hIPOxe0s23+
ju4FmJcGieHu+kc5mPlOREx9IwfxgpPjBaM4qCRR/rmYj2NKGiXsGzjYdUDD
9CLm0zT/Zov0dxxMhEznFaUccOYPtn3r4kCxZO2L85hfmm13PZ2kKXTETa3O
6uCgxF9FpbQJ7fjSRD2Uc+lqWS9/cGCiZvNEfhqFT6IpXa1XKcxrGWd/KZeC
tPbDTRvfULDvCTw1TpTBTonMTdO+UbCeG1r58Qvm59dfsSfEGNT4ItKcodB3
+NEnlSwKT6WGLVV4RiHE0qNaRYiBjOJtNdNSCikinYbjX1GIvcqpmwHaGwAo
BqtVy4Lqsa87aVQYt5uBzqS7fY3zGdDeqAhBRQa+NxMWtHMM9j33U1hsyWDe
DcXTKWoM/Nfen+DRQWGt1cmD2T8oHCI6YrKo/1doXqeKLAPpc15z5kozCLI2
uTepikJLrJlgajkFi8zowhF4Txkdm92nn1Iw23visncR+lPjiuvPZgpfxJ4n
Rubg2OqNc/MDCkGxzitL/6EQoHh3bd9FCqltL/PPpVO4JWn+sQjtzgy1mlSg
y/7b/7c/3C+Uj05HPUX+s8/BOyhMMVw7ftTfFC4eDjna7MHByGYXKYU2AtbK
whtaNBGvDNuO7tnJwRb7lW0HEYdIz56m7CIONNbNCvbF+I78JOH6QpjCnLwL
d+IwvibZwfmJPRyE9bUX5NlSuGRCq2wRj8TvaYrf86BwdUn+A1dPlB807s7Z
TyHNf5FXmDPGJdDon8kob96YQJPxnD9sSGEgxq1tQobpa7x/4G5FG5nhDBws
SyMz8V718na6hx0ZGCx9cSwslIGhkkz1D4zPvJCb3dWmDPb2XIqo3sBgxcW9
vUAZVDmLtRwzY7C4WzLHVIGB3fYonS/Y274N313BZ1CgvSijTpiBwPP5NcFN
FJrcx8X4mGC8fvTu2+XFQMVKXX/LYrTjuzxxlA6D/KXLNWSUGTwy+t8uPSMG
qodbXQW3MZiyafPOyDAGYpXnPHSLGPAGGoNOFZvQPMyXewM/KHjoogbma/9z
kRMakuP5Z9r0JwobnNdkUN0ft2r637oBcx1D64yG1u0fyi+bIf0zDPq3F4tg
MCBG/zzvH69ikNRPv5v/yKMiscnwB/M+kz+0nj80zx/cx58PE5vwI0rAJD+p
u3Q5gSsnLmwKRLwaLeV6ZSbi6orUuIlvjBCfbm4QyhMhUCA60yfcgkCiSvpt
gz0E/DKrLn1DPrBxXTDO1IlAzHu194oeBFr6zSPeZc2NlkxdT6Ax4mrKFcRh
xYTE/BHWBETW1AmN8EZebn9Cl9kS+JhhHrMYcTjUetHus+sIzPwYMdJbi8Cs
64HUB/n//qUUdYm5BE6bT9j1eiGBOzvW1UvrIw4qr2+KxrHShu3yvyYTuO6w
emU31gXTZap8tLAuKY2b7hGFONvQdtdb6wzyUX8AavGcF+5dtfmK/VlxlZjv
BALdyj58ZxwId7lrvUUejlF6EV56kRv09ypuyF8c9KwL8ovP50Ay9KHZzUYO
xCI8xA3lKSSG91oY1nLwxGns9S2yFI7qWR7Vu8FBx+X8oo2LKETrKf1diu8x
54iY5Vvka4vm8iW6LhRKnjnGHXCiYD7qwX49XwrqHje+0kgKWavNRMa7Usj1
ulaX40hB6YSNgcwsCi62+pbySvi+i9IaP+P7cxGe88B7OoXN4z/tcDTH9zbP
fUmQNdrfG6lRsZdC5qsxWindHMzJniVuizhfJbvb6+tbAnGyhzMetyCfSKn1
zBfhYINugMpr5J0KPTZepZiAUXjpycrXyM8jtC1HKXJwRkpi7/wvBKoklHna
8zh4ZiB1pLWPwGbJW7ejLyOPBWXpPiggsH7H+F3ysQT47krbWjcTEDwdq7lA
B+M59WFYcQYP7my8XWR/DevGUN09dhyB+qsCI86pE8hPili2F+M76GcChuLG
p7OPEPjlNCmuN5FAmXpa7aXTWFd+T30kUEYgqUQ6bFQmAYfmidumpxLYIqwX
vnMXAcdX6zUv4ryrWY2XCN6n95B2+bgOnPf/tSSum8Dn1vc3GOFA/fzVwGr0
R4yVTazNOg4cwsLuumH8f4iOCDBy5GCtxVRbi7UciLz3zUifxoFrwnjj2Dqs
F0QWlh1IwLx3kjFIi8f6b4V5+/ZoAl56Eov3BRFwtvMXUMV8f+v8VbEZ9dQf
Bdjaa3FQ0Wh1pAj92DM/WmJhM9YDx1IKGrFesM6rLbQuJPBoqem9r9nor8v6
tRGYn8UxTxzbcb/cXe+KG7A/M2ze06R3+K5MckLKMS4LvjUr8NHufZ1jCpuf
c9BgfD2i7AUHOb6GG9KSOBCsyo7agXIr9SZhOeTjRm5b0Ed1CmrfkkV+Mgpd
z+345hqIN1FmtrmiFKyCgB9pTOGkH88qCPO5rmlznM58CtMtxTsjML9y2tU+
LpyB/HRq3KKvWhTKihxXK+M40z7L9Cvmd2iUSULxFAaF7NBWBzkG78bJPRRS
Z4N1gy0D7XalfQ3rENeCn/msQj6Ncpnh6o64OHvBbD2l1QyKzwvmyvVQIDP/
OnkD8fSNuIQyMWZgEv1562XETbOiioB/ZBiUP+hYX3WQwazGBT3iFxH3VMaq
Bp5jcHxPtveeWwykguPipRH/ilnJjWNODPRUZ/e5WDHwcZiQef844vAxv5Uy
AQwsrRvtLPEc4is79ARmM9ASOuO3NRrx3TlkcqML++8c407N67NE3qlIO+Vr
g/caISHzv+ROChkPK+s7RzB4mFta54s8ViTolvQP4rr+lOB7BxkDa8PO8zKI
5zldM1gw4rvnEC88+CG6PHgsA3sL+1Ox3ni/unJvZzzPgbNOjgrIe5fCRJsy
p7JB/ES70j8LE0a/pOCre2OrciLWC+0ZgZGv8X+EcL5y7T4OxiX7GmYf5OCx
iMkWoTccTLf2FXsiQeFR7yzBTxjnGftGhWRj/H5eeHR8OI9C5bFh0ZPV6CAO
onx/ndn99isUpnaX0XPeiDet33Jboyl8rxw2VaiSwpsVXU5VH/G+Du3ybzIp
VH9flTY9FeuTy1eM02speI9K9qzH+xyrjDxmg/70XDm5TAv5dPSYZ3dLkKed
u0ZNLA5n8PmwZevELwx2gUvxLIzP1tb9cyKwDhst4lTQcIGBy/O4u+7Id24+
RTIRGKfZ6eGcDsZjndAhv39x/bbSxR/SUF507/X7GgcGP9nDKnXk30+SBn+v
z2NwanFDT0Qm+rUruqnAj8EVc5UT94IYTLosmLcukkFpjqBDTQiDa5PVXxUn
MOib8L3NYj4fbiSbneVU+IPxucbg3ABBM3DsbzMY/Opv+mxw3uNPHfl7/Fu/
coiHB+b7KAxMYz1j0k+8GN/Hj/ob1pcDfMygq5/2O7EuGWj8Qf0cBgPwlzjE
+zFD+3wZqjc6+EN5McTn1fzBfSt/n58P/wdya6kS
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "MainChartPoints"]] :> CompressedData["
1:eJxdV1toXFUUvRZFKYIKBf0ocapS6oNSTR/xEbubNk2apk1mMslkksnkztyZ
O487M6n4IxXhIuRHhFAoSEVkRBFBEEEKoV+X+CGIIoJQBJEpQhEiUpCK9MuZ
2Wt97HMhDOvuu886e+3HOTlQ3shU7/c8717/7z787fH43DkZDp7bo4IX+itH
gR+SW5f3fTV1gPhR6aP+K+J9srVz91DhEeInpDB48RvX2y/TwwVoT8nem59e
Gp8hfkreGB+8IX5G188SH1T+EvEh+Su9PbIZET+n/HPEL8i3fbg1QXzY4T8i
T27upreLxC9Kpr/cbpr4JSf+URmGe5j4qMa3n/iYDN3/Y7zHHb1OOP5j8tml
fsBPE78sQ/0PEr/irPeq6rWX9tfkw2v951fax+XtgWD3iF/X+D7m9yeV7w9i
0fW+B47FsZ/Cfo/Bfgr6AnsTut+Q9gkZbi9H+2kZ0I9s0n5a/u2nY+c67Wd0
f7/Tfgbx0j4pP/4weGif1Hzu0H5W7e/TflaeHSbkOOxT0BM4npJheY3TPq18
Y7RPY/+0n0O90X5O9XqP9hnVP0/7DOqf9vNOfOdldPD8w/3Pav3u0j6LfqL/
BYvjC87+Ltp44oua/8tcfw56cP05/U2Y33n9/gawODieV/6rwMk84qd/WuP9
if5p7a/v6J9W/W7RP635epj7y6h+1+ifsf0YZxAP/R27t6D6PU//Ba2Pd1H/
8YLubws4WdB6+Jz9kbX9Jlnbz3HWrp9kUc/kX7R6yCLqgf6Lut5H9F+08XpL
TvxLqs8s/ZeQb/ovaf18Q/+c2m/SP6f9+jf9c5i/9M+hv+i/jPpBPmQZ9cZ6
cXCyjH5g/vLQj/55Xe8d8ufR7+TPo1/Jv2K/lxU7/+MV3X+B/ivOvF1FPum/
ivfc/yrmBf1XrR5ewc4/Kej8v0L+gp2fSUH1+IX+a47/mlP/a47+jt0rqj53
6V/U+L/m/ovav19Q/6Lm+wPqv456oP7ryD/913G+YD4kDvZ8O59Svp1H4uP8
xPe+b+dX7ON8gL3r23mVYP0R4J7v8Jc0nseBUyU7j6Wk/fbACfCXcP4BxyXs
l/wlzAfYE+f7Xgn7A/bKGs8ocKqs9f0J+cvQh/GXES/5y3b9bln12kP+MuIj
fxnnJfkDzDfyB+gHYAkwfxl/oPwd8gfQi/wB5gf5A3xHfmAhf0Xr/THyV5Af
8ldU/0nyV9B/5K9YPboVnH/kr2g932H+KzZfXtXaU1XV5zb1r+L8In9V9/sz
zzvn+24VvKw/Z/1eFecR+UONN2D8oc2PhE78oa2POHTqL0S+yB8in+Snnf1b
s/erVA33XfZfDfMF2K9hfrD/gB8kf832U1JDvshfc+5XdduPKeCA+tehB+u/
Dl7GX8c8JH8d5xn568q3Tf666vUl9W9Y/1TD1o80bP/4DZuPuIHziPXXUL63
WH8N8LH+HbvXxPnK/De13urkb+p8eJP8jj1u2n7pOt8nTcvXc773Iq3PI+SP
7H4lwrwnf2TrNY5wHyd/ZOdHEqGeyB/ZeeK1sJ8x8LdQb+Rv4Zf8LZzH5G/h
vGH+W3Y+JI5/r4X/r8jfduJv23xI2/a331b9/2T9tXF/Yfxtu37SxvlN/jbu
a+TvYD6Qv4P7Avk76HfG33Hmb8eu13W+Tzqof+jb6+A+AOxt4H5E/TewX2DZ
wH1gTP4HLlcf7Q==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541720["NewSubplot"]] :> {
               FinancialIndicator["TRIX", 15]}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541720["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "PlotRangeMin"]] :> -0.43671716388792153`, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$541720["Space"]] :> 2.495, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541720["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, 0}, {250., 0}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJw1lwk41Pkfx0et0mXV1sPq2KkUOlzRqpQ3ElK572vMDHNgtIncO6vTUa1I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                    "]]}, {
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Line[CompressedData["
1:eJw1lws41GkbxqeD2O1kJVK+mg4OnWzHzVa4ESGHGDnLGMMMZmgdQn0xrEjI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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "SubplotIndicatorGridLines"]] :> {{0, 
                Rational[1, 2]}}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "TRIX"}]], 
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], " ", "SMA"}]]}},
              HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["TRIX", 15]}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "SubplotIndicatorParameters"]] :> {{{15}, {{9}}, {{9}}}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "SubplotIndicatorPoints"]] :> {{{}, {{2., 0.22}, {2., 
                0.22}}, {{3., 0.13}, {3., 0.18}}, {{4., 0.09}, {4., 0.15}}, {{
                5., 0.06}, {5., 0.12}}, {{6., 0.04}, {6., 0.11}}, {{7., 
                0.03}, {7., 0.1}}, {{8., 0.03}, {8., 0.09}}, {{9., 0.03}, {9.,
                 0.08}}, {{10., 0.03}, {10., 0.07}}, {{11., 0.03}, {11., 
                0.05}}, {{12., 0.03}, {12., 0.04}}, {{13., 0.02}, {13., 
                0.03}}, {{14., 0.02}, {14., 0.03}}, {{15., 0.02}, {15., 
                0.03}}, {{16., 0.08}, {16., 0.03}}, {{17., 0.06}, {17., 
                0.03}}, {{18., 0.05}, {18., 0.04}}, {{19., 0.05}, {19., 
                0.04}}, {{20., 0.05}, {20., 0.04}}, {{21., 0.05}, {21., 
                0.04}}, {{22., 0.06}, {22., 0.05}}, {{23., 0.06}, {23., 
                0.05}}, {{24., 0.06}, {24., 0.06}}, {{25., 0.05}, {25., 
                0.05}}, {{26., 0.05}, {26., 0.05}}, {{27., 0.05}, {27., 
                0.05}}, {{28., 0.04}, {28., 0.05}}, {{29., 0.04}, {29., 
                0.05}}, {{30., 0.03}, {30., 0.05}}, {{31., 0.03}, {31., 
                0.05}}, {{32., 0.02}, {32., 0.04}}, {{33., 0.02}, {33., 
                0.04}}, {{34., 0.01}, {34., 0.03}}, {{35., 0.01}, {35., 
                0.03}}, {{36., 0.01}, {36., 0.02}}, {{37., 0.02}, {37., 
                0.02}}, {{38., 0.02}, {38., 0.02}}, {{39., 0.03}, {39., 
                0.02}}, {{40., 0.04}, {40., 0.02}}, {{41., 0.06}, {41., 
                0.03}}, {{42., 0.08}, {42., 0.03}}, {{43., 0.11}, {43., 
                0.04}}, {{44., 0.14}, {44., 0.06}}, {{45., 0.17}, {45., 
                0.07}}, {{46., 0.2}, {46., 0.1}}, {{47., 0.23}, {47., 
                0.12}}, {{48., 0.26}, {48., 0.14}}, {{49., 0.29}, {49., 
                0.17}}, {{50., 0.32}, {50., 0.2}}, {{51., 
                0.35000000000000003`}, {51., 0.23}}, {{52., 0.37}, {52., 
                0.26}}, {{53., 0.39}, {53., 0.29}}, {{54., 
                0.41000000000000003`}, {54., 0.31}}, {{55., 0.42}, {55., 
                0.34}}, {{56., 0.42}, {56., 0.36}}, {{57., 0.42}, {57., 
                0.38}}, {{58., 0.41000000000000003`}, {58., 0.39}}, {{59., 
                0.4}, {59., 0.4}}, {{60., 0.38}, {60., 0.4}}, {{61., 0.37}, {
                61., 0.4}}, {{62., 0.34}, {62., 0.4}}, {{63., 0.32}, {63., 
                0.39}}, {{64., 0.29}, {64., 0.37}}, {{65., 0.25}, {65., 
                0.35000000000000003`}}, {{66., 0.21}, {66., 0.33}}, {{67., 
                0.17}, {67., 0.3}}, {{68., 0.13}, {68., 0.27}}, {{69., 
                0.09}, {69., 0.24}}, {{70., 0.05}, {70., 0.21}}, {{71., 
                0.01}, {71., 0.17}}, {{72., -0.03}, {72., 0.13}}, {{
                73., -0.07}, {73., 0.09}}, {{74., -0.11}, {74., 0.05}}, {{
                75., -0.16}, {75., 0.01}}, {{76., -0.2}, {76., -0.03}}, {{
                77., -0.24}, {77., -0.07}}, {{78., -0.27}, {78., -0.11}}, {{
                79., -0.3}, {79., -0.15}}, {{80., -0.33}, {80., -0.19}}, {{
                81., -0.35000000000000003`}, {81., -0.23}}, {{82., -0.37}, {
                82., -0.26}}, {{83., -0.38}, {83., -0.29}}, {{84., -0.39}, {
                84., -0.31}}, {{85., -0.39}, {85., -0.34}}, {{86., -0.4}, {
                86., -0.35000000000000003`}}, {{87., -0.4}, {87., -0.37}}, {{
                88., -0.39}, {88., -0.38}}, {{89., -0.38}, {89., -0.38}}, {{
                90., -0.36}, {90., -0.38}}, {{91., -0.34}, {91., -0.38}}, {{
                92., -0.31}, {92., -0.37}}, {{93., -0.28}, {93., -0.36}}, {{
                94., -0.25}, {94., -0.35000000000000003`}}, {{95., -0.22}, {
                95., -0.33}}, {{96., -0.18}, {96., -0.3}}, {{97., -0.15}, {
                97., -0.27}}, {{98., -0.11}, {98., -0.25}}, {{99., -0.08}, {
                99., -0.21}}, {{100., -0.04}, {100., -0.18}}, {{
                101., -0.01}, {101., -0.15}}, {{102., 0.02}, {
                102., -0.11}}, {{103., 0.06}, {103., -0.08}}, {{104., 0.08}, {
                104., -0.05}}, {{105., 0.11}, {105., -0.01}}, {{106., 0.13}, {
                106., 0.02}}, {{107., 0.15}, {107., 0.05}}, {{108., 0.15}, {
                108., 0.07}}, {{109., 0.16}, {109., 0.09}}, {{110., 0.16}, {
                110., 0.11}}, {{111., 0.15}, {111., 0.13}}, {{112., 0.14}, {
                112., 0.14}}, {{113., 0.13}, {113., 0.14}}, {{114., 0.12}, {
                114., 0.14}}, {{115., 0.1}, {115., 0.14}}, {{116., 0.08}, {
                116., 0.13}}, {{117., 0.07}, {117., 0.12}}, {{118., 0.05}, {
                118., 0.11}}, {{119., 0.03}, {119., 0.1}}, {{120., 0.01}, {
                120., 0.08}}, {{121., 0.}, {121., 0.07}}, {{122., -0.01}, {
                122., 0.05}}, {{123., -0.01}, {123., 0.04}}, {{124., -0.01}, {
                124., 0.02}}, {{125., -0.01}, {125., 0.01}}, {{126., 0.}, {
                126., 0.01}}, {{127., 0.01}, {127., 0.}}, {{128., 0.03}, {
                128., 0.}}, {{129., 0.05}, {129., 0.01}}, {{130., 0.07}, {
                130., 0.01}}, {{131., 0.1}, {131., 0.02}}, {{132., 0.12}, {
                132., 0.04}}, {{133., 0.15}, {133., 0.06}}, {{134., 0.18}, {
                134., 0.08}}, {{135., 0.21}, {135., 0.1}}, {{136., 0.23}, {
                136., 0.13}}, {{137., 0.26}, {137., 0.15}}, {{138., 0.27}, {
                138., 0.18}}, {{139., 0.29}, {139., 0.2}}, {{140., 0.31}, {
                140., 0.23}}, {{141., 0.33}, {141., 0.25}}, {{142., 0.34}, {
                142., 0.27}}, {{143., 0.35000000000000003`}, {143., 0.29}}, {{
                144., 0.35000000000000003`}, {144., 0.3}}, {{145., 
                0.35000000000000003`}, {145., 0.32}}, {{146., 
                0.35000000000000003`}, {146., 0.33}}, {{147., 
                0.35000000000000003`}, {147., 0.34}}, {{148., 
                0.35000000000000003`}, {148., 0.34}}, {{149., 0.34}, {149., 
                0.35000000000000003`}}, {{150., 0.33}, {150., 
                0.35000000000000003`}}, {{151., 0.33}, {151., 
                0.35000000000000003`}}, {{152., 0.33}, {152., 0.34}}, {{153., 
                0.32}, {153., 0.34}}, {{154., 0.32}, {154., 0.34}}, {{155., 
                0.31}, {155., 0.33}}, {{156., 0.3}, {156., 0.33}}, {{157., 
                0.3}, {157., 0.32}}, {{158., 0.29}, {158., 0.32}}, {{159., 
                0.28}, {159., 0.31}}, {{160., 0.27}, {160., 0.3}}, {{161., 
                0.26}, {161., 0.29}}, {{162., 0.25}, {162., 0.29}}, {{163., 
                0.24}, {163., 0.28}}, {{164., 0.23}, {164., 0.27}}, {{165., 
                0.22}, {165., 0.26}}, {{166., 0.2}, {166., 0.25}}, {{167., 
                0.18}, {167., 0.24}}, {{168., 0.16}, {168., 0.22}}, {{169., 
                0.14}, {169., 0.21}}, {{170., 0.13}, {170., 0.19}}, {{171., 
                0.11}, {171., 0.18}}, {{172., 0.09}, {172., 0.16}}, {{173., 
                0.07}, {173., 0.14}}, {{174., 0.06}, {174., 0.13}}, {{175., 
                0.04}, {175., 0.11}}, {{176., 0.02}, {176., 0.09}}, {{177., 
                0.01}, {177., 0.07}}, {{178., -0.01}, {178., 0.06}}, {{
                179., -0.02}, {179., 0.04}}, {{180., -0.04}, {180., 0.02}}, {{
                181., -0.05}, {181., 0.01}}, {{182., -0.06}, {
                182., -0.01}}, {{183., -0.06}, {183., -0.02}}, {{
                184., -0.07}, {184., -0.03}}, {{185., -0.08}, {
                185., -0.04}}, {{186., -0.09}, {186., -0.05}}, {{
                187., -0.1}, {187., -0.06}}, {{188., -0.11}, {
                188., -0.07}}, {{189., -0.12}, {189., -0.08}}, {{
                190., -0.12}, {190., -0.09}}, {{191., -0.14}, {
                191., -0.1}}, {{192., -0.15}, {192., -0.11}}, {{
                193., -0.16}, {193., -0.12}}, {{194., -0.17}, {
                194., -0.13}}, {{195., -0.19}, {195., -0.14}}, {{
                196., -0.2}, {196., -0.15}}, {{197., -0.21}, {
                197., -0.16}}, {{198., -0.22}, {198., -0.17}}, {{
                199., -0.22}, {199., -0.18}}, {{200., -0.22}, {
                200., -0.19}}, {{201., -0.21}, {201., -0.2}}, {{202., -0.2}, {
                202., -0.2}}, {{203., -0.18}, {203., -0.2}}, {{204., -0.16}, {
                204., -0.2}}, {{205., -0.14}, {205., -0.19}}, {{
                206., -0.11}, {206., -0.18}}, {{207., -0.08}, {
                207., -0.17}}, {{208., -0.04}, {208., -0.15}}, {{209., 0.}, {
                209., -0.12}}, {{210., 0.04}, {210., -0.1}}, {{211., 0.08}, {
                211., -0.06}}, {{212., 0.12}, {212., -0.03}}, {{213., 0.16}, {
                213., 0.01}}, {{214., 0.19}, {214., 0.04}}, {{215., 0.22}, {
                215., 0.08}}, {{216., 0.24}, {216., 0.11}}, {{217., 0.26}, {
                217., 0.15}}, {{218., 0.27}, {218., 0.18}}, {{219., 0.28}, {
                219., 0.2}}, {{220., 0.28}, {220., 0.22}}, {{221., 0.28}, {
                221., 0.24}}, {{222., 0.27}, {222., 0.25}}, {{223., 0.26}, {
                223., 0.26}}, {{224., 0.24}, {224., 0.26}}, {{225., 0.23}, {
                225., 0.26}}, {{226., 0.21}, {226., 0.26}}, {{227., 0.19}, {
                227., 0.25}}, {{228., 0.17}, {228., 0.24}}, {{229., 0.15}, {
                229., 0.22}}, {{230., 0.13}, {230., 0.21}}, {{231., 0.12}, {
                231., 0.19}}, {{232., 0.1}, {232., 0.17}}, {{233., 0.08}, {
                233., 0.15}}, {{234., 0.07}, {234., 0.14}}, {{235., 0.05}, {
                235., 0.12}}, {{236., 0.04}, {236., 0.1}}, {{237., 0.03}, {
                237., 0.09}}, {{238., 0.02}, {238., 0.07}}, {{239., 0.01}, {
                239., 0.06}}, {{240., 0.}, {240., 0.05}}, {{241., -0.01}, {
                241., 0.03}}, {{242., -0.01}, {242., 0.02}}, {{243., -0.02}, {
                243., 0.01}}, {{244., -0.02}, {244., 0.01}}, {{245., -0.02}, {
                245., 0.}}, {{246., -0.02}, {246., -0.01}}, {{247., -0.02}, {
                247., -0.01}}, {{248., -0.01}, {248., -0.01}}, {{249., 0.}, {
                249., -0.01}}, {{250., 0.01}, {250., -0.01}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "SubplotIndicatorValues"]] :> {{{"", ""}, {0.22, 0.22}, {0.13, 
                0.18}, {0.09, 0.15}, {0.06, 0.12}, {0.04, 0.11}, {0.03, 
                0.1}, {0.03, 0.09}, {0.03, 0.08}, {0.03, 0.07}, {0.03, 
                0.05}, {0.03, 0.04}, {0.02, 0.03}, {0.02, 0.03}, {0.02, 
                0.03}, {0.08, 0.03}, {0.06, 0.03}, {0.05, 0.04}, {0.05, 
                0.04}, {0.05, 0.04}, {0.05, 0.04}, {0.06, 0.05}, {0.06, 
                0.05}, {0.06, 0.06}, {0.05, 0.05}, {0.05, 0.05}, {0.05, 
                0.05}, {0.04, 0.05}, {0.04, 0.05}, {0.03, 0.05}, {0.03, 
                0.05}, {0.02, 0.04}, {0.02, 0.04}, {0.01, 0.03}, {0.01, 
                0.03}, {0.01, 0.02}, {0.02, 0.02}, {0.02, 0.02}, {0.03, 
                0.02}, {0.04, 0.02}, {0.06, 0.03}, {0.08, 0.03}, {0.11, 
                0.04}, {0.14, 0.06}, {0.17, 0.07}, {0.2, 0.1}, {0.23, 0.12}, {
                0.26, 0.14}, {0.29, 0.17}, {0.32, 0.2}, {0.35000000000000003`,
                 0.23}, {0.37, 0.26}, {0.39, 0.29}, {0.41000000000000003`, 
                0.31}, {0.42, 0.34}, {0.42, 0.36}, {0.42, 0.38}, {
                0.41000000000000003`, 0.39}, {0.4, 0.4}, {0.38, 0.4}, {0.37, 
                0.4}, {0.34, 0.4}, {0.32, 0.39}, {0.29, 0.37}, {0.25, 
                0.35000000000000003`}, {0.21, 0.33}, {0.17, 0.3}, {0.13, 
                0.27}, {0.09, 0.24}, {0.05, 0.21}, {0.01, 0.17}, {-0.03, 
                0.13}, {-0.07, 0.09}, {-0.11, 0.05}, {-0.16, 
                0.01}, {-0.2, -0.03}, {-0.24, -0.07}, {-0.27, -0.11}, {-0.3, \
-0.15}, {-0.33, -0.19}, {-0.35000000000000003`, -0.23}, {-0.37, -0.26}, \
{-0.38, -0.29}, {-0.39, -0.31}, {-0.39, -0.34}, {-0.4, \
-0.35000000000000003`}, {-0.4, -0.37}, {-0.39, -0.38}, {-0.38, -0.38}, \
{-0.36, -0.38}, {-0.34, -0.38}, {-0.31, -0.37}, {-0.28, -0.36}, {-0.25, \
-0.35000000000000003`}, {-0.22, -0.33}, {-0.18, -0.3}, {-0.15, -0.27}, \
{-0.11, -0.25}, {-0.08, -0.21}, {-0.04, -0.18}, {-0.01, -0.15}, {
                0.02, -0.11}, {0.06, -0.08}, {0.08, -0.05}, {0.11, -0.01}, {
                0.13, 0.02}, {0.15, 0.05}, {0.15, 0.07}, {0.16, 0.09}, {0.16, 
                0.11}, {0.15, 0.13}, {0.14, 0.14}, {0.13, 0.14}, {0.12, 
                0.14}, {0.1, 0.14}, {0.08, 0.13}, {0.07, 0.12}, {0.05, 
                0.11}, {0.03, 0.1}, {0.01, 0.08}, {0., 0.07}, {-0.01, 
                0.05}, {-0.01, 0.04}, {-0.01, 0.02}, {-0.01, 0.01}, {0., 
                0.01}, {0.01, 0.}, {0.03, 0.}, {0.05, 0.01}, {0.07, 0.01}, {
                0.1, 0.02}, {0.12, 0.04}, {0.15, 0.06}, {0.18, 0.08}, {0.21, 
                0.1}, {0.23, 0.13}, {0.26, 0.15}, {0.27, 0.18}, {0.29, 0.2}, {
                0.31, 0.23}, {0.33, 0.25}, {0.34, 0.27}, {
                0.35000000000000003`, 0.29}, {0.35000000000000003`, 0.3}, {
                0.35000000000000003`, 0.32}, {0.35000000000000003`, 0.33}, {
                0.35000000000000003`, 0.34}, {0.35000000000000003`, 0.34}, {
                0.34, 0.35000000000000003`}, {0.33, 0.35000000000000003`}, {
                0.33, 0.35000000000000003`}, {0.33, 0.34}, {0.32, 0.34}, {
                0.32, 0.34}, {0.31, 0.33}, {0.3, 0.33}, {0.3, 0.32}, {0.29, 
                0.32}, {0.28, 0.31}, {0.27, 0.3}, {0.26, 0.29}, {0.25, 
                0.29}, {0.24, 0.28}, {0.23, 0.27}, {0.22, 0.26}, {0.2, 
                0.25}, {0.18, 0.24}, {0.16, 0.22}, {0.14, 0.21}, {0.13, 
                0.19}, {0.11, 0.18}, {0.09, 0.16}, {0.07, 0.14}, {0.06, 
                0.13}, {0.04, 0.11}, {0.02, 0.09}, {0.01, 0.07}, {-0.01, 
                0.06}, {-0.02, 0.04}, {-0.04, 0.02}, {-0.05, 
                0.01}, {-0.06, -0.01}, {-0.06, -0.02}, {-0.07, -0.03}, \
{-0.08, -0.04}, {-0.09, -0.05}, {-0.1, -0.06}, {-0.11, -0.07}, {-0.12, \
-0.08}, {-0.12, -0.09}, {-0.14, -0.1}, {-0.15, -0.11}, {-0.16, -0.12}, \
{-0.17, -0.13}, {-0.19, -0.14}, {-0.2, -0.15}, {-0.21, -0.16}, {-0.22, \
-0.17}, {-0.22, -0.18}, {-0.22, -0.19}, {-0.21, -0.2}, {-0.2, -0.2}, {-0.18, \
-0.2}, {-0.16, -0.2}, {-0.14, -0.19}, {-0.11, -0.18}, {-0.08, -0.17}, {-0.04, \
-0.15}, {0., -0.12}, {0.04, -0.1}, {0.08, -0.06}, {0.12, -0.03}, {0.16, 
                0.01}, {0.19, 0.04}, {0.22, 0.08}, {0.24, 0.11}, {0.26, 
                0.15}, {0.27, 0.18}, {0.28, 0.2}, {0.28, 0.22}, {0.28, 
                0.24}, {0.27, 0.25}, {0.26, 0.26}, {0.24, 0.26}, {0.23, 
                0.26}, {0.21, 0.26}, {0.19, 0.25}, {0.17, 0.24}, {0.15, 
                0.22}, {0.13, 0.21}, {0.12, 0.19}, {0.1, 0.17}, {0.08, 
                0.15}, {0.07, 0.14}, {0.05, 0.12}, {0.04, 0.1}, {0.03, 
                0.09}, {0.02, 0.07}, {0.01, 0.06}, {0., 0.05}, {-0.01, 
                0.03}, {-0.01, 0.02}, {-0.02, 0.01}, {-0.02, 0.01}, {-0.02, 
                0.}, {-0.02, -0.01}, {-0.02, -0.01}, {-0.01, -0.01}, {
                0., -0.01}, {0.01, -0.01}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$541720["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$541720["YRange"]] :> 24.95,
              HoldPattern[
               System`TradingChartDump`$layoutData$541720[
               "SubplotPoints", {1}]] :> {{}, {0.22, 0.22}, {0.13, 0.18}, {
               0.09, 0.15}, {0.06, 0.12}, {0.04, 0.11}, {0.03, 0.1}, {0.03, 
               0.09}, {0.03, 0.08}, {0.03, 0.07}, {0.03, 0.05}, {0.03, 
               0.04}, {0.02, 0.03}, {0.02, 0.03}, {0.02, 0.03}, {0.08, 
               0.03}, {0.06, 0.03}, {0.05, 0.04}, {0.05, 0.04}, {0.05, 
               0.04}, {0.05, 0.04}, {0.06, 0.05}, {0.06, 0.05}, {0.06, 
               0.06}, {0.05, 0.05}, {0.05, 0.05}, {0.05, 0.05}, {0.04, 
               0.05}, {0.04, 0.05}, {0.03, 0.05}, {0.03, 0.05}, {0.02, 
               0.04}, {0.02, 0.04}, {0.01, 0.03}, {0.01, 0.03}, {0.01, 
               0.02}, {0.02, 0.02}, {0.02, 0.02}, {0.03, 0.02}, {0.04, 
               0.02}, {0.06, 0.03}, {0.08, 0.03}, {0.11, 0.04}, {0.14, 
               0.06}, {0.17, 0.07}, {0.2, 0.1}, {0.23, 0.12}, {0.26, 0.14}, {
               0.29, 0.17}, {0.32, 0.2}, {0.35000000000000003`, 0.23}, {0.37, 
               0.26}, {0.39, 0.29}, {0.41000000000000003`, 0.31}, {0.42, 
               0.34}, {0.42, 0.36}, {0.42, 0.38}, {0.41000000000000003`, 
               0.39}, {0.4, 0.4}, {0.38, 0.4}, {0.37, 0.4}, {0.34, 0.4}, {
               0.32, 0.39}, {0.29, 0.37}, {0.25, 0.35000000000000003`}, {0.21,
                0.33}, {0.17, 0.3}, {0.13, 0.27}, {0.09, 0.24}, {0.05, 
               0.21}, {0.01, 0.17}, {-0.03, 0.13}, {-0.07, 0.09}, {-0.11, 
               0.05}, {-0.16, 
               0.01}, {-0.2, -0.03}, {-0.24, -0.07}, {-0.27, -0.11}, {-0.3, \
-0.15}, {-0.33, -0.19}, {-0.35000000000000003`, -0.23}, {-0.37, -0.26}, \
{-0.38, -0.29}, {-0.39, -0.31}, {-0.39, -0.34}, {-0.4, \
-0.35000000000000003`}, {-0.4, -0.37}, {-0.39, -0.38}, {-0.38, -0.38}, \
{-0.36, -0.38}, {-0.34, -0.38}, {-0.31, -0.37}, {-0.28, -0.36}, {-0.25, \
-0.35000000000000003`}, {-0.22, -0.33}, {-0.18, -0.3}, {-0.15, -0.27}, \
{-0.11, -0.25}, {-0.08, -0.21}, {-0.04, -0.18}, {-0.01, -0.15}, {
               0.02, -0.11}, {0.06, -0.08}, {0.08, -0.05}, {0.11, -0.01}, {
               0.13, 0.02}, {0.15, 0.05}, {0.15, 0.07}, {0.16, 0.09}, {0.16, 
               0.11}, {0.15, 0.13}, {0.14, 0.14}, {0.13, 0.14}, {0.12, 
               0.14}, {0.1, 0.14}, {0.08, 0.13}, {0.07, 0.12}, {0.05, 0.11}, {
               0.03, 0.1}, {0.01, 0.08}, {0., 0.07}, {-0.01, 0.05}, {-0.01, 
               0.04}, {-0.01, 0.02}, {-0.01, 0.01}, {0., 0.01}, {0.01, 0.}, {
               0.03, 0.}, {0.05, 0.01}, {0.07, 0.01}, {0.1, 0.02}, {0.12, 
               0.04}, {0.15, 0.06}, {0.18, 0.08}, {0.21, 0.1}, {0.23, 0.13}, {
               0.26, 0.15}, {0.27, 0.18}, {0.29, 0.2}, {0.31, 0.23}, {0.33, 
               0.25}, {0.34, 0.27}, {0.35000000000000003`, 0.29}, {
               0.35000000000000003`, 0.3}, {0.35000000000000003`, 0.32}, {
               0.35000000000000003`, 0.33}, {0.35000000000000003`, 0.34}, {
               0.35000000000000003`, 0.34}, {0.34, 0.35000000000000003`}, {
               0.33, 0.35000000000000003`}, {0.33, 0.35000000000000003`}, {
               0.33, 0.34}, {0.32, 0.34}, {0.32, 0.34}, {0.31, 0.33}, {0.3, 
               0.33}, {0.3, 0.32}, {0.29, 0.32}, {0.28, 0.31}, {0.27, 0.3}, {
               0.26, 0.29}, {0.25, 0.29}, {0.24, 0.28}, {0.23, 0.27}, {0.22, 
               0.26}, {0.2, 0.25}, {0.18, 0.24}, {0.16, 0.22}, {0.14, 0.21}, {
               0.13, 0.19}, {0.11, 0.18}, {0.09, 0.16}, {0.07, 0.14}, {0.06, 
               0.13}, {0.04, 0.11}, {0.02, 0.09}, {0.01, 0.07}, {-0.01, 
               0.06}, {-0.02, 0.04}, {-0.04, 0.02}, {-0.05, 
               0.01}, {-0.06, -0.01}, {-0.06, -0.02}, {-0.07, -0.03}, {-0.08, \
-0.04}, {-0.09, -0.05}, {-0.1, -0.06}, {-0.11, -0.07}, {-0.12, -0.08}, \
{-0.12, -0.09}, {-0.14, -0.1}, {-0.15, -0.11}, {-0.16, -0.12}, {-0.17, \
-0.13}, {-0.19, -0.14}, {-0.2, -0.15}, {-0.21, -0.16}, {-0.22, -0.17}, \
{-0.22, -0.18}, {-0.22, -0.19}, {-0.21, -0.2}, {-0.2, -0.2}, {-0.18, -0.2}, \
{-0.16, -0.2}, {-0.14, -0.19}, {-0.11, -0.18}, {-0.08, -0.17}, {-0.04, \
-0.15}, {0., -0.12}, {0.04, -0.1}, {0.08, -0.06}, {0.12, -0.03}, {0.16, 
               0.01}, {0.19, 0.04}, {0.22, 0.08}, {0.24, 0.11}, {0.26, 
               0.15}, {0.27, 0.18}, {0.28, 0.2}, {0.28, 0.22}, {0.28, 0.24}, {
               0.27, 0.25}, {0.26, 0.26}, {0.24, 0.26}, {0.23, 0.26}, {0.21, 
               0.26}, {0.19, 0.25}, {0.17, 0.24}, {0.15, 0.22}, {0.13, 
               0.21}, {0.12, 0.19}, {0.1, 0.17}, {0.08, 0.15}, {0.07, 0.14}, {
               0.05, 0.12}, {0.04, 0.1}, {0.03, 0.09}, {0.02, 0.07}, {0.01, 
               0.06}, {0., 0.05}, {-0.01, 0.03}, {-0.01, 0.02}, {-0.02, 
               0.01}, {-0.02, 0.01}, {-0.02, 
               0.}, {-0.02, -0.01}, {-0.02, -0.01}, {-0.01, -0.01}, {
               0., -0.01}, {0.01, -0.01}}, HoldPattern[
               System`TradingChartDump`$layoutData$541720[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$541720[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$541720[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$541720[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$541720[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$541720 = 
           System`TradingChartDump`$length$541720; 
          System`TradingChartDump`$layoutData$541720["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$541720; 
          System`TradingChartDump`$modelData$541720["Data"] = 
           System`TradingChartDump`$data$541720; 
          System`TradingChartDump`$modelData$541720["Indicators"] = 
           System`TradingChartDump`$indicators$541720; 
          System`TradingChartDump`$layoutData$541720[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541720["ScalingFunctions"] = {
            System`TradingChartDump`$sy$541720, 
             System`TradingChartDump`$isy$541720}; 
          System`TradingChartDump`$layoutData$541720["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541720["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541720[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541720["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$541720["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$541720, 
            System`TradingChartDump`$layoutData$541720, 
            System`TradingChartDump`$indicators$541720]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$541720, 
            System`TradingChartDump`$layoutData$541720, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$541720[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$541720["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$541720[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$541720[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$541720["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$541720[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$541720 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541720["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541720, 
                 System`TradingChartDump`$controlmax$541720}]]]; 
          System`TradingChartDump`$plotrangemax$541720 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541720["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541720, 
                 System`TradingChartDump`$controlmax$541720}]]]; {
            System`TradingChartDump`$plotrangemin$541720, 
             System`TradingChartDump`$plotrangemax$541720} = ReplaceAll[
             
             System`TradingChartDump`$sy$541720[{
              System`TradingChartDump`$plotrangemin$541720, 
               System`TradingChartDump`$plotrangemax$541720}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$541720[
                Min[System`TradingChartDump`$lows$541720]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$541720 == 
            System`TradingChartDump`$plotrangemax$541720, {
             System`TradingChartDump`$plotrangemin$541720, 
              System`TradingChartDump`$plotrangemax$541720} = {
             System`TradingChartDump`$plotrangemin$541720 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$541720], 
              System`TradingChartDump`$plotrangemax$541720 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$541720]}]; 
          System`TradingChartDump`$newgridlines$541720 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$541720, 
            Part[System`TradingChartDump`$newgridlines$541720, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$541720, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$541720], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$541720, 1]]; 
            Part[System`TradingChartDump`$newgridlines$541720, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$541720, 1] =!= None,
                 System`TradingChartDump`$length$541720 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$541720, 
                 Part[System`TradingChartDump`$newgridlines$541720, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$541720, 1]]; 
            System`TradingChartDump`$subpricegridlines$541720 = 
             Part[System`TradingChartDump`$gridlines$541720, 2]; 
            Part[System`TradingChartDump`$newgridlines$541720, 2] = 
             If[System`TradingChartDump`$sy$541720 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541720}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541720, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541720, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$541720, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$541720, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541720}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541720, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541720, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$541720 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$541720]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"GE\"", "\" with \"", 
           "\"TRIX\"", "\"(\"", "15", "\",\"", "", "\",\"", "", "\",\"", "", 
           "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {240., -1171.8}, ImageScaled[{0.5, 0.5}], {450, 310}],
      InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$541734 = 
        "Full", System`TradingChartDump`$highlightposition$541734 = Automatic,
         System`TradingChartDump`$maxohlc$541734 = 24.95`4., 
        System`TradingChartDump`$timestampstyle$541734 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$541734 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$541734 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$541734, 
        System`TradingChartDump`$subplotpoint$541734, 
        System`TradingChartDump`$ndigits$541734 = 4, 
        System`TradingChartDump`$highlightstyle$541734 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$541734 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$541734 = True, 
        System`TradingChartDump`$timestampQ$541734 = True, 
        System`TradingChartDump`$data$541734 = {{{2012, 7, 26}, {
          19.55155642023346, 20.035505836575872`, 19.512840466926068`, 19.9, 
           57275600}}, {{2012, 7, 27}, {
          19.96928776290631, 20.327437858508603`, 19.901529636711278`, 20.25, 
           80268300}}, {{2012, 7, 30}, {
          20.120322115384614`, 20.236456730769227`, 20.023543269230768`, 
           20.13, 44993600}}, {{2012, 7, 31}, {
          20.08, 20.21547951807229, 20.08, 20.08, 38328400}}, {{2012, 8, 1}, {
          20.185798359864926`, 20.27288953207911, 20.040646406174623`, 20.06, 
           35734300}}, {{2012, 8, 2}, {
          19.860000000000003`, 20.03421052631579, 19.55029239766082, 19.86, 
           44000400}}, {{2012, 8, 3}, {
          20.144541984732825`, 20.318702290076335`, 20.096164122137402`, 
           20.28, 37891500}}, {{2012, 8, 6}, {
          20.29, 20.493190271816882`, 20.22226990939437, 20.29, 34159500}}, {{
          2012, 8, 7}, {
          20.459356060606062`, 20.507746212121216`, 20.410965909090912`, 
           20.44, 31115300}}, {{2012, 8, 8}, {
          20.36870537839124, 20.407410756782483`, 20.22356020942408, 20.33, 
           32345900}}, {{2012, 8, 9}, {
          20.263874643874647`, 20.43806267806268, 20.263874643874647`, 20.38, 
           31159700}}, {{2012, 8, 10}, {
          20.323222748815166`, 20.42, 20.265156398104267`, 20.42, 
           24419100}}, {{2012, 8, 13}, {
          20.358380181038587`, 20.377732253454024`, 20.2035636017151, 20.31, 
           26873600}}, {{2012, 8, 14}, {
          20.395453677172874`, 20.42447946513849, 20.22129894937918, 20.26, 
           30095000}}, {{2012, 8, 15}, {
          20.18324427480916, 20.34772900763359, 20.11551526717557, 20.28, 
           28870100}}, {{2012, 8, 16}, {
          20.195814726840858`, 20.457092636579574`, 20.147429928741094`, 
           20.37, 33598000}}, {{2012, 8, 17}, {
          20.33935238095238, 20.368380952380953`, 20.26194285714286, 20.32, 
           30032500}}, {{2012, 8, 20}, {
          20.269350215002387`, 20.33707596751075, 20.153248924988052`, 20.25, 
           27385500}}, {{2012, 8, 21}, {
          20.296143884892086`, 20.373573141486812`, 20.131606714628298`, 
           20.18, 30438800}}, {{2012, 8, 22}, {
          20.100322425409047`, 20.197098171318576`, 20.04225697786333, 20.11, 
           28016800}}, {{2012, 8, 23}, {
          20.06675387596899, 20.115130813953485`, 19.960324612403095`, 19.97, 
           36538800}}, {{2012, 8, 24}, {
          19.92676442307692, 20.22677884615384, 19.888052884615384`, 20.13, 
           29338200}}, {{2012, 8, 27}, {
          20.15096402877698, 20.276786570743404`, 20.121928057553955`, 20.18, 
           28775600}}, {{2012, 8, 28}, {
          20.09160980297934, 20.246458433445465`, 20.09160980297934, 20.14, 
           25912400}}, {{2012, 8, 29}, {
          20.15, 20.275816522574445`, 20.140321805955807`, 20.15, 
           19925800}}, {{2012, 8, 30}, {
          20.04740310077519, 20.10545542635659, 19.9506492248062, 19.97, 
           21237800}}, {{2012, 8, 31}, {
          20.08838242394978, 20.156117817479473`, 19.94323515210043, 20.04, 
           29679000}}, {{2012, 9, 4}, {
          19.966138469039493`, 20.024207703559238`, 19.820965382740127`, 
           19.85, 38173600}}, {{2012, 9, 5}, {
          19.883244552058112`, 20.096106537530268`, 19.84454237288136, 19.98, 
           33033500}}, {{2012, 9, 6}, {
          20.19424683247302, 20.629676208352887`, 20.17489441576725, 20.62, 
           53178600}}, {{2012, 9, 7}, {
          20.628754052802222`, 20.89, 20.609402501157945`, 20.89, 
           36379800}}, {{2012, 9, 10}, {
          20.79, 20.954539106145248`, 20.741606145251396`, 20.79, 
           33672300}}, {{2012, 9, 11}, {
          20.7932422417786, 20.9867577582214, 20.70616025937934, 20.89, 
           33593100}}, {{2012, 9, 12}, {
          20.967135678391962`, 21.218702603928733`, 20.957460027409777`, 
           21.18, 43006000}}, {{2012, 9, 13}, {
          21.0680608537693, 21.522906448683013`, 21.048705722070842`, 21.31, 
           111794200}}, {{2012, 9, 14}, {
          21.487109905020354`, 21.651650836725466`, 21.27417458163727, 21.4, 
           100148400}}, {{2012, 9, 17}, {
          21.22386394557823, 21.34, 21.194829931972787`, 21.34, 79283200}}, {{
          2012, 9, 18}, {
          21.278093525179855`, 21.52, 21.24906474820144, 21.52, 38831200}}, {{
          2012, 9, 19}, {
          21.584172982612575`, 21.768074008024968`, 21.535777975925104`, 
           21.71, 40462600}}, {{2012, 9, 20}, {
          21.63599197503344, 21.909001337494427`, 21.567739634418192`, 21.87, 
           43677000}}, {{2012, 9, 21}, {
          21.989502885042164`, 22.126023080337326`, 21.901739902352418`, 
           21.97, 66551700}}, {{2012, 9, 24}, {
          21.838998211091234`, 21.887745974955276`, 21.74150268336315, 21.8, 
           36799800}}, {{2012, 9, 25}, {
          21.8380277902286, 22.11112505602869, 21.750246526221428`, 21.76, 
           47039200}}, {{2012, 9, 26}, {
          21.608506787330317`, 21.69626696832579, 21.520746606334843`, 21.55, 
           41123300}}, {{2012, 9, 27}, {
          21.682287725472943`, 22.286739991201056`, 21.575046194456664`, 
           22.16, 67300400}}, {{2012, 9, 28}, {
          22.20852047556142, 22.393835314839276`, 22.062219286657857`, 22.15, 
           70926100}}, {{2012, 10, 1}, {
          22.161999123191585`, 22.42525208241999, 22.14249890398948, 22.24, 
           42550700}}, {{2012, 10, 2}, {
          22.3564984642387, 22.414997806055286`, 22.142000877577885`, 22.22, 
           45297400}}, {{2012, 10, 3}, {
          22.29124399825404, 22.40825840244435, 22.154727193365343`, 22.34, 
           32929400}}, {{2012, 10, 4}, {
          22.38, 22.477516339869283`, 22.204470588235292`, 22.38, 
           40344600}}, {{2012, 10, 5}, {
          22.46200692041522, 22.598494809688578`, 22.423010380622834`, 22.54, 
           38312500}}, {{2012, 10, 8}, {
          22.301243455497385`, 22.418259162303666`, 22.281740837696336`, 
           22.35, 24202200}}, {{2012, 10, 9}, {
          22.37207780725022, 22.401335101679926`, 22.04049513704686, 22.06, 
           39176000}}, {{2012, 10, 10}, {
          22.04550601872492, 22.17226036558181, 21.850499331252788`, 21.87, 
           32784100}}, {{2012, 10, 11}, {
          22.02800977343403, 22.14502443358507, 21.92074633496224, 21.95, 
           24161800}}, {{2012, 10, 12}, {
          22.017508896797153`, 22.144270462633454`, 21.851743772241996`, 
           21.92, 32954600}}, {{2012, 10, 15}, {
          21.98247349823321, 22.138515901060067`, 21.933710247349822`, 22.08, 
           29578600}}, {{2012, 10, 16}, {
          22.226289752650175`, 22.314063604240282`, 22.01173144876325, 22.08, 
           35668800}}, {{2012, 10, 17}, {
          22.203483195111303`, 22.349751200349196`, 22.154727193365343`, 
           22.34, 28272500}}, {{2012, 10, 18}, {
          22.24, 22.50325295922841, 22.230249890398948`, 22.24, 43140700}}, {{
          2012, 10, 19}, {
          21.9480163413527, 21.967517022242397`, 21.323994552882436`, 21.48, 
           107879900}}, {{2012, 10, 22}, {
          21.316018433179725`, 21.40377880184332, 20.72119815668203, 21.16, 
           86735100}}, {{2012, 10, 23}, {
          20.81825657894737, 20.867011278195488`, 20.671992481203006`, 20.75, 
           56297300}}, {{2012, 10, 24}, {
          20.8957619943556, 20.925014111006586`, 20.71049858889934, 20.73, 
           42295500}}, {{2012, 10, 25}, {
          20.964016933207905`, 21.032271872060207`, 20.505733772342428`, 
           20.73, 45769600}}, {{2012, 10, 26}, {
          20.657991473235434`, 20.862719090478446`, 20.541004263382284`, 
           20.58, 42827400}}, {{2012, 10, 31}, {
          20.735061728395063`, 20.79358024691358, 20.452222222222222`, 20.54, 
           39179300}}, {{2012, 11, 1}, {
          20.50769915651359, 20.858758200562324`, 20.497947516401123`, 20.81, 
           46231300}}, {{2012, 11, 2}, {
          20.994528390427032`, 21.14079774753637, 20.731243547630225`, 20.78, 
           47475200}}, {{2012, 11, 5}, {
          20.67519850537132, 20.938514712751047`, 20.67519850537132, 20.88, 
           30000100}}, {{2012, 11, 6}, {
          20.972000926354795`, 21.235247799907366`, 20.913501621120886`, 
           21.05, 32733200}}, {{2012, 11, 7}, {
          20.824230951254144`, 20.980217699952675`, 20.54150496923805, 20.6, 
           45253400}}, {{2012, 11, 8}, {
          20.633279080899953`, 20.66253231211106, 20.36024892292963, 20.37, 
           40770700}}, {{2012, 11, 9}, {
          20.245942857142857`, 20.77257142857143, 20.18742857142857, 20.48, 
           40306800}}, {{2012, 11, 12}, {
          20.51626615605553, 20.613776926759215`, 20.36024892292963, 20.37, 
           21816400}}, {{2012, 11, 13}, {
          20.091972920696332`, 20.433341392649908`, 20.06271276595745, 20.17, 
           41073300}}, {{2012, 11, 14}, {
          20.21200899550225, 20.231509245377314`, 19.451499250374813`, 19.51, 
           65539500}}, {{2012, 11, 15}, {
          19.403988035892322`, 19.72576271186441, 19.403988035892322`, 19.56, 
           51760300}}, {{2012, 11, 16}, {
          19.601240694789084`, 19.689007444168734`, 19.376947890818858`, 
           19.65, 45287500}}, {{2012, 11, 19}, {
          19.90617134559535, 20.208518877057113`, 19.88666505324298, 20.15, 
           38283400}}, {{2012, 11, 20}, {
          20.15876333656644, 20.178268671193017`, 19.8661833171678, 20.11, 
           26845900}}, {{2012, 11, 21}, {
          20.189506769825922`, 20.22852030947776, 20.06271276595745, 20.17, 
           41020400}}, {{2012, 11, 23}, {
          20.295684410646388`, 20.52, 20.217661596958177`, 20.52, 
           35456500}}, {{2012, 11, 26}, {
          20.364444444444445`, 20.549753086419752`, 20.35469135802469, 20.54, 
           47741300}}, {{2012, 11, 27}, {
          20.515764254911353`, 20.67177767129851, 20.330498322951605`, 20.35, 
           33001700}}, {{2012, 11, 28}, {
          20.229777672658468`, 20.619749290444656`, 19.9860454115421, 20.61, 
           34782700}}, {{2012, 11, 29}, {
          20.70724088973024, 20.824230951254144`, 20.42451490771415, 20.6, 
           27632800}}, {{2012, 11, 30}, {
          20.60974917179366, 20.726739233317563`, 20.512257453857078`, 20.6, 
           37857000}}, {{2012, 12, 3}, {
          20.651008645533143`, 20.699759846301635`, 20.280499519692604`, 20.3,
            29981900}}, {{2012, 12, 4}, {
          20.34975071907958, 20.486260786193675`, 20.19373921380633, 20.34, 
           36817200}}, {{2012, 12, 5}, {
          20.38798869524258, 20.8267545925577, 20.339236928874232`, 20.7, 
           46466500}}, {{2012, 12, 6}, {
          20.67421619092185, 20.859503977538605`, 20.557192325690217`, 20.84, 
           32751200}}, {{2012, 12, 7}, {
          20.910493942218082`, 20.94950605778192, 20.71543336439888, 20.93, 
           33548600}}, {{2012, 12, 10}, {
          20.899008882655444`, 20.967274427302478`, 20.830743338008414`, 
           20.86, 27604300}}, {{2012, 12, 11}, {
          20.940753138075312`, 21.203974895397486`, 20.823765690376565`, 
           20.97, 45757200}}, {{2012, 12, 12}, {
          21.074214876033054`, 21.40578512396694, 21.035206611570246`, 21.24, 
           42413600}}, {{2012, 12, 13}, {
          21.197002775208137`, 21.37250693802035, 21.011748381128584`, 21.08, 
           33966000}}, {{2012, 12, 14}, {
          21.07024976873265, 21.21650323774283, 21.011748381128584`, 21.08, 
           47536600}}, {{2012, 12, 17}, {
          21.146019151846783`, 21.399498404012764`, 21.146019151846783`, 
           21.38, 48483700}}, {{2012, 12, 18}, {
          21.30601659751037, 21.36452282157676, 20.876970954356842`, 21.15, 
           81119200}}, {{2012, 12, 19}, {
          21.104407425035696`, 21.123912422655877`, 20.450990004759635`, 
           20.49, 92330700}}, {{2012, 12, 20}, {
          20.57226128266033, 20.89693111638955, 20.532907363420428`, 20.71, 
           50831400}}, {{2012, 12, 21}, {
          20.510632183908047`, 20.658261494252873`, 20.235057471264366`, 
           20.55, 80833800}}, {{2012, 12, 24}, {
          20.460475504322766`, 20.62778097982709, 20.421109510086453`, 20.49, 
           15097200}}, {{2012, 12, 26}, {
          20.479364467982666`, 20.60729898892634, 20.380953298026, 20.44, 
           28557100}}, {{2012, 12, 27}, {
          20.468245529241177`, 20.537129047849202`, 20.094306428226197`, 
           20.36, 38330700}}, {{2012, 12, 28}, {
          20.119838551859097`, 20.375640900195695`, 20.1001614481409, 20.11, 
           32403400}}, {{2012, 12, 31}, {
          19.961338732729867`, 20.65983801810386, 19.931824678418295`, 20.65, 
           58785000}}, {{2013, 1, 2}, {
          21.167291471415183`, 21.196813495782568`, 20.8622305529522, 21., 
           46089500}}, {{2013, 1, 3}, {
          21.133876777251185`, 21.143715639810427`, 20.710805687203795`, 
           20.76, 48509100}}, {{2013, 1, 4}, {
          20.86983962264151, 20.91903773584906, 20.781283018867928`, 20.86, 
           29802600}}, {{2013, 1, 7}, {
          20.819517274017986`, 20.87855182205395, 20.622735447231427`, 20.79, 
           32746700}}, {{2013, 1, 8}, {
          20.766842105263162`, 20.786526315789477`, 20.353473684210527`, 
           20.57, 40045500}}, {{2013, 1, 9}, {
          20.708582338902147`, 20.738109785202866`, 20.600315035799525`, 
           20.62, 28540500}}, {{2013, 1, 10}, {
          20.702087860179493`, 20.88903637222484, 20.623372697213032`, 20.83, 
           33348200}}, {{2013, 1, 11}, {
          20.87855182205395, 20.898230004732607`, 20.68176999526739, 20.79, 
           41839700}}, {{2013, 1, 14}, {
          20.83903409090909, 20.898068181818182`, 20.730804924242427`, 20.78, 
           31715900}}, {{2013, 1, 15}, {
          20.70256603773585, 20.86983962264151, 20.673047169811323`, 20.86, 
           26551000}}, {{2013, 1, 16}, {
          20.809517045454545`, 20.858712121212122`, 20.72096590909091, 20.78, 
           38932100}}, {{2013, 1, 17}, {
          20.88127699530516, 21.196169014084504`, 20.78287323943662, 20.96, 
           63851700}}, {{2013, 1, 18}, {
          21.591588021778588`, 21.83761796733213, 21.247146098003633`, 21.69, 
           113079400}}, {{2013, 1, 22}, {
          21.82729668332576, 21.846978646069967`, 21.55174920490686, 21.66, 
           55165800}}, {{2013, 1, 23}, {
          21.629361896080216`, 21.67856426618049, 21.40303099361896, 21.59, 
           47228500}}, {{2013, 1, 24}, {
          21.611428571428572`, 21.837777777777777`, 21.6015873015873, 21.7, 
           46991100}}, {{2013, 1, 25}, {
          21.920161507402426`, 21.949676985195154`, 21.752907133243607`, 
           21.93, 41919800}}, {{2013, 1, 28}, {
          22.080960000000005`, 22.179360000000003`, 21.903840000000002`, 
           22.14, 49558400}}, {{2013, 1, 29}, {
          22.13016, 22.21872, 22.041600000000003`, 22.14, 34148000}}, {{2013, 
          1, 30}, {
          22.155303643724697`, 22.184817813765186`, 21.87, 21.87, 
           36200400}}, {{2013, 1, 31}, {
          21.85113105924596, 22.03806104129264, 21.8216157989228, 21.92, 
           34427700}}, {{2013, 2, 1}, {
          22.073023872679045`, 22.27968169761273, 21.964774535809017`, 22.26, 
           43840300}}, {{2013, 2, 4}, {
          22.0483863738234, 22.127095472882115`, 21.920484087852984`, 21.95, 
           35836600}}, {{2013, 2, 5}, {
          22.120958296362023`, 22.258722271517303`, 22.091437444543033`, 
           22.18, 30917700}}, {{2013, 2, 6}, {
          22.109518716577536`, 22.139037433155078`, 21.952085561497324`, 
           22.08, 42985800}}, {{2013, 2, 7}, {
          22.139679715302492`, 22.14951957295374, 21.913362989323847`, 22.12, 
           38325900}}, {{2013, 2, 8}, {
          22.14, 22.19904, 22.0908, 22.14, 24424600}}, {{2013, 2, 11}, {
          22.129358574610244`, 22.14903786191537, 21.99160356347439, 22.09, 
           19738700}}, {{2013, 2, 12}, {
          22.121594331266607`, 22.288883968113375`, 22.121594331266607`, 
           22.22, 34297500}}, {{2013, 2, 13}, {
          22.744429243266353`, 23.108576314664386`, 22.675536554082942`, 
           23.02, 84926900}}, {{2013, 2, 14}, {
          22.882528833831696`, 23.11873558308415, 22.74474156343443, 23.04, 
           53996500}}, {{2013, 2, 15}, {
          23.106981537140406`, 23.175869471876346`, 22.86095319879777, 22.92, 
           39283000}}, {{2013, 2, 19}, {
          23.04528, 23.37, 23.03544, 23.37, 41219000}}, {{2013, 2, 20}, {
          23.33525843656557, 23.374626228107648`, 22.980948312686888`, 23.04, 
           38107400}}, {{2013, 2, 21}, {
          23.000619088564054`, 23.169303525365432`, 22.9410834049871, 23.08, 
           47811200}}, {{2013, 2, 22}, {
          23.1603249251817, 23.259512612227446`, 23.041299700726807`, 23.2, 
           27836300}}, {{2013, 2, 25}, {
          23.314555019728193`, 23.344318281455507`, 22.630000000000003`, 
           22.63, 51619800}}, {{2013, 2, 26}, {
          22.790624728850325`, 22.96921908893709, 22.73109327548807, 22.87, 
           41316300}}, {{2013, 2, 27}, {
          22.83284552845528, 23.20975609756097, 22.813008130081297`, 23.18, 
           29676400}}, {{2013, 2, 28}, {
          23.188837209302328`, 23.27813953488372, 23.02015503875969, 23.04, 
           39714600}}, {{2013, 3, 1}, {
          22.841319534282018`, 23.158835705045277`, 22.821474773609314`, 
           23.01, 41226900}}, {{2013, 3, 4}, {
          22.970928233777396`, 23.09992264718522, 22.851856467554793`, 23.09, 
           25457800}}, {{2013, 3, 5}, {
          23.27104705383637, 23.519033488766425`, 23.251208139041967`, 23.4, 
           35728000}}, {{2013, 3, 6}, {
          23.648635403464297`, 23.648635403464297`, 23.48, 23.48, 
           31539100}}, {{2013, 3, 7}, {
          23.509839527027022`, 23.638796452702696`, 23.480080236486486`, 
           23.49, 22955700}}, {{2013, 3, 8}, {
          23.669280605805636`, 23.708960875052586`, 23.49071939419436, 23.58, 
           28952100}}, {{2013, 3, 11}, {
          23.499436917866216`, 23.558954276037255`, 23.261367485182046`, 
           23.43, 34947200}}, {{2013, 3, 12}, {
          23.39853908586074, 23.408457923964118`, 23.140649295173, 23.22, 
           36593000}}, {{2013, 3, 13}, {
          23.250404427415926`, 23.329757343550448`, 23.21072796934866, 23.3, 
           24152400}}, {{2013, 3, 14}, {
          23.361122836639932`, 23.569438581680036`, 23.321443647108484`, 23.5,
            34629800}}, {{2013, 3, 15}, {
          23.25, 23.527730375426618`, 23.17064846416382, 23.25, 58857200}}, {{
          2013, 3, 18}, {
          22.990619354838714`, 23.169225806451614`, 22.950929032258063`, 
           23.07, 33700000}}, {{2013, 3, 19}, {
          23.12015437392796, 23.17969125214408, 22.991157804459693`, 23.14, 
           36150200}}, {{2013, 3, 20}, {
          23.537813299232738`, 23.607246376811595`, 23.141052855924976`, 
           23.27, 39254000}}, {{2013, 3, 21}, {
          23.238995276942894`, 23.417604121940748`, 23.109999999999996`, 
           23.11, 38543900}}, {{2013, 3, 22}, {
          23.130406504065036`, 23.20975609756097, 23.090731707317072`, 23.18, 
           30606100}}, {{2013, 3, 25}, {
          23.268373493975904`, 23.298141135972465`, 22.87147160068847, 23.06, 
           41684400}}, {{2013, 3, 26}, {
          23.088832179930794`, 23.118598615916955`, 22.830856401384082`, 
           22.94, 32353500}}, {{2013, 3, 27}, {
          22.840623376623377`, 22.95968831168831, 22.671948051948053`, 22.92, 
           27492500}}, {{2013, 3, 28}, {
          22.95984429065744, 23.019377162629755`, 22.81101211072664, 22.94, 
           31151000}}, {{2013, 4, 1}, {
          22.85038994800693, 22.91984402079723, 22.79085788561525, 22.9, 
           27449700}}, {{2013, 4, 2}, {
          22.991311053984575`, 23.189768637532133`, 22.92185089974293, 23.16, 
           29180100}}, {{2013, 4, 3}, {
          23.19702608695652, 23.21686956521739, 22.740626086956524`, 22.82, 
           52570300}}, {{2013, 4, 4}, {
          22.830545927209705`, 22.949610051993066`, 22.780935875216638`, 22.9,
            30472100}}, {{2013, 4, 5}, {
          22.621020497165286`, 22.75992150021806, 22.58133449629307, 22.75, 
           31402200}}, {{2013, 4, 8}, {
          22.870544982698963`, 22.94, 22.652257785467125`, 22.94, 
           30493600}}, {{2013, 4, 9}, {
          23.068516912402426`, 23.068516912402426`, 22.721248915871637`, 
           22.88, 31668200}}, {{2013, 4, 10}, {
          22.913867684478376`, 23.45943596268024, 22.87418999151824, 23.39, 
           39772300}}, {{2013, 4, 11}, {
          23.36032217041119, 23.528952946163628`, 23.241288681644765`, 23.4, 
           27084400}}, {{2013, 4, 12}, {
          23.29975703324808, 23.39894714407502, 23.141052855924976`, 23.27, 
           27234300}}, {{2013, 4, 15}, {
          23.096291100394566`, 23.11613327487944, 22.630000000000003`, 22.63, 
           46453800}}, {{2013, 4, 16}, {
          22.890233766233766`, 22.92, 22.72155844155844, 22.92, 36016700}}, {{
          2013, 4, 17}, {
          22.778418277680135`, 22.847864674868188`, 22.470869947275915`, 
           22.58, 42672900}}, {{2013, 4, 18}, {
          22.579285399206, 22.668570798412, 22.39079400088222, 22.49, 
           41170900}}, {{2013, 4, 19}, {
          21.768514942528736`, 21.85781149425287, 21.44109425287356, 21.58, 
           108837900}}, {{2013, 4, 22}, {
          21.497451990632317`, 21.507372365339577`, 20.94191100702576, 21.18, 
           87828900}}, {{2013, 4, 23}, {
          21.37960465116279, 21.518497674418605`, 21.191106976744184`, 21.33, 
           65489600}}, {{2013, 4, 24}, {
          21.522090163934426`, 21.859458105646628`, 21.482399817850634`, 
           21.79, 51506700}}, {{2013, 4, 25}, {
          22.037986332574036`, 22.05783143507973, 21.74030979498861, 21.78, 
           41462900}}, {{2013, 4, 26}, {
          21.801864025213867`, 22.218460153084195`, 21.791945069788383`, 
           22.03, 47012500}}, {{2013, 4, 29}, {
          22.129676695105523`, 22.139595868881905`, 21.82218230803772, 22.09, 
           36531800}}, {{2013, 4, 30}, {
          22.11, 22.1992732166891, 22.03064602960969, 22.11, 34054800}}, {{
          2013, 5, 1}, {
          21.920406320541762`, 22.168374717832958`, 21.920406320541762`, 
           21.97, 39201600}}, {{2013, 5, 2}, {
          22.070564516129032`, 22.14, 21.971370967741933`, 22.14, 
           27651500}}, {{2013, 5, 3}, {
          22.39, 22.667766947275148`, 22.370159503766065`, 22.39, 
           45523300}}, {{2013, 5, 6}, {
          22.38015943312666, 22.45952170062002, 22.14207263064659, 22.4, 
           28563900}}, {{2013, 5, 7}, {
          22.509920634920633`, 22.60912698412698, 22.44047619047619, 22.5, 
           28211700}}, {{2013, 5, 8}, {
          22.502581486310298`, 22.83992177314211, 22.443050847457627`, 22.83, 
           39977300}}, {{2013, 5, 9}, {
          22.808340649692713`, 22.91747146619842, 22.510711150131694`, 22.6, 
           29974300}}, {{2013, 5, 10}, {
          22.591021834061134`, 22.729921397379915`, 22.412436681222708`, 
           22.72, 35117300}}, {{2013, 5, 13}, {
          22.67992122538293, 22.699763676148795`, 22.441811816192562`, 22.67, 
           30283800}}, {{2013, 5, 14}, {
          22.671251629726207`, 22.889530638852673`, 22.631564537157754`, 
           22.83, 39592300}}, {{2013, 5, 15}, {
          22.86154905335628, 23.069922547332187`, 22.732555938037866`, 23.06, 
           40153000}}, {{2013, 5, 16}, {
          22.921314997851315`, 23.16938117748174, 22.921314997851315`, 23.09, 
           33023300}}, {{2013, 5, 17}, {
          23.081538789428816`, 23.289838022165387`, 23.012105711849955`, 
           23.27, 41037700}}, {{2013, 5, 20}, {
          23.270886720407294`, 23.389919389053876`, 23.241128553245648`, 
           23.38, 32884800}}, {{2013, 5, 21}, {
          23.400562130177512`, 23.58903634826712, 23.400562130177512`, 23.47, 
           33815000}}, {{2013, 5, 22}, {
          23.590637049455157`, 23.937849958088854`, 23.56087594300084, 23.67, 
           68514400}}, {{2013, 5, 23}, {
          23.33112426035503, 23.559277261200336`, 23.261686390532542`, 23.47, 
           44383600}}, {{2013, 5, 24}, {
          23.3102422439439, 23.478869528261797`, 23.3003229919252, 23.34, 
           41015200}}, {{2013, 5, 28}, {
          23.578631355932202`, 23.648067796610167`, 23.39016101694915, 23.41, 
           47323000}}, {{2013, 5, 29}, {
          23.231768189509307`, 23.50951776649746, 23.21192893401015, 23.45, 
           39236500}}, {{2013, 5, 30}, {
          23.39016101694915, 23.56871186440678, 23.310805084745763`, 23.41, 
           29347100}}, {{2013, 5, 31}, {
          23.407915951972555`, 23.606372212692968`, 23.13007718696398, 23.14, 
           49247600}}, {{2013, 6, 3}, {
          23.18217005076142, 23.588874788494078`, 23.132571912013535`, 23.45, 
           45218400}}, {{2013, 6, 4}, {
          23.400562130177512`, 23.569196956889265`, 23.22200760777684, 23.47, 
           38701300}}, {{2013, 6, 5}, {
          23.368224699828474`, 23.397993138936535`, 23.030849056603774`, 
           23.14, 44756200}}, {{2013, 6, 6}, {
          23.06105645851155, 23.19991873396065, 22.9122754491018, 23.19, 
           42677500}}, {{2013, 6, 7}, {
          23.35254819782062, 23.759283319362954`, 23.28310561609388, 23.67, 
           49041200}}, {{2013, 6, 10}, {
          23.689201009251473`, 23.728881412952063`, 23.45111858704794, 23.59, 
           41626500}}, {{2013, 6, 11}, {
          23.300725190839696`, 23.49911365564038, 23.290805767599664`, 23.39, 
           36183000}}, {{2013, 6, 12}, {
          23.508382978723404`, 23.538140425531914`, 23.230646808510638`, 
           23.31, 33842000}}, {{2013, 6, 13}, {
          23.261845439189184`, 23.599117398648644`, 23.152728040540538`, 
           23.49, 34930500}}, {{2013, 6, 14}, {
          23.488707482993195`, 23.55814200680272, 23.27048469387755, 23.33, 
           27846000}}, {{2013, 6, 17}, {
          23.560159865376523`, 23.6593605384939, 23.460959192259146`, 23.58, 
           39278300}}, {{2013, 6, 18}, {
          23.64390464447185, 24.259062885326763`, 23.58437320180847, 24.14, 
           72766900}}, {{2013, 6, 19}, {
          24.008256880733942`, 24.15706839032527, 23.79, 23.79, 46082200}}, {{
          2013, 6, 20}, {23.63, 23.69, 23.2, 23.25, 62733200}}, {{2013, 6, 
          21}, {23.579999999999995`, 23.639999999999997`, 23.209999999999997`,
            23.36, 65025200}}, {{2013, 6, 24}, {
          23.12, 23.15, 22.76, 22.93, 48760800}}, {{2013, 6, 25}, {
          23.169999999999998`, 23.249999999999996`, 22.939999999999998`, 
           23.11, 36569100}}, {{2013, 6, 26}, {
          23.43, 23.44, 23.02, 23.25, 32531700}}, {{2013, 6, 27}, {
          23.41, 23.48, 23.26, 23.32, 30867900}}, {{2013, 6, 28}, {
          23.32, 23.44, 23.16, 23.19, 45923200}}, {{2013, 7, 1}, {
          23.209999999999997`, 23.639999999999997`, 23.189999999999998`, 
           23.34, 35784800}}, {{2013, 7, 2}, {
          23.27, 23.34, 22.88, 22.9, 47571200}}, {{2013, 7, 3}, {
          22.83, 22.98, 22.76, 22.91, 21448500}}, {{2013, 7, 5}, {
          23.17, 23.24, 22.95, 23.24, 22688900}}, {{2013, 7, 8}, {
          23.36, 23.53, 23.27, 23.32, 35481100}}, {{2013, 7, 9}, {
          23.52, 23.8, 23.51, 23.62, 31541400}}, {{2013, 7, 10}, {
          23.719999999999995`, 23.729999999999997`, 23.359999999999996`, 
           23.54, 28457100}}, {{2013, 7, 11}, {
          23.91, 23.96, 23.63, 23.94, 32618400}}, {{2013, 7, 12}, {
          23.99, 24., 23.59, 23.76, 33257700}}, {{2013, 7, 15}, {
          23.73, 23.74, 23.56, 23.63, 35853500}}, {{2013, 7, 16}, {
          23.659999999999997`, 23.669999999999998`, 23.339999999999996`, 
           23.43, 38192400}}, {{2013, 7, 17}, {
          23.539999999999996`, 23.609999999999996`, 23.429999999999996`, 
           23.54, 26858500}}, {{2013, 7, 18}, {
          23.6, 23.94, 23.56, 23.63, 41438200}}, {{2013, 7, 19}, {
          24.21, 24.95, 24.1, 24.72, 103708900}}, {{2013, 7, 22}, {
          24.77, 24.92, 24.73, 24.86, 41560800}}, {{2013, 7, 23}, {
          24.87, 24.88, 24.63, 24.71, 32553000}}, {{2013, 7, 24}, {
          24.79, 24.84, 24.56, 24.62, 27485000}}, {{2013, 7, 25}, {
          24.61, 24.69, 24.52, 24.69, 29951700}}}, 
        System`TradingChartDump`$markerstyle$541734 = 1, 
        System`TradingChartDump`$controlmin$541734 = 0.5, 
        System`TradingChartDump`$controlmax$541734 = 250.5, 
        System`TradingChartDump`$datescope$541734 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$541734 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$541734, 
        System`TradingChartDump`$max$541734, 
        System`TradingChartDump`$ohlclabel$541734 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541734, 
              System`TradingChartDump`$opens$541734]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541734, 
              System`TradingChartDump`$highs$541734]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541734, 
              System`TradingChartDump`$lows$541734]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541734, 
              System`TradingChartDump`$closes$541734]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$541734, 
              System`TradingChartDump`$visdates$541734]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$541734 = {}, 
        System`TradingChartDump`$subpricegridlines$541734 = Automatic, 
        System`TradingChartDump`$overlaypoint$541734, 
        System`TradingChartDump`$overlayvalue$541734, 
        System`TradingChartDump`$subplotvalue$541734, 
        System`TradingChartDump`$opts$541734 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "GE", " with ", "WilliamsPercentR", 
            "(", 10, ",", Null, ",", Null, ",", Null, ")"}], 
         ImageSize -> {450, 310}, AlignmentPoint -> Center, AspectRatio -> 
         GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> None, AxesOrigin -> 
         Automatic, AxesStyle -> {}, Background -> None, BaselinePosition -> 
         Automatic, BaseStyle -> {}, ColorOutput -> Automatic, 
         ContentSelectable -> Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$541734 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmglczWkXx2/W7PuSl9RLZClS3WtQPcooqUkLiVT3tt5uC5ooBo09IVt6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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyFmndUVNcWxkfFhihRiF0CAoKABikjiOJRmgrCUJUqMDAgzUKMihKwRohi
Ep+iQQVL0DwCxhAVERS72KJiI/oENaIRYyPWxPhg9tl3Z878kVmLxfrNd+e7
++6z7z7nnhmT2BkB8R1kMtm0djJZexn8qdSvXszOY+SCLz92YDL1y1Dibza0
vT5kq4+8sIzQJ11kX6eccwm6xMHlhb1vejgw8O/NIts+cNOe630lBv9+LELQ
RT5vm/yyYSXxyp+UHY90cWD26pcJO7isPnz9HDz/YInPnW17DWazxuhe2zaT
dJH/VtTpO04nzqps2PHnIvQ3ZRV6J+Yro1A3kxj8zZhhmdftjCDSRb4w9NEY
F2fiiGT3Xj6J6D+Uxffdc+5gOOpWEoO/FeTbj3SR93VcenCgA/GBUQX65dHo
b83Cco+kj45H3UZi8LdhR1vtVo8nXeSOzp56O5yIH+R/v+u/KVgftmxTe7uz
DSGoj5AYxn8EC6gwWtbsT7rIs+p/3dXDjbjH8/Ny3yj0H8H6FFQN/sMddTuJ
wd8O3meki5zzWhHgYkH8cL9i46QQ9LdjBcsefXjBG3V7icHfnrUNp+Fw0kWW
u3m9/cGEeHXoxMyt09DfgXW0tjvVuyfqjhKDvyNTp+O1vaSLvOtC+pVrL4ht
dq+Qzx+E/s7sRZ7+xsF66D9KYvAfJfhp887FsYciW4jNlXON3/dH/1HsQoKO
S1Fv9HeRGPxdWNvdNEaXdJEz99y5MfeZvcS746eGvLJAfxdW9PhkfdAr1EdL
DP6j4bh60kWeqpNXa3WJ2LRfw3y7Tljf49jBzX1Gly905Pp4ieH+GC+NA+oi
n10+zNfWk3ij+fV1l4odwd/HnR1ZtVVf8Y7r2cRq+3J3nm/SRTbsb5R6vYlY
N3+mnpuxnMfvzgx05etOXcXze0gM8Xvw40gX+denZUZ11cQl6974u93F+D3Y
CWv2bgX6ZxND/B7QD46QLnIH/U6WH9QQn0/suXv2QIzfg01+e77fyQI8v6fE
EL8nHLeSdJG77/Uu9ltGvMo1YJXrjzz+s57M6kP9DTGOcq57SQz+XjCeQ0gX
2TV6+je/6xMXuJrHXYrD+L1Y9duqBW7hqE+QGPwnwHg6kS7yBPt46zAzYv/m
y95jkri/zySms6c6k03jejYx5H8Sn29JFznR7bu7kbrEB9N/uFetwvgnsesj
fCcUd8Pze0sM8Xuzj1rDrbjlKOkiW8jeBVTWE5t/HTGunw3G781639Iptu6M
5yeG+L3hf4ujpItstMasy95m4qSosQHG5hi/N5MN/uLTBToYv4/EEL8Pe+Tf
lnFHSRf5Vqjr7W6/EA84vffBYzP092Ep3fWNHzuj/2SJwX8yzOeGpIv8y3G9
K7IOxGkGv89TKTA/vuzF8Md2u5/j9RFDfnzZArUh6SIH7l3v+yyAuPKXD+x2
vcL692XfzVyytkmB1+cnMcTvx4aqF1Ski7z4DptVVOEg8YgqG72oBOwPfuy6
Ispt/kWuZxND/H7wfg3pItc8alfe+XvihoGZ6X/8D/uzHzt3+NOdint4foXE
6j7fTwH5qCRdZPdh3qPv7iEuHPjF/nOP+Pw0RMG6Nysu1L7kOiNW+4cKfkyb
l+2uOjZ3EbGPofXr8V0c+TyhYJfye5nM3onXRwzzmwLq5T+kiyx3jh2XlUus
HPO55Y2bPP5iBct6r2w3rIrrNcQwDypgvs0lXeSur5uuHEsnvuI60sDyDObH
nzXUFU7f8DdeHzHkx59NaK32spOki1yw4PkJuwPEv+k4B3Qz4/lp8mfn/yo/
K6vD8QmQGMY3QFonoS7y/qwrPYtyiS+MM1z55C3GH8DO/vT7GqOteH5iiD8A
+lkU6SL/pvrbwzmCOE1/z76C7zD/Acxz0gUdq6WYP2LIv+BXo80a/q0cPc9g
ofEmjD+QXTHd6+Qpx/MTQ/yBMN8utpd0kcd9PvuTtenE7TZvsnV3Qf8g5h9+
eu92S/QnBv8geN4aSLrIa9cU2B78n73ETd/LdLYNw/VfEGs43n7pElusX2IY
xyDox9akiyy/vPlZ9w+Ij5Xm+2aPwviD2fhJfsZdMf+MGOIP5v9JF/nInJqc
giDi94l9C9+U4PgGs2611tXdsX/UEMP4BmvWY402v/Ke3L40hRjrG+o/mD3c
tHpZ341YvyESQ/2HCPWuzbWzWyabLiEuvdhnbbdKzE8Ii3/7XfbOYrw+YshD
CO/jpIv8TWHni+e9/vH55t6fmpbj+IYwHfsItxzMZzYxxBnC1Mv9KaSL7Mq2
/bp+BPHszq7rFixE/yns64uOs82bUCcG/yl8P4B0kcsHpawvuUw8e9l778JX
mJ+pLLN64Ik0Oz7fMWLIz1Q+n5Muckql8bN2HYg3BkVsipiG/W0q6z8lr/8U
X5xPQyWG8Q3lcZAustUiY+tFjQ4SR/oPivKP5P5DQlnTX82zKvvj+Ykh/lCm
3s7IdJB0kd+47Tf8JJ24S2PG/oqP0D+Mbah32rIvA3Vi8A/T3C9h2uwQeMxi
eQyxUbDi+dwCHN8wdm5d7NNbc3F8iGF8w2A8I0gXubKL/1yzvsTprj0mLcrB
+zeMPeziUV1qhPcfMdy/YZr9rEabz33Ihm/vRzw9ZpnMKhrrJ5zVFA3ZVGeF
+SeG/ITzcSNd5NLcUWYHsF5bedjZz6Ni7XD9EM5u/FVwyGMwru+IIT/h/HnL
QdJFvhO6MuLVHuIrD4JWnsb5tzicbWk/+ufSW3h9xJCfcM37qUabnV+8HNr+
FPHr8QU9PJuxv4WznkkBd87g+lAWITHUfwSsR06TLrJr84D85ELigV/uOv6g
EfMfwQwmbzvqdwzzRwz5j4D9pK9IF9mnLJRlhhGHHrlbG1qL9RnBigb8URwv
5Y8Y8h8B8/lm0kWe2qPT2LINxGcn+xz9owrzQ9cD1xcpMeQnUsiHNk/sOT9j
RRnxmY3nVc/vYX4iWYddNk9PX8XrI4b8RArrNW1eHN2zS+8DxAcX3jpzH/2L
I5n5qcDFo3/G8SeG+hH8arR5lUGt01cVxI8mVOddvoH5j2Ij3gzZV1uH9U8M
+Y+C55WdpIs8rmTdjLGriO977c6vu471H8VCO8y/OWgL12uIIf4omK/ySRd5
6K0uusMSiKsz3JR7S7H/T2MTD514e9gCn/+iJVbPs3rRwvP0v/PLqzFOio/5
82dgNDtk9q2eUo/7RxOr/VOiNZ+no7XZ7GLk9e3NxGuy7INyjLn/mmg2QGaV
3HUg9y8iVvt/H635vFukzS2Fg24fwPO1smmA3ot8U3z+j2YrTA/rHTHlx9cQ
w/Mfv34j0kW+uMzS8tJvjhJXP7d+6DmE+7dEs88SD20fZIL5j5EY8h8D49mH
dJEdK6wP1OP+XSvXnVZNtUD/9Bg2yjvcTDlgJK8vYtiniuH7DXJJF7mP86nU
hJvEt3oZneo4bCTPTwyrP+yQVRfM/WuIIT8xfD+VdJEX9KhM/ehPucTOz80X
3Z/G/Q1i2Zzli0uXK/jxxsRqf5tY1na7em2RS7rIdwQe7j7c1Xwq90+PZWVO
xVun2GJ+iCE/sZrxZmtzXsDM25YdiW/q9bBw8OL+LbHM5oH7a71irsuUEsP4
Kvl+Cen/xvh5yI+SdT5969rSxZgfYsiPkq+nSBd5qlVdTlMGcallT6sV27i/
vZK5nZr4JriE64wY1uFKvh9Ausj31njUFmYSf/VZ1ZzP9nD/QCVbUqzX70YW
16OJoT8o4fuKNNJFdul7+O2D8cSGuYVFfVbj+CpZ/5bAnZ1UOD7EML5Kvt9J
usjyN9/ktzMjPjPy4o9fJmJ+4tjrvLsmZTl4fcSQnzimbgcepIu83MFFd6AZ
sV3HLVmfFGB+4tj4qNgzw8fg9RFDfuL4epB0kcMF1p2e1/9BEvdfE8diqg2M
f3LnehEx9M84vl9Lusg5oROO9m2QS9xr/ei3AT7YH+LYhq0lP1X3xvudGPpD
HKzHn8olXeRHm/zalV8mvrJ3fUaEEd5fccyt6F1YxQvsh/ESw/0Vr+kn0+Z+
LhGZm38m3n/qWtMLHcx/PGt6MnLyTDvMHzHkPx7Waxflki7yU92rJRuqiccO
yD26dCT3r4tnJ991Dcztyf0bidX+j+Khn92WS7rI5c/qj22rkGt9HupTxe5/
8VljlQ/WFzHUp0qoR23WrE8VW7I1UWWiwvyomE2f/BXFfTE/xJAflWY/jtbm
OwLvWNv1t8pBWJ8qVuq6NtnzJNYXMdSnivcb0kU2c7rwOHcecZ+/a3d2r8f5
XcVubnPX88Hja4ihPlW8X5Iu8gC3SINuccQZY378xKKE+9epWMu3tvHVx/j8
3EgM44vxki5y8Rd5q5pnEj99vn/Fhht8f7xFxVb1zeoQmoXzf4LEUP8J/Pte
0kXu1JxkaPLMQWLDzscs7i7i/gYJbIrFqOPDYvjxxsQwvyTw3wuQLnKoRWfl
I1viXmUZblVLuX9gAqvo92De/q44/sRQPwl8Pe4o6SLPjg15trSa2DQ0Q/d8
D1wfJrDeKx5l2uH6qogY6idBcz1VpM0fT7PJzbjkKPGQRd3yqnB9GJjILHO3
WuYuxviJIf5EeD+bdJH1jtrqHZ1JfPDJnwefFGD8icx8Ttn0J+cxHmKIP5E/
Z5Au8o6lXq+qFxPfDH6Z2PAQ6zORjWkc769fhv2DGOozEdaDJaSLnLfC4z/9
ZxHf/mvKXtNy7m+QxJi168cmuB4wJob6SYLnoUTSRc5+vSP/tpK4e5fE4/e/
xfk9iZmN6To8FY/PJob5PYltbx3Oa6akizzplX61jwnx8Ip1ji44/9Ylsaop
gW/corA/E0N+BL9GbT7uPHH/vc7Ep4/eaLwTj/05mbX0t8+Y8QP2V2Loz8n8
eY50kfu8e7NoYTrx+kn3X+dXYn6S2ak53ZTmuD7MJob8JPPf45AuckNGYEk3
F+L/Kiy/PpqD83syG3pM9mQAru9qiKF/JvN+QLrIZz0GL3T1IL5U3S7+Th6u
b1OYScW8jwa1d+LjTwz1k8L3G0ZK+r/xj2V+Wx0tnXj+U/h8hPkjhvyn8PdJ
Fxl8iNXrix9wfkxhBv9cD0cTQ39I4fuFpIsMP1cgbhv+a7g+T0/hz5s4PsQw
vinQ7x/LJV1k2I8jhn0ZnH9TWLP6+w5c7xFD/0nRXG8WafPMf663Wvl922ss
1k+K5nq+hhjqR8h3jTarL7cjMezv4v2botlPGonh/k3hv+ciXWT4PRkxPo/B
/CscL0uVGObfVIjHlnSR4ftsQcf47VOF9Rgx1Gcq38eRS7rIGuvFVobvN3B8
UzXrrYgYxjdV8/qKtFkjvlZWz8+fY/5T2b62wyswf8SQ/1T+fS/pIof/M75W
Vl8O9jeDNFiPvcP7mxj6Qxqvb9JF1uinrQzjgP0hjX+fjvknhvynCf1Dm9Xh
ryZWx1eN/SGNWar3A/H+Job+kCY872rzVT6eyOr7swTrM43vz/H+KZshMdTn
DPay7YR7SBcZrkfg2zw/BjN4f8X+TAz55+fbTLrIkB9i9Xhcc2L/Bx7tIJ4=

             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$541734 = 
        System`TradingChartDump`$staticindicatorpos$541734, 
        System`TradingChartDump`$length$541734 = 250, 
        System`TradingChartDump`$gridlinesflag$541734 = True, 
        System`TradingChartDump`$opens$541734 = 
        Dispatch[{
         1 -> 19.55`4., 2 -> 19.97`4., 3 -> 20.12`4., 4 -> 20.08`4., 5 -> 
          20.19`4., 6 -> 19.86`4., 7 -> 20.14`4., 8 -> 20.29`4., 9 -> 
          20.46`4., 10 -> 20.37`4., 11 -> 20.26`4., 12 -> 20.32`4., 13 -> 
          20.36`4., 14 -> 20.4`4., 15 -> 20.18`4., 16 -> 20.2`4., 17 -> 
          20.34`4., 18 -> 20.27`4., 19 -> 20.3`4., 20 -> 20.1`4., 21 -> 
          20.07`4., 22 -> 19.93`4., 23 -> 20.15`4., 24 -> 20.09`4., 25 -> 
          20.15`4., 26 -> 20.05`4., 27 -> 20.09`4., 28 -> 19.97`4., 29 -> 
          19.88`4., 30 -> 20.19`4., 31 -> 20.63`4., 32 -> 20.79`4., 33 -> 
          20.79`4., 34 -> 20.97`4., 35 -> 21.07`4., 36 -> 21.49`4., 37 -> 
          21.22`4., 38 -> 21.28`4., 39 -> 21.58`4., 40 -> 21.64`4., 41 -> 
          21.99`4., 42 -> 21.84`4., 43 -> 21.84`4., 44 -> 21.61`4., 45 -> 
          21.68`4., 46 -> 22.21`4., 47 -> 22.16`4., 48 -> 22.36`4., 49 -> 
          22.29`4., 50 -> 22.38`4., 51 -> 22.46`4., 52 -> 22.3`4., 53 -> 
          22.37`4., 54 -> 22.05`4., 55 -> 22.03`4., 56 -> 22.02`4., 57 -> 
          21.98`4., 58 -> 22.23`4., 59 -> 22.2`4., 60 -> 22.24`4., 61 -> 
          21.95`4., 62 -> 21.32`4., 63 -> 20.82`4., 64 -> 20.9`4., 65 -> 
          20.96`4., 66 -> 20.66`4., 67 -> 20.74`4., 68 -> 20.51`4., 69 -> 
          20.99`4., 70 -> 20.68`4., 71 -> 20.97`4., 72 -> 20.82`4., 73 -> 
          20.63`4., 74 -> 20.25`4., 75 -> 20.52`4., 76 -> 20.09`4., 77 -> 
          20.21`4., 78 -> 19.4`4., 79 -> 19.6`4., 80 -> 19.91`4., 81 -> 
          20.16`4., 82 -> 20.19`4., 83 -> 20.3`4., 84 -> 20.36`4., 85 -> 
          20.52`4., 86 -> 20.23`4., 87 -> 20.71`4., 88 -> 20.61`4., 89 -> 
          20.65`4., 90 -> 20.35`4., 91 -> 20.39`4., 92 -> 20.67`4., 93 -> 
          20.91`4., 94 -> 20.9`4., 95 -> 20.94`4., 96 -> 21.07`4., 97 -> 
          21.2`4., 98 -> 21.07`4., 99 -> 21.15`4., 100 -> 21.31`4., 101 -> 
          21.1`4., 102 -> 20.57`4., 103 -> 20.51`4., 104 -> 20.46`4., 105 -> 
          20.48`4., 106 -> 20.47`4., 107 -> 20.12`4., 108 -> 19.96`4., 109 -> 
          21.17`4., 110 -> 21.13`4., 111 -> 20.87`4., 112 -> 20.82`4., 113 -> 
          20.77`4., 114 -> 20.71`4., 115 -> 20.7`4., 116 -> 20.88`4., 117 -> 
          20.84`4., 118 -> 20.7`4., 119 -> 20.81`4., 120 -> 20.88`4., 121 -> 
          21.59`4., 122 -> 21.83`4., 123 -> 21.63`4., 124 -> 21.61`4., 125 -> 
          21.92`4., 126 -> 22.08`4., 127 -> 22.13`4., 128 -> 22.16`4., 129 -> 
          21.85`4., 130 -> 22.07`4., 131 -> 22.05`4., 132 -> 22.12`4., 133 -> 
          22.11`4., 134 -> 22.14`4., 135 -> 22.14`4., 136 -> 22.13`4., 137 -> 
          22.12`4., 138 -> 22.74`4., 139 -> 22.88`4., 140 -> 23.11`4., 141 -> 
          23.05`4., 142 -> 23.34`4., 143 -> 23.`4., 144 -> 23.16`4., 145 -> 
          23.31`4., 146 -> 22.79`4., 147 -> 22.83`4., 148 -> 23.19`4., 149 -> 
          22.84`4., 150 -> 22.97`4., 151 -> 23.27`4., 152 -> 23.65`4., 153 -> 
          23.51`4., 154 -> 23.67`4., 155 -> 23.5`4., 156 -> 23.4`4., 157 -> 
          23.25`4., 158 -> 23.36`4., 159 -> 23.25`4., 160 -> 22.99`4., 161 -> 
          23.12`4., 162 -> 23.54`4., 163 -> 23.24`4., 164 -> 23.13`4., 165 -> 
          23.27`4., 166 -> 23.09`4., 167 -> 22.84`4., 168 -> 22.96`4., 169 -> 
          22.85`4., 170 -> 22.99`4., 171 -> 23.2`4., 172 -> 22.83`4., 173 -> 
          22.62`4., 174 -> 22.87`4., 175 -> 23.07`4., 176 -> 22.91`4., 177 -> 
          23.36`4., 178 -> 23.3`4., 179 -> 23.1`4., 180 -> 22.89`4., 181 -> 
          22.78`4., 182 -> 22.58`4., 183 -> 21.77`4., 184 -> 21.5`4., 185 -> 
          21.38`4., 186 -> 21.52`4., 187 -> 22.04`4., 188 -> 21.8`4., 189 -> 
          22.13`4., 190 -> 22.11`4., 191 -> 21.92`4., 192 -> 22.07`4., 193 -> 
          22.39`4., 194 -> 22.38`4., 195 -> 22.51`4., 196 -> 22.5`4., 197 -> 
          22.81`4., 198 -> 22.59`4., 199 -> 22.68`4., 200 -> 22.67`4., 201 -> 
          22.86`4., 202 -> 22.92`4., 203 -> 23.08`4., 204 -> 23.27`4., 205 -> 
          23.4`4., 206 -> 23.59`4., 207 -> 23.33`4., 208 -> 23.31`4., 209 -> 
          23.58`4., 210 -> 23.23`4., 211 -> 23.39`4., 212 -> 23.41`4., 213 -> 
          23.18`4., 214 -> 23.4`4., 215 -> 23.37`4., 216 -> 23.06`4., 217 -> 
          23.35`4., 218 -> 23.69`4., 219 -> 23.3`4., 220 -> 23.51`4., 221 -> 
          23.26`4., 222 -> 23.49`4., 223 -> 23.56`4., 224 -> 23.64`4., 225 -> 
          24.01`4., 226 -> 23.63`4., 227 -> 23.58`4., 228 -> 23.12`4., 229 -> 
          23.17`4., 230 -> 23.43`4., 231 -> 23.41`4., 232 -> 23.32`4., 233 -> 
          23.21`4., 234 -> 23.27`4., 235 -> 22.83`4., 236 -> 23.17`4., 237 -> 
          23.36`4., 238 -> 23.52`4., 239 -> 23.72`4., 240 -> 23.91`4., 241 -> 
          23.99`4., 242 -> 23.73`4., 243 -> 23.66`4., 244 -> 23.54`4., 245 -> 
          23.6`4., 246 -> 24.21`4., 247 -> 24.77`4., 248 -> 24.87`4., 249 -> 
          24.79`4., 250 -> 24.61`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$541734 = 
        Dispatch[{
         1 -> 20.04`4., 2 -> 20.33`4., 3 -> 20.24`4., 4 -> 20.22`4., 5 -> 
          20.27`4., 6 -> 20.03`4., 7 -> 20.32`4., 8 -> 20.49`4., 9 -> 
          20.51`4., 10 -> 20.41`4., 11 -> 20.44`4., 12 -> 20.42`4., 13 -> 
          20.38`4., 14 -> 20.42`4., 15 -> 20.35`4., 16 -> 20.46`4., 17 -> 
          20.37`4., 18 -> 20.34`4., 19 -> 20.37`4., 20 -> 20.2`4., 21 -> 
          20.12`4., 22 -> 20.23`4., 23 -> 20.28`4., 24 -> 20.25`4., 25 -> 
          20.28`4., 26 -> 20.11`4., 27 -> 20.16`4., 28 -> 20.02`4., 29 -> 
          20.1`4., 30 -> 20.63`4., 31 -> 20.89`4., 32 -> 20.95`4., 33 -> 
          20.99`4., 34 -> 21.22`4., 35 -> 21.52`4., 36 -> 21.65`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.77`4., 40 -> 21.91`4., 41 -> 
          22.13`4., 42 -> 21.89`4., 43 -> 22.11`4., 44 -> 21.7`4., 45 -> 
          22.29`4., 46 -> 22.39`4., 47 -> 22.43`4., 48 -> 22.41`4., 49 -> 
          22.41`4., 50 -> 22.48`4., 51 -> 22.6`4., 52 -> 22.42`4., 53 -> 
          22.4`4., 54 -> 22.17`4., 55 -> 22.15`4., 56 -> 22.14`4., 57 -> 
          22.14`4., 58 -> 22.31`4., 59 -> 22.35`4., 60 -> 22.5`4., 61 -> 
          21.97`4., 62 -> 21.4`4., 63 -> 20.87`4., 64 -> 20.93`4., 65 -> 
          21.03`4., 66 -> 20.86`4., 67 -> 20.79`4., 68 -> 20.86`4., 69 -> 
          21.14`4., 70 -> 20.94`4., 71 -> 21.24`4., 72 -> 20.98`4., 73 -> 
          20.66`4., 74 -> 20.77`4., 75 -> 20.61`4., 76 -> 20.43`4., 77 -> 
          20.23`4., 78 -> 19.73`4., 79 -> 19.69`4., 80 -> 20.21`4., 81 -> 
          20.18`4., 82 -> 20.23`4., 83 -> 20.52`4., 84 -> 20.55`4., 85 -> 
          20.67`4., 86 -> 20.62`4., 87 -> 20.82`4., 88 -> 20.73`4., 89 -> 
          20.7`4., 90 -> 20.49`4., 91 -> 20.83`4., 92 -> 20.86`4., 93 -> 
          20.95`4., 94 -> 20.97`4., 95 -> 21.2`4., 96 -> 21.41`4., 97 -> 
          21.37`4., 98 -> 21.22`4., 99 -> 21.4`4., 100 -> 21.36`4., 101 -> 
          21.12`4., 102 -> 20.9`4., 103 -> 20.66`4., 104 -> 20.63`4., 105 -> 
          20.61`4., 106 -> 20.54`4., 107 -> 20.38`4., 108 -> 20.66`4., 109 -> 
          21.2`4., 110 -> 21.14`4., 111 -> 20.92`4., 112 -> 20.88`4., 113 -> 
          20.79`4., 114 -> 20.74`4., 115 -> 20.89`4., 116 -> 20.9`4., 117 -> 
          20.9`4., 118 -> 20.87`4., 119 -> 20.86`4., 120 -> 21.2`4., 121 -> 
          21.84`4., 122 -> 21.85`4., 123 -> 21.68`4., 124 -> 21.84`4., 125 -> 
          21.95`4., 126 -> 22.18`4., 127 -> 22.22`4., 128 -> 22.18`4., 129 -> 
          22.04`4., 130 -> 22.28`4., 131 -> 22.13`4., 132 -> 22.26`4., 133 -> 
          22.14`4., 134 -> 22.15`4., 135 -> 22.2`4., 136 -> 22.15`4., 137 -> 
          22.29`4., 138 -> 23.11`4., 139 -> 23.12`4., 140 -> 23.18`4., 141 -> 
          23.37`4., 142 -> 23.37`4., 143 -> 23.17`4., 144 -> 23.26`4., 145 -> 
          23.34`4., 146 -> 22.97`4., 147 -> 23.21`4., 148 -> 23.28`4., 149 -> 
          23.16`4., 150 -> 23.1`4., 151 -> 23.52`4., 152 -> 23.65`4., 153 -> 
          23.64`4., 154 -> 23.71`4., 155 -> 23.56`4., 156 -> 23.41`4., 157 -> 
          23.33`4., 158 -> 23.57`4., 159 -> 23.53`4., 160 -> 23.17`4., 161 -> 
          23.18`4., 162 -> 23.61`4., 163 -> 23.42`4., 164 -> 23.21`4., 165 -> 
          23.3`4., 166 -> 23.12`4., 167 -> 22.96`4., 168 -> 23.02`4., 169 -> 
          22.92`4., 170 -> 23.19`4., 171 -> 23.22`4., 172 -> 22.95`4., 173 -> 
          22.76`4., 174 -> 22.94`4., 175 -> 23.07`4., 176 -> 23.46`4., 177 -> 
          23.53`4., 178 -> 23.4`4., 179 -> 23.12`4., 180 -> 22.92`4., 181 -> 
          22.85`4., 182 -> 22.67`4., 183 -> 21.86`4., 184 -> 21.51`4., 185 -> 
          21.52`4., 186 -> 21.86`4., 187 -> 22.06`4., 188 -> 22.22`4., 189 -> 
          22.14`4., 190 -> 22.2`4., 191 -> 22.17`4., 192 -> 22.14`4., 193 -> 
          22.67`4., 194 -> 22.46`4., 195 -> 22.61`4., 196 -> 22.84`4., 197 -> 
          22.92`4., 198 -> 22.73`4., 199 -> 22.7`4., 200 -> 22.89`4., 201 -> 
          23.07`4., 202 -> 23.17`4., 203 -> 23.29`4., 204 -> 23.39`4., 205 -> 
          23.59`4., 206 -> 23.94`4., 207 -> 23.56`4., 208 -> 23.48`4., 209 -> 
          23.65`4., 210 -> 23.51`4., 211 -> 23.57`4., 212 -> 23.61`4., 213 -> 
          23.59`4., 214 -> 23.57`4., 215 -> 23.4`4., 216 -> 23.2`4., 217 -> 
          23.76`4., 218 -> 23.73`4., 219 -> 23.5`4., 220 -> 23.54`4., 221 -> 
          23.6`4., 222 -> 23.56`4., 223 -> 23.66`4., 224 -> 24.26`4., 225 -> 
          24.16`4., 226 -> 23.69`4., 227 -> 23.64`4., 228 -> 23.15`4., 229 -> 
          23.25`4., 230 -> 23.44`4., 231 -> 23.48`4., 232 -> 23.44`4., 233 -> 
          23.64`4., 234 -> 23.34`4., 235 -> 22.98`4., 236 -> 23.24`4., 237 -> 
          23.53`4., 238 -> 23.8`4., 239 -> 23.73`4., 240 -> 23.96`4., 241 -> 
          24.`4., 242 -> 23.74`4., 243 -> 23.67`4., 244 -> 23.61`4., 245 -> 
          23.94`4., 246 -> 24.95`4., 247 -> 24.92`4., 248 -> 24.88`4., 249 -> 
          24.84`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$541734 = 
        Dispatch[{
         1 -> 19.51`4., 2 -> 19.9`4., 3 -> 20.02`4., 4 -> 20.08`4., 5 -> 
          20.04`4., 6 -> 19.55`4., 7 -> 20.1`4., 8 -> 20.22`4., 9 -> 20.41`4.,
           10 -> 20.22`4., 11 -> 20.26`4., 12 -> 20.27`4., 13 -> 20.2`4., 14 -> 
          20.22`4., 15 -> 20.12`4., 16 -> 20.15`4., 17 -> 20.26`4., 18 -> 
          20.15`4., 19 -> 20.13`4., 20 -> 20.04`4., 21 -> 19.96`4., 22 -> 
          19.89`4., 23 -> 20.12`4., 24 -> 20.09`4., 25 -> 20.14`4., 26 -> 
          19.95`4., 27 -> 19.94`4., 28 -> 19.82`4., 29 -> 19.84`4., 30 -> 
          20.17`4., 31 -> 20.61`4., 32 -> 20.74`4., 33 -> 20.71`4., 34 -> 
          20.96`4., 35 -> 21.05`4., 36 -> 21.27`4., 37 -> 21.19`4., 38 -> 
          21.25`4., 39 -> 21.54`4., 40 -> 21.57`4., 41 -> 21.9`4., 42 -> 
          21.74`4., 43 -> 21.75`4., 44 -> 21.52`4., 45 -> 21.58`4., 46 -> 
          22.06`4., 47 -> 22.14`4., 48 -> 22.14`4., 49 -> 22.15`4., 50 -> 
          22.2`4., 51 -> 22.42`4., 52 -> 22.28`4., 53 -> 22.04`4., 54 -> 
          21.85`4., 55 -> 21.92`4., 56 -> 21.85`4., 57 -> 21.93`4., 58 -> 
          22.01`4., 59 -> 22.15`4., 60 -> 22.23`4., 61 -> 21.32`4., 62 -> 
          20.72`4., 63 -> 20.67`4., 64 -> 20.71`4., 65 -> 20.51`4., 66 -> 
          20.54`4., 67 -> 20.45`4., 68 -> 20.5`4., 69 -> 20.73`4., 70 -> 
          20.68`4., 71 -> 20.91`4., 72 -> 20.54`4., 73 -> 20.36`4., 74 -> 
          20.19`4., 75 -> 20.36`4., 76 -> 20.06`4., 77 -> 19.45`4., 78 -> 
          19.4`4., 79 -> 19.38`4., 80 -> 19.89`4., 81 -> 19.87`4., 82 -> 
          20.06`4., 83 -> 20.22`4., 84 -> 20.35`4., 85 -> 20.33`4., 86 -> 
          19.99`4., 87 -> 20.42`4., 88 -> 20.51`4., 89 -> 20.28`4., 90 -> 
          20.19`4., 91 -> 20.34`4., 92 -> 20.56`4., 93 -> 20.72`4., 94 -> 
          20.83`4., 95 -> 20.82`4., 96 -> 21.04`4., 97 -> 21.01`4., 98 -> 
          21.01`4., 99 -> 21.15`4., 100 -> 20.88`4., 101 -> 20.45`4., 102 -> 
          20.53`4., 103 -> 20.24`4., 104 -> 20.42`4., 105 -> 20.38`4., 106 -> 
          20.09`4., 107 -> 20.1`4., 108 -> 19.93`4., 109 -> 20.86`4., 110 -> 
          20.71`4., 111 -> 20.78`4., 112 -> 20.62`4., 113 -> 20.35`4., 114 -> 
          20.6`4., 115 -> 20.62`4., 116 -> 20.68`4., 117 -> 20.73`4., 118 -> 
          20.67`4., 119 -> 20.72`4., 120 -> 20.78`4., 121 -> 21.25`4., 122 -> 
          21.55`4., 123 -> 21.4`4., 124 -> 21.6`4., 125 -> 21.75`4., 126 -> 
          21.9`4., 127 -> 22.04`4., 128 -> 21.87`4., 129 -> 21.82`4., 130 -> 
          21.96`4., 131 -> 21.92`4., 132 -> 22.09`4., 133 -> 21.95`4., 134 -> 
          21.91`4., 135 -> 22.09`4., 136 -> 21.99`4., 137 -> 22.12`4., 138 -> 
          22.68`4., 139 -> 22.74`4., 140 -> 22.86`4., 141 -> 23.04`4., 142 -> 
          22.98`4., 143 -> 22.94`4., 144 -> 23.04`4., 145 -> 22.63`4., 146 -> 
          22.73`4., 147 -> 22.81`4., 148 -> 23.02`4., 149 -> 22.82`4., 150 -> 
          22.85`4., 151 -> 23.25`4., 152 -> 23.48`4., 153 -> 23.48`4., 154 -> 
          23.49`4., 155 -> 23.26`4., 156 -> 23.14`4., 157 -> 23.21`4., 158 -> 
          23.32`4., 159 -> 23.17`4., 160 -> 22.95`4., 161 -> 22.99`4., 162 -> 
          23.14`4., 163 -> 23.11`4., 164 -> 23.09`4., 165 -> 22.87`4., 166 -> 
          22.83`4., 167 -> 22.67`4., 168 -> 22.81`4., 169 -> 22.79`4., 170 -> 
          22.92`4., 171 -> 22.74`4., 172 -> 22.78`4., 173 -> 22.58`4., 174 -> 
          22.65`4., 175 -> 22.72`4., 176 -> 22.87`4., 177 -> 23.24`4., 178 -> 
          23.14`4., 179 -> 22.63`4., 180 -> 22.72`4., 181 -> 22.47`4., 182 -> 
          22.39`4., 183 -> 21.44`4., 184 -> 20.94`4., 185 -> 21.19`4., 186 -> 
          21.48`4., 187 -> 21.74`4., 188 -> 21.79`4., 189 -> 21.82`4., 190 -> 
          22.03`4., 191 -> 21.92`4., 192 -> 21.97`4., 193 -> 22.37`4., 194 -> 
          22.14`4., 195 -> 22.44`4., 196 -> 22.44`4., 197 -> 22.51`4., 198 -> 
          22.41`4., 199 -> 22.44`4., 200 -> 22.63`4., 201 -> 22.73`4., 202 -> 
          22.92`4., 203 -> 23.01`4., 204 -> 23.24`4., 205 -> 23.4`4., 206 -> 
          23.56`4., 207 -> 23.26`4., 208 -> 23.3`4., 209 -> 23.39`4., 210 -> 
          23.21`4., 211 -> 23.31`4., 212 -> 23.13`4., 213 -> 23.13`4., 214 -> 
          23.22`4., 215 -> 23.03`4., 216 -> 22.91`4., 217 -> 23.28`4., 218 -> 
          23.45`4., 219 -> 23.29`4., 220 -> 23.23`4., 221 -> 23.15`4., 222 -> 
          23.27`4., 223 -> 23.46`4., 224 -> 23.58`4., 225 -> 23.79`4., 226 -> 
          23.2`4., 227 -> 23.21`4., 228 -> 22.76`4., 229 -> 22.94`4., 230 -> 
          23.02`4., 231 -> 23.26`4., 232 -> 23.16`4., 233 -> 23.19`4., 234 -> 
          22.88`4., 235 -> 22.76`4., 236 -> 22.95`4., 237 -> 23.27`4., 238 -> 
          23.51`4., 239 -> 23.36`4., 240 -> 23.63`4., 241 -> 23.59`4., 242 -> 
          23.56`4., 243 -> 23.34`4., 244 -> 23.43`4., 245 -> 23.56`4., 246 -> 
          24.1`4., 247 -> 24.73`4., 248 -> 24.63`4., 249 -> 24.56`4., 250 -> 
          24.52`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$541734 = 
        Dispatch[{
         1 -> 19.9`4., 2 -> 20.25`4., 3 -> 20.13`4., 4 -> 20.08`4., 5 -> 
          20.06`4., 6 -> 19.86`4., 7 -> 20.28`4., 8 -> 20.29`4., 9 -> 
          20.44`4., 10 -> 20.33`4., 11 -> 20.38`4., 12 -> 20.42`4., 13 -> 
          20.31`4., 14 -> 20.26`4., 15 -> 20.28`4., 16 -> 20.37`4., 17 -> 
          20.32`4., 18 -> 20.25`4., 19 -> 20.18`4., 20 -> 20.11`4., 21 -> 
          19.97`4., 22 -> 20.13`4., 23 -> 20.18`4., 24 -> 20.14`4., 25 -> 
          20.15`4., 26 -> 19.97`4., 27 -> 20.04`4., 28 -> 19.85`4., 29 -> 
          19.98`4., 30 -> 20.62`4., 31 -> 20.89`4., 32 -> 20.79`4., 33 -> 
          20.89`4., 34 -> 21.18`4., 35 -> 21.31`4., 36 -> 21.4`4., 37 -> 
          21.34`4., 38 -> 21.52`4., 39 -> 21.71`4., 40 -> 21.87`4., 41 -> 
          21.97`4., 42 -> 21.8`4., 43 -> 21.76`4., 44 -> 21.55`4., 45 -> 
          22.16`4., 46 -> 22.15`4., 47 -> 22.24`4., 48 -> 22.22`4., 49 -> 
          22.34`4., 50 -> 22.38`4., 51 -> 22.54`4., 52 -> 22.35`4., 53 -> 
          22.06`4., 54 -> 21.87`4., 55 -> 21.95`4., 56 -> 21.92`4., 57 -> 
          22.08`4., 58 -> 22.08`4., 59 -> 22.34`4., 60 -> 22.24`4., 61 -> 
          21.48`4., 62 -> 21.16`4., 63 -> 20.75`4., 64 -> 20.73`4., 65 -> 
          20.73`4., 66 -> 20.58`4., 67 -> 20.54`4., 68 -> 20.81`4., 69 -> 
          20.78`4., 70 -> 20.88`4., 71 -> 21.05`4., 72 -> 20.6`4., 73 -> 
          20.37`4., 74 -> 20.48`4., 75 -> 20.37`4., 76 -> 20.17`4., 77 -> 
          19.51`4., 78 -> 19.56`4., 79 -> 19.65`4., 80 -> 20.15`4., 81 -> 
          20.11`4., 82 -> 20.17`4., 83 -> 20.52`4., 84 -> 20.54`4., 85 -> 
          20.35`4., 86 -> 20.61`4., 87 -> 20.6`4., 88 -> 20.6`4., 89 -> 
          20.3`4., 90 -> 20.34`4., 91 -> 20.7`4., 92 -> 20.84`4., 93 -> 
          20.93`4., 94 -> 20.86`4., 95 -> 20.97`4., 96 -> 21.24`4., 97 -> 
          21.08`4., 98 -> 21.08`4., 99 -> 21.38`4., 100 -> 21.15`4., 101 -> 
          20.49`4., 102 -> 20.71`4., 103 -> 20.55`4., 104 -> 20.49`4., 105 -> 
          20.44`4., 106 -> 20.36`4., 107 -> 20.11`4., 108 -> 20.65`4., 109 -> 
          21.`4., 110 -> 20.76`4., 111 -> 20.86`4., 112 -> 20.79`4., 113 -> 
          20.57`4., 114 -> 20.62`4., 115 -> 20.83`4., 116 -> 20.79`4., 117 -> 
          20.78`4., 118 -> 20.86`4., 119 -> 20.78`4., 120 -> 20.96`4., 121 -> 
          21.69`4., 122 -> 21.66`4., 123 -> 21.59`4., 124 -> 21.7`4., 125 -> 
          21.93`4., 126 -> 22.14`4., 127 -> 22.14`4., 128 -> 21.87`4., 129 -> 
          21.92`4., 130 -> 22.26`4., 131 -> 21.95`4., 132 -> 22.18`4., 133 -> 
          22.08`4., 134 -> 22.12`4., 135 -> 22.14`4., 136 -> 22.09`4., 137 -> 
          22.22`4., 138 -> 23.02`4., 139 -> 23.04`4., 140 -> 22.92`4., 141 -> 
          23.37`4., 142 -> 23.04`4., 143 -> 23.08`4., 144 -> 23.2`4., 145 -> 
          22.63`4., 146 -> 22.87`4., 147 -> 23.18`4., 148 -> 23.04`4., 149 -> 
          23.01`4., 150 -> 23.09`4., 151 -> 23.4`4., 152 -> 23.48`4., 153 -> 
          23.49`4., 154 -> 23.58`4., 155 -> 23.43`4., 156 -> 23.22`4., 157 -> 
          23.3`4., 158 -> 23.5`4., 159 -> 23.25`4., 160 -> 23.07`4., 161 -> 
          23.14`4., 162 -> 23.27`4., 163 -> 23.11`4., 164 -> 23.18`4., 165 -> 
          23.06`4., 166 -> 22.94`4., 167 -> 22.92`4., 168 -> 22.94`4., 169 -> 
          22.9`4., 170 -> 23.16`4., 171 -> 22.82`4., 172 -> 22.9`4., 173 -> 
          22.75`4., 174 -> 22.94`4., 175 -> 22.88`4., 176 -> 23.39`4., 177 -> 
          23.4`4., 178 -> 23.27`4., 179 -> 22.63`4., 180 -> 22.92`4., 181 -> 
          22.58`4., 182 -> 22.49`4., 183 -> 21.58`4., 184 -> 21.18`4., 185 -> 
          21.33`4., 186 -> 21.79`4., 187 -> 21.78`4., 188 -> 22.03`4., 189 -> 
          22.09`4., 190 -> 22.11`4., 191 -> 21.97`4., 192 -> 22.14`4., 193 -> 
          22.39`4., 194 -> 22.4`4., 195 -> 22.5`4., 196 -> 22.83`4., 197 -> 
          22.6`4., 198 -> 22.72`4., 199 -> 22.67`4., 200 -> 22.83`4., 201 -> 
          23.06`4., 202 -> 23.09`4., 203 -> 23.27`4., 204 -> 23.38`4., 205 -> 
          23.47`4., 206 -> 23.67`4., 207 -> 23.47`4., 208 -> 23.34`4., 209 -> 
          23.41`4., 210 -> 23.45`4., 211 -> 23.41`4., 212 -> 23.14`4., 213 -> 
          23.45`4., 214 -> 23.47`4., 215 -> 23.14`4., 216 -> 23.19`4., 217 -> 
          23.67`4., 218 -> 23.59`4., 219 -> 23.39`4., 220 -> 23.31`4., 221 -> 
          23.49`4., 222 -> 23.33`4., 223 -> 23.58`4., 224 -> 24.14`4., 225 -> 
          23.79`4., 226 -> 23.25`4., 227 -> 23.36`4., 228 -> 22.93`4., 229 -> 
          23.11`4., 230 -> 23.25`4., 231 -> 23.32`4., 232 -> 23.19`4., 233 -> 
          23.34`4., 234 -> 22.9`4., 235 -> 22.91`4., 236 -> 23.24`4., 237 -> 
          23.32`4., 238 -> 23.62`4., 239 -> 23.54`4., 240 -> 23.94`4., 241 -> 
          23.76`4., 242 -> 23.63`4., 243 -> 23.43`4., 244 -> 23.54`4., 245 -> 
          23.63`4., 246 -> 24.72`4., 247 -> 24.86`4., 248 -> 24.71`4., 249 -> 
          24.62`4., 250 -> 24.69`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$541734 = True, 
        System`TradingChartDump`$gridlines$541734 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$541734, 
        System`TradingChartDump`$plotrangemin$541734 = 19.0982952853598, 
        System`TradingChartDump`$plotrangemax$541734 = 25.507305210918112`, 
        System`TradingChartDump`$layoutData$541734, 
        System`TradingChartDump`$gridlinesscope$541734 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$541734 = {True, True}, 
        System`TradingChartDump`$indicators$541734 = {
         FinancialIndicator["WilliamsPercentR", 10]}, 
        System`TradingChartDump`$mouseQ$541734 = False, 
        System`TradingChartDump`$modelData$541734 = 
        System`TradingChartDump`modelData$540948, 
        System`TradingChartDump`$sy$541734 = Identity, 
        System`TradingChartDump`$isy$541734 = Identity, 
        System`TradingChartDump`$appearance$541734 = Automatic, 
        System`TradingChartDump`$perfgoal$541734 = "Quality", 
        System`TradingChartDump`$axesorigin$541734 = Automatic, 
        System`TradingChartDump`$framestyle$541734 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$541734 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$541734 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$541734 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$541734 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$541734, 
        System`TradingChartDump`$newgridlines$541734 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{19.0982952853598, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$541734 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$541734 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$541734 = "GraphicsFrame", 
        System`TradingChartDump`$frame$541734 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$541734 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$541734 = 
              Switch[System`TradingChartDump`$highlightposition$541734, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$541734], {
                 1, System`TradingChartDump`$length$541734}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$541734], {
                 1, System`TradingChartDump`$length$541734}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$541734, 
                   Charting`nearestDate[System`TradingChartDump`$dates$541734, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$541734]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$541734]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$541734, 
                    Floor[System`TradingChartDump`$controlmin$541734] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$541734, 
                    Floor[System`TradingChartDump`$controlmax$541734]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$541734 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$541734 = 
            If[
             System`TradingChartDump`$fastpos$541734 =!= True, 
              System`TradingChartDump`$fastpos$541734 = 
               Clip[System`TradingChartDump`$fastpos$541734, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$541734 = (
                  Floor[System`TradingChartDump`$controlmax$541734] - Floor[
                  System`TradingChartDump`$controlmin$541734]) (
                  System`TradingChartDump`$fastpos$541734/100) + 
                Floor[System`TradingChartDump`$controlmin$541734]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$541734], {
                Floor[System`TradingChartDump`$controlmin$541734] + 1, 
                 Floor[System`TradingChartDump`$controlmax$541734]}], 
              System`TradingChartDump`$staticindicatorpos$541734]; 
           System`TradingChartDump`$mouseQ$541734 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$541734]], 
              System`TradingChartDump`$highlightposition$541734 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$541734 = If[
              And[
              System`TradingChartDump`$bouncingballQ$541734, 
               System`TradingChartDump`$mouseQ$541734, 
               System`TradingChartDump`$appearance$541734 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$541734[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$541734]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$541734[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$541734, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$541734[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$541734]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$541734[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$541734[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541734, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541734[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541734, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541734, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541734[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541734[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$541734 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$541734, 
                 System`TradingChartDump`$defaultframeticksstyle$541734, 
                 System`TradingChartDump`$defaultlabelstyle$541734, 
                 System`TradingChartDump`$framestyle$541734, 
                 System`TradingChartDump`$frameticksstyle$541734, 
                 System`TradingChartDump`$labelstyle$541734}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541734 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$541734, 
                 System`TradingChartDump`$labelstyle$541734, 
                 System`TradingChartDump`$defaultframeticksstyle$541734, 
                 System`TradingChartDump`$defaultlabelstyle$541734}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$541734 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541734, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$541734 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541734, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$541734 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$541734, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$541734 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$541734 = 
             Part[System`TradingChartDump`$tickstextstyle$541734, 1], 
             System`TradingChartDump`$tickstextstyle$541734 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541734[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541734, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541734[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541734[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541734[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$541734[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541734, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$541734]], 
                    Style[":", System`TradingChartDump`$textstyle$541734]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$541734[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541734]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541734[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$541734[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$541734, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$541734]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$541734[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$541734, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$541734[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541734, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$541734, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$541734[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$541734[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541734[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$541734[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$541734[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$541734], 1], 
                   Floor[System`TradingChartDump`$controlmax$541734]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$541734[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$541734[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$541734[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$541734[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$541734[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541734[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$541734[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$541734[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$541734[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$541734[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$541734[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$541734[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$541734[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$541734[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$541734[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$541734, 
                  System`TradingChartDump`$mouseQ$541734], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$541734 - 0.5, 
                   System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$541734 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$541734 + 0.5, 
                    System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541734, 1]}, {
                    System`TradingChartDump`$indicatorpos$541734 + 0.5, 
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$541734[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$541734, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$541734[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$541734]]], {}]; 
              System`TradingChartDump`$subplotgridlines$541734[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$541734[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$541734[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$541734[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$541734 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$541734, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541734, 
                   System`TradingChartDump`$opens$541734]], 12, 
                 System`TradingChartDump`$textstyle$541734, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$541734, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541734, 
                   System`TradingChartDump`$highs$541734]], 12, 
                 System`TradingChartDump`$textstyle$541734, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$541734, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541734, 
                   System`TradingChartDump`$lows$541734]], 12, 
                 System`TradingChartDump`$textstyle$541734, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$541734, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541734, 
                   System`TradingChartDump`$closes$541734]], 12, 
                 System`TradingChartDump`$textstyle$541734, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$541734, 
                   System`TradingChartDump`$visdates$541734]], 12, 
                 System`TradingChartDump`$textstyle$541734, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$541734, 
                  System`TradingChartDump`$mouseQ$541734], {{
                  System`TradingChartDump`$timestampstyle$541734, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$541734 - 0.5, 
                    System`TradingChartDump`$plotrangemin$541734}, 
                    If[
                    System`TradingChartDump`$timestampdepth$541734 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$541734[1]}, {
                    System`TradingChartDump`$indicatorpos$541734 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541734}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$541734, 1]}, {
                    System`TradingChartDump`$indicatorpos$541734 + 0.5, 
                    System`TradingChartDump`$plotrangemin$541734}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$541734, {
               System`TradingChartDump`$highlightstyle$541734, 
                Dynamic[System`TradingChartDump`$ohlcpoint$541734]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$541734[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541734, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$541734[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$541734[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$541734, Length[
                    System`TradingChartDump`$layoutData$541734[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$541734}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$541734] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$541734] + 0.5}, {
                System`TradingChartDump`$plotrangemin$541734, 
                 System`TradingChartDump`$plotrangemax$541734}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$541734, Left, {
                 False, System`TradingChartDump`$frame$541734}, 
                 Blank[], {System`TradingChartDump`$frame$541734, False}], {
                False, System`TradingChartDump`$frame$541734}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$541734, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$541734]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$541734 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           387.02286107677577`}, {-286.92264150943396`, -65.76792452830186}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541734 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541734, 1]], 
               Part[System`TradingChartDump`$framestyle$541734, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$541734]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$541734} -> 
                   System`TradingChartDump`$isy$541734[
                    System`TradingChartDump`$plotrangemin$541734], {
                    0, System`TradingChartDump`$plotrangemax$541734} -> 
                   System`TradingChartDump`$isy$541734[
                    System`TradingChartDump`$plotrangemax$541734]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$541734[
                   System`TradingChartDump`$plotrangemin$541734], 
                   System`TradingChartDump`$isy$541734[
                   System`TradingChartDump`$plotrangemax$541734]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$541734, 
                   System`TradingChartDump`$isy$541734}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541734, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541734 > 
                    System`TradingChartDump`$plotrangemin$541734, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541734 > 
                    System`TradingChartDump`$plotrangemin$541734, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$541734, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$541734 > 
                    System`TradingChartDump`$plotrangemin$541734, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$541734 > 
                    System`TradingChartDump`$plotrangemin$541734, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541734, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541734, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541734 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541734,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541734], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541734 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541734, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541734]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$541734, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$541734[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$541734[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$541734, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$541734[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$541734, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$541734[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$541734, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$541734[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541734[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541734[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$541734[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$541734], 
                    Style[":", System`TradingChartDump`$textstyle$541734]], 
                    Style[":", System`TradingChartDump`$textstyle$541734]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$541734[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$541734]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$541734[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$541734}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$541734, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$541734 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$541734[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$541734, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$541734, Left, {
                    False, System`TradingChartDump`$frame$541734}, 
                    Blank[], {
                    System`TradingChartDump`$frame$541734, False}], {
                   System`TradingChartDump`$frame$541734, 
                    System`TradingChartDump`$frame$541734}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$541734, 
                    System`TradingChartDump`$controlmax$541734}] + 0.5, {
                   System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$541734]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$541734) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$541734 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$541734 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$541734, 1]], 
                   Part[System`TradingChartDump`$framestyle$541734, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$541734]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$541734[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$541734[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$541734[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541734, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$541734, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$541734, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$541734, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$541734 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
541734, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$541734], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$541734 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$541734, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$541734]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$541734, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$541734) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$541734 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$541734[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           475.9407855006933}, {-55.989622641509435`, -0.7009433962264069}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$541734, 
              Dynamic[System`TradingChartDump`$ohlclabel$541734], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$541734}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$541734 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$541734, 2]], 
               Part[System`TradingChartDump`$framestyle$541734, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$541734]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$541734, {1, 0} + 
                  Map[
                   IntegerPart, {
                    System`TradingChartDump`$controlmin$541734, 
                    System`TradingChartDump`$controlmax$541734}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$541734] + 
                    0.5, System`TradingChartDump`$plotrangemin$541734}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$541734], 
                    System`TradingChartDump`$plotrangemin$541734}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$541734, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$541734, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$541734, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$541734 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$541734, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$541734], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$541734 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$541734,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$541734]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$541734] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$541734[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$541734] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$541734[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$541734] = {HoldPattern[
               System`TradingChartDump`$min$541734[1]] :> -98.89}}, {
          DownValues[System`TradingChartDump`$max$541734] = {HoldPattern[
               System`TradingChartDump`$max$541734[1]] :> 0.}}, {
          DownValues[System`TradingChartDump`$subplotvalue$541734] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$541734[1, 1]] :> 
             Invisible[-16.15]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$541734] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$541734[
               1]] :> {-100, -50}}}, {
          DownValues[System`TradingChartDump`$layoutData$541734] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$541734["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "AllValues"]] :> CompressedData["
1:eJxFVwk4lVsXppIh0aCkJH7kIJGzv72PhCUVlTKkQVcqXSKKkooGqWSoaLjI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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541734["AppendedAdjust"]] :> 
             9.888558976166351, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "AppendedBox"]] :> {-113.71842822591304`, 0.}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "AppendedMin"]] :> -103.82986924974668`, HoldPattern[
               System`TradingChartDump`$layoutData$541734["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$541734["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$541734["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$541734["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541734["DataMax"]] :> 
             24.95, HoldPattern[
               System`TradingChartDump`$layoutData$541734["DataMin"]] :> 
             19.376947890818858`, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "MainChartAllValues"]] :> CompressedData["
1:eJxFVwk81csXp5Il0aKkJP4Rkcid38yVcCRRKUta9KToka2QVLRok6Wi5SFb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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "MainChartPoints"]] :> CompressedData["
1:eJxdV1toXFUUvRZFKYIKBf0ocapS6oNSTR/xEbubNk2apk1mMslkksnkztyZ
O487M6n4IxXhIuRHhFAoSEVkRBFBEEEKoV+X+CGIIoJQBJEpQhEiUpCK9MuZ
2Wt97HMhDOvuu886e+3HOTlQ3shU7/c8717/7z787fH43DkZDp7bo4IX+itH
gR+SW5f3fTV1gPhR6aP+K+J9srVz91DhEeInpDB48RvX2y/TwwVoT8nem59e
Gp8hfkreGB+8IX5G188SH1T+EvEh+Su9PbIZET+n/HPEL8i3fbg1QXzY4T8i
T27upreLxC9Kpr/cbpr4JSf+URmGe5j4qMa3n/iYDN3/Y7zHHb1OOP5j8tml
fsBPE78sQ/0PEr/irPeq6rWX9tfkw2v951fax+XtgWD3iF/X+D7m9yeV7w9i
0fW+B47FsZ/Cfo/Bfgr6AnsTut+Q9gkZbi9H+2kZ0I9s0n5a/u2nY+c67Wd0
f7/Tfgbx0j4pP/4weGif1Hzu0H5W7e/TflaeHSbkOOxT0BM4npJheY3TPq18
Y7RPY/+0n0O90X5O9XqP9hnVP0/7DOqf9vNOfOdldPD8w/3Pav3u0j6LfqL/
BYvjC87+Ltp44oua/8tcfw56cP05/U2Y33n9/gawODieV/6rwMk84qd/WuP9
if5p7a/v6J9W/W7RP635epj7y6h+1+ifsf0YZxAP/R27t6D6PU//Ba2Pd1H/
8YLubws4WdB6+Jz9kbX9Jlnbz3HWrp9kUc/kX7R6yCLqgf6Lut5H9F+08XpL
TvxLqs8s/ZeQb/ovaf18Q/+c2m/SP6f9+jf9c5i/9M+hv+i/jPpBPmQZ9cZ6
cXCyjH5g/vLQj/55Xe8d8ufR7+TPo1/Jv2K/lxU7/+MV3X+B/ivOvF1FPum/
ivfc/yrmBf1XrR5ewc4/Kej8v0L+gp2fSUH1+IX+a47/mlP/a47+jt0rqj53
6V/U+L/m/ovav19Q/6Lm+wPqv456oP7ryD/913G+YD4kDvZ8O59Svp1H4uP8
xPe+b+dX7ON8gL3r23mVYP0R4J7v8Jc0nseBUyU7j6Wk/fbACfCXcP4BxyXs
l/wlzAfYE+f7Xgn7A/bKGs8ocKqs9f0J+cvQh/GXES/5y3b9bln12kP+MuIj
fxnnJfkDzDfyB+gHYAkwfxl/oPwd8gfQi/wB5gf5A3xHfmAhf0Xr/THyV5Af
8ldU/0nyV9B/5K9YPboVnH/kr2g932H+KzZfXtXaU1XV5zb1r+L8In9V9/sz
zzvn+24VvKw/Z/1eFecR+UONN2D8oc2PhE78oa2POHTqL0S+yB8in+Snnf1b
s/erVA33XfZfDfMF2K9hfrD/gB8kf832U1JDvshfc+5XdduPKeCA+tehB+u/
Dl7GX8c8JH8d5xn568q3Tf666vUl9W9Y/1TD1o80bP/4DZuPuIHziPXXUL63
WH8N8LH+HbvXxPnK/De13urkb+p8eJP8jj1u2n7pOt8nTcvXc773Iq3PI+SP
7H4lwrwnf2TrNY5wHyd/ZOdHEqGeyB/ZeeK1sJ8x8LdQb+Rv4Zf8LZzH5G/h
vGH+W3Y+JI5/r4X/r8jfduJv23xI2/a331b9/2T9tXF/Yfxtu37SxvlN/jbu
a+TvYD6Qv4P7Avk76HfG33Hmb8eu13W+Tzqof+jb6+A+AOxt4H5E/TewX2DZ
wH1gTP4HLlcf7Q==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541734["NewSubplot"]] :> {
               FinancialIndicator["WilliamsPercentR", 10]}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$541734["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "PlotRangeMin"]] :> -103.82986924974668`, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$541734["Space"]] :> 2.495, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541734["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, -80}, {250., -80}}], 
                    Line[{{0, -50}, {250., -50}}], 
                    Line[{{0, -20}, {250., -20}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJxdV3s81fcfPlGp2aU1SpgOuURIyC3xIHIpuTsojnM4OMfRslqpqe9atyWr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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "SubplotIndicatorGridLines"]] :> {{-100, -50, 0}}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "WilliamsR"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["WilliamsPercentR", 10]}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "SubplotIndicatorParameters"]] :> {{{10}}}, HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "SubplotIndicatorPoints"]] :> CompressedData["
1:eJxdl1lsVHUUxgdFJU2MqEVQsQyLWBaRUspe+NPSBSh036ftnXZm2s7SYnxB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              "], HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "SubplotIndicatorValues"]] :> CompressedData["
1:eJw9VVloU0EUTXGlIG7VukbTRZumW5q0aWsT0yRN0jTa5OW9lyhFUFBBFCv+
uKNIUVSsfy6IIm4faqkoWkXJqKCgtiAqVRChPypaquLSUrX43juHDLQ382bm
3HvPuXPHsmaztHaMyWTK0v5GaDtD/TtyBmtF+5d4t3lcvvBk951vc9cI7Wtn
aLVHGNMNXrHFrf3qioqwsZArdmr/++86uX+uWKADvLcLA6+zWEjdZu1Lnli/
ThuXnMDrrwXeU5do7Xj4q+ieVxzTTOvXEHA2xYgvA/+zLBz62J/C+v2oMGBT
YZx/1wz7N4JzT2TR81wbJXFh0kdXUujuskMx4Dh+pE0cRhzZpeLUSX0sFFYD
aDx5sOL8Xhvndq7PJ84krJsmIs6RQvG7SN9QzbyXMr8I4q1ZjDiSTuKWk89q
5pFHvguwv3uG0D+3TnYRPywGtDDan8WR31UFfFxTxQydcDmeseCvAf6GQsC9
rgD3jUS+k8irKoV1u4q4p6ag32BSXGjTA5SxnqXAfo8D97gPeGEZvHSnyJME
e1GG7rdU4JWlWB8qcBMKeVyGeX4zcRuhx+xK1ksu5m9rkF/OdPJRlrEGf63N
8NvYRJ3KgNeXxbmJPFOnKgfP2einLmNRF1nEd2E+kgSvLgl5BSXkdTQBnc6S
h08J5HUjhfnBJujcVos8/Q3wc66O+XiB9zgMXZ8HWVfuzLqR/3Yv+B72A2dM
CPFMqMf5D/mM24q8TjupRxF1HE4jv7HMO4d14qJfJ+qiYzRtuO318b4tQj5b
3Vhv8eD7bg/iuxkATztK4a+dfcA8h3qw3rWBOKuph1M80t35rKjrLxHM8wKs
hzrkuy2IeHfxvs/z854Xg/eOCu4vJw+LsX6gHn7CzeQlhDyPuMg3/U1TcP6R
hHx+RqHPg4RYZ+gcQxwnJMahIL9VEuroNe/bR4n6h8BHtgK7Mo46MScy99jA
3xehLgvYH2y8v0tQt7eTqJspMfjdyPv5QkX8apJ1poJfrwI/vTHEsS2W8QdL
nVb6YesC7Huz4C+3AnFZKsFTtIR1MZDGfalnvVUyjhrwesiS2Qcdzez/f9LQ
+Vsa70MB9bJD7ysexuVH3s4A35EA+1YT9h1W4M++nP01CvxR9iNLC+9JIc7/
czCeRtZjhO/NUvZf4tqqGKeF71sDzveo4D0m43uxCp6sCej1Msb+Tr+vqP/l
5aiLPSrmQzLO3Qmy//mQf4ud96GWfX4kbexb4WC/cvM9C7JefcA9w76x2sb7
O5M6lPI9caJeF1WI/2r50fQ=
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$541734["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$541734["YRange"]] :> 24.95,
              HoldPattern[
               System`TradingChartDump`$layoutData$541734[
               "SubplotPoints", {1}]] :> CompressedData["
1:eJw9VW1IU1EYnn0jRF+Wfa6mac75NTedmltzm9ucK7e7e++WSFCQQRQZ/emb
IqSoyP71QRTR149KiqIsip0KCkqDqKggAv9UpFjRJ1bSvfd52IF5PPec87zv
+zzv+x7Lqg3S6lEmk2lY+2Vpv+5Q/9acoVrRORDvMY/NF57sV2c63DVC+9od
WukRxnKtV2x0a/9diYqwsZErtml/+287eX6OmK8DvLMLA6+7WEg9Zu1LnljT
ro3zTuD11wLvsUu0dd3/UXTHKw5rU9vnEHDWx4gvA/+TLBz62JPC/t2oMGBT
Ydx/24z5bwT3Hsmir1cbJXFh0seVpNDNZYdiwHF8S5s4DD+yS8XxY/pYIKwG
0DjyYMX9XTau7dyfR5yJ2DdNgJ/DBeJnkX6gmnEvYXwR+FuzCH4kncQtJ5/V
jCOPfC/E+Z7pQv/cNslF/LAY1NzofBJHfJcU8HFZFdN1wuV4ZgZ/DbD3KwTc
qwpwX0vkO4m4qlLYt6vwe0oK+g0lxdkO3UEZ+1kK5q9x4B7xAS8sg5eeFHmS
MJ+TofsNFXhlKeaHCtyEQh6XYp3fTNxG6DGrkvmSi/WbGsSXM418lGVmg7+2
ZthtbKJOZcB7lcW1iTxTpyoH79lopy4zIy+yiO/CejgJXl0S4gpKiOtQAjqd
Ig8fE4jrWgrrfU3QuaMWcfobYOd0HePxAu9hGLr2BplX7sy+Ef8WL/j+7QfO
6BD8GV+P++/z6bcVcZ1wUo8i6vg7jfjGMO4c5omLdp3Ii66RtGH2qY/1Voh4
Nrmx3+LB9x0e+Hc9AJ62lsJeJ/uAeTb1YL5rA35WUw+neKCb81mR1wMRrPMC
zIc6xLs5CH+3s97n+lnnxeC9q4Lny8nDIuzvrYedcDN5CSHOgy7yTXtTFdx/
ICGe71Hocy8h2g2dY/DjqEQ/FMS3QkIevWS9fZCofwh8ZCuYW+PIE3MiU8cG
/u4IdZnP/mBj/S5G3t5MIm8mx2B3HevzmQr/1STzTAW/XgV2nsbgx+ZYxh5m
6tTqx1wXYN+bCXu5FfDLUgmeoiXMi8E06qWe+VZJP2rA635L5hx0NLP//0lD
5y9pvA8LqZcdel/00C8/4nYG+I4E2LeacO6AAnv2ZeyvUeCPsB9ZWlgnBbj/
z0F/GpmPEb43S9h/iWurop8Wvm8NuN+ngveYjO/FKniyJqDX8xj7O+2+oP4X
liEvdqpY/5Jx71aQ/c+H+FvsrIda9vnhtHFuuYP9ys33LMh89QH3JPvGShvr
dwZ1KOV74kS+FlaI/1SN0fI=
              "], HoldPattern[
               System`TradingChartDump`$layoutData$541734[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$541734[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$541734[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$541734[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$541734[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$541734 = 
           System`TradingChartDump`$length$541734; 
          System`TradingChartDump`$layoutData$541734["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$541734; 
          System`TradingChartDump`$modelData$541734["Data"] = 
           System`TradingChartDump`$data$541734; 
          System`TradingChartDump`$modelData$541734["Indicators"] = 
           System`TradingChartDump`$indicators$541734; 
          System`TradingChartDump`$layoutData$541734[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$541734["ScalingFunctions"] = {
            System`TradingChartDump`$sy$541734, 
             System`TradingChartDump`$isy$541734}; 
          System`TradingChartDump`$layoutData$541734["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541734["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$541734[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$541734["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$541734["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$541734, 
            System`TradingChartDump`$layoutData$541734, 
            System`TradingChartDump`$indicators$541734]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$541734, 
            System`TradingChartDump`$layoutData$541734, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$541734[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$541734["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$541734[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$541734[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$541734["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$541734[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$541734 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541734["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541734, 
                 System`TradingChartDump`$controlmax$541734}]]]; 
          System`TradingChartDump`$plotrangemax$541734 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$541734["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$541734, 
                 System`TradingChartDump`$controlmax$541734}]]]; {
            System`TradingChartDump`$plotrangemin$541734, 
             System`TradingChartDump`$plotrangemax$541734} = ReplaceAll[
             
             System`TradingChartDump`$sy$541734[{
              System`TradingChartDump`$plotrangemin$541734, 
               System`TradingChartDump`$plotrangemax$541734}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$541734[
                Min[System`TradingChartDump`$lows$541734]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$541734 == 
            System`TradingChartDump`$plotrangemax$541734, {
             System`TradingChartDump`$plotrangemin$541734, 
              System`TradingChartDump`$plotrangemax$541734} = {
             System`TradingChartDump`$plotrangemin$541734 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$541734], 
              System`TradingChartDump`$plotrangemax$541734 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$541734]}]; 
          System`TradingChartDump`$newgridlines$541734 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$541734, 
            Part[System`TradingChartDump`$newgridlines$541734, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$541734, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$541734], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$541734, 1]]; 
            Part[System`TradingChartDump`$newgridlines$541734, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$541734, 1] =!= None,
                 System`TradingChartDump`$length$541734 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$541734, 
                 Part[System`TradingChartDump`$newgridlines$541734, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$541734, 1]]; 
            System`TradingChartDump`$subpricegridlines$541734 = 
             Part[System`TradingChartDump`$gridlines$541734, 2]; 
            Part[System`TradingChartDump`$newgridlines$541734, 2] = 
             If[System`TradingChartDump`$sy$541734 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541734}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541734, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541734, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$541734, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$541734, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$541734}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$541734, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$541734, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$541734 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$541734]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"GE\"", "\" with \"", 
           "\"WilliamsPercentR\"", "\"(\"", "10", "\",\"", "", "\",\"", "", 
           "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {720., -1171.8}, 
      ImageScaled[{0.5, 0.5}], {450, 310}]}}, {}},
  ContentSelectable->True,
  ImageSize->{972., 1351.2},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5838127298204575`*^9, 3.583812961262695*^9, 
  3.583813408555279*^9, 3.5838137803205423`*^9, 3.5838140342170644`*^9, 
  3.5838141358198757`*^9}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Comany: Financial Indicators for Micrososft\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}, {
   3.583812331977702*^9, 3.5838123364259567`*^9}, {3.5838140918583612`*^9, 
   3.5838140950095415`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"indic", ",", "par1", ",", "par2", ",", "par3", ",", "par4"}], 
    "}"}], ",", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"indic", "=", 
          RowBox[{"FinancialIndicator", "[", "indicator", "]"}]}], ";", 
         RowBox[{"par1", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "1"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par2", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "2"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par3", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "3"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "4", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par4", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "4"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "5", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"Quiet", "[", 
          RowBox[{"TradingChart", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<MSFT\>\"", ",", 
              RowBox[{"DatePlus", "[", 
               RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"FinancialIndicator", "[", 
              RowBox[{
              "indicator", ",", "par1", ",", "par2", ",", "par3", ",", 
               "par4"}], "]"}], "}"}], ",", 
            RowBox[{"PlotLabel", "\[Rule]", 
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{
               "\"\<Last \>\"", ",", "365", ",", " ", "\"\< days of \>\"", 
                ",", "\"\<MSFT\>\"", ",", "\"\< with \>\"", ",", "indicator", 
                ",", "\"\<(\>\"", ",", "par1", ",", "\"\<,\>\"", ",", "par2", 
                ",", "\"\<,\>\"", ",", "par3", ",", "\"\<,\>\"", ",", "par4", 
                ",", "\"\<)\>\""}], "}"}], "]"}]}], ",", 
            RowBox[{"ImageSize", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"450", ",", "310"}], "}"}]}]}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"indicator", ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<AverageTrueRange\>\"", ",", "\"\<FastStochastic\>\"", ",", 
            " ", "\"\<FullStochastic\>\"", ",", 
            "\"\<ParabolicStopAndReversal\>\"", ",", 
            "\"\<PolarizedFractalEfficiency\>\"", ",", 
            "\"\<RelativeStrengthIndex\>\"", ",", "\"\<TRIX\>\"", ",", 
            "\"\<WilliamsPercentR\>\""}], "}"}]}], "}"}]}], "]"}], ",", "2"}],
      "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.583811787947585*^9, {3.5838119623005576`*^9, 3.583812031980543*^9}, {
   3.583812156077641*^9, 3.583812211852831*^9}, {3.5838124507184935`*^9, 
   3.58381256150383*^9}, {3.583812608815536*^9, 3.5838126437915363`*^9}, {
   3.5838126817437077`*^9, 3.583812712720479*^9}, {3.583812927170745*^9, 
   3.5838129379693623`*^9}, {3.583813333539988*^9, 3.5838133966595984`*^9}, {
   3.5838134480685387`*^9, 3.583813448403558*^9}, {3.5838137582942824`*^9, 
   3.583813769668933*^9}, {3.583813999222063*^9, 3.5838139995740833`*^9}, {
   3.5838140562623253`*^9, 3.5838140665499134`*^9}, {3.5838141056541505`*^9, 
   3.5838141123575335`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$545613 = 
        "Full", System`TradingChartDump`$highlightposition$545613 = Automatic,
         System`TradingChartDump`$maxohlc$545613 = 36.43`4., 
        System`TradingChartDump`$timestampstyle$545613 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$545613 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$545613 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$545613, 
        System`TradingChartDump`$subplotpoint$545613, 
        System`TradingChartDump`$ndigits$545613 = 4, 
        System`TradingChartDump`$highlightstyle$545613 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$545613 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$545613 = True, 
        System`TradingChartDump`$timestampQ$545613 = True, 
        System`TradingChartDump`$data$545613 = {{{2012, 7, 26}, {
          28.367935528120714`, 28.62997256515775, 28.232064471879287`, 28.3, 
           45301400}}, {{2012, 7, 27}, {
          28.60827956989247, 28.967338709677417`, 28.317150537634404`, 28.88, 
           44242600}}, {{2012, 7, 30}, {
          28.866734143049936`, 28.934655870445347`, 28.58534412955466, 28.76, 
           28905000}}, {{2012, 7, 31}, {
          28.609704784526638`, 28.832914828639293`, 28.464133016627077`, 28.6,
            37620900}}, {{2012, 8, 1}, {
          28.714675280516833`, 28.77290037402244, 28.3459163549813, 28.54, 
           31721800}}, {{2012, 8, 2}, {
          28.349410757108597`, 28.65998287084618, 28.11648167180541, 28.33, 
           39520500}}, {{2012, 8, 3}, {
          28.65650756302521, 29.054379831932774`, 28.60798655462185, 28.87, 
           35859400}}, {{2012, 8, 6}, {
          29.108514190317194`, 29.215245409015022`, 28.924160267111848`, 
           29.06, 27471800}}, {{2012, 8, 7}, {
          29.185588235294116`, 29.457352941176467`, 28.99147058823529, 29.37, 
           28002900}}, {{2012, 8, 8}, {
          29.31356083086054, 29.56584569732938, 29.21652818991098, 29.43, 
           26257600}}, {{2012, 8, 9}, {
          29.493245901639348`, 29.745573770491806`, 29.40590163934427, 29.6, 
           24920800}}, {{2012, 8, 10}, {
          29.59763313609467, 29.714082840236685`, 29.355029585798814`, 29.52, 
           27810300}}, {{2012, 8, 13}, {
          29.451184600197433`, 29.55792694965449, 29.26681145113524, 29.49, 
           23049100}}, {{2012, 8, 14}, {
          29.596050448058413`, 29.68395950879522, 29.31278791901759, 29.43, 
           34551400}}, {{2012, 8, 15}, {
          29.412086092715235`, 29.578145695364242`, 29.324172185430466`, 29.5,
            24351000}}, {{2012, 8, 16}, {
          29.65968810916179, 30.22630929174789, 29.561994801819363`, 30.07, 
           35787200}}, {{2012, 8, 17}, {
          30.19953398058253, 30.19953398058253, 29.87722330097088, 30.18, 
           32589900}}, {{2012, 8, 20}, {
          30.108152244632407`, 30.13745933636956, 29.873695510735203`, 30.03, 
           23737700}}, {{2012, 8, 21}, {
          30.050922077922078`, 30.24631168831169, 29.90437987012987, 30.09, 
           28822700}}, {{2012, 8, 22}, {
          29.878837590045844`, 30.044885396201707`, 29.761627373935823`, 
           29.83, 33437400}}, {{2012, 8, 23}, {
          29.68699272967614, 29.696761401189683`, 29.384163912756108`, 29.56, 
           28355600}}, {{2012, 8, 24}, {
          29.547202225130892`, 29.91837369109948, 29.478828534031415`, 29.85, 
           22943300}}, {{2012, 8, 27}, {
          30.214447702834796`, 30.243753665689148`, 29.88231345715216, 29.98, 
           34691100}}, {{2012, 8, 28}, {
          29.988377407770162`, 30.08605941887039, 29.81254978778975, 29.92, 
           23947900}}, {{2012, 8, 29}, {
          29.940000000000005`, 30.037683523654167`, 29.734864600326272`, 
           29.94, 23346800}}, {{2012, 8, 30}, {
          29.82515171503958, 29.90330474934037, 29.52230870712401, 29.62, 
           23982100}}, {{2012, 8, 31}, {
          29.895068137573006`, 30.246774821544452`, 29.68013627514601, 30.11, 
           36590100}}, {{2012, 9, 4}, {
          29.748617966436328`, 29.953780848963476`, 29.45552813425469, 29.69, 
           48556700}}, {{2012, 9, 5}, {
          29.523915761763735`, 29.8267752550181, 29.51414610069102, 29.69, 
           33650000}}, {{2012, 9, 6}, {
          29.789792663476874`, 30.629767145135563`, 29.750724082934607`, 
           30.62, 48371700}}, {{2012, 9, 7}, {
          30.317906300484655`, 30.347208400646206`, 30.01511793214863, 30.23, 
           42649100}}, {{2012, 9, 10}, {
          30.11745768229167, 30.185839843750003`, 29.804853515625005`, 30.01, 
           40524000}}, {{2012, 9, 11}, {
          29.982305943488143`, 30.197232867814222`, 29.90415069827866, 30.08, 
           25191800}}, {{2012, 9, 12}, {
          30.22630929174789, 30.46077322936972, 30.021153346328784`, 30.07, 
           32775800}}, {{2012, 9, 13}, {
          30.171163542340008`, 30.454414996767934`, 29.692566257272134`, 
           30.22, 45047300}}, {{2012, 9, 14}, {
          30.29461390579942, 30.52907721884011, 30.09922781159884, 30.49, 
           51422800}}, {{2012, 9, 17}, {
          30.47046139057994, 30.53884652355014, 30.323921819929506`, 30.49, 
           36488500}}, {{2012, 9, 18}, {
          30.381847338037208`, 30.489307248236052`, 30.31346375881976, 30.46, 
           34542700}}, {{2012, 9, 19}, {
          30.369072463768113`, 30.466753623188403`, 30.320231884057968`, 
           30.33, 48871900}}, {{2012, 9, 20}, {
          30.231605723370425`, 30.74930365659777, 30.19253418124006, 30.72, 
           45543000}}, {{2012, 9, 21}, {
          30.704459762744467`, 30.88030458480282, 30.3723084321898, 30.47, 
           102348900}}, {{2012, 9, 24}, {
          30.284925276153345`, 30.353310591293045`, 29.933229369720596`, 
           30.07, 46825900}}, {{2012, 9, 25}, {
          30.23710102007239, 30.285949325435997`, 29.660691016781836`, 29.69, 
           54266400}}, {{2012, 9, 26}, {
          29.577447795823662`, 29.890023201856145`, 29.3430162412993, 29.47, 
           54672000}}, {{2012, 9, 27}, {
          29.46976790450929, 29.694429708222817`, 29.196266578249343`, 29.46, 
           47129900}}, {{2012, 9, 28}, {
          29.480262096774194`, 29.558407258064516`, 29.050463709677416`, 
           29.07, 54229300}}, {{2012, 10, 1}, {
          29.122621227534758`, 29.288701254662598`, 28.741614106476774`, 
           28.81, 54042700}}, {{2012, 10, 2}, {
          28.98953472690492, 29.194649359406608`, 28.813722184760618`, 28.97, 
           43338900}}, {{2012, 10, 3}, {
          29.062541862022776`, 29.296995981245818`, 28.98439048894843, 29.17, 
           46655900}}, {{2012, 10, 4}, {
          29.271398601398595`, 29.329999999999995`, 28.880722610722604`, 
           29.33, 43634900}}, {{2012, 10, 5}, {
          29.531216080402007`, 29.55075376884422, 29.052542713567835`, 29.16, 
           41133900}}, {{2012, 10, 8}, {
          28.953243787777033`, 29.226756212222973`, 28.865329079919412`, 
           29.09, 29752000}}, {{2012, 10, 9}, {
          28.990710382513658`, 29.049316939890705`, 28.502322404371583`, 28.6,
            45121100}}, {{2012, 10, 10}, {
          28.476069703243613`, 28.632370600414074`, 28.280693581780536`, 
           28.31, 47227100}}, {{2012, 10, 11}, {
          28.543751295336786`, 28.573056994818653`, 28.20185146804836, 28.28, 
           41488500}}, {{2012, 10, 12}, {
          28.29535616438356, 28.637205479452053`, 28.12931506849315, 28.52, 
           46464700}}, {{2012, 10, 15}, {
          28.693226025076243`, 29.03516096238563, 28.57599118942731, 28.83, 
           42440200}}, {{2012, 10, 16}, {
          28.770922346558155`, 29.054235334011526`, 28.643919972872162`, 
           28.81, 47739400}}, {{2012, 10, 17}, {
          28.626664413653266`, 28.958850963163233`, 28.421490368367696`, 
           28.91, 44206100}}, {{2012, 10, 18}, {
          28.966542372881356`, 29.044698305084747`, 28.585532203389832`, 
           28.82, 59238500}}, {{2012, 10, 19}, {
          28.380551675977653`, 28.409860335195525`, 27.843226256983236`, 
           27.98, 90470800}}, {{2012, 10, 22}, {
          28.063053571428572`, 28.16073214285714, 27.183946428571428`, 27.35, 
           83374000}}, {{2012, 10, 23}, {
          27.126488413547236`, 27.546524064171123`, 27.116720142602496`, 27.4,
            64414800}}, {{2012, 10, 24}, {
          27.503942652329755`, 27.543010752688176`, 27.220698924731188`, 
           27.25, 53320400}}, {{2012, 10, 25}, {
          27.532772596843618`, 27.542539454806313`, 27.210466284074606`, 
           27.23, 54084300}}, {{2012, 10, 26}, {
          27.21806451612903, 27.687004608294927`, 27.198525345622116`, 27.56, 
           57790000}}, {{2012, 10, 31}, {
          27.88976874562018, 28.21213735108619, 27.840925017519268`, 27.88, 
           69464100}}, {{2012, 11, 1}, {
          28.17566395663957, 28.879078590785912`, 28.15612466124662, 28.84, 
           72047900}}, {{2012, 11, 2}, {
          28.907925423728813`, 29.08377627118644, 28.653918644067797`, 28.82, 
           57131600}}, {{2012, 11, 5}, {
          28.930232872089103`, 29.047438407019914`, 28.646986162672967`, 
           28.94, 38070800}}, {{2012, 11, 6}, {
          29.13092431346283, 29.50214333556598, 28.92577695914267, 29.17, 
           43401500}}, {{2012, 11, 7}, {
          28.849632049518576`, 29.14272008253095, 28.380691196698766`, 28.41, 
           57871800}}, {{2012, 11, 8}, {
          28.442790697674425`, 28.68697674418605, 28.13023255813954, 28.14, 
           49841800}}, {{2012, 11, 9}, {
          28.2088380159556, 28.511633714880336`, 28.14046479361776, 28.16, 
           43291200}}, {{2012, 11, 12}, {
          28.273416017009215`, 28.341803685329555`, 27.560230333097095`, 
           27.57, 61112300}}, {{2012, 11, 13}, {
          26.611059431524552`, 26.88682170542636, 26.345145810262093`, 26.68, 
           131689200}}, {{2012, 11, 14}, {
          26.823889716840533`, 26.873125931445603`, 26.390611028315945`, 
           26.43, 76086100}}, {{2012, 11, 15}, {
          26.476699174793698`, 26.565348837209303`, 26.230450112528132`, 
           26.26, 50955600}}, {{2012, 11, 16}, {
          26.267737556561087`, 26.2972850678733, 25.942714932126695`, 26.12, 
           64083300}}, {{2012, 11, 19}, {
          26.398952487841374`, 26.398952487841374`, 26.07389075944631, 26.33, 
           57179300}}, {{2012, 11, 20}, {
          26.359251216772744`, 26.39865219019094, 26.06374391613628, 26.31, 
           47070400}}, {{2012, 11, 21}, {
          26.30365120593692, 26.75665306122449, 26.264259740259742`, 26.54, 
           66360300}}, {{2012, 11, 23}, {
          26.817126353790613`, 27.348938628158844`, 26.787581227436824`, 
           27.28, 57845700}}, {{2012, 11, 26}, {
          27.127754654983573`, 27.167155896312522`, 26.763293172690766`, 
           26.98, 85198700}}, {{2012, 11, 27}, {
          26.945760709010344`, 26.96545790251108, 26.630605612998526`, 26.67, 
           45018600}}, {{2012, 11, 28}, {
          26.605244883040935`, 26.97955043859649, 26.368841374269003`, 26.95, 
           53018400}}, {{2012, 11, 29}, {
          26.697565862708718`, 26.943762523191094`, 26.451369202226346`, 
           26.54, 69551400}}, {{2012, 11, 30}, {
          26.643538692712244`, 26.7223365890308, 26.09195341848234, 26.22, 
           83690200}}, {{2012, 12, 3}, {
          26.37470298902762, 26.414097616345064`, 26.000454029511918`, 26.03, 
           53173800}}, {{2012, 12, 4}, {
          26.098028062191883`, 26.226056124383767`, 25.9404550625711, 25.97, 
           49777500}}, {{2012, 12, 5}, {
          25.984349456317954`, 26.526100487439066`, 25.86614923134608, 26.27, 
           68283800}}, {{2012, 12, 6}, {
          26.408802843247283`, 26.57625888514777, 26.211795735129066`, 26.33, 
           39182300}}, {{2012, 12, 7}, {
          26.414557823129254`, 26.414557823129254`, 25.97136054421769, 26.06, 
           46162100}}, {{2012, 12, 10}, {
          26.155783221974758`, 26.559543429844098`, 26.116391982182627`, 
           26.53, 47031100}}, {{2012, 12, 11}, {
          26.64405197657394, 27.077448755490483`, 26.64405197657394, 26.91, 
           52282800}}, {{2012, 12, 12}, {
          27.11563509544787, 27.20428046989721, 26.67240822320117, 26.83, 
           43966300}}, {{2012, 12, 13}, {
          26.90682405016599, 27.10379933603836, 26.5424197713021, 26.7, 
           45080100}}, {{2012, 12, 14}, {
          26.695412159641922`, 26.71510630361805, 26.29168220813129, 26.4, 
           42077500}}, {{2012, 12, 17}, {
          26.38469003690037, 26.80818450184502, 26.27635424354244, 26.69, 
           42046100}}, {{2012, 12, 18}, {
          26.834724238026126`, 27.208933236574747`, 26.726400580551527`, 
           27.14, 50486900}}, {{2012, 12, 19}, {
          27.274295129989014`, 27.313694617356276`, 26.8409007689491, 26.9, 
           53519900}}, {{2012, 12, 20}, {
          26.94485549132948, 27.26, 26.738041907514454`, 27.26, 52607300}}, {{
          2012, 12, 21}, {
          27.04, 27.079402550091075`, 26.59672131147541, 27.04, 98776500}}, {{
          2012, 12, 24}, {
          26.78787878787879, 26.83712121212121, 26.59090909090909, 26.65, 
           20842400}}, {{2012, 12, 26}, {
          26.617405063291137`, 26.784810126582276`, 26.292442293373043`, 
           26.45, 31631100}}, {{2012, 12, 27}, {
          26.481064540059347`, 26.678022997032638`, 26.165931008902074`, 
           26.55, 39394000}}, {{2012, 12, 28}, {
          26.307589453860636`, 26.494726930320144`, 26.149999999999995`, 
           26.15, 28239900}}, {{2012, 12, 31}, {
          26.191797079745413`, 26.369101460127293`, 25.97509172594534, 26.31, 
           42749500}}, {{2013, 1, 2}, {
          26.8356263577118, 27.30832729905865, 26.737146994931205`, 27.2, 
           52899300}}, {{2013, 1, 3}, {
          27.214282568807338`, 27.233981651376148`, 26.75135412844037, 26.84, 
           48294400}}, {{2013, 1, 4}, {
          26.862071802543007`, 26.93102468212416, 26.330149588631265`, 26.34, 
           52521100}}, {{2013, 1, 7}, {
          26.36880104908205, 26.477152491569875`, 26.240749344323717`, 26.29, 
           37110400}}, {{2013, 1, 8}, {
          26.346986817325796`, 26.386384180790955`, 26.061355932203387`, 
           26.15, 44703100}}, {{2013, 1, 9}, {
          26.319700374531838`, 26.34925093632959, 26.162097378277153`, 26.3, 
           49047900}}, {{2013, 1, 10}, {
          26.247127739984883`, 26.572139077853365`, 25.89256991685563, 26.06, 
           71431300}}, {{2013, 1, 11}, {
          26.08519567648155, 26.51847185985837, 25.87840477077898, 26.42, 
           55512100}}, {{2013, 1, 14}, {
          26.489847526961693`, 26.667103012272218`, 26.351982149497953`, 
           26.48, 48324400}}, {{2013, 1, 15}, {
          26.42572583608967, 26.878794560823223`, 26.42572583608967, 26.8, 
           48244500}}, {{2013, 1, 16}, {
          26.738332100591716`, 26.817119082840236`, 26.600454881656805`, 
           26.63, 41077400}}, {{2013, 1, 17}, {
          26.78090275229358, 27.05668990825688, 26.65285871559633, 26.84, 
           51685900}}, {{2013, 1, 18}, {
          26.692256880733947`, 26.879398165137616`, 26.633159633027525`, 
           26.84, 52167700}}, {{2013, 1, 22}, {
          26.887734806629833`, 27.035469613259668`, 26.592265193370167`, 
           26.74, 58650600}}, {{2013, 1, 23}, {
          26.786236870699025`, 27.21954364360739, 26.786236870699025`, 27.19, 
           50387700}}, {{2013, 1, 24}, {
          27.27893593919653, 27.643311617806734`, 27.052432138979373`, 27.21, 
           101739300}}, {{2013, 1, 25}, {
          27.164519368723095`, 27.804727403156384`, 26.97738163558106, 27.46, 
           81847700}}, {{2013, 1, 28}, {
          27.58849516302401, 27.80518452167682, 27.342257255463995`, 27.49, 
           56056500}}, {{2013, 1, 29}, {
          27.402848982506246`, 27.708200642627627`, 27.186147804355585`, 
           27.59, 49242600}}, {{2013, 1, 30}, {
          27.58758707360862, 27.764872531418312`, 27.341357271095156`, 27.43, 
           43580500}}, {{2013, 1, 31}, {
          27.374921675774136`, 27.55223315118397, 26.990746812386156`, 27.04, 
           50530000}}, {{2013, 2, 1}, {
          27.253909774436092`, 27.628195488721804`, 27.135714285714286`, 
           27.51, 55565900}}, {{2013, 2, 4}, {
          27.453575072886295`, 27.60133381924198, 27.010298833819242`, 27.03, 
           50540000}}, {{2013, 2, 5}, {
          27.198167272727268`, 27.237556363636358`, 26.942138181818176`, 
           27.08, 35410400}}, {{2013, 2, 6}, {
          26.969400146305773`, 27.12700073152889, 26.841349670811994`, 26.93, 
           41889600}}, {{2013, 2, 7}, {
          26.938947947214075`, 26.978346774193547`, 26.692705278592374`, 
           26.87, 38028300}}, {{2013, 2, 8}, {
          26.933049001814883`, 27.287560798548096`, 26.893658802177857`, 
           27.13, 33318500}}, {{2013, 2, 11}, {
          27.23316582914573, 27.499095477386938`, 27.085427135678394`, 27.44, 
           32247700}}, {{2013, 2, 12}, {
          27.459999999999997`, 27.57819225251076, 27.33195839311334, 27.46, 
           35990900}}, {{2013, 2, 13}, {
          27.511498394577234`, 27.688801284338204`, 27.462247591865854`, 
           27.61, 41715600}}, {{2013, 2, 14}, {
          27.501797432239663`, 27.639700427960058`, 27.45254636233952, 27.62, 
           32663200}}, {{2013, 2, 15}, {
          27.619550160656903`, 27.737750803284538`, 27.46194930382006, 27.59, 
           49650900}}, {{2013, 2, 19}, {
          27.68121212121212, 27.889714795008913`, 27.6017825311943, 27.85, 
           38781400}}, {{2013, 2, 20}, {
          27.938227484750627`, 28.007750269106566`, 27.64027269465375, 27.68, 
           44110200}}, {{2013, 2, 21}, {
          27.548272098945073`, 27.548272098945073`, 27.041797017097128`, 27.3,
            49078500}}, {{2013, 2, 22}, {
          27.49054755043228, 27.570000000000004`, 27.29191642651297, 27.57, 
           31425900}}, {{2013, 2, 25}, {
          27.7758348556814, 27.85527950310559, 27.18, 27.18, 48011800}}, {{
          2013, 2, 26}, {
          27.18993058092802, 27.408403361344536`, 27.150208257215926`, 27.18, 
           49923300}}, {{2013, 2, 27}, {
          27.232664509169368`, 27.808701905789285`, 27.143279395900755`, 
           27.62, 36394700}}, {{2013, 2, 28}, {
          27.689453237410067`, 27.7788381294964, 27.55041007194244, 27.61, 
           35840200}}, {{2013, 3, 1}, {
          27.53156350626118, 27.789796064400715`, 27.332923076923077`, 27.76, 
           34849700}}, {{2013, 3, 4}, {
          27.652131438721142`, 27.950000000000003`, 27.503197158081708`, 
           27.95, 38157500}}, {{2013, 3, 5}, {
          28.090423280423277`, 28.33865961199294, 27.961340388007052`, 28.15, 
           41432200}}, {{2013, 3, 6}, {
          28.009145603417586`, 28.029003203987184`, 27.582207191171236`, 
           27.89, 51448500}}, {{2013, 3, 7}, {
          27.910213219616203`, 28.079004975124377`, 27.810923951670222`, 
           27.94, 29196700}}, {{2013, 3, 8}, {
          28.058303571428567`, 28.137760714285708`, 27.770271428571426`, 
           27.81, 37667800}}, {{2013, 3, 11}, {
          27.74952278435594, 27.779318263365624`, 27.48136347326875, 27.68, 
           36627500}}, {{2013, 3, 12}, {
          27.650476531709067`, 27.759727696166248`, 27.451838050877825`, 
           27.72, 39255200}}, {{2013, 3, 13}, {
          27.680340257879656`, 27.829319484240685`, 27.56115687679083, 27.73, 
           29093400}}, {{2013, 3, 14}, {
          27.800995024875622`, 27.959857853589195`, 27.731492537313432`, 
           27.94, 55914800}}, {{2013, 3, 15}, {
          27.83007132667618, 27.95914407988588, 27.780427960057064`, 27.84, 
           92710300}}, {{2013, 3, 18}, {
          27.681565836298926`, 28.07871886120996, 27.612064056939495`, 27.9, 
           44809400}}, {{2013, 3, 19}, {
          27.92042583392477, 28.01971611071682, 27.831064584811926`, 27.98, 
           51901600}}, {{2013, 3, 20}, {
          28.13985875706215, 28.28879943502825, 27.980988700564975`, 28.12, 
           35447800}}, {{2013, 3, 21}, {
          27.909999999999997`, 28.158221273568124`, 27.85042689434365, 27.91, 
           34233200}}, {{2013, 3, 22}, {
          27.990424778761064`, 28.13936283185841, 27.901061946902658`, 28.05, 
           28720900}}, {{2013, 3, 25}, {
          28.099005681818188`, 28.14865056818182, 27.76142045454546, 27.96, 
           44154000}}, {{2013, 3, 26}, {
          28.03943181818182, 28.138721590909096`, 27.910355113636367`, 27.96, 
           27824300}}, {{2013, 3, 27}, {
          27.941621431089178`, 28.24943602396898, 27.88204441311244, 28.17, 
           36047400}}, {{2013, 3, 28}, {
          28.12202726319469, 28.459650471862986`, 28.06244669695911, 28.41, 
           55453800}}, {{2013, 4, 1}, {
          28.439790283117794`, 28.459650471862986`, 28.16174764068508, 28.41, 
           29201100}}, {{2013, 4, 2}, {
          28.391458333333336`, 28.64965277777778, 28.321944444444448`, 28.6, 
           28456500}}, {{2013, 4, 3}, {
          28.548669467787114`, 28.747268907563026`, 28.34014005602241, 28.36, 
           35062800}}, {{2013, 4, 4}, {
          28.191468531468526`, 28.409930069930063`, 28.072307692307685`, 28.4,
            45263200}}, {{2013, 4, 5}, {
          28.02334494773519, 28.5794425087108, 27.91411149825784, 28.5, 
           50927300}}, {{2013, 4, 8}, {
          28.529020636586218`, 28.529020636586218`, 28.270839454354668`, 
           28.39, 34759500}}, {{2013, 4, 9}, {
          28.526241134751775`, 29.608510638297872`, 28.47659574468085, 29.4, 
           77733800}}, {{2013, 4, 10}, {
          29.364924042272122`, 30.109722589167763`, 29.315270805812414`, 
           30.07, 71116700}}, {{2013, 4, 11}, {
          28.89889426399447, 28.998203178991016`, 28.531451278507255`, 28.74, 
           130923200}}, {{2013, 4, 12}, {
          28.649583188607156`, 28.818402222994095`, 28.460903091351163`, 
           28.59, 62886300}}, {{2013, 4, 15}, {
          28.450278842802366`, 28.77797838968281, 28.311254792610665`, 28.49, 
           56332900}}, {{2013, 4, 16}, {
          28.700483258543322`, 28.93882637210908, 28.501863997238523`, 28.77, 
           52797300}}, {{2013, 4, 17}, {
          28.64986125563649, 28.83854318418314, 28.40159556018037, 28.63, 
           52840700}}, {{2013, 4, 18}, {
          28.74888850295241, 28.77868009725599, 28.302014588398748`, 28.59, 
           56906600}}, {{2013, 4, 19}, {
          29.411058112193484`, 30.02668458179375, 29.40112865300638, 29.56, 
           99790700}}, {{2013, 4, 22}, {
          30.093610120012976`, 30.967615958482, 30.063814466428806`, 30.62, 
           137904000}}, {{2013, 4, 23}, {
          30.489313725490195`, 30.687941176470588`, 30.17150980392157, 30.39, 
           59126900}}, {{2013, 4, 24}, {
          30.407896725440807`, 31.69889168765743, 30.388035264483626`, 31.54, 
           90946600}}, {{2013, 4, 25}, {
          31.491584220413277`, 32.61380087664371, 31.32275516593613, 31.72, 
           110700200}}, {{2013, 4, 26}, {
          31.679238754325258`, 31.758685121107266`, 31.23235294117647, 31.57, 
           47799300}}, {{2013, 4, 29}, {
          31.575712971481146`, 32.449506286415215`, 31.545924563017483`, 
           32.38, 59116400}}, {{2013, 4, 30}, {
          32.33375226586102, 32.87993051359516, 32.05569788519637, 32.87, 
           75165200}}, {{2013, 5, 1}, {
          32.69852383863081, 32.84746943765282, 32.3708435207824, 32.49, 
           54330900}}, {{2013, 5, 2}, {
          32.40367611580218, 32.939930639324494`, 32.16534077201448, 32.93, 
           46059500}}, {{2013, 5, 3}, {
          33.00178560764407, 33.28979396834876, 32.85281576590026, 33.26, 
           46784600}}, {{2013, 5, 6}, {
          33.18234666666667, 33.66886222222222, 33.013555555555556`, 33.51, 
           40978300}}, {{2013, 5, 7}, {
          33.41765235664965, 33.55668567997598, 33.01048333833683, 33.08, 
           43078300}}, {{2013, 5, 8}, {
          32.83944225522885, 33.00825704759018, 32.422370415277356`, 32.76, 
           51595700}}, {{2013, 5, 9}, {
          32.61866197183099, 32.76760563380282, 32.36049295774649, 32.43, 
           46417800}}, {{2013, 5, 10}, {
          32.44014071581524, 32.48978892627715, 32.09260324258183, 32.46, 
           36394900}}, {{2013, 5, 13}, {
          32.382924613987285`, 32.83972146533454, 32.323342415985465`, 32.8, 
           36027600}}, {{2013, 5, 14}, {
          32.86, 33.53, 32.8, 33.53, 56870100}}, {{2013, 5, 15}, {
          33.45, 33.9, 33.43, 33.85, 46303900}}, {{2013, 5, 16}, {
          33.64, 34.15, 33.55, 34.08, 59382900}}, {{2013, 5, 17}, {
          34.13, 34.87, 34.1, 34.87, 60666700}}, {{2013, 5, 20}, {
          34.73, 35.1, 34.68, 35.08, 54020800}}, {{2013, 5, 21}, {
          35.1, 35.27, 34.72, 34.85, 48702400}}, {{2013, 5, 22}, {
          34.79, 34.84, 34.36, 34.61, 66047500}}, {{2013, 5, 23}, {
          34.23, 34.55, 33.9, 34.15, 51102700}}, {{2013, 5, 24}, {
          33.92, 34.28, 33.9, 34.27, 33174400}}, {{2013, 5, 28}, {
          34.42, 35.18, 34.41, 35.02, 48212100}}, {{2013, 5, 29}, {
          34.74, 35.02, 34.57, 34.88, 38412200}}, {{2013, 5, 30}, {
          34.849999999999994`, 35.24999999999999, 34.809999999999995`, 35.03, 
           51131000}}, {{2013, 5, 31}, {
          34.82, 35.28, 34.79, 34.9, 56165700}}, {{2013, 6, 3}, {
          34.919999999999995`, 35.629999999999995`, 34.82999999999999, 35.59, 
           51252600}}, {{2013, 6, 4}, {
          35.62, 35.74, 34.77, 34.99, 65529500}}, {{2013, 6, 5}, {
          34.6, 34.89, 34.43, 34.78, 46025100}}, {{2013, 6, 6}, {
          34.84, 35.11, 34.49, 34.96, 37618500}}, {{2013, 6, 7}, {
          35.25, 35.78, 35.06, 35.67, 40757300}}, {{2013, 6, 10}, {
          35.51, 35.65, 35.14, 35.47, 35994500}}, {{2013, 6, 11}, {
          35.05, 35.18, 34.68, 34.84, 39435900}}, {{2013, 6, 12}, {
          35.14, 35.27, 34.85, 35., 37372700}}, {{2013, 6, 13}, {
          34.99, 35.02, 34.59, 34.72, 45654900}}, {{2013, 6, 14}, {
          34.55, 34.69, 34.25, 34.4, 53192600}}, {{2013, 6, 17}, {
          34.69, 35.16, 34.63, 35., 49670100}}, {{2013, 6, 18}, {
          34.97, 35.17, 34.9, 34.98, 28616500}}, {{2013, 6, 19}, {
          34.96, 35.09, 34.59, 34.59, 30816200}}, {{2013, 6, 20}, {
          34.26, 34.33, 33.37, 33.49, 54493700}}, {{2013, 6, 21}, {
          33.66, 33.73, 33.05, 33.27, 85338500}}, {{2013, 6, 24}, {
          32.94, 34.2, 32.57, 33.72, 56109000}}, {{2013, 6, 25}, {
          34.08, 34.38, 33.46, 33.67, 44073400}}, {{2013, 6, 26}, {
          34.12, 34.48, 33.89, 34.35, 48665900}}, {{2013, 6, 27}, {
          34.52, 34.78, 34.5, 34.62, 28993100}}, {{2013, 6, 28}, {
          34.38, 34.79, 34.34, 34.54, 65545500}}, {{2013, 7, 1}, {
          34.75, 34.99, 34.33, 34.36, 31055400}}, {{2013, 7, 2}, {
          34.41, 34.44, 33.63, 33.94, 37630000}}, {{2013, 7, 3}, {
          33.66, 34.37, 33.6, 34.01, 15994400}}, {{2013, 7, 5}, {
          34.09, 34.24, 33.58, 34.21, 26085900}}, {{2013, 7, 8}, {
          34.35, 34.59, 33.98, 34.33, 32396900}}, {{2013, 7, 9}, {
          34.58, 34.6, 34.14, 34.35, 25318500}}, {{2013, 7, 10}, {
          34.34, 34.81, 34.32, 34.7, 29658800}}, {{2013, 7, 11}, {
          35., 35.77, 34.9, 35.69, 53638300}}, {{2013, 7, 12}, {
          35.58, 35.73, 35.28, 35.67, 35501200}}, {{2013, 7, 15}, {
          35.66, 36.22, 35.58, 36.17, 34142600}}, {{2013, 7, 16}, {
          36.01, 36.43, 35.96, 36.27, 36378500}}, {{2013, 7, 17}, {
          36.34, 36.39, 35.49, 35.74, 37285100}}, {{2013, 7, 18}, {
          35.72, 35.89, 35.22, 35.44, 49547100}}, {{2013, 7, 19}, {
          32.4, 32.67, 31.02, 31.4, 248428500}}, {{2013, 7, 22}, {
          31.7, 32.01, 31.6, 32.01, 79040700}}, {{2013, 7, 23}, {
          31.91, 32.04, 31.71, 31.82, 65810400}}, {{2013, 7, 24}, {
          32.04, 32.19, 31.89, 31.96, 52803100}}, {{2013, 7, 25}, {
          31.62, 31.65, 31.25, 31.39, 63213000}}}, 
        System`TradingChartDump`$markerstyle$545613 = 1, 
        System`TradingChartDump`$controlmin$545613 = 0.5, 
        System`TradingChartDump`$controlmax$545613 = 250.5, 
        System`TradingChartDump`$datescope$545613 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$545613 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$545613, 
        System`TradingChartDump`$max$545613, 
        System`TradingChartDump`$ohlclabel$545613 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545613, 
              System`TradingChartDump`$opens$545613]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545613, 
              System`TradingChartDump`$highs$545613]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545613, 
              System`TradingChartDump`$lows$545613]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545613, 
              System`TradingChartDump`$closes$545613]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545613, 
              System`TradingChartDump`$visdates$545613]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$545613 = {}, 
        System`TradingChartDump`$subpricegridlines$545613 = Automatic, 
        System`TradingChartDump`$overlaypoint$545613, 
        System`TradingChartDump`$overlayvalue$545613, 
        System`TradingChartDump`$subplotvalue$545613, 
        System`TradingChartDump`$opts$545613 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "MSFT", " with ", "AverageTrueRange",
             "(", 14, ",", Null, ",", Null, ",", Null, ")"}], 
         ImageSize -> {450, 310}, AlignmentPoint -> Center, AspectRatio -> 
         GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> None, AxesOrigin -> 
         Automatic, AxesStyle -> {}, Background -> None, BaselinePosition -> 
         Automatic, BaseStyle -> {}, ColorOutput -> Automatic, 
         ContentSelectable -> Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$545613 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmgtcj+f7xyNbDokp/ORUIcmhckrnO2EhOipppcO3vt/6VsKIsIVpDtGo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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyNmglYjmnUx5ssY5K1sku2bElp0d4tkvZdi9KmRW8LsnwYvJiECUOILGPN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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$545613 = 
        System`TradingChartDump`$staticindicatorpos$545613, 
        System`TradingChartDump`$length$545613 = 250, 
        System`TradingChartDump`$gridlinesflag$545613 = True, 
        System`TradingChartDump`$opens$545613 = 
        Dispatch[{
         1 -> 28.37`4., 2 -> 28.61`4., 3 -> 28.87`4., 4 -> 28.61`4., 5 -> 
          28.71`4., 6 -> 28.35`4., 7 -> 28.66`4., 8 -> 29.11`4., 9 -> 
          29.19`4., 10 -> 29.31`4., 11 -> 29.49`4., 12 -> 29.6`4., 13 -> 
          29.45`4., 14 -> 29.6`4., 15 -> 29.41`4., 16 -> 29.66`4., 17 -> 
          30.2`4., 18 -> 30.11`4., 19 -> 30.05`4., 20 -> 29.88`4., 21 -> 
          29.69`4., 22 -> 29.55`4., 23 -> 30.21`4., 24 -> 29.99`4., 25 -> 
          29.94`4., 26 -> 29.83`4., 27 -> 29.9`4., 28 -> 29.75`4., 29 -> 
          29.52`4., 30 -> 29.79`4., 31 -> 30.32`4., 32 -> 30.12`4., 33 -> 
          29.98`4., 34 -> 30.23`4., 35 -> 30.17`4., 36 -> 30.29`4., 37 -> 
          30.47`4., 38 -> 30.38`4., 39 -> 30.37`4., 40 -> 30.23`4., 41 -> 
          30.7`4., 42 -> 30.28`4., 43 -> 30.24`4., 44 -> 29.58`4., 45 -> 
          29.47`4., 46 -> 29.48`4., 47 -> 29.12`4., 48 -> 28.99`4., 49 -> 
          29.06`4., 50 -> 29.27`4., 51 -> 29.53`4., 52 -> 28.95`4., 53 -> 
          28.99`4., 54 -> 28.48`4., 55 -> 28.54`4., 56 -> 28.3`4., 57 -> 
          28.69`4., 58 -> 28.77`4., 59 -> 28.63`4., 60 -> 28.97`4., 61 -> 
          28.38`4., 62 -> 28.06`4., 63 -> 27.13`4., 64 -> 27.5`4., 65 -> 
          27.53`4., 66 -> 27.22`4., 67 -> 27.89`4., 68 -> 28.18`4., 69 -> 
          28.91`4., 70 -> 28.93`4., 71 -> 29.13`4., 72 -> 28.85`4., 73 -> 
          28.44`4., 74 -> 28.21`4., 75 -> 28.27`4., 76 -> 26.61`4., 77 -> 
          26.82`4., 78 -> 26.48`4., 79 -> 26.27`4., 80 -> 26.4`4., 81 -> 
          26.36`4., 82 -> 26.3`4., 83 -> 26.82`4., 84 -> 27.13`4., 85 -> 
          26.95`4., 86 -> 26.61`4., 87 -> 26.7`4., 88 -> 26.64`4., 89 -> 
          26.37`4., 90 -> 26.1`4., 91 -> 25.98`4., 92 -> 26.41`4., 93 -> 
          26.41`4., 94 -> 26.16`4., 95 -> 26.64`4., 96 -> 27.12`4., 97 -> 
          26.91`4., 98 -> 26.7`4., 99 -> 26.38`4., 100 -> 26.83`4., 101 -> 
          27.27`4., 102 -> 26.94`4., 103 -> 27.04`4., 104 -> 26.79`4., 105 -> 
          26.62`4., 106 -> 26.48`4., 107 -> 26.31`4., 108 -> 26.19`4., 109 -> 
          26.84`4., 110 -> 27.21`4., 111 -> 26.86`4., 112 -> 26.37`4., 113 -> 
          26.35`4., 114 -> 26.32`4., 115 -> 26.25`4., 116 -> 26.09`4., 117 -> 
          26.49`4., 118 -> 26.43`4., 119 -> 26.74`4., 120 -> 26.78`4., 121 -> 
          26.69`4., 122 -> 26.89`4., 123 -> 26.79`4., 124 -> 27.28`4., 125 -> 
          27.16`4., 126 -> 27.59`4., 127 -> 27.4`4., 128 -> 27.59`4., 129 -> 
          27.37`4., 130 -> 27.25`4., 131 -> 27.45`4., 132 -> 27.2`4., 133 -> 
          26.97`4., 134 -> 26.94`4., 135 -> 26.93`4., 136 -> 27.23`4., 137 -> 
          27.46`4., 138 -> 27.51`4., 139 -> 27.5`4., 140 -> 27.62`4., 141 -> 
          27.68`4., 142 -> 27.94`4., 143 -> 27.55`4., 144 -> 27.49`4., 145 -> 
          27.78`4., 146 -> 27.19`4., 147 -> 27.23`4., 148 -> 27.69`4., 149 -> 
          27.53`4., 150 -> 27.65`4., 151 -> 28.09`4., 152 -> 28.01`4., 153 -> 
          27.91`4., 154 -> 28.06`4., 155 -> 27.75`4., 156 -> 27.65`4., 157 -> 
          27.68`4., 158 -> 27.8`4., 159 -> 27.83`4., 160 -> 27.68`4., 161 -> 
          27.92`4., 162 -> 28.14`4., 163 -> 27.91`4., 164 -> 27.99`4., 165 -> 
          28.1`4., 166 -> 28.04`4., 167 -> 27.94`4., 168 -> 28.12`4., 169 -> 
          28.44`4., 170 -> 28.39`4., 171 -> 28.55`4., 172 -> 28.19`4., 173 -> 
          28.02`4., 174 -> 28.53`4., 175 -> 28.53`4., 176 -> 29.36`4., 177 -> 
          28.9`4., 178 -> 28.65`4., 179 -> 28.45`4., 180 -> 28.7`4., 181 -> 
          28.65`4., 182 -> 28.75`4., 183 -> 29.41`4., 184 -> 30.09`4., 185 -> 
          30.49`4., 186 -> 30.41`4., 187 -> 31.49`4., 188 -> 31.68`4., 189 -> 
          31.58`4., 190 -> 32.33`4., 191 -> 32.7`4., 192 -> 32.4`4., 193 -> 
          33.`4., 194 -> 33.18`4., 195 -> 33.42`4., 196 -> 32.84`4., 197 -> 
          32.62`4., 198 -> 32.44`4., 199 -> 32.38`4., 200 -> 32.86`4., 201 -> 
          33.45`4., 202 -> 33.64`4., 203 -> 34.13`4., 204 -> 34.73`4., 205 -> 
          35.1`4., 206 -> 34.79`4., 207 -> 34.23`4., 208 -> 33.92`4., 209 -> 
          34.42`4., 210 -> 34.74`4., 211 -> 34.85`4., 212 -> 34.82`4., 213 -> 
          34.92`4., 214 -> 35.62`4., 215 -> 34.6`4., 216 -> 34.84`4., 217 -> 
          35.25`4., 218 -> 35.51`4., 219 -> 35.05`4., 220 -> 35.14`4., 221 -> 
          34.99`4., 222 -> 34.55`4., 223 -> 34.69`4., 224 -> 34.97`4., 225 -> 
          34.96`4., 226 -> 34.26`4., 227 -> 33.66`4., 228 -> 32.94`4., 229 -> 
          34.08`4., 230 -> 34.12`4., 231 -> 34.52`4., 232 -> 34.38`4., 233 -> 
          34.75`4., 234 -> 34.41`4., 235 -> 33.66`4., 236 -> 34.09`4., 237 -> 
          34.35`4., 238 -> 34.58`4., 239 -> 34.34`4., 240 -> 35.`4., 241 -> 
          35.58`4., 242 -> 35.66`4., 243 -> 36.01`4., 244 -> 36.34`4., 245 -> 
          35.72`4., 246 -> 32.4`4., 247 -> 31.7`4., 248 -> 31.91`4., 249 -> 
          32.04`4., 250 -> 31.62`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$545613 = 
        Dispatch[{
         1 -> 28.63`4., 2 -> 28.97`4., 3 -> 28.93`4., 4 -> 28.83`4., 5 -> 
          28.77`4., 6 -> 28.66`4., 7 -> 29.05`4., 8 -> 29.22`4., 9 -> 
          29.46`4., 10 -> 29.57`4., 11 -> 29.75`4., 12 -> 29.71`4., 13 -> 
          29.56`4., 14 -> 29.68`4., 15 -> 29.58`4., 16 -> 30.23`4., 17 -> 
          30.2`4., 18 -> 30.14`4., 19 -> 30.25`4., 20 -> 30.04`4., 21 -> 
          29.7`4., 22 -> 29.92`4., 23 -> 30.24`4., 24 -> 30.09`4., 25 -> 
          30.04`4., 26 -> 29.9`4., 27 -> 30.25`4., 28 -> 29.95`4., 29 -> 
          29.83`4., 30 -> 30.63`4., 31 -> 30.35`4., 32 -> 30.19`4., 33 -> 
          30.2`4., 34 -> 30.46`4., 35 -> 30.45`4., 36 -> 30.53`4., 37 -> 
          30.54`4., 38 -> 30.49`4., 39 -> 30.47`4., 40 -> 30.75`4., 41 -> 
          30.88`4., 42 -> 30.35`4., 43 -> 30.29`4., 44 -> 29.89`4., 45 -> 
          29.69`4., 46 -> 29.56`4., 47 -> 29.29`4., 48 -> 29.19`4., 49 -> 
          29.3`4., 50 -> 29.33`4., 51 -> 29.55`4., 52 -> 29.23`4., 53 -> 
          29.05`4., 54 -> 28.63`4., 55 -> 28.57`4., 56 -> 28.64`4., 57 -> 
          29.04`4., 58 -> 29.05`4., 59 -> 28.96`4., 60 -> 29.04`4., 61 -> 
          28.41`4., 62 -> 28.16`4., 63 -> 27.55`4., 64 -> 27.54`4., 65 -> 
          27.54`4., 66 -> 27.69`4., 67 -> 28.21`4., 68 -> 28.88`4., 69 -> 
          29.08`4., 70 -> 29.05`4., 71 -> 29.5`4., 72 -> 29.14`4., 73 -> 
          28.69`4., 74 -> 28.51`4., 75 -> 28.34`4., 76 -> 26.89`4., 77 -> 
          26.87`4., 78 -> 26.57`4., 79 -> 26.3`4., 80 -> 26.4`4., 81 -> 
          26.4`4., 82 -> 26.76`4., 83 -> 27.35`4., 84 -> 27.17`4., 85 -> 
          26.97`4., 86 -> 26.98`4., 87 -> 26.94`4., 88 -> 26.72`4., 89 -> 
          26.41`4., 90 -> 26.23`4., 91 -> 26.53`4., 92 -> 26.58`4., 93 -> 
          26.41`4., 94 -> 26.56`4., 95 -> 27.08`4., 96 -> 27.2`4., 97 -> 
          27.1`4., 98 -> 26.72`4., 99 -> 26.81`4., 100 -> 27.21`4., 101 -> 
          27.31`4., 102 -> 27.26`4., 103 -> 27.08`4., 104 -> 26.84`4., 105 -> 
          26.78`4., 106 -> 26.68`4., 107 -> 26.49`4., 108 -> 26.37`4., 109 -> 
          27.31`4., 110 -> 27.23`4., 111 -> 26.93`4., 112 -> 26.48`4., 113 -> 
          26.39`4., 114 -> 26.35`4., 115 -> 26.57`4., 116 -> 26.52`4., 117 -> 
          26.67`4., 118 -> 26.88`4., 119 -> 26.82`4., 120 -> 27.06`4., 121 -> 
          26.88`4., 122 -> 27.04`4., 123 -> 27.22`4., 124 -> 27.64`4., 125 -> 
          27.8`4., 126 -> 27.81`4., 127 -> 27.71`4., 128 -> 27.76`4., 129 -> 
          27.55`4., 130 -> 27.63`4., 131 -> 27.6`4., 132 -> 27.24`4., 133 -> 
          27.13`4., 134 -> 26.98`4., 135 -> 27.29`4., 136 -> 27.5`4., 137 -> 
          27.58`4., 138 -> 27.69`4., 139 -> 27.64`4., 140 -> 27.74`4., 141 -> 
          27.89`4., 142 -> 28.01`4., 143 -> 27.55`4., 144 -> 27.57`4., 145 -> 
          27.86`4., 146 -> 27.41`4., 147 -> 27.81`4., 148 -> 27.78`4., 149 -> 
          27.79`4., 150 -> 27.95`4., 151 -> 28.34`4., 152 -> 28.03`4., 153 -> 
          28.08`4., 154 -> 28.14`4., 155 -> 27.78`4., 156 -> 27.76`4., 157 -> 
          27.83`4., 158 -> 27.96`4., 159 -> 27.96`4., 160 -> 28.08`4., 161 -> 
          28.02`4., 162 -> 28.29`4., 163 -> 28.16`4., 164 -> 28.14`4., 165 -> 
          28.15`4., 166 -> 28.14`4., 167 -> 28.25`4., 168 -> 28.46`4., 169 -> 
          28.46`4., 170 -> 28.65`4., 171 -> 28.75`4., 172 -> 28.41`4., 173 -> 
          28.58`4., 174 -> 28.53`4., 175 -> 29.61`4., 176 -> 30.11`4., 177 -> 
          29.`4., 178 -> 28.82`4., 179 -> 28.78`4., 180 -> 28.94`4., 181 -> 
          28.84`4., 182 -> 28.78`4., 183 -> 30.03`4., 184 -> 30.97`4., 185 -> 
          30.69`4., 186 -> 31.7`4., 187 -> 32.61`4., 188 -> 31.76`4., 189 -> 
          32.45`4., 190 -> 32.88`4., 191 -> 32.85`4., 192 -> 32.94`4., 193 -> 
          33.29`4., 194 -> 33.67`4., 195 -> 33.56`4., 196 -> 33.01`4., 197 -> 
          32.77`4., 198 -> 32.49`4., 199 -> 32.84`4., 200 -> 33.53`4., 201 -> 
          33.9`4., 202 -> 34.15`4., 203 -> 34.87`4., 204 -> 35.1`4., 205 -> 
          35.27`4., 206 -> 34.84`4., 207 -> 34.55`4., 208 -> 34.28`4., 209 -> 
          35.18`4., 210 -> 35.02`4., 211 -> 35.25`4., 212 -> 35.28`4., 213 -> 
          35.63`4., 214 -> 35.74`4., 215 -> 34.89`4., 216 -> 35.11`4., 217 -> 
          35.78`4., 218 -> 35.65`4., 219 -> 35.18`4., 220 -> 35.27`4., 221 -> 
          35.02`4., 222 -> 34.69`4., 223 -> 35.16`4., 224 -> 35.17`4., 225 -> 
          35.09`4., 226 -> 34.33`4., 227 -> 33.73`4., 228 -> 34.2`4., 229 -> 
          34.38`4., 230 -> 34.48`4., 231 -> 34.78`4., 232 -> 34.79`4., 233 -> 
          34.99`4., 234 -> 34.44`4., 235 -> 34.37`4., 236 -> 34.24`4., 237 -> 
          34.59`4., 238 -> 34.6`4., 239 -> 34.81`4., 240 -> 35.77`4., 241 -> 
          35.73`4., 242 -> 36.22`4., 243 -> 36.43`4., 244 -> 36.39`4., 245 -> 
          35.89`4., 246 -> 32.67`4., 247 -> 32.01`4., 248 -> 32.04`4., 249 -> 
          32.19`4., 250 -> 31.65`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {197},
             {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 173}, {}, {
            33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$545613 = 
        Dispatch[{
         1 -> 28.23`4., 2 -> 28.32`4., 3 -> 28.59`4., 4 -> 28.46`4., 5 -> 
          28.35`4., 6 -> 28.12`4., 7 -> 28.61`4., 8 -> 28.92`4., 9 -> 
          28.99`4., 10 -> 29.22`4., 11 -> 29.41`4., 12 -> 29.36`4., 13 -> 
          29.27`4., 14 -> 29.31`4., 15 -> 29.32`4., 16 -> 29.56`4., 17 -> 
          29.88`4., 18 -> 29.87`4., 19 -> 29.9`4., 20 -> 29.76`4., 21 -> 
          29.38`4., 22 -> 29.48`4., 23 -> 29.88`4., 24 -> 29.81`4., 25 -> 
          29.73`4., 26 -> 29.52`4., 27 -> 29.68`4., 28 -> 29.46`4., 29 -> 
          29.51`4., 30 -> 29.75`4., 31 -> 30.02`4., 32 -> 29.8`4., 33 -> 
          29.9`4., 34 -> 30.02`4., 35 -> 29.69`4., 36 -> 30.1`4., 37 -> 
          30.32`4., 38 -> 30.31`4., 39 -> 30.32`4., 40 -> 30.19`4., 41 -> 
          30.37`4., 42 -> 29.93`4., 43 -> 29.66`4., 44 -> 29.34`4., 45 -> 
          29.2`4., 46 -> 29.05`4., 47 -> 28.74`4., 48 -> 28.81`4., 49 -> 
          28.98`4., 50 -> 28.88`4., 51 -> 29.05`4., 52 -> 28.87`4., 53 -> 
          28.5`4., 54 -> 28.28`4., 55 -> 28.2`4., 56 -> 28.13`4., 57 -> 
          28.58`4., 58 -> 28.64`4., 59 -> 28.42`4., 60 -> 28.59`4., 61 -> 
          27.84`4., 62 -> 27.18`4., 63 -> 27.12`4., 64 -> 27.22`4., 65 -> 
          27.21`4., 66 -> 27.2`4., 67 -> 27.84`4., 68 -> 28.16`4., 69 -> 
          28.65`4., 70 -> 28.65`4., 71 -> 28.93`4., 72 -> 28.38`4., 73 -> 
          28.13`4., 74 -> 28.14`4., 75 -> 27.56`4., 76 -> 26.35`4., 77 -> 
          26.39`4., 78 -> 26.23`4., 79 -> 25.94`4., 80 -> 26.07`4., 81 -> 
          26.06`4., 82 -> 26.26`4., 83 -> 26.79`4., 84 -> 26.76`4., 85 -> 
          26.63`4., 86 -> 26.37`4., 87 -> 26.45`4., 88 -> 26.09`4., 89 -> 
          26.`4., 90 -> 25.94`4., 91 -> 25.87`4., 92 -> 26.21`4., 93 -> 
          25.97`4., 94 -> 26.12`4., 95 -> 26.64`4., 96 -> 26.67`4., 97 -> 
          26.54`4., 98 -> 26.29`4., 99 -> 26.28`4., 100 -> 26.73`4., 101 -> 
          26.84`4., 102 -> 26.74`4., 103 -> 26.6`4., 104 -> 26.59`4., 105 -> 
          26.29`4., 106 -> 26.17`4., 107 -> 26.15`4., 108 -> 25.98`4., 109 -> 
          26.74`4., 110 -> 26.75`4., 111 -> 26.33`4., 112 -> 26.24`4., 113 -> 
          26.06`4., 114 -> 26.16`4., 115 -> 25.89`4., 116 -> 25.88`4., 117 -> 
          26.35`4., 118 -> 26.43`4., 119 -> 26.6`4., 120 -> 26.65`4., 121 -> 
          26.63`4., 122 -> 26.59`4., 123 -> 26.79`4., 124 -> 27.05`4., 125 -> 
          26.98`4., 126 -> 27.34`4., 127 -> 27.19`4., 128 -> 27.34`4., 129 -> 
          26.99`4., 130 -> 27.14`4., 131 -> 27.01`4., 132 -> 26.94`4., 133 -> 
          26.84`4., 134 -> 26.69`4., 135 -> 26.89`4., 136 -> 27.09`4., 137 -> 
          27.33`4., 138 -> 27.46`4., 139 -> 27.45`4., 140 -> 27.46`4., 141 -> 
          27.6`4., 142 -> 27.64`4., 143 -> 27.04`4., 144 -> 27.29`4., 145 -> 
          27.18`4., 146 -> 27.15`4., 147 -> 27.14`4., 148 -> 27.55`4., 149 -> 
          27.33`4., 150 -> 27.5`4., 151 -> 27.96`4., 152 -> 27.58`4., 153 -> 
          27.81`4., 154 -> 27.77`4., 155 -> 27.48`4., 156 -> 27.45`4., 157 -> 
          27.56`4., 158 -> 27.73`4., 159 -> 27.78`4., 160 -> 27.61`4., 161 -> 
          27.83`4., 162 -> 27.98`4., 163 -> 27.85`4., 164 -> 27.9`4., 165 -> 
          27.76`4., 166 -> 27.91`4., 167 -> 27.88`4., 168 -> 28.06`4., 169 -> 
          28.16`4., 170 -> 28.32`4., 171 -> 28.34`4., 172 -> 28.07`4., 173 -> 
          27.91`4., 174 -> 28.27`4., 175 -> 28.48`4., 176 -> 29.32`4., 177 -> 
          28.53`4., 178 -> 28.46`4., 179 -> 28.31`4., 180 -> 28.5`4., 181 -> 
          28.4`4., 182 -> 28.3`4., 183 -> 29.4`4., 184 -> 30.06`4., 185 -> 
          30.17`4., 186 -> 30.39`4., 187 -> 31.32`4., 188 -> 31.23`4., 189 -> 
          31.55`4., 190 -> 32.06`4., 191 -> 32.37`4., 192 -> 32.17`4., 193 -> 
          32.85`4., 194 -> 33.01`4., 195 -> 33.01`4., 196 -> 32.42`4., 197 -> 
          32.36`4., 198 -> 32.09`4., 199 -> 32.32`4., 200 -> 32.8`4., 201 -> 
          33.43`4., 202 -> 33.55`4., 203 -> 34.1`4., 204 -> 34.68`4., 205 -> 
          34.72`4., 206 -> 34.36`4., 207 -> 33.9`4., 208 -> 33.9`4., 209 -> 
          34.41`4., 210 -> 34.57`4., 211 -> 34.81`4., 212 -> 34.79`4., 213 -> 
          34.83`4., 214 -> 34.77`4., 215 -> 34.43`4., 216 -> 34.49`4., 217 -> 
          35.06`4., 218 -> 35.14`4., 219 -> 34.68`4., 220 -> 34.85`4., 221 -> 
          34.59`4., 222 -> 34.25`4., 223 -> 34.63`4., 224 -> 34.9`4., 225 -> 
          34.59`4., 226 -> 33.37`4., 227 -> 33.05`4., 228 -> 32.57`4., 229 -> 
          33.46`4., 230 -> 33.89`4., 231 -> 34.5`4., 232 -> 34.34`4., 233 -> 
          34.33`4., 234 -> 33.63`4., 235 -> 33.6`4., 236 -> 33.58`4., 237 -> 
          33.98`4., 238 -> 34.14`4., 239 -> 34.32`4., 240 -> 34.9`4., 241 -> 
          35.28`4., 242 -> 35.58`4., 243 -> 35.96`4., 244 -> 35.49`4., 245 -> 
          35.22`4., 246 -> 31.02`4., 247 -> 31.6`4., 248 -> 31.71`4., 249 -> 
          31.89`4., 250 -> 31.25`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$545613 = 
        Dispatch[{
         1 -> 28.3`4., 2 -> 28.88`4., 3 -> 28.76`4., 4 -> 28.6`4., 5 -> 
          28.54`4., 6 -> 28.33`4., 7 -> 28.87`4., 8 -> 29.06`4., 9 -> 
          29.37`4., 10 -> 29.43`4., 11 -> 29.6`4., 12 -> 29.52`4., 13 -> 
          29.49`4., 14 -> 29.43`4., 15 -> 29.5`4., 16 -> 30.07`4., 17 -> 
          30.18`4., 18 -> 30.03`4., 19 -> 30.09`4., 20 -> 29.83`4., 21 -> 
          29.56`4., 22 -> 29.85`4., 23 -> 29.98`4., 24 -> 29.92`4., 25 -> 
          29.94`4., 26 -> 29.62`4., 27 -> 30.11`4., 28 -> 29.69`4., 29 -> 
          29.69`4., 30 -> 30.62`4., 31 -> 30.23`4., 32 -> 30.01`4., 33 -> 
          30.08`4., 34 -> 30.07`4., 35 -> 30.22`4., 36 -> 30.49`4., 37 -> 
          30.49`4., 38 -> 30.46`4., 39 -> 30.33`4., 40 -> 30.72`4., 41 -> 
          30.47`4., 42 -> 30.07`4., 43 -> 29.69`4., 44 -> 29.47`4., 45 -> 
          29.46`4., 46 -> 29.07`4., 47 -> 28.81`4., 48 -> 28.97`4., 49 -> 
          29.17`4., 50 -> 29.33`4., 51 -> 29.16`4., 52 -> 29.09`4., 53 -> 
          28.6`4., 54 -> 28.31`4., 55 -> 28.28`4., 56 -> 28.52`4., 57 -> 
          28.83`4., 58 -> 28.81`4., 59 -> 28.91`4., 60 -> 28.82`4., 61 -> 
          27.98`4., 62 -> 27.35`4., 63 -> 27.4`4., 64 -> 27.25`4., 65 -> 
          27.23`4., 66 -> 27.56`4., 67 -> 27.88`4., 68 -> 28.84`4., 69 -> 
          28.82`4., 70 -> 28.94`4., 71 -> 29.17`4., 72 -> 28.41`4., 73 -> 
          28.14`4., 74 -> 28.16`4., 75 -> 27.57`4., 76 -> 26.68`4., 77 -> 
          26.43`4., 78 -> 26.26`4., 79 -> 26.12`4., 80 -> 26.33`4., 81 -> 
          26.31`4., 82 -> 26.54`4., 83 -> 27.28`4., 84 -> 26.98`4., 85 -> 
          26.67`4., 86 -> 26.95`4., 87 -> 26.54`4., 88 -> 26.22`4., 89 -> 
          26.03`4., 90 -> 25.97`4., 91 -> 26.27`4., 92 -> 26.33`4., 93 -> 
          26.06`4., 94 -> 26.53`4., 95 -> 26.91`4., 96 -> 26.83`4., 97 -> 
          26.7`4., 98 -> 26.4`4., 99 -> 26.69`4., 100 -> 27.14`4., 101 -> 
          26.9`4., 102 -> 27.26`4., 103 -> 27.04`4., 104 -> 26.65`4., 105 -> 
          26.45`4., 106 -> 26.55`4., 107 -> 26.15`4., 108 -> 26.31`4., 109 -> 
          27.2`4., 110 -> 26.84`4., 111 -> 26.34`4., 112 -> 26.29`4., 113 -> 
          26.15`4., 114 -> 26.3`4., 115 -> 26.06`4., 116 -> 26.42`4., 117 -> 
          26.48`4., 118 -> 26.8`4., 119 -> 26.63`4., 120 -> 26.84`4., 121 -> 
          26.84`4., 122 -> 26.74`4., 123 -> 27.19`4., 124 -> 27.21`4., 125 -> 
          27.46`4., 126 -> 27.49`4., 127 -> 27.59`4., 128 -> 27.43`4., 129 -> 
          27.04`4., 130 -> 27.51`4., 131 -> 27.03`4., 132 -> 27.08`4., 133 -> 
          26.93`4., 134 -> 26.87`4., 135 -> 27.13`4., 136 -> 27.44`4., 137 -> 
          27.46`4., 138 -> 27.61`4., 139 -> 27.62`4., 140 -> 27.59`4., 141 -> 
          27.85`4., 142 -> 27.68`4., 143 -> 27.3`4., 144 -> 27.57`4., 145 -> 
          27.18`4., 146 -> 27.18`4., 147 -> 27.62`4., 148 -> 27.61`4., 149 -> 
          27.76`4., 150 -> 27.95`4., 151 -> 28.15`4., 152 -> 27.89`4., 153 -> 
          27.94`4., 154 -> 27.81`4., 155 -> 27.68`4., 156 -> 27.72`4., 157 -> 
          27.73`4., 158 -> 27.94`4., 159 -> 27.84`4., 160 -> 27.9`4., 161 -> 
          27.98`4., 162 -> 28.12`4., 163 -> 27.91`4., 164 -> 28.05`4., 165 -> 
          27.96`4., 166 -> 27.96`4., 167 -> 28.17`4., 168 -> 28.41`4., 169 -> 
          28.41`4., 170 -> 28.6`4., 171 -> 28.36`4., 172 -> 28.4`4., 173 -> 
          28.5`4., 174 -> 28.39`4., 175 -> 29.4`4., 176 -> 30.07`4., 177 -> 
          28.74`4., 178 -> 28.59`4., 179 -> 28.49`4., 180 -> 28.77`4., 181 -> 
          28.63`4., 182 -> 28.59`4., 183 -> 29.56`4., 184 -> 30.62`4., 185 -> 
          30.39`4., 186 -> 31.54`4., 187 -> 31.72`4., 188 -> 31.57`4., 189 -> 
          32.38`4., 190 -> 32.87`4., 191 -> 32.49`4., 192 -> 32.93`4., 193 -> 
          33.26`4., 194 -> 33.51`4., 195 -> 33.08`4., 196 -> 32.76`4., 197 -> 
          32.43`4., 198 -> 32.46`4., 199 -> 32.8`4., 200 -> 33.53`4., 201 -> 
          33.85`4., 202 -> 34.08`4., 203 -> 34.87`4., 204 -> 35.08`4., 205 -> 
          34.85`4., 206 -> 34.61`4., 207 -> 34.15`4., 208 -> 34.27`4., 209 -> 
          35.02`4., 210 -> 34.88`4., 211 -> 35.03`4., 212 -> 34.9`4., 213 -> 
          35.59`4., 214 -> 34.99`4., 215 -> 34.78`4., 216 -> 34.96`4., 217 -> 
          35.67`4., 218 -> 35.47`4., 219 -> 34.84`4., 220 -> 35.`4., 221 -> 
          34.72`4., 222 -> 34.4`4., 223 -> 35.`4., 224 -> 34.98`4., 225 -> 
          34.59`4., 226 -> 33.49`4., 227 -> 33.27`4., 228 -> 33.72`4., 229 -> 
          33.67`4., 230 -> 34.35`4., 231 -> 34.62`4., 232 -> 34.54`4., 233 -> 
          34.36`4., 234 -> 33.94`4., 235 -> 34.01`4., 236 -> 34.21`4., 237 -> 
          34.33`4., 238 -> 34.35`4., 239 -> 34.7`4., 240 -> 35.69`4., 241 -> 
          35.67`4., 242 -> 36.17`4., 243 -> 36.27`4., 244 -> 35.74`4., 245 -> 
          35.44`4., 246 -> 31.4`4., 247 -> 32.01`4., 248 -> 31.82`4., 249 -> 
          31.96`4., 250 -> 31.39`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$545613 = True, 
        System`TradingChartDump`$gridlines$545613 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$545613, 
        System`TradingChartDump`$plotrangemin$545613 = 25.337956692913384`, 
        System`TradingChartDump`$plotrangemax$545613 = 37.48638507686539, 
        System`TradingChartDump`$layoutData$545613, 
        System`TradingChartDump`$gridlinesscope$545613 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$545613 = {True, True}, 
        System`TradingChartDump`$indicators$545613 = {
         FinancialIndicator["AverageTrueRange", 14]}, 
        System`TradingChartDump`$mouseQ$545613 = False, 
        System`TradingChartDump`$modelData$545613 = 
        System`TradingChartDump`modelData$542678, 
        System`TradingChartDump`$sy$545613 = Identity, 
        System`TradingChartDump`$isy$545613 = Identity, 
        System`TradingChartDump`$appearance$545613 = Automatic, 
        System`TradingChartDump`$perfgoal$545613 = "Quality", 
        System`TradingChartDump`$axesorigin$545613 = Automatic, 
        System`TradingChartDump`$framestyle$545613 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$545613 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$545613 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$545613 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$545613 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$545613, 
        System`TradingChartDump`$newgridlines$545613 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{25.337956692913384`, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$545613 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$545613 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$545613 = "GraphicsFrame", 
        System`TradingChartDump`$frame$545613 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$545613 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$545613 = 
              Switch[System`TradingChartDump`$highlightposition$545613, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$545613], {
                 1, System`TradingChartDump`$length$545613}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$545613], {
                 1, System`TradingChartDump`$length$545613}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$545613, 
                   Charting`nearestDate[System`TradingChartDump`$dates$545613, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$545613]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$545613]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$545613, 
                    Floor[System`TradingChartDump`$controlmin$545613] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$545613, 
                    Floor[System`TradingChartDump`$controlmax$545613]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$545613 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$545613 = 
            If[System`TradingChartDump`$fastpos$545613 =!= True, 
              System`TradingChartDump`$fastpos$545613 = 
               Clip[System`TradingChartDump`$fastpos$545613, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$545613 = (
                  Floor[System`TradingChartDump`$controlmax$545613] - Floor[
                  System`TradingChartDump`$controlmin$545613]) (
                  System`TradingChartDump`$fastpos$545613/100) + 
                Floor[System`TradingChartDump`$controlmin$545613]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$545613], {
                Floor[System`TradingChartDump`$controlmin$545613] + 1, 
                 Floor[System`TradingChartDump`$controlmax$545613]}], 
              System`TradingChartDump`$staticindicatorpos$545613]; 
           System`TradingChartDump`$mouseQ$545613 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$545613]], 
              System`TradingChartDump`$highlightposition$545613 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$545613 = If[
              And[
              System`TradingChartDump`$bouncingballQ$545613, 
               System`TradingChartDump`$mouseQ$545613, 
               System`TradingChartDump`$appearance$545613 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$545613[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$545613]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$545613[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$545613, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$545613[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$545613]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$545613[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$545613[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545613, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545613[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545613, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545613, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545613[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545613[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$545613 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$545613, 
                 System`TradingChartDump`$defaultframeticksstyle$545613, 
                 System`TradingChartDump`$defaultlabelstyle$545613, 
                 System`TradingChartDump`$framestyle$545613, 
                 System`TradingChartDump`$frameticksstyle$545613, 
                 System`TradingChartDump`$labelstyle$545613}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545613 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$545613, 
                 System`TradingChartDump`$labelstyle$545613, 
                 System`TradingChartDump`$defaultframeticksstyle$545613, 
                 System`TradingChartDump`$defaultlabelstyle$545613}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545613 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545613, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$545613 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545613, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$545613 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545613, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$545613 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$545613 = 
             Part[System`TradingChartDump`$tickstextstyle$545613, 1], 
             System`TradingChartDump`$tickstextstyle$545613 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545613[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545613, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545613[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545613[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545613[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$545613[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545613, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$545613]], 
                    Style[":", System`TradingChartDump`$textstyle$545613]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$545613[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545613]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545613[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$545613[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$545613, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$545613]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$545613[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545613, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545613[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545613, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545613, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$545613[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545613[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545613[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$545613[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$545613[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$545613], 1], 
                   Floor[System`TradingChartDump`$controlmax$545613]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$545613[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$545613[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$545613[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$545613[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$545613[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545613[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$545613[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$545613[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$545613[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545613[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$545613[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$545613[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$545613[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$545613[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$545613[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$545613, 
                  System`TradingChartDump`$mouseQ$545613], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$545613 - 0.5, 
                   System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$545613 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$545613 + 0.5, 
                    System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545613, 1]}, {
                    System`TradingChartDump`$indicatorpos$545613 + 0.5, 
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$545613[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$545613, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$545613[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545613]]], {}]; 
              System`TradingChartDump`$subplotgridlines$545613[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$545613[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$545613[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545613[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$545613 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$545613, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545613, 
                   System`TradingChartDump`$opens$545613]], 12, 
                 System`TradingChartDump`$textstyle$545613, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$545613, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545613, 
                   System`TradingChartDump`$highs$545613]], 12, 
                 System`TradingChartDump`$textstyle$545613, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$545613, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545613, 
                   System`TradingChartDump`$lows$545613]], 12, 
                 System`TradingChartDump`$textstyle$545613, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$545613, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545613, 
                   System`TradingChartDump`$closes$545613]], 12, 
                 System`TradingChartDump`$textstyle$545613, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545613, 
                   System`TradingChartDump`$visdates$545613]], 12, 
                 System`TradingChartDump`$textstyle$545613, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$545613, 
                  System`TradingChartDump`$mouseQ$545613], {{
                  System`TradingChartDump`$timestampstyle$545613, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$545613 - 0.5, 
                    System`TradingChartDump`$plotrangemin$545613}, 
                    If[
                    System`TradingChartDump`$timestampdepth$545613 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$545613[1]}, {
                    System`TradingChartDump`$indicatorpos$545613 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545613}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545613, 1]}, {
                    System`TradingChartDump`$indicatorpos$545613 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545613}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$545613, {
               System`TradingChartDump`$highlightstyle$545613, 
                Dynamic[System`TradingChartDump`$ohlcpoint$545613]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$545613[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545613, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$545613[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$545613[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$545613, Length[
                    System`TradingChartDump`$layoutData$545613[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$545613}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$545613] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$545613] + 0.5}, {
                System`TradingChartDump`$plotrangemin$545613, 
                 System`TradingChartDump`$plotrangemax$545613}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$545613, Left, {
                 False, System`TradingChartDump`$frame$545613}, 
                 Blank[], {System`TradingChartDump`$frame$545613, False}], {
                False, System`TradingChartDump`$frame$545613}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$545613, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$545613]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$545613 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           387.0228610767757}, {-286.92264150943396`, -65.76792452830186}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545613 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545613, 1]], 
               Part[System`TradingChartDump`$framestyle$545613, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$545613]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$545613} -> 
                   System`TradingChartDump`$isy$545613[
                    System`TradingChartDump`$plotrangemin$545613], {
                    0, System`TradingChartDump`$plotrangemax$545613} -> 
                   System`TradingChartDump`$isy$545613[
                    System`TradingChartDump`$plotrangemax$545613]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$545613[
                   System`TradingChartDump`$plotrangemin$545613], 
                   System`TradingChartDump`$isy$545613[
                   System`TradingChartDump`$plotrangemax$545613]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$545613, 
                   System`TradingChartDump`$isy$545613}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545613, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545613 > 
                    System`TradingChartDump`$plotrangemin$545613, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545613 > 
                    System`TradingChartDump`$plotrangemin$545613, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545613, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545613 > 
                    System`TradingChartDump`$plotrangemin$545613, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545613 > 
                    System`TradingChartDump`$plotrangemin$545613, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545613, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545613, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545613 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545613,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545613], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545613 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545613, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545613]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$545613, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$545613[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$545613[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545613, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$545613[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$545613, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545613[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545613, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545613[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545613[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545613[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545613[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545613], 
                    Style[":", System`TradingChartDump`$textstyle$545613]], 
                    Style[":", System`TradingChartDump`$textstyle$545613]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$545613[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545613]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545613[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$545613}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$545613, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$545613 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$545613[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$545613, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$545613, Left, {
                    False, System`TradingChartDump`$frame$545613}, 
                    Blank[], {
                    System`TradingChartDump`$frame$545613, False}], {
                   System`TradingChartDump`$frame$545613, 
                    System`TradingChartDump`$frame$545613}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$545613, 
                    System`TradingChartDump`$controlmax$545613}] + 0.5, {
                   System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$545613]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$545613) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$545613 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$545613 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$545613, 1]], 
                   Part[System`TradingChartDump`$framestyle$545613, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$545613]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545613[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545613[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$545613[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545613, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545613, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$545613, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$545613, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$545613 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
545613, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$545613], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$545613 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$545613, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$545613]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$545613, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$545613) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$545613 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$545613[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           475.9407855006933}, {-55.989622641509435`, -0.7009433962264069}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$545613, 
              Dynamic[System`TradingChartDump`$ohlclabel$545613], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$545613}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545613 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545613, 2]], 
               Part[System`TradingChartDump`$framestyle$545613, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$545613]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$545613, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$545613, 
                    System`TradingChartDump`$controlmax$545613}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$545613] + 
                    0.5, System`TradingChartDump`$plotrangemin$545613}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$545613], 
                    System`TradingChartDump`$plotrangemin$545613}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$545613, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545613, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545613, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545613 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545613, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545613], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545613 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545613,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545613]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$545613] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$545613[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$545613] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$545613[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$545613] = {HoldPattern[
               System`TradingChartDump`$min$545613[1]] :> 0.34}}, {
          DownValues[System`TradingChartDump`$max$545613] = {HoldPattern[
               System`TradingChartDump`$max$545613[1]] :> 
             0.9400000000000001}}, {
          DownValues[System`TradingChartDump`$subplotvalue$545613] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$545613[1, 1]] :> 
             Invisible[0.8300000000000001]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$545613] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$545613[1]] :> {
               Rational[1, 2], 1}}}, {
          DownValues[System`TradingChartDump`$layoutData$545613] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$545613["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "AllValues"]] :> CompressedData["
1:eJxVVgk8VVv7Fo1Cg6GuSlKZKhS5nb323uc5XE1mGZtHXEMpypdyQyFSEn2K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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545613["AppendedAdjust"]] :> 
             0.06031016708891171, HoldPattern[
               System`TradingChartDump`$layoutData$545613["AppendedBox"]] :> {
              0.28688870302833575`, 1.222803129728601}, HoldPattern[
               System`TradingChartDump`$layoutData$545613["AppendedMin"]] :> 
             0.3073610376653509, HoldPattern[
               System`TradingChartDump`$layoutData$545613["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$545613["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$545613["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$545613["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545613["DataMax"]] :> 
             36.43, HoldPattern[
               System`TradingChartDump`$layoutData$545613["DataMin"]] :> 
             25.86614923134608, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "MainChartAllValues"]] :> CompressedData["
1:eJxdlglYzdv6x1OZ0mBocEISmtBAOvZv2t9dJ1NzGs1jdRqIoiuiolJSGtwo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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "MainChartPoints"]] :> CompressedData["
1:eJxdlltoXFUUhqdFUIKgYkSRUqdVSqylVGNtmzbJTmqaNEmTTO6XSXLmfp9U
pCiRyqFShCIEn0QRGS/4IhTBlyAqscUnKyIoVRCZIoiQIgWplD6Zk/V/D+cc
CMOftf/9r9tee+9Jr4zn7onFYne3/nbob2eM71b3D9e2vuETTv9wN1ZbL/ff
AN/nrt5uS65dAT/o3ns3+MCtruX6x2c7L4EfcwF7dRK8yz1xcTOx/gc47tau
bG34QKfwXrMvgZ9yAb21Dt4nPXCbC5bvvgje7zoDB86DD0T4B+3XBx9y41vs
zYe6hJ+19QfBz7mBIAH3gttdEF7Lo+DnLb6f2e+wxbMGfsH8/Q18xL0WEO6C
j7qbgfub4GPupSCAW+AOy8cH4OMuGQjsQv+Erf8ce2cEd4nP+m7T7wA7q+dO
Yd9ZPK3Ye8L58XtcABNHsfcq39gjOHbS/Re0yznsJ9UP2F+0/daxC7+KvS+i
3xeJ75TWC/unpIe9X3zs/VafH+m/AePfEfYHrB7PwD8tf+Gfdk9vFwD7oPoB
+2DkPAyZ3ij7D1k/9WMfVv9iH1Y/YT8T9tc/Y/p/Yx+x+H7CPqL+Oi77qPkz
J+yPuvz2h33Mfp2wG1N/sH5M/Sy8MaZ5AD9h8V+XvktE/Emon4U3EpH8jls8
Rfjj7pNguyfhy94Gf9z2fxv9CTuvlzvEF64L+xPW373CGxN2HnYLxyZVX/iT
qhf8Sc0z+JOqH/pTyjf8KYvvM/hTrj34/oU/Fd4vNq3zBH9a8wa+7HeOiT9t
/dIHfybi/4zmKfwZ2+9N9GfUP/Bn1W/wZ83fL+DPql/gz+r8wZ9TveifOVv/
F/w55Z/+mbP4W8jfvK3/FP15038Z/rzbvo/eQl/r96G/EK6XWzB+O/27oP6E
LzwDP2n+DMJPhvf3k6Y/DD8Zzm9s0epdgb9o/bAKf9H41+Av2vn5EP5S2D8X
wf6SzdOv4S9Z/g+Rv2Wbd4fJv/A54l/WPCb/y7b/O/A9nRfhuBeuj/OsfheE
PU/9yf6e7gvhhvb7B3893ffCTc/i34N+yuI5i34q7L9L2X33Pvop3Wfop8Lx
NFK6b4k3pfkg3Eypnuinw/Mkntb9j34Ee+mIfjrsXyOt9xH6aZ1/9NPqL+Z3
xs7Pn+hnNC/Rz2j+o58Jx+NndH+in7H++xL9yH7NjPqL+LM6r+hnw/eHy2pe
yl8vq/mBftbyeb/sjazV7zb6EdzMav4Tfy48/+MR7HLh+9TLWb6T3A85zSf0
c/o/90XO8psRbrKe+ycffl/E8zpv6OfVX+jLfh79vM3j79DP63yjH+E385H3
YSH8PosX5K+wK+i+6JZ+QfUW9gvqX+FGQfPBSb9geivCTel1CceK5t8rwvGi
/Bd2wt8Ke0X5I+zLnhJuaL8j6Bf1nkC/qPyjX7J4r6Jfsn66iX5J86hH+iXF
I+zLfkm4IX5VeKNk52VEuFmy8/iwcKxs53WvcFz4grAraz6hXzZ/30C/rPsK
/bL19/foly3fr6Mvfgb9iu4L9Ct2Xn5Bv2L9/hX6Fd036Ff0i77WJ9Gv6D5E
P7I+VlU/o1+1/YfQr5r/31D/quXnI+pfNb3fqX9V/lP/qtXjAPpV3dfo1/Se
Qb+meYt+Te8f9GvWbzuIv2b5e5z4a9YP+4m/FtGv6T2Mft32/xX9eiT/wo/0
Sr+ufhH267rf0Nd+6+jX1e86n826/Kf/V/Relj2+onkp7FbUL93ufxyzRGk=

              "], HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545613["NewSubplot"]] :> {
               FinancialIndicator["AverageTrueRange", 14]}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545613["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545613["PlotRangeMin"]] :> 
             0.3073610376653509, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$545613["Space"]] :> 
             3.6430000000000002`, HoldPattern[
               System`TradingChartDump`$layoutData$545613["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {{}}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJw1lwlUlFUbx0dQVEhwQQWBGCQ1MQhUBFHhD4gOq+ybLO8szMLMABoqGOAY
Iqbklrkg0QR6/DC3UDLMZMwgMUMtFVDAAYSUADFcUEi/vvPdh3PmcH7nuf/7
f557n3vf97UTpYenGPB4vFf//v73n/0BypNVd+O7vP6P47Byj0tCjfYh44kI
rBudHPO2k7E5HDInBRfsILZA3K4DL2dLiK1hv0yen15BzMfFX5X8XhPimZgR
lT/spetg/B6yjNYX1bkSz4a0Lie56HQ74/chnIBWL09iB2zOFvsGnNQz/gCb
fr6XXRhF7IQMfprjX3kPGDsjO3vAJk9AcRf88e62vae+o/h8TBttL13W3MZ4
Acy7m+esciVeCNPewz7un7UydkX0RrFX8UbiRci49ejpoJDYDd/GnN+VPZXY
HfUr18f+6N3CeDF+d3vyvfqr+4w9YH+wx2TWLuIlOJDQb/tdJo1fCsH4vd6B
qTTfMhT/UcsTXKK4J+qE3Yk5I5SvF4xVp85f+ZTqAxTuXvYlHow1QGvHScnO
aBrvDSu/qg0CJ8YabxhMERWMbCa9D7qdjGc+dCe9DzrnpHJ5rygfX7g932Q9
Us7y0fjibGFVxiVfqmc5fg3fMqe2hbFmOW605BfUu1D+fvg7VNgnKyO9H0am
Pw77dC3NvwIBzR2Ri5sYa1bA6WuL8px/KL4SgV0/Vm2bR/mvRKxK02+5heoT
4PCGBrGnBcUF2Ocfu6M0g/T+4J3O00yW0Pz+0Nx+ZX5mD8UD0FU9yWjIiuIB
KPyzXZt+nuKBqHPr9SpZQPFA9HiFjjK9SfUFwdl4q9neKRQPwp72/JraeNIH
o/qmIN15JsWDsfuL5uMRn1A8BNdaLyunaSgegoau6b9fvk/7swrLp5bZzzVi
50OzCmt8PlyUcI36PRR71z2/3R/BGKEILL8qjm+k/QxF0/F3bequM9aFIvQn
34nLvEkfhqEJMkkJx+ZHGA6ZWe8Wvkt+YXh9/OjLEzfYeF0YgiutH27tI304
jq92MmguIH04Whynf7RwB+nDkWPpM7rVnrEuHKq7y2/UnaXzHoGF+o4315ay
+wMRWBq043zCS3ZfaCKwcU7T1/kcY10ETp5oLR18QPpIeF9IdQ2JIf9ITCkt
X+vUxvLTROJgvbdXSz3lH4m4mm/GuWWQPgrWe9q/OJNM+igUxco+XtNP+iic
G9+9yIXWQxeFFE+zjr/HkT4aO11qTMN8SB+N+QcKk68MkT4ab6IuRW1XkH80
XocUFh+sofWLQdaVDx2LRbR/MbAy1K4K9yB9DHR3z23odCV9DMoSei7+Fkz6
WPxsGZDSFU/6WKRPK7oUlkX6WMTduXmjx4f0sZjq8tzzSijp42AXVPz55GjS
x8F4k2fAKJA+Dnt3X3xfQPerLg5JxeoxFWWkj0f+KN0xZJM+Hg0261z4KtLH
Y1HWq+SNStLHY1hZI/OfS/rVeNwZMFB2k/UnVkNuL/YonkD9sxotK8SjnQZI
vxpXfR52vzOD1j8BqkNmmytofiTAVhMQ6jhM/Z+ALwuHZu06zO4HXQKCX7WU
OBTS+UrElopb5fctSZ+IsNWcRUUM6RNh/rTS8MoHdH4SUZtc6rJ8gM5vEsKd
T7x20DFGEkrtngkidHTfJYGr6P7Yt5qxLgmWtkt/XdJK90cyDvg9v9VH5x/J
kEfWLz3uSP7JmOIh1gZPIv9kDH9k5zV3KeXPwVS04G35AKuPz+E3o6ftrwNp
PTnkP6nOmKBjzHE4N/aQ9b7ptD8cnILKS5JoPi0HA/cKYd4qWi8OmUdH/bD1
I5afnkNv9YZ1x7ypfiHur40drjdlzBdiQL5AXGLF6oMQFwrU16Wz2POBE+Lt
aYsZxhPvMX8h1MMOUUvWNzN/Ic5OUoakGDLWCVHX7iib+KiJ+Qsh3D/38icm
TM8TwUUfnluZycbzRahMzpqZW83iEGEo7gurV29YnBMh8liAS7wTPa9E0F24
53FMwMZrRag1TjOsymOsE6FR1p9uc5SxXoRt1qlLLm4hfzFOVF92DnFn8/HF
gOukkSAN+YtRPzU2q86fMSfG+oOtQyces3w0YjwWXracm0X1i/FkbPqIj57V
qxMjyNmkRDSb6hcje0Aje7KskflLcOl58Dyz84z5Ehier3Fz7rjL/CVIMvoG
dhWMOQlqZXXbhtYy1khQUdvLxT+5w/wlMGnV2artWVwnQYRBqVvrIRbXS/DW
vLDqj4uMeSnY3yyVOvHYeH4KflpZsj//GosjBWVjXx7Z9QNjLgWTCy+8LDUm
/xQUDfi/OGPAWJuCeS/C3Bo3snp0Kdjk42J4ZJjF9SnYdmXBA9FjWn8pZpwu
uT3mK9ZvfCl8Z/8dOqOBzrMUzq3mGW/pfuCksH85uv8G3X8aKQbt3ttv4chY
K8V787c8fT2a7hspXIOMugf62PnQS9F9v6eyyoreZ2UYtDy+0XMce5/my/BD
1+UC/lV6nsmgsdXbr0lk79+cDJ9WhlctutbN/GV48Mzk7PpExloZnt6WDC6+
w1gnQ0WhZtyoaX8yfxlihfPDBj5ncZ4c93kBPZEXGfPlqDZZcdvfmjHkWOd4
Y0baWMacHN8ZNEW5n2P5aOQwLV24fc5/GGvluDov83qCMWPdv/pnrYnj1rL6
9HI8Nb01O9KBvh8UGA7p+OWShOpXgH/O3OaeAWMoEGfEvTPmGVsPToGdHs+K
VFEsrlHgZ49bi5IaWVyrgHzoQqboFGOdAkdnHgp1T2GsV2BxM+dvWEbfG6nI
OFRTk2jJmJ+Kb8dETTl8k9Y/FePltqEH1OSfivWCMvvr9L2iSUVlfOAYrwa2
n9pU9FwfG5cTQP6p6E1OE0TYUf2p6Etq5z8eIn8lmjpzf8l9Qf5K7Jf+Nuyn
oPqViJyXs8qB1otTQjdl5PuzhVS/EhsEm4b/NGGsVcLvjM3A4EHyV6JLkfHT
l35UvxIT9/Vk9n5N/ioM9Qb29TSx/PkqmCTkzrp3hDFUOGvFe9ZgSf4qKDPb
7s5yJ38VbBuazizUUP+pkPiIZ2bxlvpPhfBA/u7PFlL/qVCu3XnnbiH1nxol
XZFLHAZZv/DVCMqftvWfTsZQI7uv6ZdvHKn/1JBZ6dtOxVP/qyHJK/CxWU7+
avw1eG1z9yTyV6PIymyDZgebT6/G7jsmXd58+p5NQ3eumDOdSP2fhvLGE9MH
8sk/DY2TX4SNWkPnLw17TOdEDg5T/WloG58T0Lad+j8NI48GT7/ZRv2fhvfd
Oz/ebtnP/NOwXZE7eWpsH/NPR1e6cHYxr5f5p6OjoKPNrLmH+adjy5sj+/d9
1uP1X4lg3ZU=
                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "SubplotIndicatorGridLines"]] :> {{
                Rational[1, 2], 
                Rational[3, 4], 1}}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "ATR"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["AverageTrueRange", 14]}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "SubplotIndicatorParameters"]] :> {{{14}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "SubplotIndicatorPoints"]] :> {{{}, {{2., 0.67}}, {{3., 
                0.64}}, {{4., 0.62}}, {{5., 0.61}}, {{6., 0.61}}, {{7., 
                0.61}}, {{8., 0.6}}, {{9., 0.59}}, {{10., 
                0.5700000000000001}}, {{11., 0.55}}, {{12., 0.54}}, {{13., 
                0.52}}, {{14., 0.51}}, {{15., 0.49}}, {{16., 0.51}}, {{17., 
                0.5}}, {{18., 0.48}}, {{19., 0.47000000000000003`}}, {{20., 
                0.46}}, {{21., 0.46}}, {{22., 0.46}}, {{23., 0.45}}, {{24., 
                0.44}}, {{25., 0.43}}, {{26., 0.43}}, {{27., 0.44}}, {{28., 
                0.46}}, {{29., 0.45}}, {{30., 0.48}}, {{31., 0.49}}, {{32., 
                0.49}}, {{33., 0.47000000000000003`}}, {{34., 
                0.47000000000000003`}}, {{35., 0.49}}, {{36., 0.49}}, {{37., 
                0.47000000000000003`}}, {{38., 0.45}}, {{39., 0.43}}, {{40., 
                0.44}}, {{41., 0.44}}, {{42., 0.45}}, {{43., 0.46}}, {{44., 
                0.47000000000000003`}}, {{45., 0.47000000000000003`}}, {{46., 
                0.47000000000000003`}}, {{47., 0.48}}, {{48., 
                0.47000000000000003`}}, {{49., 0.46}}, {{50., 0.46}}, {{51., 
                0.46}}, {{52., 0.45}}, {{53., 0.46}}, {{54., 0.46}}, {{55., 
                0.45}}, {{56., 0.45}}, {{57., 0.46}}, {{58., 0.46}}, {{59., 
                0.46}}, {{60., 0.46}}, {{61., 0.5}}, {{62., 0.53}}, {{63., 
                0.52}}, {{64., 0.51}}, {{65., 0.5}}, {{66., 0.5}}, {{67., 
                0.51}}, {{68., 0.54}}, {{69., 0.53}}, {{70., 0.53}}, {{71., 
                0.53}}, {{72., 0.55}}, {{73., 0.55}}, {{74., 0.54}}, {{75., 
                0.55}}, {{76., 0.6}}, {{77., 0.59}}, {{78., 
                0.5700000000000001}}, {{79., 0.56}}, {{80., 0.54}}, {{81., 
                0.53}}, {{82., 0.52}}, {{83., 0.54}}, {{84., 0.54}}, {{85., 
                0.53}}, {{86., 0.53}}, {{87., 0.53}}, {{88., 0.54}}, {{89., 
                0.53}}, {{90., 0.51}}, {{91., 0.52}}, {{92., 0.51}}, {{93., 
                0.51}}, {{94., 0.51}}, {{95., 0.51}}, {{96., 0.51}}, {{97., 
                0.51}}, {{98., 0.51}}, {{99., 0.51}}, {{100., 0.51}}, {{101., 
                0.51}}, {{102., 0.51}}, {{103., 0.52}}, {{104., 0.51}}, {{
                105., 0.51}}, {{106., 0.51}}, {{107., 0.51}}, {{108., 
                0.5}}, {{109., 0.53}}, {{110., 0.53}}, {{111., 0.53}}, {{112.,
                 0.51}}, {{113., 0.5}}, {{114., 0.48}}, {{115., 0.49}}, {{
                116., 0.5}}, {{117., 0.49}}, {{118., 0.49}}, {{119., 
                0.47000000000000003`}}, {{120., 0.46}}, {{121., 0.45}}, {{
                122., 0.45}}, {{123., 0.45}}, {{124., 0.46}}, {{125., 
                0.49}}, {{126., 0.49}}, {{127., 0.49}}, {{128., 0.48}}, {{
                129., 0.49}}, {{130., 0.5}}, {{131., 0.5}}, {{132., 0.49}}, {{
                133., 0.47000000000000003`}}, {{134., 0.46}}, {{135., 
                0.46}}, {{136., 0.45}}, {{137., 0.44}}, {{138., 0.42}}, {{
                139., 0.41000000000000003`}}, {{140., 0.4}}, {{141., 
                0.39}}, {{142., 0.39}}, {{143., 0.41000000000000003`}}, {{
                144., 0.4}}, {{145., 0.42}}, {{146., 
                0.41000000000000003`}}, {{147., 0.42}}, {{148., 
                0.41000000000000003`}}, {{149., 0.41000000000000003`}}, {{
                150., 0.42}}, {{151., 0.41000000000000003`}}, {{152., 
                0.43}}, {{153., 0.41000000000000003`}}, {{154., 
                0.41000000000000003`}}, {{155., 0.4}}, {{156., 0.4}}, {{157., 
                0.39}}, {{158., 0.38}}, {{159., 0.36}}, {{160., 0.37}}, {{
                161., 0.36}}, {{162., 0.35000000000000003`}}, {{163., 
                0.35000000000000003`}}, {{164., 0.34}}, {{165., 
                0.35000000000000003`}}, {{166., 0.34}}, {{167., 0.34}}, {{
                168., 0.34}}, {{169., 0.34}}, {{170., 0.34}}, {{171., 
                0.34}}, {{172., 0.34}}, {{173., 0.37}}, {{174., 0.36}}, {{
                175., 0.42}}, {{176., 0.45}}, {{177., 0.53}}, {{178., 
                0.51}}, {{179., 0.51}}, {{180., 0.51}}, {{181., 0.5}}, {{182.,
                 0.5}}, {{183., 0.5700000000000001}}, {{184., 0.63}}, {{185., 
                0.62}}, {{186., 0.67}}, {{187., 0.71}}, {{188., 
                0.7000000000000001}}, {{189., 0.71}}, {{190., 0.72}}, {{191., 
                0.71}}, {{192., 0.71}}, {{193., 0.6900000000000001}}, {{194., 
                0.6900000000000001}}, {{195., 0.68}}, {{196., 0.68}}, {{197., 
                0.66}}, {{198., 0.64}}, {{199., 0.63}}, {{200., 0.64}}, {{
                201., 0.63}}, {{202., 0.62}}, {{203., 0.64}}, {{204., 
                0.62}}, {{205., 0.62}}, {{206., 0.61}}, {{207., 0.61}}, {{
                208., 0.6}}, {{209., 0.62}}, {{210., 0.61}}, {{211., 0.6}}, {{
                212., 0.59}}, {{213., 0.6}}, {{214., 0.63}}, {{215., 
                0.62}}, {{216., 0.62}}, {{217., 0.64}}, {{218., 0.63}}, {{
                219., 0.64}}, {{220., 0.63}}, {{221., 0.61}}, {{222., 
                0.6}}, {{223., 0.61}}, {{224., 0.59}}, {{225., 0.58}}, {{226.,
                 0.63}}, {{227., 0.63}}, {{228., 0.7000000000000001}}, {{229.,
                 0.72}}, {{230., 0.73}}, {{231., 0.7000000000000001}}, {{232.,
                 0.6900000000000001}}, {{233., 0.68}}, {{234., 
                0.6900000000000001}}, {{235., 0.7000000000000001}}, {{236., 
                0.7000000000000001}}, {{237., 0.6900000000000001}}, {{238., 
                0.67}}, {{239., 0.66}}, {{240., 0.6900000000000001}}, {{241., 
                0.67}}, {{242., 0.67}}, {{243., 0.66}}, {{244., 0.67}}, {{
                245., 0.67}}, {{246., 0.9400000000000001}}, {{247., 0.92}}, {{
                248., 0.88}}, {{249., 0.84}}, {{250., 0.8300000000000001}}}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "SubplotIndicatorValues"]] :> {{{""}, {0.67}, {0.64}, {0.62}, {
                0.61}, {0.61}, {0.61}, {0.6}, {0.59}, {0.5700000000000001}, {
                0.55}, {0.54}, {0.52}, {0.51}, {0.49}, {0.51}, {0.5}, {
                0.48}, {0.47000000000000003`}, {0.46}, {0.46}, {0.46}, {
                0.45}, {0.44}, {0.43}, {0.43}, {0.44}, {0.46}, {0.45}, {
                0.48}, {0.49}, {0.49}, {0.47000000000000003`}, {
                0.47000000000000003`}, {0.49}, {0.49}, {
                0.47000000000000003`}, {0.45}, {0.43}, {0.44}, {0.44}, {
                0.45}, {0.46}, {0.47000000000000003`}, {
                0.47000000000000003`}, {0.47000000000000003`}, {0.48}, {
                0.47000000000000003`}, {0.46}, {0.46}, {0.46}, {0.45}, {
                0.46}, {0.46}, {0.45}, {0.45}, {0.46}, {0.46}, {0.46}, {
                0.46}, {0.5}, {0.53}, {0.52}, {0.51}, {0.5}, {0.5}, {0.51}, {
                0.54}, {0.53}, {0.53}, {0.53}, {0.55}, {0.55}, {0.54}, {
                0.55}, {0.6}, {0.59}, {0.5700000000000001}, {0.56}, {0.54}, {
                0.53}, {0.52}, {0.54}, {0.54}, {0.53}, {0.53}, {0.53}, {
                0.54}, {0.53}, {0.51}, {0.52}, {0.51}, {0.51}, {0.51}, {
                0.51}, {0.51}, {0.51}, {0.51}, {0.51}, {0.51}, {0.51}, {
                0.51}, {0.52}, {0.51}, {0.51}, {0.51}, {0.51}, {0.5}, {
                0.53}, {0.53}, {0.53}, {0.51}, {0.5}, {0.48}, {0.49}, {0.5}, {
                0.49}, {0.49}, {0.47000000000000003`}, {0.46}, {0.45}, {
                0.45}, {0.45}, {0.46}, {0.49}, {0.49}, {0.49}, {0.48}, {
                0.49}, {0.5}, {0.5}, {0.49}, {0.47000000000000003`}, {0.46}, {
                0.46}, {0.45}, {0.44}, {0.42}, {0.41000000000000003`}, {
                0.4}, {0.39}, {0.39}, {0.41000000000000003`}, {0.4}, {0.42}, {
                0.41000000000000003`}, {0.42}, {0.41000000000000003`}, {
                0.41000000000000003`}, {0.42}, {0.41000000000000003`}, {
                0.43}, {0.41000000000000003`}, {0.41000000000000003`}, {
                0.4}, {0.4}, {0.39}, {0.38}, {0.36}, {0.37}, {0.36}, {
                0.35000000000000003`}, {0.35000000000000003`}, {0.34}, {
                0.35000000000000003`}, {0.34}, {0.34}, {0.34}, {0.34}, {
                0.34}, {0.34}, {0.34}, {0.37}, {0.36}, {0.42}, {0.45}, {
                0.53}, {0.51}, {0.51}, {0.51}, {0.5}, {0.5}, {
                0.5700000000000001}, {0.63}, {0.62}, {0.67}, {0.71}, {
                0.7000000000000001}, {0.71}, {0.72}, {0.71}, {0.71}, {
                0.6900000000000001}, {0.6900000000000001}, {0.68}, {0.68}, {
                0.66}, {0.64}, {0.63}, {0.64}, {0.63}, {0.62}, {0.64}, {
                0.62}, {0.62}, {0.61}, {0.61}, {0.6}, {0.62}, {0.61}, {0.6}, {
                0.59}, {0.6}, {0.63}, {0.62}, {0.62}, {0.64}, {0.63}, {
                0.64}, {0.63}, {0.61}, {0.6}, {0.61}, {0.59}, {0.58}, {
                0.63}, {0.63}, {0.7000000000000001}, {0.72}, {0.73}, {
                0.7000000000000001}, {0.6900000000000001}, {0.68}, {
                0.6900000000000001}, {0.7000000000000001}, {
                0.7000000000000001}, {0.6900000000000001}, {0.67}, {0.66}, {
                0.6900000000000001}, {0.67}, {0.67}, {0.66}, {0.67}, {0.67}, {
                0.9400000000000001}, {0.92}, {0.88}, {0.84}, {
                0.8300000000000001}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$545613["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$545613["YRange"]] :> 36.43,
              HoldPattern[
               System`TradingChartDump`$layoutData$545613[
               "SubplotPoints", {1}]] :> {{}, {0.67}, {0.64}, {0.62}, {
               0.61}, {0.61}, {0.61}, {0.6}, {0.59}, {0.5700000000000001}, {
               0.55}, {0.54}, {0.52}, {0.51}, {0.49}, {0.51}, {0.5}, {0.48}, {
               0.47000000000000003`}, {0.46}, {0.46}, {0.46}, {0.45}, {
               0.44}, {0.43}, {0.43}, {0.44}, {0.46}, {0.45}, {0.48}, {
               0.49}, {0.49}, {0.47000000000000003`}, {
               0.47000000000000003`}, {0.49}, {0.49}, {
               0.47000000000000003`}, {0.45}, {0.43}, {0.44}, {0.44}, {
               0.45}, {0.46}, {0.47000000000000003`}, {
               0.47000000000000003`}, {0.47000000000000003`}, {0.48}, {
               0.47000000000000003`}, {0.46}, {0.46}, {0.46}, {0.45}, {
               0.46}, {0.46}, {0.45}, {0.45}, {0.46}, {0.46}, {0.46}, {
               0.46}, {0.5}, {0.53}, {0.52}, {0.51}, {0.5}, {0.5}, {0.51}, {
               0.54}, {0.53}, {0.53}, {0.53}, {0.55}, {0.55}, {0.54}, {
               0.55}, {0.6}, {0.59}, {0.5700000000000001}, {0.56}, {0.54}, {
               0.53}, {0.52}, {0.54}, {0.54}, {0.53}, {0.53}, {0.53}, {
               0.54}, {0.53}, {0.51}, {0.52}, {0.51}, {0.51}, {0.51}, {
               0.51}, {0.51}, {0.51}, {0.51}, {0.51}, {0.51}, {0.51}, {
               0.51}, {0.52}, {0.51}, {0.51}, {0.51}, {0.51}, {0.5}, {0.53}, {
               0.53}, {0.53}, {0.51}, {0.5}, {0.48}, {0.49}, {0.5}, {0.49}, {
               0.49}, {0.47000000000000003`}, {0.46}, {0.45}, {0.45}, {
               0.45}, {0.46}, {0.49}, {0.49}, {0.49}, {0.48}, {0.49}, {0.5}, {
               0.5}, {0.49}, {0.47000000000000003`}, {0.46}, {0.46}, {0.45}, {
               0.44}, {0.42}, {0.41000000000000003`}, {0.4}, {0.39}, {0.39}, {
               0.41000000000000003`}, {0.4}, {0.42}, {0.41000000000000003`}, {
               0.42}, {0.41000000000000003`}, {0.41000000000000003`}, {
               0.42}, {0.41000000000000003`}, {0.43}, {
               0.41000000000000003`}, {0.41000000000000003`}, {0.4}, {0.4}, {
               0.39}, {0.38}, {0.36}, {0.37}, {0.36}, {
               0.35000000000000003`}, {0.35000000000000003`}, {0.34}, {
               0.35000000000000003`}, {0.34}, {0.34}, {0.34}, {0.34}, {
               0.34}, {0.34}, {0.34}, {0.37}, {0.36}, {0.42}, {0.45}, {
               0.53}, {0.51}, {0.51}, {0.51}, {0.5}, {0.5}, {
               0.5700000000000001}, {0.63}, {0.62}, {0.67}, {0.71}, {
               0.7000000000000001}, {0.71}, {0.72}, {0.71}, {0.71}, {
               0.6900000000000001}, {0.6900000000000001}, {0.68}, {0.68}, {
               0.66}, {0.64}, {0.63}, {0.64}, {0.63}, {0.62}, {0.64}, {
               0.62}, {0.62}, {0.61}, {0.61}, {0.6}, {0.62}, {0.61}, {0.6}, {
               0.59}, {0.6}, {0.63}, {0.62}, {0.62}, {0.64}, {0.63}, {0.64}, {
               0.63}, {0.61}, {0.6}, {0.61}, {0.59}, {0.58}, {0.63}, {0.63}, {
               0.7000000000000001}, {0.72}, {0.73}, {0.7000000000000001}, {
               0.6900000000000001}, {0.68}, {0.6900000000000001}, {
               0.7000000000000001}, {0.7000000000000001}, {
               0.6900000000000001}, {0.67}, {0.66}, {0.6900000000000001}, {
               0.67}, {0.67}, {0.66}, {0.67}, {0.67}, {0.9400000000000001}, {
               0.92}, {0.88}, {0.84}, {0.8300000000000001}}, HoldPattern[
               System`TradingChartDump`$layoutData$545613[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$545613[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$545613[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$545613[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$545613[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$545613 = 
           System`TradingChartDump`$length$545613; 
          System`TradingChartDump`$layoutData$545613["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$545613; 
          System`TradingChartDump`$modelData$545613["Data"] = 
           System`TradingChartDump`$data$545613; 
          System`TradingChartDump`$modelData$545613["Indicators"] = 
           System`TradingChartDump`$indicators$545613; 
          System`TradingChartDump`$layoutData$545613[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545613["ScalingFunctions"] = {
            System`TradingChartDump`$sy$545613, 
             System`TradingChartDump`$isy$545613}; 
          System`TradingChartDump`$layoutData$545613["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545613["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545613[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545613["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$545613["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$545613, 
            System`TradingChartDump`$layoutData$545613, 
            System`TradingChartDump`$indicators$545613]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$545613, 
            System`TradingChartDump`$layoutData$545613, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$545613[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$545613["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$545613[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$545613[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$545613["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$545613[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$545613 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545613["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545613, 
                 System`TradingChartDump`$controlmax$545613}]]]; 
          System`TradingChartDump`$plotrangemax$545613 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545613["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545613, 
                 System`TradingChartDump`$controlmax$545613}]]]; {
            System`TradingChartDump`$plotrangemin$545613, 
             System`TradingChartDump`$plotrangemax$545613} = ReplaceAll[
             
             System`TradingChartDump`$sy$545613[{
              System`TradingChartDump`$plotrangemin$545613, 
               System`TradingChartDump`$plotrangemax$545613}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$545613[
                Min[System`TradingChartDump`$lows$545613]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$545613 == 
            System`TradingChartDump`$plotrangemax$545613, {
             System`TradingChartDump`$plotrangemin$545613, 
              System`TradingChartDump`$plotrangemax$545613} = {
             System`TradingChartDump`$plotrangemin$545613 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$545613], 
              System`TradingChartDump`$plotrangemax$545613 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$545613]}]; 
          System`TradingChartDump`$newgridlines$545613 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$545613, 
            Part[System`TradingChartDump`$newgridlines$545613, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$545613, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$545613], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$545613, 1]]; 
            Part[System`TradingChartDump`$newgridlines$545613, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$545613, 1] =!= None,
                 System`TradingChartDump`$length$545613 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$545613, 
                 Part[System`TradingChartDump`$newgridlines$545613, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$545613, 1]]; 
            System`TradingChartDump`$subpricegridlines$545613 = 
             Part[System`TradingChartDump`$gridlines$545613, 2]; 
            Part[System`TradingChartDump`$newgridlines$545613, 2] = 
             If[System`TradingChartDump`$sy$545613 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545613}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545613, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545613, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$545613, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$545613, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545613}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545613, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545613, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$545613 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$545613]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"MSFT\"", "\" with \"", 
           "\"AverageTrueRange\"", "\"(\"", "14", "\",\"", "", "\",\"", "", 
           "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {240., -167.4}, ImageScaled[{0.5, 0.5}], {450, 310}], 
     InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$545627 = 
        "Full", System`TradingChartDump`$highlightposition$545627 = Automatic,
         System`TradingChartDump`$maxohlc$545627 = 36.43`4., 
        System`TradingChartDump`$timestampstyle$545627 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$545627 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$545627 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$545627, 
        System`TradingChartDump`$subplotpoint$545627, 
        System`TradingChartDump`$ndigits$545627 = 4, 
        System`TradingChartDump`$highlightstyle$545627 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$545627 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$545627 = True, 
        System`TradingChartDump`$timestampQ$545627 = True, 
        System`TradingChartDump`$data$545627 = {{{2012, 7, 26}, {
          28.367935528120714`, 28.62997256515775, 28.232064471879287`, 28.3, 
           45301400}}, {{2012, 7, 27}, {
          28.60827956989247, 28.967338709677417`, 28.317150537634404`, 28.88, 
           44242600}}, {{2012, 7, 30}, {
          28.866734143049936`, 28.934655870445347`, 28.58534412955466, 28.76, 
           28905000}}, {{2012, 7, 31}, {
          28.609704784526638`, 28.832914828639293`, 28.464133016627077`, 28.6,
            37620900}}, {{2012, 8, 1}, {
          28.714675280516833`, 28.77290037402244, 28.3459163549813, 28.54, 
           31721800}}, {{2012, 8, 2}, {
          28.349410757108597`, 28.65998287084618, 28.11648167180541, 28.33, 
           39520500}}, {{2012, 8, 3}, {
          28.65650756302521, 29.054379831932774`, 28.60798655462185, 28.87, 
           35859400}}, {{2012, 8, 6}, {
          29.108514190317194`, 29.215245409015022`, 28.924160267111848`, 
           29.06, 27471800}}, {{2012, 8, 7}, {
          29.185588235294116`, 29.457352941176467`, 28.99147058823529, 29.37, 
           28002900}}, {{2012, 8, 8}, {
          29.31356083086054, 29.56584569732938, 29.21652818991098, 29.43, 
           26257600}}, {{2012, 8, 9}, {
          29.493245901639348`, 29.745573770491806`, 29.40590163934427, 29.6, 
           24920800}}, {{2012, 8, 10}, {
          29.59763313609467, 29.714082840236685`, 29.355029585798814`, 29.52, 
           27810300}}, {{2012, 8, 13}, {
          29.451184600197433`, 29.55792694965449, 29.26681145113524, 29.49, 
           23049100}}, {{2012, 8, 14}, {
          29.596050448058413`, 29.68395950879522, 29.31278791901759, 29.43, 
           34551400}}, {{2012, 8, 15}, {
          29.412086092715235`, 29.578145695364242`, 29.324172185430466`, 29.5,
            24351000}}, {{2012, 8, 16}, {
          29.65968810916179, 30.22630929174789, 29.561994801819363`, 30.07, 
           35787200}}, {{2012, 8, 17}, {
          30.19953398058253, 30.19953398058253, 29.87722330097088, 30.18, 
           32589900}}, {{2012, 8, 20}, {
          30.108152244632407`, 30.13745933636956, 29.873695510735203`, 30.03, 
           23737700}}, {{2012, 8, 21}, {
          30.050922077922078`, 30.24631168831169, 29.90437987012987, 30.09, 
           28822700}}, {{2012, 8, 22}, {
          29.878837590045844`, 30.044885396201707`, 29.761627373935823`, 
           29.83, 33437400}}, {{2012, 8, 23}, {
          29.68699272967614, 29.696761401189683`, 29.384163912756108`, 29.56, 
           28355600}}, {{2012, 8, 24}, {
          29.547202225130892`, 29.91837369109948, 29.478828534031415`, 29.85, 
           22943300}}, {{2012, 8, 27}, {
          30.214447702834796`, 30.243753665689148`, 29.88231345715216, 29.98, 
           34691100}}, {{2012, 8, 28}, {
          29.988377407770162`, 30.08605941887039, 29.81254978778975, 29.92, 
           23947900}}, {{2012, 8, 29}, {
          29.940000000000005`, 30.037683523654167`, 29.734864600326272`, 
           29.94, 23346800}}, {{2012, 8, 30}, {
          29.82515171503958, 29.90330474934037, 29.52230870712401, 29.62, 
           23982100}}, {{2012, 8, 31}, {
          29.895068137573006`, 30.246774821544452`, 29.68013627514601, 30.11, 
           36590100}}, {{2012, 9, 4}, {
          29.748617966436328`, 29.953780848963476`, 29.45552813425469, 29.69, 
           48556700}}, {{2012, 9, 5}, {
          29.523915761763735`, 29.8267752550181, 29.51414610069102, 29.69, 
           33650000}}, {{2012, 9, 6}, {
          29.789792663476874`, 30.629767145135563`, 29.750724082934607`, 
           30.62, 48371700}}, {{2012, 9, 7}, {
          30.317906300484655`, 30.347208400646206`, 30.01511793214863, 30.23, 
           42649100}}, {{2012, 9, 10}, {
          30.11745768229167, 30.185839843750003`, 29.804853515625005`, 30.01, 
           40524000}}, {{2012, 9, 11}, {
          29.982305943488143`, 30.197232867814222`, 29.90415069827866, 30.08, 
           25191800}}, {{2012, 9, 12}, {
          30.22630929174789, 30.46077322936972, 30.021153346328784`, 30.07, 
           32775800}}, {{2012, 9, 13}, {
          30.171163542340008`, 30.454414996767934`, 29.692566257272134`, 
           30.22, 45047300}}, {{2012, 9, 14}, {
          30.29461390579942, 30.52907721884011, 30.09922781159884, 30.49, 
           51422800}}, {{2012, 9, 17}, {
          30.47046139057994, 30.53884652355014, 30.323921819929506`, 30.49, 
           36488500}}, {{2012, 9, 18}, {
          30.381847338037208`, 30.489307248236052`, 30.31346375881976, 30.46, 
           34542700}}, {{2012, 9, 19}, {
          30.369072463768113`, 30.466753623188403`, 30.320231884057968`, 
           30.33, 48871900}}, {{2012, 9, 20}, {
          30.231605723370425`, 30.74930365659777, 30.19253418124006, 30.72, 
           45543000}}, {{2012, 9, 21}, {
          30.704459762744467`, 30.88030458480282, 30.3723084321898, 30.47, 
           102348900}}, {{2012, 9, 24}, {
          30.284925276153345`, 30.353310591293045`, 29.933229369720596`, 
           30.07, 46825900}}, {{2012, 9, 25}, {
          30.23710102007239, 30.285949325435997`, 29.660691016781836`, 29.69, 
           54266400}}, {{2012, 9, 26}, {
          29.577447795823662`, 29.890023201856145`, 29.3430162412993, 29.47, 
           54672000}}, {{2012, 9, 27}, {
          29.46976790450929, 29.694429708222817`, 29.196266578249343`, 29.46, 
           47129900}}, {{2012, 9, 28}, {
          29.480262096774194`, 29.558407258064516`, 29.050463709677416`, 
           29.07, 54229300}}, {{2012, 10, 1}, {
          29.122621227534758`, 29.288701254662598`, 28.741614106476774`, 
           28.81, 54042700}}, {{2012, 10, 2}, {
          28.98953472690492, 29.194649359406608`, 28.813722184760618`, 28.97, 
           43338900}}, {{2012, 10, 3}, {
          29.062541862022776`, 29.296995981245818`, 28.98439048894843, 29.17, 
           46655900}}, {{2012, 10, 4}, {
          29.271398601398595`, 29.329999999999995`, 28.880722610722604`, 
           29.33, 43634900}}, {{2012, 10, 5}, {
          29.531216080402007`, 29.55075376884422, 29.052542713567835`, 29.16, 
           41133900}}, {{2012, 10, 8}, {
          28.953243787777033`, 29.226756212222973`, 28.865329079919412`, 
           29.09, 29752000}}, {{2012, 10, 9}, {
          28.990710382513658`, 29.049316939890705`, 28.502322404371583`, 28.6,
            45121100}}, {{2012, 10, 10}, {
          28.476069703243613`, 28.632370600414074`, 28.280693581780536`, 
           28.31, 47227100}}, {{2012, 10, 11}, {
          28.543751295336786`, 28.573056994818653`, 28.20185146804836, 28.28, 
           41488500}}, {{2012, 10, 12}, {
          28.29535616438356, 28.637205479452053`, 28.12931506849315, 28.52, 
           46464700}}, {{2012, 10, 15}, {
          28.693226025076243`, 29.03516096238563, 28.57599118942731, 28.83, 
           42440200}}, {{2012, 10, 16}, {
          28.770922346558155`, 29.054235334011526`, 28.643919972872162`, 
           28.81, 47739400}}, {{2012, 10, 17}, {
          28.626664413653266`, 28.958850963163233`, 28.421490368367696`, 
           28.91, 44206100}}, {{2012, 10, 18}, {
          28.966542372881356`, 29.044698305084747`, 28.585532203389832`, 
           28.82, 59238500}}, {{2012, 10, 19}, {
          28.380551675977653`, 28.409860335195525`, 27.843226256983236`, 
           27.98, 90470800}}, {{2012, 10, 22}, {
          28.063053571428572`, 28.16073214285714, 27.183946428571428`, 27.35, 
           83374000}}, {{2012, 10, 23}, {
          27.126488413547236`, 27.546524064171123`, 27.116720142602496`, 27.4,
            64414800}}, {{2012, 10, 24}, {
          27.503942652329755`, 27.543010752688176`, 27.220698924731188`, 
           27.25, 53320400}}, {{2012, 10, 25}, {
          27.532772596843618`, 27.542539454806313`, 27.210466284074606`, 
           27.23, 54084300}}, {{2012, 10, 26}, {
          27.21806451612903, 27.687004608294927`, 27.198525345622116`, 27.56, 
           57790000}}, {{2012, 10, 31}, {
          27.88976874562018, 28.21213735108619, 27.840925017519268`, 27.88, 
           69464100}}, {{2012, 11, 1}, {
          28.17566395663957, 28.879078590785912`, 28.15612466124662, 28.84, 
           72047900}}, {{2012, 11, 2}, {
          28.907925423728813`, 29.08377627118644, 28.653918644067797`, 28.82, 
           57131600}}, {{2012, 11, 5}, {
          28.930232872089103`, 29.047438407019914`, 28.646986162672967`, 
           28.94, 38070800}}, {{2012, 11, 6}, {
          29.13092431346283, 29.50214333556598, 28.92577695914267, 29.17, 
           43401500}}, {{2012, 11, 7}, {
          28.849632049518576`, 29.14272008253095, 28.380691196698766`, 28.41, 
           57871800}}, {{2012, 11, 8}, {
          28.442790697674425`, 28.68697674418605, 28.13023255813954, 28.14, 
           49841800}}, {{2012, 11, 9}, {
          28.2088380159556, 28.511633714880336`, 28.14046479361776, 28.16, 
           43291200}}, {{2012, 11, 12}, {
          28.273416017009215`, 28.341803685329555`, 27.560230333097095`, 
           27.57, 61112300}}, {{2012, 11, 13}, {
          26.611059431524552`, 26.88682170542636, 26.345145810262093`, 26.68, 
           131689200}}, {{2012, 11, 14}, {
          26.823889716840533`, 26.873125931445603`, 26.390611028315945`, 
           26.43, 76086100}}, {{2012, 11, 15}, {
          26.476699174793698`, 26.565348837209303`, 26.230450112528132`, 
           26.26, 50955600}}, {{2012, 11, 16}, {
          26.267737556561087`, 26.2972850678733, 25.942714932126695`, 26.12, 
           64083300}}, {{2012, 11, 19}, {
          26.398952487841374`, 26.398952487841374`, 26.07389075944631, 26.33, 
           57179300}}, {{2012, 11, 20}, {
          26.359251216772744`, 26.39865219019094, 26.06374391613628, 26.31, 
           47070400}}, {{2012, 11, 21}, {
          26.30365120593692, 26.75665306122449, 26.264259740259742`, 26.54, 
           66360300}}, {{2012, 11, 23}, {
          26.817126353790613`, 27.348938628158844`, 26.787581227436824`, 
           27.28, 57845700}}, {{2012, 11, 26}, {
          27.127754654983573`, 27.167155896312522`, 26.763293172690766`, 
           26.98, 85198700}}, {{2012, 11, 27}, {
          26.945760709010344`, 26.96545790251108, 26.630605612998526`, 26.67, 
           45018600}}, {{2012, 11, 28}, {
          26.605244883040935`, 26.97955043859649, 26.368841374269003`, 26.95, 
           53018400}}, {{2012, 11, 29}, {
          26.697565862708718`, 26.943762523191094`, 26.451369202226346`, 
           26.54, 69551400}}, {{2012, 11, 30}, {
          26.643538692712244`, 26.7223365890308, 26.09195341848234, 26.22, 
           83690200}}, {{2012, 12, 3}, {
          26.37470298902762, 26.414097616345064`, 26.000454029511918`, 26.03, 
           53173800}}, {{2012, 12, 4}, {
          26.098028062191883`, 26.226056124383767`, 25.9404550625711, 25.97, 
           49777500}}, {{2012, 12, 5}, {
          25.984349456317954`, 26.526100487439066`, 25.86614923134608, 26.27, 
           68283800}}, {{2012, 12, 6}, {
          26.408802843247283`, 26.57625888514777, 26.211795735129066`, 26.33, 
           39182300}}, {{2012, 12, 7}, {
          26.414557823129254`, 26.414557823129254`, 25.97136054421769, 26.06, 
           46162100}}, {{2012, 12, 10}, {
          26.155783221974758`, 26.559543429844098`, 26.116391982182627`, 
           26.53, 47031100}}, {{2012, 12, 11}, {
          26.64405197657394, 27.077448755490483`, 26.64405197657394, 26.91, 
           52282800}}, {{2012, 12, 12}, {
          27.11563509544787, 27.20428046989721, 26.67240822320117, 26.83, 
           43966300}}, {{2012, 12, 13}, {
          26.90682405016599, 27.10379933603836, 26.5424197713021, 26.7, 
           45080100}}, {{2012, 12, 14}, {
          26.695412159641922`, 26.71510630361805, 26.29168220813129, 26.4, 
           42077500}}, {{2012, 12, 17}, {
          26.38469003690037, 26.80818450184502, 26.27635424354244, 26.69, 
           42046100}}, {{2012, 12, 18}, {
          26.834724238026126`, 27.208933236574747`, 26.726400580551527`, 
           27.14, 50486900}}, {{2012, 12, 19}, {
          27.274295129989014`, 27.313694617356276`, 26.8409007689491, 26.9, 
           53519900}}, {{2012, 12, 20}, {
          26.94485549132948, 27.26, 26.738041907514454`, 27.26, 52607300}}, {{
          2012, 12, 21}, {
          27.04, 27.079402550091075`, 26.59672131147541, 27.04, 98776500}}, {{
          2012, 12, 24}, {
          26.78787878787879, 26.83712121212121, 26.59090909090909, 26.65, 
           20842400}}, {{2012, 12, 26}, {
          26.617405063291137`, 26.784810126582276`, 26.292442293373043`, 
           26.45, 31631100}}, {{2012, 12, 27}, {
          26.481064540059347`, 26.678022997032638`, 26.165931008902074`, 
           26.55, 39394000}}, {{2012, 12, 28}, {
          26.307589453860636`, 26.494726930320144`, 26.149999999999995`, 
           26.15, 28239900}}, {{2012, 12, 31}, {
          26.191797079745413`, 26.369101460127293`, 25.97509172594534, 26.31, 
           42749500}}, {{2013, 1, 2}, {
          26.8356263577118, 27.30832729905865, 26.737146994931205`, 27.2, 
           52899300}}, {{2013, 1, 3}, {
          27.214282568807338`, 27.233981651376148`, 26.75135412844037, 26.84, 
           48294400}}, {{2013, 1, 4}, {
          26.862071802543007`, 26.93102468212416, 26.330149588631265`, 26.34, 
           52521100}}, {{2013, 1, 7}, {
          26.36880104908205, 26.477152491569875`, 26.240749344323717`, 26.29, 
           37110400}}, {{2013, 1, 8}, {
          26.346986817325796`, 26.386384180790955`, 26.061355932203387`, 
           26.15, 44703100}}, {{2013, 1, 9}, {
          26.319700374531838`, 26.34925093632959, 26.162097378277153`, 26.3, 
           49047900}}, {{2013, 1, 10}, {
          26.247127739984883`, 26.572139077853365`, 25.89256991685563, 26.06, 
           71431300}}, {{2013, 1, 11}, {
          26.08519567648155, 26.51847185985837, 25.87840477077898, 26.42, 
           55512100}}, {{2013, 1, 14}, {
          26.489847526961693`, 26.667103012272218`, 26.351982149497953`, 
           26.48, 48324400}}, {{2013, 1, 15}, {
          26.42572583608967, 26.878794560823223`, 26.42572583608967, 26.8, 
           48244500}}, {{2013, 1, 16}, {
          26.738332100591716`, 26.817119082840236`, 26.600454881656805`, 
           26.63, 41077400}}, {{2013, 1, 17}, {
          26.78090275229358, 27.05668990825688, 26.65285871559633, 26.84, 
           51685900}}, {{2013, 1, 18}, {
          26.692256880733947`, 26.879398165137616`, 26.633159633027525`, 
           26.84, 52167700}}, {{2013, 1, 22}, {
          26.887734806629833`, 27.035469613259668`, 26.592265193370167`, 
           26.74, 58650600}}, {{2013, 1, 23}, {
          26.786236870699025`, 27.21954364360739, 26.786236870699025`, 27.19, 
           50387700}}, {{2013, 1, 24}, {
          27.27893593919653, 27.643311617806734`, 27.052432138979373`, 27.21, 
           101739300}}, {{2013, 1, 25}, {
          27.164519368723095`, 27.804727403156384`, 26.97738163558106, 27.46, 
           81847700}}, {{2013, 1, 28}, {
          27.58849516302401, 27.80518452167682, 27.342257255463995`, 27.49, 
           56056500}}, {{2013, 1, 29}, {
          27.402848982506246`, 27.708200642627627`, 27.186147804355585`, 
           27.59, 49242600}}, {{2013, 1, 30}, {
          27.58758707360862, 27.764872531418312`, 27.341357271095156`, 27.43, 
           43580500}}, {{2013, 1, 31}, {
          27.374921675774136`, 27.55223315118397, 26.990746812386156`, 27.04, 
           50530000}}, {{2013, 2, 1}, {
          27.253909774436092`, 27.628195488721804`, 27.135714285714286`, 
           27.51, 55565900}}, {{2013, 2, 4}, {
          27.453575072886295`, 27.60133381924198, 27.010298833819242`, 27.03, 
           50540000}}, {{2013, 2, 5}, {
          27.198167272727268`, 27.237556363636358`, 26.942138181818176`, 
           27.08, 35410400}}, {{2013, 2, 6}, {
          26.969400146305773`, 27.12700073152889, 26.841349670811994`, 26.93, 
           41889600}}, {{2013, 2, 7}, {
          26.938947947214075`, 26.978346774193547`, 26.692705278592374`, 
           26.87, 38028300}}, {{2013, 2, 8}, {
          26.933049001814883`, 27.287560798548096`, 26.893658802177857`, 
           27.13, 33318500}}, {{2013, 2, 11}, {
          27.23316582914573, 27.499095477386938`, 27.085427135678394`, 27.44, 
           32247700}}, {{2013, 2, 12}, {
          27.459999999999997`, 27.57819225251076, 27.33195839311334, 27.46, 
           35990900}}, {{2013, 2, 13}, {
          27.511498394577234`, 27.688801284338204`, 27.462247591865854`, 
           27.61, 41715600}}, {{2013, 2, 14}, {
          27.501797432239663`, 27.639700427960058`, 27.45254636233952, 27.62, 
           32663200}}, {{2013, 2, 15}, {
          27.619550160656903`, 27.737750803284538`, 27.46194930382006, 27.59, 
           49650900}}, {{2013, 2, 19}, {
          27.68121212121212, 27.889714795008913`, 27.6017825311943, 27.85, 
           38781400}}, {{2013, 2, 20}, {
          27.938227484750627`, 28.007750269106566`, 27.64027269465375, 27.68, 
           44110200}}, {{2013, 2, 21}, {
          27.548272098945073`, 27.548272098945073`, 27.041797017097128`, 27.3,
            49078500}}, {{2013, 2, 22}, {
          27.49054755043228, 27.570000000000004`, 27.29191642651297, 27.57, 
           31425900}}, {{2013, 2, 25}, {
          27.7758348556814, 27.85527950310559, 27.18, 27.18, 48011800}}, {{
          2013, 2, 26}, {
          27.18993058092802, 27.408403361344536`, 27.150208257215926`, 27.18, 
           49923300}}, {{2013, 2, 27}, {
          27.232664509169368`, 27.808701905789285`, 27.143279395900755`, 
           27.62, 36394700}}, {{2013, 2, 28}, {
          27.689453237410067`, 27.7788381294964, 27.55041007194244, 27.61, 
           35840200}}, {{2013, 3, 1}, {
          27.53156350626118, 27.789796064400715`, 27.332923076923077`, 27.76, 
           34849700}}, {{2013, 3, 4}, {
          27.652131438721142`, 27.950000000000003`, 27.503197158081708`, 
           27.95, 38157500}}, {{2013, 3, 5}, {
          28.090423280423277`, 28.33865961199294, 27.961340388007052`, 28.15, 
           41432200}}, {{2013, 3, 6}, {
          28.009145603417586`, 28.029003203987184`, 27.582207191171236`, 
           27.89, 51448500}}, {{2013, 3, 7}, {
          27.910213219616203`, 28.079004975124377`, 27.810923951670222`, 
           27.94, 29196700}}, {{2013, 3, 8}, {
          28.058303571428567`, 28.137760714285708`, 27.770271428571426`, 
           27.81, 37667800}}, {{2013, 3, 11}, {
          27.74952278435594, 27.779318263365624`, 27.48136347326875, 27.68, 
           36627500}}, {{2013, 3, 12}, {
          27.650476531709067`, 27.759727696166248`, 27.451838050877825`, 
           27.72, 39255200}}, {{2013, 3, 13}, {
          27.680340257879656`, 27.829319484240685`, 27.56115687679083, 27.73, 
           29093400}}, {{2013, 3, 14}, {
          27.800995024875622`, 27.959857853589195`, 27.731492537313432`, 
           27.94, 55914800}}, {{2013, 3, 15}, {
          27.83007132667618, 27.95914407988588, 27.780427960057064`, 27.84, 
           92710300}}, {{2013, 3, 18}, {
          27.681565836298926`, 28.07871886120996, 27.612064056939495`, 27.9, 
           44809400}}, {{2013, 3, 19}, {
          27.92042583392477, 28.01971611071682, 27.831064584811926`, 27.98, 
           51901600}}, {{2013, 3, 20}, {
          28.13985875706215, 28.28879943502825, 27.980988700564975`, 28.12, 
           35447800}}, {{2013, 3, 21}, {
          27.909999999999997`, 28.158221273568124`, 27.85042689434365, 27.91, 
           34233200}}, {{2013, 3, 22}, {
          27.990424778761064`, 28.13936283185841, 27.901061946902658`, 28.05, 
           28720900}}, {{2013, 3, 25}, {
          28.099005681818188`, 28.14865056818182, 27.76142045454546, 27.96, 
           44154000}}, {{2013, 3, 26}, {
          28.03943181818182, 28.138721590909096`, 27.910355113636367`, 27.96, 
           27824300}}, {{2013, 3, 27}, {
          27.941621431089178`, 28.24943602396898, 27.88204441311244, 28.17, 
           36047400}}, {{2013, 3, 28}, {
          28.12202726319469, 28.459650471862986`, 28.06244669695911, 28.41, 
           55453800}}, {{2013, 4, 1}, {
          28.439790283117794`, 28.459650471862986`, 28.16174764068508, 28.41, 
           29201100}}, {{2013, 4, 2}, {
          28.391458333333336`, 28.64965277777778, 28.321944444444448`, 28.6, 
           28456500}}, {{2013, 4, 3}, {
          28.548669467787114`, 28.747268907563026`, 28.34014005602241, 28.36, 
           35062800}}, {{2013, 4, 4}, {
          28.191468531468526`, 28.409930069930063`, 28.072307692307685`, 28.4,
            45263200}}, {{2013, 4, 5}, {
          28.02334494773519, 28.5794425087108, 27.91411149825784, 28.5, 
           50927300}}, {{2013, 4, 8}, {
          28.529020636586218`, 28.529020636586218`, 28.270839454354668`, 
           28.39, 34759500}}, {{2013, 4, 9}, {
          28.526241134751775`, 29.608510638297872`, 28.47659574468085, 29.4, 
           77733800}}, {{2013, 4, 10}, {
          29.364924042272122`, 30.109722589167763`, 29.315270805812414`, 
           30.07, 71116700}}, {{2013, 4, 11}, {
          28.89889426399447, 28.998203178991016`, 28.531451278507255`, 28.74, 
           130923200}}, {{2013, 4, 12}, {
          28.649583188607156`, 28.818402222994095`, 28.460903091351163`, 
           28.59, 62886300}}, {{2013, 4, 15}, {
          28.450278842802366`, 28.77797838968281, 28.311254792610665`, 28.49, 
           56332900}}, {{2013, 4, 16}, {
          28.700483258543322`, 28.93882637210908, 28.501863997238523`, 28.77, 
           52797300}}, {{2013, 4, 17}, {
          28.64986125563649, 28.83854318418314, 28.40159556018037, 28.63, 
           52840700}}, {{2013, 4, 18}, {
          28.74888850295241, 28.77868009725599, 28.302014588398748`, 28.59, 
           56906600}}, {{2013, 4, 19}, {
          29.411058112193484`, 30.02668458179375, 29.40112865300638, 29.56, 
           99790700}}, {{2013, 4, 22}, {
          30.093610120012976`, 30.967615958482, 30.063814466428806`, 30.62, 
           137904000}}, {{2013, 4, 23}, {
          30.489313725490195`, 30.687941176470588`, 30.17150980392157, 30.39, 
           59126900}}, {{2013, 4, 24}, {
          30.407896725440807`, 31.69889168765743, 30.388035264483626`, 31.54, 
           90946600}}, {{2013, 4, 25}, {
          31.491584220413277`, 32.61380087664371, 31.32275516593613, 31.72, 
           110700200}}, {{2013, 4, 26}, {
          31.679238754325258`, 31.758685121107266`, 31.23235294117647, 31.57, 
           47799300}}, {{2013, 4, 29}, {
          31.575712971481146`, 32.449506286415215`, 31.545924563017483`, 
           32.38, 59116400}}, {{2013, 4, 30}, {
          32.33375226586102, 32.87993051359516, 32.05569788519637, 32.87, 
           75165200}}, {{2013, 5, 1}, {
          32.69852383863081, 32.84746943765282, 32.3708435207824, 32.49, 
           54330900}}, {{2013, 5, 2}, {
          32.40367611580218, 32.939930639324494`, 32.16534077201448, 32.93, 
           46059500}}, {{2013, 5, 3}, {
          33.00178560764407, 33.28979396834876, 32.85281576590026, 33.26, 
           46784600}}, {{2013, 5, 6}, {
          33.18234666666667, 33.66886222222222, 33.013555555555556`, 33.51, 
           40978300}}, {{2013, 5, 7}, {
          33.41765235664965, 33.55668567997598, 33.01048333833683, 33.08, 
           43078300}}, {{2013, 5, 8}, {
          32.83944225522885, 33.00825704759018, 32.422370415277356`, 32.76, 
           51595700}}, {{2013, 5, 9}, {
          32.61866197183099, 32.76760563380282, 32.36049295774649, 32.43, 
           46417800}}, {{2013, 5, 10}, {
          32.44014071581524, 32.48978892627715, 32.09260324258183, 32.46, 
           36394900}}, {{2013, 5, 13}, {
          32.382924613987285`, 32.83972146533454, 32.323342415985465`, 32.8, 
           36027600}}, {{2013, 5, 14}, {
          32.86, 33.53, 32.8, 33.53, 56870100}}, {{2013, 5, 15}, {
          33.45, 33.9, 33.43, 33.85, 46303900}}, {{2013, 5, 16}, {
          33.64, 34.15, 33.55, 34.08, 59382900}}, {{2013, 5, 17}, {
          34.13, 34.87, 34.1, 34.87, 60666700}}, {{2013, 5, 20}, {
          34.73, 35.1, 34.68, 35.08, 54020800}}, {{2013, 5, 21}, {
          35.1, 35.27, 34.72, 34.85, 48702400}}, {{2013, 5, 22}, {
          34.79, 34.84, 34.36, 34.61, 66047500}}, {{2013, 5, 23}, {
          34.23, 34.55, 33.9, 34.15, 51102700}}, {{2013, 5, 24}, {
          33.92, 34.28, 33.9, 34.27, 33174400}}, {{2013, 5, 28}, {
          34.42, 35.18, 34.41, 35.02, 48212100}}, {{2013, 5, 29}, {
          34.74, 35.02, 34.57, 34.88, 38412200}}, {{2013, 5, 30}, {
          34.849999999999994`, 35.24999999999999, 34.809999999999995`, 35.03, 
           51131000}}, {{2013, 5, 31}, {
          34.82, 35.28, 34.79, 34.9, 56165700}}, {{2013, 6, 3}, {
          34.919999999999995`, 35.629999999999995`, 34.82999999999999, 35.59, 
           51252600}}, {{2013, 6, 4}, {
          35.62, 35.74, 34.77, 34.99, 65529500}}, {{2013, 6, 5}, {
          34.6, 34.89, 34.43, 34.78, 46025100}}, {{2013, 6, 6}, {
          34.84, 35.11, 34.49, 34.96, 37618500}}, {{2013, 6, 7}, {
          35.25, 35.78, 35.06, 35.67, 40757300}}, {{2013, 6, 10}, {
          35.51, 35.65, 35.14, 35.47, 35994500}}, {{2013, 6, 11}, {
          35.05, 35.18, 34.68, 34.84, 39435900}}, {{2013, 6, 12}, {
          35.14, 35.27, 34.85, 35., 37372700}}, {{2013, 6, 13}, {
          34.99, 35.02, 34.59, 34.72, 45654900}}, {{2013, 6, 14}, {
          34.55, 34.69, 34.25, 34.4, 53192600}}, {{2013, 6, 17}, {
          34.69, 35.16, 34.63, 35., 49670100}}, {{2013, 6, 18}, {
          34.97, 35.17, 34.9, 34.98, 28616500}}, {{2013, 6, 19}, {
          34.96, 35.09, 34.59, 34.59, 30816200}}, {{2013, 6, 20}, {
          34.26, 34.33, 33.37, 33.49, 54493700}}, {{2013, 6, 21}, {
          33.66, 33.73, 33.05, 33.27, 85338500}}, {{2013, 6, 24}, {
          32.94, 34.2, 32.57, 33.72, 56109000}}, {{2013, 6, 25}, {
          34.08, 34.38, 33.46, 33.67, 44073400}}, {{2013, 6, 26}, {
          34.12, 34.48, 33.89, 34.35, 48665900}}, {{2013, 6, 27}, {
          34.52, 34.78, 34.5, 34.62, 28993100}}, {{2013, 6, 28}, {
          34.38, 34.79, 34.34, 34.54, 65545500}}, {{2013, 7, 1}, {
          34.75, 34.99, 34.33, 34.36, 31055400}}, {{2013, 7, 2}, {
          34.41, 34.44, 33.63, 33.94, 37630000}}, {{2013, 7, 3}, {
          33.66, 34.37, 33.6, 34.01, 15994400}}, {{2013, 7, 5}, {
          34.09, 34.24, 33.58, 34.21, 26085900}}, {{2013, 7, 8}, {
          34.35, 34.59, 33.98, 34.33, 32396900}}, {{2013, 7, 9}, {
          34.58, 34.6, 34.14, 34.35, 25318500}}, {{2013, 7, 10}, {
          34.34, 34.81, 34.32, 34.7, 29658800}}, {{2013, 7, 11}, {
          35., 35.77, 34.9, 35.69, 53638300}}, {{2013, 7, 12}, {
          35.58, 35.73, 35.28, 35.67, 35501200}}, {{2013, 7, 15}, {
          35.66, 36.22, 35.58, 36.17, 34142600}}, {{2013, 7, 16}, {
          36.01, 36.43, 35.96, 36.27, 36378500}}, {{2013, 7, 17}, {
          36.34, 36.39, 35.49, 35.74, 37285100}}, {{2013, 7, 18}, {
          35.72, 35.89, 35.22, 35.44, 49547100}}, {{2013, 7, 19}, {
          32.4, 32.67, 31.02, 31.4, 248428500}}, {{2013, 7, 22}, {
          31.7, 32.01, 31.6, 32.01, 79040700}}, {{2013, 7, 23}, {
          31.91, 32.04, 31.71, 31.82, 65810400}}, {{2013, 7, 24}, {
          32.04, 32.19, 31.89, 31.96, 52803100}}, {{2013, 7, 25}, {
          31.62, 31.65, 31.25, 31.39, 63213000}}}, 
        System`TradingChartDump`$markerstyle$545627 = 1, 
        System`TradingChartDump`$controlmin$545627 = 0.5, 
        System`TradingChartDump`$controlmax$545627 = 250.5, 
        System`TradingChartDump`$datescope$545627 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$545627 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$545627, 
        System`TradingChartDump`$max$545627, 
        System`TradingChartDump`$ohlclabel$545627 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545627, 
              System`TradingChartDump`$opens$545627]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545627, 
              System`TradingChartDump`$highs$545627]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545627, 
              System`TradingChartDump`$lows$545627]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545627, 
              System`TradingChartDump`$closes$545627]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545627, 
              System`TradingChartDump`$visdates$545627]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$545627 = {}, 
        System`TradingChartDump`$subpricegridlines$545627 = Automatic, 
        System`TradingChartDump`$overlaypoint$545627, 
        System`TradingChartDump`$overlayvalue$545627, 
        System`TradingChartDump`$subplotvalue$545627, 
        System`TradingChartDump`$opts$545627 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "MSFT", " with ", "FastStochastic", 
            "(", 14, ",", 3, ",", Null, ",", Null, ")"}], 
         ImageSize -> {450, 310}, AlignmentPoint -> Center, AspectRatio -> 
         GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> None, AxesOrigin -> 
         Automatic, AxesStyle -> {}, Background -> None, BaselinePosition -> 
         Automatic, BaseStyle -> {}, ColorOutput -> Automatic, 
         ContentSelectable -> Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$545627 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmgtcj+f7xyNbDokp/ORUIcmhckrnO2EhOipppcO3vt/6VsKIsIVpDtGo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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyNmglYjmnUx5ssY5K1sku2bElp0d4tkvZdi9KmRW8LsnwYvJiECUOILGPN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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$545627 = 
        System`TradingChartDump`$staticindicatorpos$545627, 
        System`TradingChartDump`$length$545627 = 250, 
        System`TradingChartDump`$gridlinesflag$545627 = True, 
        System`TradingChartDump`$opens$545627 = 
        Dispatch[{
         1 -> 28.37`4., 2 -> 28.61`4., 3 -> 28.87`4., 4 -> 28.61`4., 5 -> 
          28.71`4., 6 -> 28.35`4., 7 -> 28.66`4., 8 -> 29.11`4., 9 -> 
          29.19`4., 10 -> 29.31`4., 11 -> 29.49`4., 12 -> 29.6`4., 13 -> 
          29.45`4., 14 -> 29.6`4., 15 -> 29.41`4., 16 -> 29.66`4., 17 -> 
          30.2`4., 18 -> 30.11`4., 19 -> 30.05`4., 20 -> 29.88`4., 21 -> 
          29.69`4., 22 -> 29.55`4., 23 -> 30.21`4., 24 -> 29.99`4., 25 -> 
          29.94`4., 26 -> 29.83`4., 27 -> 29.9`4., 28 -> 29.75`4., 29 -> 
          29.52`4., 30 -> 29.79`4., 31 -> 30.32`4., 32 -> 30.12`4., 33 -> 
          29.98`4., 34 -> 30.23`4., 35 -> 30.17`4., 36 -> 30.29`4., 37 -> 
          30.47`4., 38 -> 30.38`4., 39 -> 30.37`4., 40 -> 30.23`4., 41 -> 
          30.7`4., 42 -> 30.28`4., 43 -> 30.24`4., 44 -> 29.58`4., 45 -> 
          29.47`4., 46 -> 29.48`4., 47 -> 29.12`4., 48 -> 28.99`4., 49 -> 
          29.06`4., 50 -> 29.27`4., 51 -> 29.53`4., 52 -> 28.95`4., 53 -> 
          28.99`4., 54 -> 28.48`4., 55 -> 28.54`4., 56 -> 28.3`4., 57 -> 
          28.69`4., 58 -> 28.77`4., 59 -> 28.63`4., 60 -> 28.97`4., 61 -> 
          28.38`4., 62 -> 28.06`4., 63 -> 27.13`4., 64 -> 27.5`4., 65 -> 
          27.53`4., 66 -> 27.22`4., 67 -> 27.89`4., 68 -> 28.18`4., 69 -> 
          28.91`4., 70 -> 28.93`4., 71 -> 29.13`4., 72 -> 28.85`4., 73 -> 
          28.44`4., 74 -> 28.21`4., 75 -> 28.27`4., 76 -> 26.61`4., 77 -> 
          26.82`4., 78 -> 26.48`4., 79 -> 26.27`4., 80 -> 26.4`4., 81 -> 
          26.36`4., 82 -> 26.3`4., 83 -> 26.82`4., 84 -> 27.13`4., 85 -> 
          26.95`4., 86 -> 26.61`4., 87 -> 26.7`4., 88 -> 26.64`4., 89 -> 
          26.37`4., 90 -> 26.1`4., 91 -> 25.98`4., 92 -> 26.41`4., 93 -> 
          26.41`4., 94 -> 26.16`4., 95 -> 26.64`4., 96 -> 27.12`4., 97 -> 
          26.91`4., 98 -> 26.7`4., 99 -> 26.38`4., 100 -> 26.83`4., 101 -> 
          27.27`4., 102 -> 26.94`4., 103 -> 27.04`4., 104 -> 26.79`4., 105 -> 
          26.62`4., 106 -> 26.48`4., 107 -> 26.31`4., 108 -> 26.19`4., 109 -> 
          26.84`4., 110 -> 27.21`4., 111 -> 26.86`4., 112 -> 26.37`4., 113 -> 
          26.35`4., 114 -> 26.32`4., 115 -> 26.25`4., 116 -> 26.09`4., 117 -> 
          26.49`4., 118 -> 26.43`4., 119 -> 26.74`4., 120 -> 26.78`4., 121 -> 
          26.69`4., 122 -> 26.89`4., 123 -> 26.79`4., 124 -> 27.28`4., 125 -> 
          27.16`4., 126 -> 27.59`4., 127 -> 27.4`4., 128 -> 27.59`4., 129 -> 
          27.37`4., 130 -> 27.25`4., 131 -> 27.45`4., 132 -> 27.2`4., 133 -> 
          26.97`4., 134 -> 26.94`4., 135 -> 26.93`4., 136 -> 27.23`4., 137 -> 
          27.46`4., 138 -> 27.51`4., 139 -> 27.5`4., 140 -> 27.62`4., 141 -> 
          27.68`4., 142 -> 27.94`4., 143 -> 27.55`4., 144 -> 27.49`4., 145 -> 
          27.78`4., 146 -> 27.19`4., 147 -> 27.23`4., 148 -> 27.69`4., 149 -> 
          27.53`4., 150 -> 27.65`4., 151 -> 28.09`4., 152 -> 28.01`4., 153 -> 
          27.91`4., 154 -> 28.06`4., 155 -> 27.75`4., 156 -> 27.65`4., 157 -> 
          27.68`4., 158 -> 27.8`4., 159 -> 27.83`4., 160 -> 27.68`4., 161 -> 
          27.92`4., 162 -> 28.14`4., 163 -> 27.91`4., 164 -> 27.99`4., 165 -> 
          28.1`4., 166 -> 28.04`4., 167 -> 27.94`4., 168 -> 28.12`4., 169 -> 
          28.44`4., 170 -> 28.39`4., 171 -> 28.55`4., 172 -> 28.19`4., 173 -> 
          28.02`4., 174 -> 28.53`4., 175 -> 28.53`4., 176 -> 29.36`4., 177 -> 
          28.9`4., 178 -> 28.65`4., 179 -> 28.45`4., 180 -> 28.7`4., 181 -> 
          28.65`4., 182 -> 28.75`4., 183 -> 29.41`4., 184 -> 30.09`4., 185 -> 
          30.49`4., 186 -> 30.41`4., 187 -> 31.49`4., 188 -> 31.68`4., 189 -> 
          31.58`4., 190 -> 32.33`4., 191 -> 32.7`4., 192 -> 32.4`4., 193 -> 
          33.`4., 194 -> 33.18`4., 195 -> 33.42`4., 196 -> 32.84`4., 197 -> 
          32.62`4., 198 -> 32.44`4., 199 -> 32.38`4., 200 -> 32.86`4., 201 -> 
          33.45`4., 202 -> 33.64`4., 203 -> 34.13`4., 204 -> 34.73`4., 205 -> 
          35.1`4., 206 -> 34.79`4., 207 -> 34.23`4., 208 -> 33.92`4., 209 -> 
          34.42`4., 210 -> 34.74`4., 211 -> 34.85`4., 212 -> 34.82`4., 213 -> 
          34.92`4., 214 -> 35.62`4., 215 -> 34.6`4., 216 -> 34.84`4., 217 -> 
          35.25`4., 218 -> 35.51`4., 219 -> 35.05`4., 220 -> 35.14`4., 221 -> 
          34.99`4., 222 -> 34.55`4., 223 -> 34.69`4., 224 -> 34.97`4., 225 -> 
          34.96`4., 226 -> 34.26`4., 227 -> 33.66`4., 228 -> 32.94`4., 229 -> 
          34.08`4., 230 -> 34.12`4., 231 -> 34.52`4., 232 -> 34.38`4., 233 -> 
          34.75`4., 234 -> 34.41`4., 235 -> 33.66`4., 236 -> 34.09`4., 237 -> 
          34.35`4., 238 -> 34.58`4., 239 -> 34.34`4., 240 -> 35.`4., 241 -> 
          35.58`4., 242 -> 35.66`4., 243 -> 36.01`4., 244 -> 36.34`4., 245 -> 
          35.72`4., 246 -> 32.4`4., 247 -> 31.7`4., 248 -> 31.91`4., 249 -> 
          32.04`4., 250 -> 31.62`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$545627 = 
        Dispatch[{
         1 -> 28.63`4., 2 -> 28.97`4., 3 -> 28.93`4., 4 -> 28.83`4., 5 -> 
          28.77`4., 6 -> 28.66`4., 7 -> 29.05`4., 8 -> 29.22`4., 9 -> 
          29.46`4., 10 -> 29.57`4., 11 -> 29.75`4., 12 -> 29.71`4., 13 -> 
          29.56`4., 14 -> 29.68`4., 15 -> 29.58`4., 16 -> 30.23`4., 17 -> 
          30.2`4., 18 -> 30.14`4., 19 -> 30.25`4., 20 -> 30.04`4., 21 -> 
          29.7`4., 22 -> 29.92`4., 23 -> 30.24`4., 24 -> 30.09`4., 25 -> 
          30.04`4., 26 -> 29.9`4., 27 -> 30.25`4., 28 -> 29.95`4., 29 -> 
          29.83`4., 30 -> 30.63`4., 31 -> 30.35`4., 32 -> 30.19`4., 33 -> 
          30.2`4., 34 -> 30.46`4., 35 -> 30.45`4., 36 -> 30.53`4., 37 -> 
          30.54`4., 38 -> 30.49`4., 39 -> 30.47`4., 40 -> 30.75`4., 41 -> 
          30.88`4., 42 -> 30.35`4., 43 -> 30.29`4., 44 -> 29.89`4., 45 -> 
          29.69`4., 46 -> 29.56`4., 47 -> 29.29`4., 48 -> 29.19`4., 49 -> 
          29.3`4., 50 -> 29.33`4., 51 -> 29.55`4., 52 -> 29.23`4., 53 -> 
          29.05`4., 54 -> 28.63`4., 55 -> 28.57`4., 56 -> 28.64`4., 57 -> 
          29.04`4., 58 -> 29.05`4., 59 -> 28.96`4., 60 -> 29.04`4., 61 -> 
          28.41`4., 62 -> 28.16`4., 63 -> 27.55`4., 64 -> 27.54`4., 65 -> 
          27.54`4., 66 -> 27.69`4., 67 -> 28.21`4., 68 -> 28.88`4., 69 -> 
          29.08`4., 70 -> 29.05`4., 71 -> 29.5`4., 72 -> 29.14`4., 73 -> 
          28.69`4., 74 -> 28.51`4., 75 -> 28.34`4., 76 -> 26.89`4., 77 -> 
          26.87`4., 78 -> 26.57`4., 79 -> 26.3`4., 80 -> 26.4`4., 81 -> 
          26.4`4., 82 -> 26.76`4., 83 -> 27.35`4., 84 -> 27.17`4., 85 -> 
          26.97`4., 86 -> 26.98`4., 87 -> 26.94`4., 88 -> 26.72`4., 89 -> 
          26.41`4., 90 -> 26.23`4., 91 -> 26.53`4., 92 -> 26.58`4., 93 -> 
          26.41`4., 94 -> 26.56`4., 95 -> 27.08`4., 96 -> 27.2`4., 97 -> 
          27.1`4., 98 -> 26.72`4., 99 -> 26.81`4., 100 -> 27.21`4., 101 -> 
          27.31`4., 102 -> 27.26`4., 103 -> 27.08`4., 104 -> 26.84`4., 105 -> 
          26.78`4., 106 -> 26.68`4., 107 -> 26.49`4., 108 -> 26.37`4., 109 -> 
          27.31`4., 110 -> 27.23`4., 111 -> 26.93`4., 112 -> 26.48`4., 113 -> 
          26.39`4., 114 -> 26.35`4., 115 -> 26.57`4., 116 -> 26.52`4., 117 -> 
          26.67`4., 118 -> 26.88`4., 119 -> 26.82`4., 120 -> 27.06`4., 121 -> 
          26.88`4., 122 -> 27.04`4., 123 -> 27.22`4., 124 -> 27.64`4., 125 -> 
          27.8`4., 126 -> 27.81`4., 127 -> 27.71`4., 128 -> 27.76`4., 129 -> 
          27.55`4., 130 -> 27.63`4., 131 -> 27.6`4., 132 -> 27.24`4., 133 -> 
          27.13`4., 134 -> 26.98`4., 135 -> 27.29`4., 136 -> 27.5`4., 137 -> 
          27.58`4., 138 -> 27.69`4., 139 -> 27.64`4., 140 -> 27.74`4., 141 -> 
          27.89`4., 142 -> 28.01`4., 143 -> 27.55`4., 144 -> 27.57`4., 145 -> 
          27.86`4., 146 -> 27.41`4., 147 -> 27.81`4., 148 -> 27.78`4., 149 -> 
          27.79`4., 150 -> 27.95`4., 151 -> 28.34`4., 152 -> 28.03`4., 153 -> 
          28.08`4., 154 -> 28.14`4., 155 -> 27.78`4., 156 -> 27.76`4., 157 -> 
          27.83`4., 158 -> 27.96`4., 159 -> 27.96`4., 160 -> 28.08`4., 161 -> 
          28.02`4., 162 -> 28.29`4., 163 -> 28.16`4., 164 -> 28.14`4., 165 -> 
          28.15`4., 166 -> 28.14`4., 167 -> 28.25`4., 168 -> 28.46`4., 169 -> 
          28.46`4., 170 -> 28.65`4., 171 -> 28.75`4., 172 -> 28.41`4., 173 -> 
          28.58`4., 174 -> 28.53`4., 175 -> 29.61`4., 176 -> 30.11`4., 177 -> 
          29.`4., 178 -> 28.82`4., 179 -> 28.78`4., 180 -> 28.94`4., 181 -> 
          28.84`4., 182 -> 28.78`4., 183 -> 30.03`4., 184 -> 30.97`4., 185 -> 
          30.69`4., 186 -> 31.7`4., 187 -> 32.61`4., 188 -> 31.76`4., 189 -> 
          32.45`4., 190 -> 32.88`4., 191 -> 32.85`4., 192 -> 32.94`4., 193 -> 
          33.29`4., 194 -> 33.67`4., 195 -> 33.56`4., 196 -> 33.01`4., 197 -> 
          32.77`4., 198 -> 32.49`4., 199 -> 32.84`4., 200 -> 33.53`4., 201 -> 
          33.9`4., 202 -> 34.15`4., 203 -> 34.87`4., 204 -> 35.1`4., 205 -> 
          35.27`4., 206 -> 34.84`4., 207 -> 34.55`4., 208 -> 34.28`4., 209 -> 
          35.18`4., 210 -> 35.02`4., 211 -> 35.25`4., 212 -> 35.28`4., 213 -> 
          35.63`4., 214 -> 35.74`4., 215 -> 34.89`4., 216 -> 35.11`4., 217 -> 
          35.78`4., 218 -> 35.65`4., 219 -> 35.18`4., 220 -> 35.27`4., 221 -> 
          35.02`4., 222 -> 34.69`4., 223 -> 35.16`4., 224 -> 35.17`4., 225 -> 
          35.09`4., 226 -> 34.33`4., 227 -> 33.73`4., 228 -> 34.2`4., 229 -> 
          34.38`4., 230 -> 34.48`4., 231 -> 34.78`4., 232 -> 34.79`4., 233 -> 
          34.99`4., 234 -> 34.44`4., 235 -> 34.37`4., 236 -> 34.24`4., 237 -> 
          34.59`4., 238 -> 34.6`4., 239 -> 34.81`4., 240 -> 35.77`4., 241 -> 
          35.73`4., 242 -> 36.22`4., 243 -> 36.43`4., 244 -> 36.39`4., 245 -> 
          35.89`4., 246 -> 32.67`4., 247 -> 32.01`4., 248 -> 32.04`4., 249 -> 
          32.19`4., 250 -> 31.65`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$545627 = 
        Dispatch[{
         1 -> 28.23`4., 2 -> 28.32`4., 3 -> 28.59`4., 4 -> 28.46`4., 5 -> 
          28.35`4., 6 -> 28.12`4., 7 -> 28.61`4., 8 -> 28.92`4., 9 -> 
          28.99`4., 10 -> 29.22`4., 11 -> 29.41`4., 12 -> 29.36`4., 13 -> 
          29.27`4., 14 -> 29.31`4., 15 -> 29.32`4., 16 -> 29.56`4., 17 -> 
          29.88`4., 18 -> 29.87`4., 19 -> 29.9`4., 20 -> 29.76`4., 21 -> 
          29.38`4., 22 -> 29.48`4., 23 -> 29.88`4., 24 -> 29.81`4., 25 -> 
          29.73`4., 26 -> 29.52`4., 27 -> 29.68`4., 28 -> 29.46`4., 29 -> 
          29.51`4., 30 -> 29.75`4., 31 -> 30.02`4., 32 -> 29.8`4., 33 -> 
          29.9`4., 34 -> 30.02`4., 35 -> 29.69`4., 36 -> 30.1`4., 37 -> 
          30.32`4., 38 -> 30.31`4., 39 -> 30.32`4., 40 -> 30.19`4., 41 -> 
          30.37`4., 42 -> 29.93`4., 43 -> 29.66`4., 44 -> 29.34`4., 45 -> 
          29.2`4., 46 -> 29.05`4., 47 -> 28.74`4., 48 -> 28.81`4., 49 -> 
          28.98`4., 50 -> 28.88`4., 51 -> 29.05`4., 52 -> 28.87`4., 53 -> 
          28.5`4., 54 -> 28.28`4., 55 -> 28.2`4., 56 -> 28.13`4., 57 -> 
          28.58`4., 58 -> 28.64`4., 59 -> 28.42`4., 60 -> 28.59`4., 61 -> 
          27.84`4., 62 -> 27.18`4., 63 -> 27.12`4., 64 -> 27.22`4., 65 -> 
          27.21`4., 66 -> 27.2`4., 67 -> 27.84`4., 68 -> 28.16`4., 69 -> 
          28.65`4., 70 -> 28.65`4., 71 -> 28.93`4., 72 -> 28.38`4., 73 -> 
          28.13`4., 74 -> 28.14`4., 75 -> 27.56`4., 76 -> 26.35`4., 77 -> 
          26.39`4., 78 -> 26.23`4., 79 -> 25.94`4., 80 -> 26.07`4., 81 -> 
          26.06`4., 82 -> 26.26`4., 83 -> 26.79`4., 84 -> 26.76`4., 85 -> 
          26.63`4., 86 -> 26.37`4., 87 -> 26.45`4., 88 -> 26.09`4., 89 -> 
          26.`4., 90 -> 25.94`4., 91 -> 25.87`4., 92 -> 26.21`4., 93 -> 
          25.97`4., 94 -> 26.12`4., 95 -> 26.64`4., 96 -> 26.67`4., 97 -> 
          26.54`4., 98 -> 26.29`4., 99 -> 26.28`4., 100 -> 26.73`4., 101 -> 
          26.84`4., 102 -> 26.74`4., 103 -> 26.6`4., 104 -> 26.59`4., 105 -> 
          26.29`4., 106 -> 26.17`4., 107 -> 26.15`4., 108 -> 25.98`4., 109 -> 
          26.74`4., 110 -> 26.75`4., 111 -> 26.33`4., 112 -> 26.24`4., 113 -> 
          26.06`4., 114 -> 26.16`4., 115 -> 25.89`4., 116 -> 25.88`4., 117 -> 
          26.35`4., 118 -> 26.43`4., 119 -> 26.6`4., 120 -> 26.65`4., 121 -> 
          26.63`4., 122 -> 26.59`4., 123 -> 26.79`4., 124 -> 27.05`4., 125 -> 
          26.98`4., 126 -> 27.34`4., 127 -> 27.19`4., 128 -> 27.34`4., 129 -> 
          26.99`4., 130 -> 27.14`4., 131 -> 27.01`4., 132 -> 26.94`4., 133 -> 
          26.84`4., 134 -> 26.69`4., 135 -> 26.89`4., 136 -> 27.09`4., 137 -> 
          27.33`4., 138 -> 27.46`4., 139 -> 27.45`4., 140 -> 27.46`4., 141 -> 
          27.6`4., 142 -> 27.64`4., 143 -> 27.04`4., 144 -> 27.29`4., 145 -> 
          27.18`4., 146 -> 27.15`4., 147 -> 27.14`4., 148 -> 27.55`4., 149 -> 
          27.33`4., 150 -> 27.5`4., 151 -> 27.96`4., 152 -> 27.58`4., 153 -> 
          27.81`4., 154 -> 27.77`4., 155 -> 27.48`4., 156 -> 27.45`4., 157 -> 
          27.56`4., 158 -> 27.73`4., 159 -> 27.78`4., 160 -> 27.61`4., 161 -> 
          27.83`4., 162 -> 27.98`4., 163 -> 27.85`4., 164 -> 27.9`4., 165 -> 
          27.76`4., 166 -> 27.91`4., 167 -> 27.88`4., 168 -> 28.06`4., 169 -> 
          28.16`4., 170 -> 28.32`4., 171 -> 28.34`4., 172 -> 28.07`4., 173 -> 
          27.91`4., 174 -> 28.27`4., 175 -> 28.48`4., 176 -> 29.32`4., 177 -> 
          28.53`4., 178 -> 28.46`4., 179 -> 28.31`4., 180 -> 28.5`4., 181 -> 
          28.4`4., 182 -> 28.3`4., 183 -> 29.4`4., 184 -> 30.06`4., 185 -> 
          30.17`4., 186 -> 30.39`4., 187 -> 31.32`4., 188 -> 31.23`4., 189 -> 
          31.55`4., 190 -> 32.06`4., 191 -> 32.37`4., 192 -> 32.17`4., 193 -> 
          32.85`4., 194 -> 33.01`4., 195 -> 33.01`4., 196 -> 32.42`4., 197 -> 
          32.36`4., 198 -> 32.09`4., 199 -> 32.32`4., 200 -> 32.8`4., 201 -> 
          33.43`4., 202 -> 33.55`4., 203 -> 34.1`4., 204 -> 34.68`4., 205 -> 
          34.72`4., 206 -> 34.36`4., 207 -> 33.9`4., 208 -> 33.9`4., 209 -> 
          34.41`4., 210 -> 34.57`4., 211 -> 34.81`4., 212 -> 34.79`4., 213 -> 
          34.83`4., 214 -> 34.77`4., 215 -> 34.43`4., 216 -> 34.49`4., 217 -> 
          35.06`4., 218 -> 35.14`4., 219 -> 34.68`4., 220 -> 34.85`4., 221 -> 
          34.59`4., 222 -> 34.25`4., 223 -> 34.63`4., 224 -> 34.9`4., 225 -> 
          34.59`4., 226 -> 33.37`4., 227 -> 33.05`4., 228 -> 32.57`4., 229 -> 
          33.46`4., 230 -> 33.89`4., 231 -> 34.5`4., 232 -> 34.34`4., 233 -> 
          34.33`4., 234 -> 33.63`4., 235 -> 33.6`4., 236 -> 33.58`4., 237 -> 
          33.98`4., 238 -> 34.14`4., 239 -> 34.32`4., 240 -> 34.9`4., 241 -> 
          35.28`4., 242 -> 35.58`4., 243 -> 35.96`4., 244 -> 35.49`4., 245 -> 
          35.22`4., 246 -> 31.02`4., 247 -> 31.6`4., 248 -> 31.71`4., 249 -> 
          31.89`4., 250 -> 31.25`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$545627 = 
        Dispatch[{
         1 -> 28.3`4., 2 -> 28.88`4., 3 -> 28.76`4., 4 -> 28.6`4., 5 -> 
          28.54`4., 6 -> 28.33`4., 7 -> 28.87`4., 8 -> 29.06`4., 9 -> 
          29.37`4., 10 -> 29.43`4., 11 -> 29.6`4., 12 -> 29.52`4., 13 -> 
          29.49`4., 14 -> 29.43`4., 15 -> 29.5`4., 16 -> 30.07`4., 17 -> 
          30.18`4., 18 -> 30.03`4., 19 -> 30.09`4., 20 -> 29.83`4., 21 -> 
          29.56`4., 22 -> 29.85`4., 23 -> 29.98`4., 24 -> 29.92`4., 25 -> 
          29.94`4., 26 -> 29.62`4., 27 -> 30.11`4., 28 -> 29.69`4., 29 -> 
          29.69`4., 30 -> 30.62`4., 31 -> 30.23`4., 32 -> 30.01`4., 33 -> 
          30.08`4., 34 -> 30.07`4., 35 -> 30.22`4., 36 -> 30.49`4., 37 -> 
          30.49`4., 38 -> 30.46`4., 39 -> 30.33`4., 40 -> 30.72`4., 41 -> 
          30.47`4., 42 -> 30.07`4., 43 -> 29.69`4., 44 -> 29.47`4., 45 -> 
          29.46`4., 46 -> 29.07`4., 47 -> 28.81`4., 48 -> 28.97`4., 49 -> 
          29.17`4., 50 -> 29.33`4., 51 -> 29.16`4., 52 -> 29.09`4., 53 -> 
          28.6`4., 54 -> 28.31`4., 55 -> 28.28`4., 56 -> 28.52`4., 57 -> 
          28.83`4., 58 -> 28.81`4., 59 -> 28.91`4., 60 -> 28.82`4., 61 -> 
          27.98`4., 62 -> 27.35`4., 63 -> 27.4`4., 64 -> 27.25`4., 65 -> 
          27.23`4., 66 -> 27.56`4., 67 -> 27.88`4., 68 -> 28.84`4., 69 -> 
          28.82`4., 70 -> 28.94`4., 71 -> 29.17`4., 72 -> 28.41`4., 73 -> 
          28.14`4., 74 -> 28.16`4., 75 -> 27.57`4., 76 -> 26.68`4., 77 -> 
          26.43`4., 78 -> 26.26`4., 79 -> 26.12`4., 80 -> 26.33`4., 81 -> 
          26.31`4., 82 -> 26.54`4., 83 -> 27.28`4., 84 -> 26.98`4., 85 -> 
          26.67`4., 86 -> 26.95`4., 87 -> 26.54`4., 88 -> 26.22`4., 89 -> 
          26.03`4., 90 -> 25.97`4., 91 -> 26.27`4., 92 -> 26.33`4., 93 -> 
          26.06`4., 94 -> 26.53`4., 95 -> 26.91`4., 96 -> 26.83`4., 97 -> 
          26.7`4., 98 -> 26.4`4., 99 -> 26.69`4., 100 -> 27.14`4., 101 -> 
          26.9`4., 102 -> 27.26`4., 103 -> 27.04`4., 104 -> 26.65`4., 105 -> 
          26.45`4., 106 -> 26.55`4., 107 -> 26.15`4., 108 -> 26.31`4., 109 -> 
          27.2`4., 110 -> 26.84`4., 111 -> 26.34`4., 112 -> 26.29`4., 113 -> 
          26.15`4., 114 -> 26.3`4., 115 -> 26.06`4., 116 -> 26.42`4., 117 -> 
          26.48`4., 118 -> 26.8`4., 119 -> 26.63`4., 120 -> 26.84`4., 121 -> 
          26.84`4., 122 -> 26.74`4., 123 -> 27.19`4., 124 -> 27.21`4., 125 -> 
          27.46`4., 126 -> 27.49`4., 127 -> 27.59`4., 128 -> 27.43`4., 129 -> 
          27.04`4., 130 -> 27.51`4., 131 -> 27.03`4., 132 -> 27.08`4., 133 -> 
          26.93`4., 134 -> 26.87`4., 135 -> 27.13`4., 136 -> 27.44`4., 137 -> 
          27.46`4., 138 -> 27.61`4., 139 -> 27.62`4., 140 -> 27.59`4., 141 -> 
          27.85`4., 142 -> 27.68`4., 143 -> 27.3`4., 144 -> 27.57`4., 145 -> 
          27.18`4., 146 -> 27.18`4., 147 -> 27.62`4., 148 -> 27.61`4., 149 -> 
          27.76`4., 150 -> 27.95`4., 151 -> 28.15`4., 152 -> 27.89`4., 153 -> 
          27.94`4., 154 -> 27.81`4., 155 -> 27.68`4., 156 -> 27.72`4., 157 -> 
          27.73`4., 158 -> 27.94`4., 159 -> 27.84`4., 160 -> 27.9`4., 161 -> 
          27.98`4., 162 -> 28.12`4., 163 -> 27.91`4., 164 -> 28.05`4., 165 -> 
          27.96`4., 166 -> 27.96`4., 167 -> 28.17`4., 168 -> 28.41`4., 169 -> 
          28.41`4., 170 -> 28.6`4., 171 -> 28.36`4., 172 -> 28.4`4., 173 -> 
          28.5`4., 174 -> 28.39`4., 175 -> 29.4`4., 176 -> 30.07`4., 177 -> 
          28.74`4., 178 -> 28.59`4., 179 -> 28.49`4., 180 -> 28.77`4., 181 -> 
          28.63`4., 182 -> 28.59`4., 183 -> 29.56`4., 184 -> 30.62`4., 185 -> 
          30.39`4., 186 -> 31.54`4., 187 -> 31.72`4., 188 -> 31.57`4., 189 -> 
          32.38`4., 190 -> 32.87`4., 191 -> 32.49`4., 192 -> 32.93`4., 193 -> 
          33.26`4., 194 -> 33.51`4., 195 -> 33.08`4., 196 -> 32.76`4., 197 -> 
          32.43`4., 198 -> 32.46`4., 199 -> 32.8`4., 200 -> 33.53`4., 201 -> 
          33.85`4., 202 -> 34.08`4., 203 -> 34.87`4., 204 -> 35.08`4., 205 -> 
          34.85`4., 206 -> 34.61`4., 207 -> 34.15`4., 208 -> 34.27`4., 209 -> 
          35.02`4., 210 -> 34.88`4., 211 -> 35.03`4., 212 -> 34.9`4., 213 -> 
          35.59`4., 214 -> 34.99`4., 215 -> 34.78`4., 216 -> 34.96`4., 217 -> 
          35.67`4., 218 -> 35.47`4., 219 -> 34.84`4., 220 -> 35.`4., 221 -> 
          34.72`4., 222 -> 34.4`4., 223 -> 35.`4., 224 -> 34.98`4., 225 -> 
          34.59`4., 226 -> 33.49`4., 227 -> 33.27`4., 228 -> 33.72`4., 229 -> 
          33.67`4., 230 -> 34.35`4., 231 -> 34.62`4., 232 -> 34.54`4., 233 -> 
          34.36`4., 234 -> 33.94`4., 235 -> 34.01`4., 236 -> 34.21`4., 237 -> 
          34.33`4., 238 -> 34.35`4., 239 -> 34.7`4., 240 -> 35.69`4., 241 -> 
          35.67`4., 242 -> 36.17`4., 243 -> 36.27`4., 244 -> 35.74`4., 245 -> 
          35.44`4., 246 -> 31.4`4., 247 -> 32.01`4., 248 -> 31.82`4., 249 -> 
          31.96`4., 250 -> 31.39`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$545627 = True, 
        System`TradingChartDump`$gridlines$545627 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$545627, 
        System`TradingChartDump`$plotrangemin$545627 = 25.337956692913384`, 
        System`TradingChartDump`$plotrangemax$545627 = 37.48638507686539, 
        System`TradingChartDump`$layoutData$545627, 
        System`TradingChartDump`$gridlinesscope$545627 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$545627 = {True, True}, 
        System`TradingChartDump`$indicators$545627 = {
         FinancialIndicator["FastStochastic", 14, 3]}, 
        System`TradingChartDump`$mouseQ$545627 = False, 
        System`TradingChartDump`$modelData$545627 = 
        System`TradingChartDump`modelData$542986, 
        System`TradingChartDump`$sy$545627 = Identity, 
        System`TradingChartDump`$isy$545627 = Identity, 
        System`TradingChartDump`$appearance$545627 = Automatic, 
        System`TradingChartDump`$perfgoal$545627 = "Quality", 
        System`TradingChartDump`$axesorigin$545627 = Automatic, 
        System`TradingChartDump`$framestyle$545627 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$545627 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$545627 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$545627 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$545627 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$545627, 
        System`TradingChartDump`$newgridlines$545627 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{25.337956692913384`, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$545627 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$545627 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$545627 = "GraphicsFrame", 
        System`TradingChartDump`$frame$545627 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$545627 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$545627 = 
              Switch[System`TradingChartDump`$highlightposition$545627, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$545627], {
                 1, System`TradingChartDump`$length$545627}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$545627], {
                 1, System`TradingChartDump`$length$545627}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$545627, 
                   Charting`nearestDate[System`TradingChartDump`$dates$545627, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$545627]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$545627]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$545627, 
                    Floor[System`TradingChartDump`$controlmin$545627] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$545627, 
                    Floor[System`TradingChartDump`$controlmax$545627]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$545627 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$545627 = 
            If[System`TradingChartDump`$fastpos$545627 =!= True, 
              System`TradingChartDump`$fastpos$545627 = 
               Clip[System`TradingChartDump`$fastpos$545627, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$545627 = (
                  Floor[System`TradingChartDump`$controlmax$545627] - Floor[
                  System`TradingChartDump`$controlmin$545627]) (
                  System`TradingChartDump`$fastpos$545627/100) + 
                Floor[System`TradingChartDump`$controlmin$545627]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$545627], {
                Floor[System`TradingChartDump`$controlmin$545627] + 1, 
                 Floor[System`TradingChartDump`$controlmax$545627]}], 
              System`TradingChartDump`$staticindicatorpos$545627]; 
           System`TradingChartDump`$mouseQ$545627 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$545627]], 
              System`TradingChartDump`$highlightposition$545627 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$545627 = If[
              And[
              System`TradingChartDump`$bouncingballQ$545627, 
               System`TradingChartDump`$mouseQ$545627, 
               System`TradingChartDump`$appearance$545627 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$545627[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$545627]]], {}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$545627[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$545627, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$545627[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$545627]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$545627[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$545627[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545627, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545627[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545627, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545627, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545627[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545627[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$545627 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$545627, 
                 System`TradingChartDump`$defaultframeticksstyle$545627, 
                 System`TradingChartDump`$defaultlabelstyle$545627, 
                 System`TradingChartDump`$framestyle$545627, 
                 System`TradingChartDump`$frameticksstyle$545627, 
                 System`TradingChartDump`$labelstyle$545627}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545627 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$545627, 
                 System`TradingChartDump`$labelstyle$545627, 
                 System`TradingChartDump`$defaultframeticksstyle$545627, 
                 System`TradingChartDump`$defaultlabelstyle$545627}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545627 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545627, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$545627 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545627, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$545627 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545627, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$545627 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$545627 = 
             Part[System`TradingChartDump`$tickstextstyle$545627, 1], 
             System`TradingChartDump`$tickstextstyle$545627 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545627[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545627, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545627[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545627[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545627[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$545627[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545627, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$545627]], 
                    Style[":", System`TradingChartDump`$textstyle$545627]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$545627[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545627]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545627[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$545627[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$545627, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$545627]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$545627[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545627, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545627[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545627, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545627, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$545627[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545627[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545627[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$545627[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$545627[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$545627], 1], 
                   Floor[System`TradingChartDump`$controlmax$545627]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$545627[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$545627[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$545627[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$545627[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$545627[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545627[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$545627[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$545627[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$545627[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545627[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$545627[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$545627[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$545627[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$545627[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$545627[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$545627, 
                  System`TradingChartDump`$mouseQ$545627], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$545627 - 0.5, 
                   System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$545627 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$545627 + 0.5, 
                    System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545627, 1]}, {
                    System`TradingChartDump`$indicatorpos$545627 + 0.5, 
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$545627[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$545627, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$545627[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545627]]], {}]; 
              System`TradingChartDump`$subplotgridlines$545627[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$545627[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$545627[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545627[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$545627 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$545627, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545627, 
                   System`TradingChartDump`$opens$545627]], 12, 
                 System`TradingChartDump`$textstyle$545627, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$545627, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545627, 
                   System`TradingChartDump`$highs$545627]], 12, 
                 System`TradingChartDump`$textstyle$545627, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$545627, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545627, 
                   System`TradingChartDump`$lows$545627]], 12, 
                 System`TradingChartDump`$textstyle$545627, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$545627, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545627, 
                   System`TradingChartDump`$closes$545627]], 12, 
                 System`TradingChartDump`$textstyle$545627, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545627, 
                   System`TradingChartDump`$visdates$545627]], 12, 
                 System`TradingChartDump`$textstyle$545627, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$545627, 
                  System`TradingChartDump`$mouseQ$545627], {{
                  System`TradingChartDump`$timestampstyle$545627, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$545627 - 0.5, 
                    System`TradingChartDump`$plotrangemin$545627}, 
                    If[
                    System`TradingChartDump`$timestampdepth$545627 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$545627[1]}, {
                    System`TradingChartDump`$indicatorpos$545627 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545627}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545627, 1]}, {
                    System`TradingChartDump`$indicatorpos$545627 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545627}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$545627, {
               System`TradingChartDump`$highlightstyle$545627, 
                Dynamic[System`TradingChartDump`$ohlcpoint$545627]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$545627[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545627, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$545627[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$545627[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$545627, Length[
                    System`TradingChartDump`$layoutData$545627[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$545627}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$545627] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$545627] + 0.5}, {
                System`TradingChartDump`$plotrangemin$545627, 
                 System`TradingChartDump`$plotrangemax$545627}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$545627, Left, {
                 False, System`TradingChartDump`$frame$545627}, 
                 Blank[], {System`TradingChartDump`$frame$545627, False}], {
                False, System`TradingChartDump`$frame$545627}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$545627, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$545627]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$545627 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           387.02286107677577`}, {-286.92264150943396`, -65.76792452830186}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545627 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545627, 1]], 
               Part[System`TradingChartDump`$framestyle$545627, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$545627]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$545627} -> 
                   System`TradingChartDump`$isy$545627[
                    System`TradingChartDump`$plotrangemin$545627], {
                    0, System`TradingChartDump`$plotrangemax$545627} -> 
                   System`TradingChartDump`$isy$545627[
                    System`TradingChartDump`$plotrangemax$545627]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$545627[
                   System`TradingChartDump`$plotrangemin$545627], 
                   System`TradingChartDump`$isy$545627[
                   System`TradingChartDump`$plotrangemax$545627]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$545627, 
                   System`TradingChartDump`$isy$545627}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545627, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545627 > 
                    System`TradingChartDump`$plotrangemin$545627, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545627 > 
                    System`TradingChartDump`$plotrangemin$545627, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545627, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545627 > 
                    System`TradingChartDump`$plotrangemin$545627, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545627 > 
                    System`TradingChartDump`$plotrangemin$545627, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545627, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545627, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545627 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545627,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545627], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545627 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545627, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545627]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$545627, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$545627[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$545627[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545627, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$545627[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$545627, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545627[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545627, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545627[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545627[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545627[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545627[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545627], 
                    Style[":", System`TradingChartDump`$textstyle$545627]], 
                    Style[":", System`TradingChartDump`$textstyle$545627]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$545627[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545627]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545627[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$545627}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$545627, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$545627 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$545627[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$545627, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$545627, Left, {
                    False, System`TradingChartDump`$frame$545627}, 
                    Blank[], {
                    System`TradingChartDump`$frame$545627, False}], {
                   System`TradingChartDump`$frame$545627, 
                    System`TradingChartDump`$frame$545627}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$545627, 
                    System`TradingChartDump`$controlmax$545627}] + 0.5, {
                   System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$545627]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$545627) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$545627 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$545627 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$545627, 1]], 
                   Part[System`TradingChartDump`$framestyle$545627, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$545627]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545627[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545627[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$545627[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545627, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545627, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$545627, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$545627, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$545627 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
545627, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$545627], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$545627 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$545627, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$545627]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$545627, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$545627) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$545627 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$545627[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           475.9407855006933}, {-55.989622641509435`, -0.7009433962264069}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$545627, 
              Dynamic[System`TradingChartDump`$ohlclabel$545627], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$545627}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545627 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545627, 2]], 
               Part[System`TradingChartDump`$framestyle$545627, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$545627]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$545627, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$545627, 
                    System`TradingChartDump`$controlmax$545627}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$545627] + 
                    0.5, System`TradingChartDump`$plotrangemin$545627}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$545627], 
                    System`TradingChartDump`$plotrangemin$545627}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$545627, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545627, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545627, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545627 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545627, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545627], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545627 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545627,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545627]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$545627] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$545627[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$545627] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$545627[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$545627] = {HoldPattern[
               System`TradingChartDump`$min$545627[1]] :> 0.9}}, {
          DownValues[System`TradingChartDump`$max$545627] = {HoldPattern[
               System`TradingChartDump`$max$545627[1]] :> 100.}}, {
          DownValues[System`TradingChartDump`$subplotvalue$545627] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$545627[1, 1]] :> 
             Invisible[6.84], HoldPattern[
               System`TradingChartDump`$subplotvalue$545627[1, 2]] :> 
             Invisible[13.]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$545627] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$545627[1]] :> {50, 
              100}}}, {
          DownValues[System`TradingChartDump`$layoutData$545627] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$545627["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "AllValues"]] :> CompressedData["
1:eJxVVgk8VVv7Fo1Cg6GuSlKZKhS5nb323uc5XE1mGZtHXEMpypdyQyFSEn2K
3DKkUkSoSKYGt+EWkUaEJhlKkhL1LZz+/f7rd87vnHevd73P8z5rve/aU9Zu
stkgKSEh0U2/fb9fF96IdiUsHuTfrTdJZOElI1+mZ81CY55fUHIXixsOryY+
OcyiNNoj3uQ9C4FrnXvFNhady3rfCB6yqLrj8nW/I4vxfwXffX6DRXWPdmHF
JBbLDXSSP51mMTuoeNDJeBaxF3Wrm2U5yAa5Xz/cwsLd7rKN8u8cEtx+H1zR
y0JBkY6tHNxsDddvpM/PHdtp/OwghxWr/WY0uXAIGzy7paaQg6mKzLzGpRwi
vGXV7l3k0PPAscT8Dw65Nh/Nqg5wyL7mVzvWioPFaLcv485zWHbh5sceGw4n
muYuGxTDYZS9zsvaSA4Hqmtd3gt4hHbezYl6waFFOuu0gj4PGRPzoLQ6Djls
9169qTwcVnp6Bb/h8Kh5w0I5IY8Ptz9LdpdymFjSE+8/kscfse0HHdfSeILQ
TysvcPCTKwyM8eOwueyfMOVmDiMXe5vW1XPg3V4nO/M8ilvNjKXKOaREbu0d
psQje90UJdUCDrZZCSdOjuARsPvHkIvBHIZefdnNU1zT6Dl/TsrgsF1yZ9JM
ij91+Bv/BB8Ork+sv2l/4uD7UFfh+G4OtZtH7DtVyUE+ZLyPbjGHJ94e7vMS
eThplV+vleIhdc4utcGRh1LGgnrpexwM9PX1o3V5zLoW6b6N4jh2ejz1n8Oj
LsPIwm0Ij7dSP0jnVh6DzbKGmGVxmNq2P9zWh0fWWc/vzr/xGNddFrc5lMcz
OYfwFhsecoZ7HreH0XyO6WkJrXj8XbueM/bnsVTb/1K3NQ+mgf7z5VF2a1/z
otk8ljw3XfGgiMfVBT1xlqt4CITaKcvqedQkXFR528ZB5b3ywS1LqX/1q5FT
z3A4POroV/1FPI6uPtR034GD0amAyMeNHD6/uBnCz+GgqGc4/SblOTz7gF6z
DAdvVresg56HlihZj6dXWciMs1zydhGH2Ohn463KWVyqdgyvms3hTchzqUE9
LIL/ym8dZsbh6uvtI3zrWchTnfxsqe3m4+VNz226Xfuc7xEclPc2GITUsIg7
05Elw3D49MBP/0gAC60vHcNPUNw77U/2PlvAoitfQ7qR1lPVu/Swc/osdvh/
e559iEWtXPVt5SksJil0vZqczOLZqqOaPtEs7oSPspQYwUE9/z8fHqWw6K1p
WtFAcesuddx+7U7rKOSyyLeThYcVvF7ReowMUXHaPJLyqZNJr3lEkBq7Kr7F
ldZt2+eJ43QJynpeXJ2uxULFeOSq+kkEEePmSzTtI4j7Fpq3ax6BzMzMYklq
V0taqtTPJbijc7ymMZzgel3cgQdzCL5U5uytO08wM+n08/k0fu1MrSQLQxZC
De1bXRosZKWdTUdSnUbtsTd0OcVibuuR5VsUKZ+TRxtOnGQRlefcMo3qsf2t
5OUftN6HaBn4RgRwEF3Y1O2zhkVbR6p52DQOXoqlzfZUD+P1gtya8ywaKnUC
OqdSPdsdPbuDaF+otxC5RxKETTPaEuDAwsHz/vZljgw89SyKhjYyaBl7RPHH
OgaznzjqBNcx+JJmVfadYWBy8kB2/kEGK95LX7drF6BO+W6dshkDdzMS+G4s
g5L3o4qnODOomOwdbD2agaXTmzFy1D41ujAk1ZhB0urHUjklDBr+Wdny9y0G
z1AgbetEsLfLU8flGoMP36Pzb2sTZAXErNyUyECr47pQs4tB6iuXdR4rKa/9
iyuudTN4/O1oW4Q3g0rTHPe4dgZKU1cYhY+jPGK7ZZovM8h941QySYJB3n4N
c0k3Bld+yztT8kGAtkWe5bUCBkZKhZ+u1AjwonN3cEYIg5v37/DzDBnMvXor
OziawUzpNMWzXwSYnDJtmypdf6HXo+bOJAao+8bykQy0LVVjX6QwiPq4K6NS
nqBxrsRHtXMMQt2j8kwNCIy2pA15Hs4gPrE+9pAyQUGR6/mzixl81m82GHOJ
gYZqtXrRfAafDnya9eoegxTjzes68xjcV5NO3UnPjXXFQxOTR1T37UsXW1gR
TH66y+pDAYNrnZrLI40IOo/Z5ZceYWDw/EreEgWCcSt8KkxiGRg+WR9tXs1g
2qCQXTUUL4qTsm76h8GmE6t9/LQZNOvNf3concEGZzrUGbTOPOSR+heDsWGB
x45/FWCURstGf6rzj0PL0nIpXklzVlibBUHmisBCx2IGFiE5814TgvDOzow9
tpSf/+wkhzYGq12KixI5Bit3uaWp+zE4w+QPyR3FYLne87Hv1jIo8M033KXF
QDppQ5CrE923RYu37XopQPm0lzm+hxi4TI9Wq3shQGvPmkP5exjE1kYETFjK
IPuGrXFZGtV9jOXKHg8GXsnaGV9eMAj2Ev556SiDgAKnSzoVlP+GzKIppyjv
rw+Z3XIE6hKtRUpJDDI9u1jVeuqnqJD1N9Unr2N5mMIIWpeR9yrm0/OXbD9F
yoDWbe9Mm9kesgSvErrGZKYQ2o/KM+bSc7axeFuC5D2CFSPezPjbgaDlcfIh
VWp/aG1ec4r2g93jNJLNcgkk48/qraPzr2XOnb93jeC/5SaHE3sZaCo/V1+1
n9Z7YcOMQjUC2QMu7hUnCG57lbYnSRIEHV8l1X6UoHJeWZcuPcfLb3r8Vc4S
mCVrZq2l+y+/M0dltyrBFBtFNbssBh8tNN77UF6taiUPbr5koLs68XDCIoLv
rYH7axUJlnaeuHx9F8En2TTBN1uCGDtL18ExBJ8vZT2z20b5nWtdYJdJMHzm
WIWn3gQrl4hcryUT6FrD0ojOb8qJYWsKCOL/CXKXiyNIsTV1ut5IYDLKrOkt
9Rvt9KH52yAWJwMOz82WJjBesDFyWQRB1Yj24VcWEyy5rBLcHEXQ1+YVdAjk
yz4f6XhKUG+7WsZHnZ7j/a70Q/vl4VWd6dMI2qL3Kw27T3B1Tdq5NzRO3OjQ
92vKaD35rtrC2BFYTpwhr3ebIN35z9CKANJ/v+p3EGwpt3dR/kzg1LN1wwV7
FjHR/4aOPExwNm5wiccwFtu7TC8eoXFd1+w9K1Bg8a5ELUjvBkFNqNGiP2gf
TJrVlcTsIMixrXYOpHjl8dGnz1I9jF+f3u1fSvDt6pTuU7Q/VhWpLLSoIvAf
Zj7e+ArV52sYn9dJILTdqnqbrpM2dvENp3b+sUYm8xhB8nb7ZnWKF5Eok1pM
16Vd2TJJZgjt5+ds5NW+EWRHBJS2LWIx//GF6NwnVKfAHXqBmiw+JTR9P/ua
YNJEu4XplN+8so3eLZSHR13mZ1l1FqHlq4fLNhFMNRhvtJvO97xPPvNvPcGE
9bLSz4QsinTyAntG0b7O49TZrVSPj8qmrlq/7AODd3a42bBItexOsUyl90a6
nrs87fuDzeukzItYdOTeKAkay0Ltx5JZ7fS+Y9/JGkq9IxBUqjrax7DwbR5a
YGfCQlLG/5VnKAvNiuJZkn4s3pa4LS2Lp+9/Tq7/zaXvhycnxJQpTeShHv9S
T3YvfT8NdeTDf7AI6r5U2Et5FFypvRdUwWJTT8P6DEsW2Rk7Y7XKWLyedV7T
j973WVVVLfYfWOydvbXrnjOLdCfV62nVLFyVeiqtzFnklurGOFD/FHW5lZnO
HKImfr9bNZTHHRul6fajecRc/5Ce20Xfz24NHfN2Bg+r3RebJmbyaEjdssB+
HQ/79/8efHdBiAhLNcUTNkJsvNw+NMoC2NE3iBCKKhp6glIhRLzVxZJ9Qnwp
GuYRJgC+ns+bMGUYsMFm+sFEL+DB45a7vrrA8PA3L7Z7AFnClgYtRWCCQcZJ
y/8Ag4dpjtHyBFytJb6MOwmov+L0CgKBiz098xMeAomnEvY4ULv3wcftojLq
P/cxGW0IIEMtSo4+L++ekDRNB1iUU/oaawF+jrnH05FApbqFSxYPxA0vW7hO
C/g9Q//7DnfAuX8AKV6c9KNrwKNk+ucSoN9fL+L5m2JbXoR/79IhI0JkKb1Q
NokG/B3EzyNEWN4/IRq4b5JE4noWocWaFri76P/Hnf/L7sefKoJC3wIDcdxY
EbT6Ai4UxwsSoS9chosIP/rGcRGCm2ngDaKB9ckijOhb6CZCv1kuXrdWhMl9
jrXiuL+LYNPXbzaLn/NingdEWNgXP1Qcr1HsFyXmWfkr35/8+vP2+JVvf56m
v/hK9A1VEfrCWDuKsLmPl5U4zxhxXG8RPlP30sO/1vf/7hPrfB6Q7gPUFg3o
FgL0hfGqgVgfuq9H6fhNhB19gfMxgKMn5t8u9ufEfCDOb50YZ8YvHX/i9Ovy
l5hvOQb4zxPnexcDvHTF/rcx4K8iGsDpxf/l0Y8/RrzOTLyfmmKdXX7l369X
w699HMjvZ3zxuZpoNJBf9899NBrALRTjzDYa8Dv2M29xXkOEA/raiXU6KkQf
/IJBGHieKxT7ic9ho3Ag3/EQ6yUc0D1ViP8BEj3RGg==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$545627["AppendedAdjust"]] :> 
             9.9096801397399, HoldPattern[
               System`TradingChartDump`$layoutData$545627["AppendedBox"]] :> {
              0.7677188122108538, 130.}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "AppendedMin"]] :> -4.051641467268945, HoldPattern[
               System`TradingChartDump`$layoutData$545627["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$545627["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$545627["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$545627["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545627["DataMax"]] :> 
             36.43, HoldPattern[
               System`TradingChartDump`$layoutData$545627["DataMin"]] :> 
             25.86614923134608, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "MainChartAllValues"]] :> CompressedData["
1:eJxdlglYzdv6x1OZ0mBocEISmtBAOvZv2t9dJ1NzGs1jdRqIoiuiolJSGtwo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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "MainChartPoints"]] :> CompressedData["
1:eJxdlltoXFUUhqdFUIKgYkSRUqdVSqylVGNtmzbJTmqaNEmTTO6XSXLmfp9U
pCiRyqFShCIEn0QRGS/4IhTBlyAqscUnKyIoVRCZIoiQIgWplD6Zk/V/D+cc
CMOftf/9r9tee+9Jr4zn7onFYne3/nbob2eM71b3D9e2vuETTv9wN1ZbL/ff
AN/nrt5uS65dAT/o3ns3+MCtruX6x2c7L4EfcwF7dRK8yz1xcTOx/gc47tau
bG34QKfwXrMvgZ9yAb21Dt4nPXCbC5bvvgje7zoDB86DD0T4B+3XBx9y41vs
zYe6hJ+19QfBz7mBIAH3gttdEF7Lo+DnLb6f2e+wxbMGfsH8/Q18xL0WEO6C
j7qbgfub4GPupSCAW+AOy8cH4OMuGQjsQv+Erf8ce2cEd4nP+m7T7wA7q+dO
Yd9ZPK3Ye8L58XtcABNHsfcq39gjOHbS/Re0yznsJ9UP2F+0/daxC7+KvS+i
3xeJ75TWC/unpIe9X3zs/VafH+m/AePfEfYHrB7PwD8tf+Gfdk9vFwD7oPoB
+2DkPAyZ3ij7D1k/9WMfVv9iH1Y/YT8T9tc/Y/p/Yx+x+H7CPqL+Oi77qPkz
J+yPuvz2h33Mfp2wG1N/sH5M/Sy8MaZ5AD9h8V+XvktE/Emon4U3EpH8jls8
Rfjj7pNguyfhy94Gf9z2fxv9CTuvlzvEF64L+xPW373CGxN2HnYLxyZVX/iT
qhf8Sc0z+JOqH/pTyjf8KYvvM/hTrj34/oU/Fd4vNq3zBH9a8wa+7HeOiT9t
/dIHfybi/4zmKfwZ2+9N9GfUP/Bn1W/wZ83fL+DPql/gz+r8wZ9TveifOVv/
F/w55Z/+mbP4W8jfvK3/FP15038Z/rzbvo/eQl/r96G/EK6XWzB+O/27oP6E
LzwDP2n+DMJPhvf3k6Y/DD8Zzm9s0epdgb9o/bAKf9H41+Av2vn5EP5S2D8X
wf6SzdOv4S9Z/g+Rv2Wbd4fJv/A54l/WPCb/y7b/O/A9nRfhuBeuj/OsfheE
PU/9yf6e7gvhhvb7B3893ffCTc/i34N+yuI5i34q7L9L2X33Pvop3Wfop8Lx
NFK6b4k3pfkg3Eypnuinw/Mkntb9j34Ee+mIfjrsXyOt9xH6aZ1/9NPqL+Z3
xs7Pn+hnNC/Rz2j+o58Jx+NndH+in7H++xL9yH7NjPqL+LM6r+hnw/eHy2pe
yl8vq/mBftbyeb/sjazV7zb6EdzMav4Tfy48/+MR7HLh+9TLWb6T3A85zSf0
c/o/90XO8psRbrKe+ycffl/E8zpv6OfVX+jLfh79vM3j79DP63yjH+E385H3
YSH8PosX5K+wK+i+6JZ+QfUW9gvqX+FGQfPBSb9geivCTel1CceK5t8rwvGi
/Bd2wt8Ke0X5I+zLnhJuaL8j6Bf1nkC/qPyjX7J4r6Jfsn66iX5J86hH+iXF
I+zLfkm4IX5VeKNk52VEuFmy8/iwcKxs53WvcFz4grAraz6hXzZ/30C/rPsK
/bL19/foly3fr6Mvfgb9iu4L9Ct2Xn5Bv2L9/hX6Fd036Ff0i77WJ9Gv6D5E
P7I+VlU/o1+1/YfQr5r/31D/quXnI+pfNb3fqX9V/lP/qtXjAPpV3dfo1/Se
Qb+meYt+Te8f9GvWbzuIv2b5e5z4a9YP+4m/FtGv6T2Mft32/xX9eiT/wo/0
Sr+ufhH267rf0Nd+6+jX1e86n826/Kf/V/Relj2+onkp7FbUL93ufxyzRGk=

              "], HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545627["NewSubplot"]] :> {
               FinancialIndicator["FastStochastic", 14, 3]}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545627["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "PlotRangeMin"]] :> -4.051641467268945, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$545627["Space"]] :> 
             3.6430000000000002`, HoldPattern[
               System`TradingChartDump`$layoutData$545627["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, 20}, {250., 20}}], 
                    Line[{{0, 80}, {250., 80}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJxdV2dYVNcWHTWIWJCIlIjgECDSRBAREIE19KLSpLdhhjIwtEB84hfljUak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                    "]]}, {
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Line[CompressedData["
1:eJw9VwdUk2cXjlsE46hSVEawgKCCgAoUFB9QlmGD7JGEEEIIqIALEFKxiAOk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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "SubplotIndicatorGridLines"]] :> {{50, 100}}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "FastStochastic"}]], 
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], " ", ""}]]}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["FastStochastic", 14, 3]}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "SubplotIndicatorParameters"]] :> {{{14, 3}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "SubplotIndicatorPoints"]] :> CompressedData["
1:eJxtmQuMnFUVxweVUqtCpa0ilDql9EnBPrePpd1vZ3f23d1vZufV7badfW/3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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "SubplotIndicatorValues"]] :> CompressedData["
1:eJxdl3lsVFUUxgcJi4iAQF2g1FYspQW00BVq2zcdpjOdaWfem5m3gARZIhJj
ACUqonEjFSRESDAqRAmmoJggQowRNZoILojIomCVEEI1ogFCBIIhBIwz/X7z
/nCSyc29795zv3POd5ZbMm9x6sG+gUCgT/Z/Nfu/IftP7S7qPHvLZCM/RnuW
j9wxwDF+OJD9tceMqtzvkmUEcr/nO4zOs9buon5txto9l8fPes4yHm0c1N31
93SjfFZ2JRo3uruWNA66baqRExN5IWT8Mz77oSBj7IhkV16JSv6TtrE3e3zt
b0nJecA1CnIbtthGDoa1zUG+Y2zJiuve6xh35i4+7xgbN2R/L9vCa/F9hG2c
y8Lq/J7z4zPCfy6j9Qbu+zEjPKWu9Fph6/xST3gvoPd2xkdcY1BOoQpX+Be5
Or81JTzPcu9NUeG5YBlPZ8X0jLKE89ek7LIqZTy0IPv7JmnkpuO3m7LnEkty
7rH0/QkL+7fIHq+2y56uLTvvTAr3TyHp+UtM93wSlJwvYsJ50NM4pEP4r5rC
12NqX1Gb0ZT7MCalfefjwhPo0P0r48J5ImbkYC1oNcHRIZz9Hek50/LnvXYY
nZGd59mSd9iW/E0p7Jox1uX8utjT+eW21g9Y8Ccjvbzp8MSSvlV9tW9wSPzr
LEYPeGvdKz1Xl7B+oblX3rZi2WfDjbp37SjpNatUeM+OwN7V7Bsn/C82CM/C
KvFwbZXkzq7VPbFK7qmRX5YME4+6KuS3kRebe4cdhdo/6GbZYccAzk1BjyLZ
73SIe6vxY1h2P21Ivok/rrUKdzwquyyNEo/F6A9vRhaKpzU10i9SpvHbEvQu
YF8xfijQ/stjFAc9tayPk313hWT/NbXCcZ+j89VtxIMte/1l6ftE4mamg574
udDR98K4vj+cRo8wvEtI/5Nh+eOpCLysEp6NQfGjvpRz9cjvh/6l8Olcs/Qc
7vtZevWXnfeUwoNb8dvd0uPxEuxUCa/Kpde+FnhQo/1jG6X/0Qbh+rRW/DrU
SFy0gKtR+I06+NeA/8sUT911jLcTXxPAH8D+oxSnjQ3S90P8GGnGv9XgqSBe
64i/Vn3/qBFek7/nhMFjwvuExrIk9jbJ9yH8EEf/BLyLa//HLvYzhfO4JdzX
Urp/uEe+sYUjTB7+LCP5I+LIS2PHoOQ9006dCCsuxrVih/6Kg8oG+D4Vv9Vp
/RR14PeQ7Fhmsj8hPC0Nmq9D35V18Djk2092rZH8cD1xXi39t5Vp3/xK6l0L
6/UaB4Z17+tN8Jz7h1HvIjGdXxEjL5r4J+HPe89NTGpenJDe0/J6eFrfSR49
kaJupmWnlzLi9+R8HGbkzzsy0qfGEb466mYJ6wW2xtKE/DI2LbucS8OXlPD/
GZb8t8E16n/1vhu/bG0hn9USP03Uz1bqV7PO7ze1b0Gr/N1kkY8S0u/NjO6t
o27+nMF/eXwZ5MCrCR51Dn2+Tkn/Npt+JKJ5eUrx9L6p+zJJ+NCi9etRf94L
f1lE927O13Xy7ggTfduF7zXq6CKLvseFL2npMwscZbZwzDAlfyF6mdR9l75i
Uwd9DPG1MeqvKy5i0nc/4+oo/m7T+J4pHH3a4XcHc86/A8/mJOnPTPRP+HbW
/fjlaJv2V8LTE6bi6jGTPJDQ/isd/lxxm6S/wi9h5H3l+jzMz3v1+5f6cMIl
D7ri2TJT9p1tU1csjdPS5Is0fMD+PUnp85alcRJ949S08Kz3pPcf9IPHpuv+
IXzvCpJf6Z9iDdgrSL8UggfME4a+bzaoH02cD+r+z4nXoRHyrSP7TYFHYfLi
fMZLLnmAPut4Wjy/nz72YkrrZ4jjra78djhDH+rR39I3n3S0fsTlPP1u0KNP
9WTneo986alefUAeDzrwDb9sT5PfHPqkPB/yOOHtcvwxl7w1mH5uPfotgWer
wFFOHk975CXyXmAG/Gf9mKdzu8G3y5Zdu+HRwbTfb+R5q3yahncW+deSnIHw
bB/xd96m3vKOKHSlxy549B3xHHHofzz6eNfvs5UvbPJau/Z1kicOttPHJHjP
kC/SvKdOkd82kocDbcJ3JYXfOrQvYIpXh8L0HcT/hrGyx7st9JVRn6/iU0Ry
vsz3U7X+uyLfLyme6+lXinn/lYkHZ4J+H9wr/64g/p3GeyTO+2s68WTyTorR
zxAPzfQb63lflOEPj33Xk9SNuPg4lHhcnaTutVMPqCf9k7wfkbMvnwcdv24q
juGPB2/qmK+ir1lDfMwlLt6AV0WeH3/K6w75m3fVprTff6vfj/KOnsI7pol3
3STyQgX38I45Ukn+HI3fK4z/AEEgprs=
              "], HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$545627["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$545627["YRange"]] :> 36.43,
              HoldPattern[
               System`TradingChartDump`$layoutData$545627[
               "SubplotPoints", {1}]] :> CompressedData["
1:eJxdl3lsVFUUxkcNi4iAQF2g1FYsLQW00BVq2zcdpjOdaWfem5m3gARZIhJj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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545627[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$545627[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$545627[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$545627[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$545627[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$545627 = 
           System`TradingChartDump`$length$545627; 
          System`TradingChartDump`$layoutData$545627["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$545627; 
          System`TradingChartDump`$modelData$545627["Data"] = 
           System`TradingChartDump`$data$545627; 
          System`TradingChartDump`$modelData$545627["Indicators"] = 
           System`TradingChartDump`$indicators$545627; 
          System`TradingChartDump`$layoutData$545627[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545627["ScalingFunctions"] = {
            System`TradingChartDump`$sy$545627, 
             System`TradingChartDump`$isy$545627}; 
          System`TradingChartDump`$layoutData$545627["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545627["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545627[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545627["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$545627["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$545627, 
            System`TradingChartDump`$layoutData$545627, 
            System`TradingChartDump`$indicators$545627]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$545627, 
            System`TradingChartDump`$layoutData$545627, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$545627[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$545627["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$545627[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$545627[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$545627["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$545627[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$545627 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545627["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545627, 
                 System`TradingChartDump`$controlmax$545627}]]]; 
          System`TradingChartDump`$plotrangemax$545627 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545627["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545627, 
                 System`TradingChartDump`$controlmax$545627}]]]; {
            System`TradingChartDump`$plotrangemin$545627, 
             System`TradingChartDump`$plotrangemax$545627} = ReplaceAll[
             
             System`TradingChartDump`$sy$545627[{
              System`TradingChartDump`$plotrangemin$545627, 
               System`TradingChartDump`$plotrangemax$545627}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$545627[
                Min[System`TradingChartDump`$lows$545627]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$545627 == 
            System`TradingChartDump`$plotrangemax$545627, {
             System`TradingChartDump`$plotrangemin$545627, 
              System`TradingChartDump`$plotrangemax$545627} = {
             System`TradingChartDump`$plotrangemin$545627 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$545627], 
              System`TradingChartDump`$plotrangemax$545627 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$545627]}]; 
          System`TradingChartDump`$newgridlines$545627 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$545627, 
            Part[System`TradingChartDump`$newgridlines$545627, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$545627, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$545627], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$545627, 1]]; 
            Part[System`TradingChartDump`$newgridlines$545627, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$545627, 1] =!= None,
                 System`TradingChartDump`$length$545627 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$545627, 
                 Part[System`TradingChartDump`$newgridlines$545627, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$545627, 1]]; 
            System`TradingChartDump`$subpricegridlines$545627 = 
             Part[System`TradingChartDump`$gridlines$545627, 2]; 
            Part[System`TradingChartDump`$newgridlines$545627, 2] = 
             If[System`TradingChartDump`$sy$545627 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545627}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545627, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545627, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$545627, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$545627, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545627}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545627, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545627, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$545627 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$545627]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"MSFT\"", "\" with \"", 
           "\"FastStochastic\"", "\"(\"", "14", "\",\"", "3", "\",\"", "", 
           "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {720., -167.4}, 
      ImageScaled[{0.5, 0.5}], {450, 310}]}, {InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$545642 = 
        "Full", System`TradingChartDump`$highlightposition$545642 = Automatic,
         System`TradingChartDump`$maxohlc$545642 = 36.43`4., 
        System`TradingChartDump`$timestampstyle$545642 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$545642 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$545642 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$545642, 
        System`TradingChartDump`$subplotpoint$545642, 
        System`TradingChartDump`$ndigits$545642 = 4, 
        System`TradingChartDump`$highlightstyle$545642 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$545642 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$545642 = True, 
        System`TradingChartDump`$timestampQ$545642 = True, 
        System`TradingChartDump`$data$545642 = {{{2012, 7, 26}, {
          28.367935528120714`, 28.62997256515775, 28.232064471879287`, 28.3, 
           45301400}}, {{2012, 7, 27}, {
          28.60827956989247, 28.967338709677417`, 28.317150537634404`, 28.88, 
           44242600}}, {{2012, 7, 30}, {
          28.866734143049936`, 28.934655870445347`, 28.58534412955466, 28.76, 
           28905000}}, {{2012, 7, 31}, {
          28.609704784526638`, 28.832914828639293`, 28.464133016627077`, 28.6,
            37620900}}, {{2012, 8, 1}, {
          28.714675280516833`, 28.77290037402244, 28.3459163549813, 28.54, 
           31721800}}, {{2012, 8, 2}, {
          28.349410757108597`, 28.65998287084618, 28.11648167180541, 28.33, 
           39520500}}, {{2012, 8, 3}, {
          28.65650756302521, 29.054379831932774`, 28.60798655462185, 28.87, 
           35859400}}, {{2012, 8, 6}, {
          29.108514190317194`, 29.215245409015022`, 28.924160267111848`, 
           29.06, 27471800}}, {{2012, 8, 7}, {
          29.185588235294116`, 29.457352941176467`, 28.99147058823529, 29.37, 
           28002900}}, {{2012, 8, 8}, {
          29.31356083086054, 29.56584569732938, 29.21652818991098, 29.43, 
           26257600}}, {{2012, 8, 9}, {
          29.493245901639348`, 29.745573770491806`, 29.40590163934427, 29.6, 
           24920800}}, {{2012, 8, 10}, {
          29.59763313609467, 29.714082840236685`, 29.355029585798814`, 29.52, 
           27810300}}, {{2012, 8, 13}, {
          29.451184600197433`, 29.55792694965449, 29.26681145113524, 29.49, 
           23049100}}, {{2012, 8, 14}, {
          29.596050448058413`, 29.68395950879522, 29.31278791901759, 29.43, 
           34551400}}, {{2012, 8, 15}, {
          29.412086092715235`, 29.578145695364242`, 29.324172185430466`, 29.5,
            24351000}}, {{2012, 8, 16}, {
          29.65968810916179, 30.22630929174789, 29.561994801819363`, 30.07, 
           35787200}}, {{2012, 8, 17}, {
          30.19953398058253, 30.19953398058253, 29.87722330097088, 30.18, 
           32589900}}, {{2012, 8, 20}, {
          30.108152244632407`, 30.13745933636956, 29.873695510735203`, 30.03, 
           23737700}}, {{2012, 8, 21}, {
          30.050922077922078`, 30.24631168831169, 29.90437987012987, 30.09, 
           28822700}}, {{2012, 8, 22}, {
          29.878837590045844`, 30.044885396201707`, 29.761627373935823`, 
           29.83, 33437400}}, {{2012, 8, 23}, {
          29.68699272967614, 29.696761401189683`, 29.384163912756108`, 29.56, 
           28355600}}, {{2012, 8, 24}, {
          29.547202225130892`, 29.91837369109948, 29.478828534031415`, 29.85, 
           22943300}}, {{2012, 8, 27}, {
          30.214447702834796`, 30.243753665689148`, 29.88231345715216, 29.98, 
           34691100}}, {{2012, 8, 28}, {
          29.988377407770162`, 30.08605941887039, 29.81254978778975, 29.92, 
           23947900}}, {{2012, 8, 29}, {
          29.940000000000005`, 30.037683523654167`, 29.734864600326272`, 
           29.94, 23346800}}, {{2012, 8, 30}, {
          29.82515171503958, 29.90330474934037, 29.52230870712401, 29.62, 
           23982100}}, {{2012, 8, 31}, {
          29.895068137573006`, 30.246774821544452`, 29.68013627514601, 30.11, 
           36590100}}, {{2012, 9, 4}, {
          29.748617966436328`, 29.953780848963476`, 29.45552813425469, 29.69, 
           48556700}}, {{2012, 9, 5}, {
          29.523915761763735`, 29.8267752550181, 29.51414610069102, 29.69, 
           33650000}}, {{2012, 9, 6}, {
          29.789792663476874`, 30.629767145135563`, 29.750724082934607`, 
           30.62, 48371700}}, {{2012, 9, 7}, {
          30.317906300484655`, 30.347208400646206`, 30.01511793214863, 30.23, 
           42649100}}, {{2012, 9, 10}, {
          30.11745768229167, 30.185839843750003`, 29.804853515625005`, 30.01, 
           40524000}}, {{2012, 9, 11}, {
          29.982305943488143`, 30.197232867814222`, 29.90415069827866, 30.08, 
           25191800}}, {{2012, 9, 12}, {
          30.22630929174789, 30.46077322936972, 30.021153346328784`, 30.07, 
           32775800}}, {{2012, 9, 13}, {
          30.171163542340008`, 30.454414996767934`, 29.692566257272134`, 
           30.22, 45047300}}, {{2012, 9, 14}, {
          30.29461390579942, 30.52907721884011, 30.09922781159884, 30.49, 
           51422800}}, {{2012, 9, 17}, {
          30.47046139057994, 30.53884652355014, 30.323921819929506`, 30.49, 
           36488500}}, {{2012, 9, 18}, {
          30.381847338037208`, 30.489307248236052`, 30.31346375881976, 30.46, 
           34542700}}, {{2012, 9, 19}, {
          30.369072463768113`, 30.466753623188403`, 30.320231884057968`, 
           30.33, 48871900}}, {{2012, 9, 20}, {
          30.231605723370425`, 30.74930365659777, 30.19253418124006, 30.72, 
           45543000}}, {{2012, 9, 21}, {
          30.704459762744467`, 30.88030458480282, 30.3723084321898, 30.47, 
           102348900}}, {{2012, 9, 24}, {
          30.284925276153345`, 30.353310591293045`, 29.933229369720596`, 
           30.07, 46825900}}, {{2012, 9, 25}, {
          30.23710102007239, 30.285949325435997`, 29.660691016781836`, 29.69, 
           54266400}}, {{2012, 9, 26}, {
          29.577447795823662`, 29.890023201856145`, 29.3430162412993, 29.47, 
           54672000}}, {{2012, 9, 27}, {
          29.46976790450929, 29.694429708222817`, 29.196266578249343`, 29.46, 
           47129900}}, {{2012, 9, 28}, {
          29.480262096774194`, 29.558407258064516`, 29.050463709677416`, 
           29.07, 54229300}}, {{2012, 10, 1}, {
          29.122621227534758`, 29.288701254662598`, 28.741614106476774`, 
           28.81, 54042700}}, {{2012, 10, 2}, {
          28.98953472690492, 29.194649359406608`, 28.813722184760618`, 28.97, 
           43338900}}, {{2012, 10, 3}, {
          29.062541862022776`, 29.296995981245818`, 28.98439048894843, 29.17, 
           46655900}}, {{2012, 10, 4}, {
          29.271398601398595`, 29.329999999999995`, 28.880722610722604`, 
           29.33, 43634900}}, {{2012, 10, 5}, {
          29.531216080402007`, 29.55075376884422, 29.052542713567835`, 29.16, 
           41133900}}, {{2012, 10, 8}, {
          28.953243787777033`, 29.226756212222973`, 28.865329079919412`, 
           29.09, 29752000}}, {{2012, 10, 9}, {
          28.990710382513658`, 29.049316939890705`, 28.502322404371583`, 28.6,
            45121100}}, {{2012, 10, 10}, {
          28.476069703243613`, 28.632370600414074`, 28.280693581780536`, 
           28.31, 47227100}}, {{2012, 10, 11}, {
          28.543751295336786`, 28.573056994818653`, 28.20185146804836, 28.28, 
           41488500}}, {{2012, 10, 12}, {
          28.29535616438356, 28.637205479452053`, 28.12931506849315, 28.52, 
           46464700}}, {{2012, 10, 15}, {
          28.693226025076243`, 29.03516096238563, 28.57599118942731, 28.83, 
           42440200}}, {{2012, 10, 16}, {
          28.770922346558155`, 29.054235334011526`, 28.643919972872162`, 
           28.81, 47739400}}, {{2012, 10, 17}, {
          28.626664413653266`, 28.958850963163233`, 28.421490368367696`, 
           28.91, 44206100}}, {{2012, 10, 18}, {
          28.966542372881356`, 29.044698305084747`, 28.585532203389832`, 
           28.82, 59238500}}, {{2012, 10, 19}, {
          28.380551675977653`, 28.409860335195525`, 27.843226256983236`, 
           27.98, 90470800}}, {{2012, 10, 22}, {
          28.063053571428572`, 28.16073214285714, 27.183946428571428`, 27.35, 
           83374000}}, {{2012, 10, 23}, {
          27.126488413547236`, 27.546524064171123`, 27.116720142602496`, 27.4,
            64414800}}, {{2012, 10, 24}, {
          27.503942652329755`, 27.543010752688176`, 27.220698924731188`, 
           27.25, 53320400}}, {{2012, 10, 25}, {
          27.532772596843618`, 27.542539454806313`, 27.210466284074606`, 
           27.23, 54084300}}, {{2012, 10, 26}, {
          27.21806451612903, 27.687004608294927`, 27.198525345622116`, 27.56, 
           57790000}}, {{2012, 10, 31}, {
          27.88976874562018, 28.21213735108619, 27.840925017519268`, 27.88, 
           69464100}}, {{2012, 11, 1}, {
          28.17566395663957, 28.879078590785912`, 28.15612466124662, 28.84, 
           72047900}}, {{2012, 11, 2}, {
          28.907925423728813`, 29.08377627118644, 28.653918644067797`, 28.82, 
           57131600}}, {{2012, 11, 5}, {
          28.930232872089103`, 29.047438407019914`, 28.646986162672967`, 
           28.94, 38070800}}, {{2012, 11, 6}, {
          29.13092431346283, 29.50214333556598, 28.92577695914267, 29.17, 
           43401500}}, {{2012, 11, 7}, {
          28.849632049518576`, 29.14272008253095, 28.380691196698766`, 28.41, 
           57871800}}, {{2012, 11, 8}, {
          28.442790697674425`, 28.68697674418605, 28.13023255813954, 28.14, 
           49841800}}, {{2012, 11, 9}, {
          28.2088380159556, 28.511633714880336`, 28.14046479361776, 28.16, 
           43291200}}, {{2012, 11, 12}, {
          28.273416017009215`, 28.341803685329555`, 27.560230333097095`, 
           27.57, 61112300}}, {{2012, 11, 13}, {
          26.611059431524552`, 26.88682170542636, 26.345145810262093`, 26.68, 
           131689200}}, {{2012, 11, 14}, {
          26.823889716840533`, 26.873125931445603`, 26.390611028315945`, 
           26.43, 76086100}}, {{2012, 11, 15}, {
          26.476699174793698`, 26.565348837209303`, 26.230450112528132`, 
           26.26, 50955600}}, {{2012, 11, 16}, {
          26.267737556561087`, 26.2972850678733, 25.942714932126695`, 26.12, 
           64083300}}, {{2012, 11, 19}, {
          26.398952487841374`, 26.398952487841374`, 26.07389075944631, 26.33, 
           57179300}}, {{2012, 11, 20}, {
          26.359251216772744`, 26.39865219019094, 26.06374391613628, 26.31, 
           47070400}}, {{2012, 11, 21}, {
          26.30365120593692, 26.75665306122449, 26.264259740259742`, 26.54, 
           66360300}}, {{2012, 11, 23}, {
          26.817126353790613`, 27.348938628158844`, 26.787581227436824`, 
           27.28, 57845700}}, {{2012, 11, 26}, {
          27.127754654983573`, 27.167155896312522`, 26.763293172690766`, 
           26.98, 85198700}}, {{2012, 11, 27}, {
          26.945760709010344`, 26.96545790251108, 26.630605612998526`, 26.67, 
           45018600}}, {{2012, 11, 28}, {
          26.605244883040935`, 26.97955043859649, 26.368841374269003`, 26.95, 
           53018400}}, {{2012, 11, 29}, {
          26.697565862708718`, 26.943762523191094`, 26.451369202226346`, 
           26.54, 69551400}}, {{2012, 11, 30}, {
          26.643538692712244`, 26.7223365890308, 26.09195341848234, 26.22, 
           83690200}}, {{2012, 12, 3}, {
          26.37470298902762, 26.414097616345064`, 26.000454029511918`, 26.03, 
           53173800}}, {{2012, 12, 4}, {
          26.098028062191883`, 26.226056124383767`, 25.9404550625711, 25.97, 
           49777500}}, {{2012, 12, 5}, {
          25.984349456317954`, 26.526100487439066`, 25.86614923134608, 26.27, 
           68283800}}, {{2012, 12, 6}, {
          26.408802843247283`, 26.57625888514777, 26.211795735129066`, 26.33, 
           39182300}}, {{2012, 12, 7}, {
          26.414557823129254`, 26.414557823129254`, 25.97136054421769, 26.06, 
           46162100}}, {{2012, 12, 10}, {
          26.155783221974758`, 26.559543429844098`, 26.116391982182627`, 
           26.53, 47031100}}, {{2012, 12, 11}, {
          26.64405197657394, 27.077448755490483`, 26.64405197657394, 26.91, 
           52282800}}, {{2012, 12, 12}, {
          27.11563509544787, 27.20428046989721, 26.67240822320117, 26.83, 
           43966300}}, {{2012, 12, 13}, {
          26.90682405016599, 27.10379933603836, 26.5424197713021, 26.7, 
           45080100}}, {{2012, 12, 14}, {
          26.695412159641922`, 26.71510630361805, 26.29168220813129, 26.4, 
           42077500}}, {{2012, 12, 17}, {
          26.38469003690037, 26.80818450184502, 26.27635424354244, 26.69, 
           42046100}}, {{2012, 12, 18}, {
          26.834724238026126`, 27.208933236574747`, 26.726400580551527`, 
           27.14, 50486900}}, {{2012, 12, 19}, {
          27.274295129989014`, 27.313694617356276`, 26.8409007689491, 26.9, 
           53519900}}, {{2012, 12, 20}, {
          26.94485549132948, 27.26, 26.738041907514454`, 27.26, 52607300}}, {{
          2012, 12, 21}, {
          27.04, 27.079402550091075`, 26.59672131147541, 27.04, 98776500}}, {{
          2012, 12, 24}, {
          26.78787878787879, 26.83712121212121, 26.59090909090909, 26.65, 
           20842400}}, {{2012, 12, 26}, {
          26.617405063291137`, 26.784810126582276`, 26.292442293373043`, 
           26.45, 31631100}}, {{2012, 12, 27}, {
          26.481064540059347`, 26.678022997032638`, 26.165931008902074`, 
           26.55, 39394000}}, {{2012, 12, 28}, {
          26.307589453860636`, 26.494726930320144`, 26.149999999999995`, 
           26.15, 28239900}}, {{2012, 12, 31}, {
          26.191797079745413`, 26.369101460127293`, 25.97509172594534, 26.31, 
           42749500}}, {{2013, 1, 2}, {
          26.8356263577118, 27.30832729905865, 26.737146994931205`, 27.2, 
           52899300}}, {{2013, 1, 3}, {
          27.214282568807338`, 27.233981651376148`, 26.75135412844037, 26.84, 
           48294400}}, {{2013, 1, 4}, {
          26.862071802543007`, 26.93102468212416, 26.330149588631265`, 26.34, 
           52521100}}, {{2013, 1, 7}, {
          26.36880104908205, 26.477152491569875`, 26.240749344323717`, 26.29, 
           37110400}}, {{2013, 1, 8}, {
          26.346986817325796`, 26.386384180790955`, 26.061355932203387`, 
           26.15, 44703100}}, {{2013, 1, 9}, {
          26.319700374531838`, 26.34925093632959, 26.162097378277153`, 26.3, 
           49047900}}, {{2013, 1, 10}, {
          26.247127739984883`, 26.572139077853365`, 25.89256991685563, 26.06, 
           71431300}}, {{2013, 1, 11}, {
          26.08519567648155, 26.51847185985837, 25.87840477077898, 26.42, 
           55512100}}, {{2013, 1, 14}, {
          26.489847526961693`, 26.667103012272218`, 26.351982149497953`, 
           26.48, 48324400}}, {{2013, 1, 15}, {
          26.42572583608967, 26.878794560823223`, 26.42572583608967, 26.8, 
           48244500}}, {{2013, 1, 16}, {
          26.738332100591716`, 26.817119082840236`, 26.600454881656805`, 
           26.63, 41077400}}, {{2013, 1, 17}, {
          26.78090275229358, 27.05668990825688, 26.65285871559633, 26.84, 
           51685900}}, {{2013, 1, 18}, {
          26.692256880733947`, 26.879398165137616`, 26.633159633027525`, 
           26.84, 52167700}}, {{2013, 1, 22}, {
          26.887734806629833`, 27.035469613259668`, 26.592265193370167`, 
           26.74, 58650600}}, {{2013, 1, 23}, {
          26.786236870699025`, 27.21954364360739, 26.786236870699025`, 27.19, 
           50387700}}, {{2013, 1, 24}, {
          27.27893593919653, 27.643311617806734`, 27.052432138979373`, 27.21, 
           101739300}}, {{2013, 1, 25}, {
          27.164519368723095`, 27.804727403156384`, 26.97738163558106, 27.46, 
           81847700}}, {{2013, 1, 28}, {
          27.58849516302401, 27.80518452167682, 27.342257255463995`, 27.49, 
           56056500}}, {{2013, 1, 29}, {
          27.402848982506246`, 27.708200642627627`, 27.186147804355585`, 
           27.59, 49242600}}, {{2013, 1, 30}, {
          27.58758707360862, 27.764872531418312`, 27.341357271095156`, 27.43, 
           43580500}}, {{2013, 1, 31}, {
          27.374921675774136`, 27.55223315118397, 26.990746812386156`, 27.04, 
           50530000}}, {{2013, 2, 1}, {
          27.253909774436092`, 27.628195488721804`, 27.135714285714286`, 
           27.51, 55565900}}, {{2013, 2, 4}, {
          27.453575072886295`, 27.60133381924198, 27.010298833819242`, 27.03, 
           50540000}}, {{2013, 2, 5}, {
          27.198167272727268`, 27.237556363636358`, 26.942138181818176`, 
           27.08, 35410400}}, {{2013, 2, 6}, {
          26.969400146305773`, 27.12700073152889, 26.841349670811994`, 26.93, 
           41889600}}, {{2013, 2, 7}, {
          26.938947947214075`, 26.978346774193547`, 26.692705278592374`, 
           26.87, 38028300}}, {{2013, 2, 8}, {
          26.933049001814883`, 27.287560798548096`, 26.893658802177857`, 
           27.13, 33318500}}, {{2013, 2, 11}, {
          27.23316582914573, 27.499095477386938`, 27.085427135678394`, 27.44, 
           32247700}}, {{2013, 2, 12}, {
          27.459999999999997`, 27.57819225251076, 27.33195839311334, 27.46, 
           35990900}}, {{2013, 2, 13}, {
          27.511498394577234`, 27.688801284338204`, 27.462247591865854`, 
           27.61, 41715600}}, {{2013, 2, 14}, {
          27.501797432239663`, 27.639700427960058`, 27.45254636233952, 27.62, 
           32663200}}, {{2013, 2, 15}, {
          27.619550160656903`, 27.737750803284538`, 27.46194930382006, 27.59, 
           49650900}}, {{2013, 2, 19}, {
          27.68121212121212, 27.889714795008913`, 27.6017825311943, 27.85, 
           38781400}}, {{2013, 2, 20}, {
          27.938227484750627`, 28.007750269106566`, 27.64027269465375, 27.68, 
           44110200}}, {{2013, 2, 21}, {
          27.548272098945073`, 27.548272098945073`, 27.041797017097128`, 27.3,
            49078500}}, {{2013, 2, 22}, {
          27.49054755043228, 27.570000000000004`, 27.29191642651297, 27.57, 
           31425900}}, {{2013, 2, 25}, {
          27.7758348556814, 27.85527950310559, 27.18, 27.18, 48011800}}, {{
          2013, 2, 26}, {
          27.18993058092802, 27.408403361344536`, 27.150208257215926`, 27.18, 
           49923300}}, {{2013, 2, 27}, {
          27.232664509169368`, 27.808701905789285`, 27.143279395900755`, 
           27.62, 36394700}}, {{2013, 2, 28}, {
          27.689453237410067`, 27.7788381294964, 27.55041007194244, 27.61, 
           35840200}}, {{2013, 3, 1}, {
          27.53156350626118, 27.789796064400715`, 27.332923076923077`, 27.76, 
           34849700}}, {{2013, 3, 4}, {
          27.652131438721142`, 27.950000000000003`, 27.503197158081708`, 
           27.95, 38157500}}, {{2013, 3, 5}, {
          28.090423280423277`, 28.33865961199294, 27.961340388007052`, 28.15, 
           41432200}}, {{2013, 3, 6}, {
          28.009145603417586`, 28.029003203987184`, 27.582207191171236`, 
           27.89, 51448500}}, {{2013, 3, 7}, {
          27.910213219616203`, 28.079004975124377`, 27.810923951670222`, 
           27.94, 29196700}}, {{2013, 3, 8}, {
          28.058303571428567`, 28.137760714285708`, 27.770271428571426`, 
           27.81, 37667800}}, {{2013, 3, 11}, {
          27.74952278435594, 27.779318263365624`, 27.48136347326875, 27.68, 
           36627500}}, {{2013, 3, 12}, {
          27.650476531709067`, 27.759727696166248`, 27.451838050877825`, 
           27.72, 39255200}}, {{2013, 3, 13}, {
          27.680340257879656`, 27.829319484240685`, 27.56115687679083, 27.73, 
           29093400}}, {{2013, 3, 14}, {
          27.800995024875622`, 27.959857853589195`, 27.731492537313432`, 
           27.94, 55914800}}, {{2013, 3, 15}, {
          27.83007132667618, 27.95914407988588, 27.780427960057064`, 27.84, 
           92710300}}, {{2013, 3, 18}, {
          27.681565836298926`, 28.07871886120996, 27.612064056939495`, 27.9, 
           44809400}}, {{2013, 3, 19}, {
          27.92042583392477, 28.01971611071682, 27.831064584811926`, 27.98, 
           51901600}}, {{2013, 3, 20}, {
          28.13985875706215, 28.28879943502825, 27.980988700564975`, 28.12, 
           35447800}}, {{2013, 3, 21}, {
          27.909999999999997`, 28.158221273568124`, 27.85042689434365, 27.91, 
           34233200}}, {{2013, 3, 22}, {
          27.990424778761064`, 28.13936283185841, 27.901061946902658`, 28.05, 
           28720900}}, {{2013, 3, 25}, {
          28.099005681818188`, 28.14865056818182, 27.76142045454546, 27.96, 
           44154000}}, {{2013, 3, 26}, {
          28.03943181818182, 28.138721590909096`, 27.910355113636367`, 27.96, 
           27824300}}, {{2013, 3, 27}, {
          27.941621431089178`, 28.24943602396898, 27.88204441311244, 28.17, 
           36047400}}, {{2013, 3, 28}, {
          28.12202726319469, 28.459650471862986`, 28.06244669695911, 28.41, 
           55453800}}, {{2013, 4, 1}, {
          28.439790283117794`, 28.459650471862986`, 28.16174764068508, 28.41, 
           29201100}}, {{2013, 4, 2}, {
          28.391458333333336`, 28.64965277777778, 28.321944444444448`, 28.6, 
           28456500}}, {{2013, 4, 3}, {
          28.548669467787114`, 28.747268907563026`, 28.34014005602241, 28.36, 
           35062800}}, {{2013, 4, 4}, {
          28.191468531468526`, 28.409930069930063`, 28.072307692307685`, 28.4,
            45263200}}, {{2013, 4, 5}, {
          28.02334494773519, 28.5794425087108, 27.91411149825784, 28.5, 
           50927300}}, {{2013, 4, 8}, {
          28.529020636586218`, 28.529020636586218`, 28.270839454354668`, 
           28.39, 34759500}}, {{2013, 4, 9}, {
          28.526241134751775`, 29.608510638297872`, 28.47659574468085, 29.4, 
           77733800}}, {{2013, 4, 10}, {
          29.364924042272122`, 30.109722589167763`, 29.315270805812414`, 
           30.07, 71116700}}, {{2013, 4, 11}, {
          28.89889426399447, 28.998203178991016`, 28.531451278507255`, 28.74, 
           130923200}}, {{2013, 4, 12}, {
          28.649583188607156`, 28.818402222994095`, 28.460903091351163`, 
           28.59, 62886300}}, {{2013, 4, 15}, {
          28.450278842802366`, 28.77797838968281, 28.311254792610665`, 28.49, 
           56332900}}, {{2013, 4, 16}, {
          28.700483258543322`, 28.93882637210908, 28.501863997238523`, 28.77, 
           52797300}}, {{2013, 4, 17}, {
          28.64986125563649, 28.83854318418314, 28.40159556018037, 28.63, 
           52840700}}, {{2013, 4, 18}, {
          28.74888850295241, 28.77868009725599, 28.302014588398748`, 28.59, 
           56906600}}, {{2013, 4, 19}, {
          29.411058112193484`, 30.02668458179375, 29.40112865300638, 29.56, 
           99790700}}, {{2013, 4, 22}, {
          30.093610120012976`, 30.967615958482, 30.063814466428806`, 30.62, 
           137904000}}, {{2013, 4, 23}, {
          30.489313725490195`, 30.687941176470588`, 30.17150980392157, 30.39, 
           59126900}}, {{2013, 4, 24}, {
          30.407896725440807`, 31.69889168765743, 30.388035264483626`, 31.54, 
           90946600}}, {{2013, 4, 25}, {
          31.491584220413277`, 32.61380087664371, 31.32275516593613, 31.72, 
           110700200}}, {{2013, 4, 26}, {
          31.679238754325258`, 31.758685121107266`, 31.23235294117647, 31.57, 
           47799300}}, {{2013, 4, 29}, {
          31.575712971481146`, 32.449506286415215`, 31.545924563017483`, 
           32.38, 59116400}}, {{2013, 4, 30}, {
          32.33375226586102, 32.87993051359516, 32.05569788519637, 32.87, 
           75165200}}, {{2013, 5, 1}, {
          32.69852383863081, 32.84746943765282, 32.3708435207824, 32.49, 
           54330900}}, {{2013, 5, 2}, {
          32.40367611580218, 32.939930639324494`, 32.16534077201448, 32.93, 
           46059500}}, {{2013, 5, 3}, {
          33.00178560764407, 33.28979396834876, 32.85281576590026, 33.26, 
           46784600}}, {{2013, 5, 6}, {
          33.18234666666667, 33.66886222222222, 33.013555555555556`, 33.51, 
           40978300}}, {{2013, 5, 7}, {
          33.41765235664965, 33.55668567997598, 33.01048333833683, 33.08, 
           43078300}}, {{2013, 5, 8}, {
          32.83944225522885, 33.00825704759018, 32.422370415277356`, 32.76, 
           51595700}}, {{2013, 5, 9}, {
          32.61866197183099, 32.76760563380282, 32.36049295774649, 32.43, 
           46417800}}, {{2013, 5, 10}, {
          32.44014071581524, 32.48978892627715, 32.09260324258183, 32.46, 
           36394900}}, {{2013, 5, 13}, {
          32.382924613987285`, 32.83972146533454, 32.323342415985465`, 32.8, 
           36027600}}, {{2013, 5, 14}, {
          32.86, 33.53, 32.8, 33.53, 56870100}}, {{2013, 5, 15}, {
          33.45, 33.9, 33.43, 33.85, 46303900}}, {{2013, 5, 16}, {
          33.64, 34.15, 33.55, 34.08, 59382900}}, {{2013, 5, 17}, {
          34.13, 34.87, 34.1, 34.87, 60666700}}, {{2013, 5, 20}, {
          34.73, 35.1, 34.68, 35.08, 54020800}}, {{2013, 5, 21}, {
          35.1, 35.27, 34.72, 34.85, 48702400}}, {{2013, 5, 22}, {
          34.79, 34.84, 34.36, 34.61, 66047500}}, {{2013, 5, 23}, {
          34.23, 34.55, 33.9, 34.15, 51102700}}, {{2013, 5, 24}, {
          33.92, 34.28, 33.9, 34.27, 33174400}}, {{2013, 5, 28}, {
          34.42, 35.18, 34.41, 35.02, 48212100}}, {{2013, 5, 29}, {
          34.74, 35.02, 34.57, 34.88, 38412200}}, {{2013, 5, 30}, {
          34.849999999999994`, 35.24999999999999, 34.809999999999995`, 35.03, 
           51131000}}, {{2013, 5, 31}, {
          34.82, 35.28, 34.79, 34.9, 56165700}}, {{2013, 6, 3}, {
          34.919999999999995`, 35.629999999999995`, 34.82999999999999, 35.59, 
           51252600}}, {{2013, 6, 4}, {
          35.62, 35.74, 34.77, 34.99, 65529500}}, {{2013, 6, 5}, {
          34.6, 34.89, 34.43, 34.78, 46025100}}, {{2013, 6, 6}, {
          34.84, 35.11, 34.49, 34.96, 37618500}}, {{2013, 6, 7}, {
          35.25, 35.78, 35.06, 35.67, 40757300}}, {{2013, 6, 10}, {
          35.51, 35.65, 35.14, 35.47, 35994500}}, {{2013, 6, 11}, {
          35.05, 35.18, 34.68, 34.84, 39435900}}, {{2013, 6, 12}, {
          35.14, 35.27, 34.85, 35., 37372700}}, {{2013, 6, 13}, {
          34.99, 35.02, 34.59, 34.72, 45654900}}, {{2013, 6, 14}, {
          34.55, 34.69, 34.25, 34.4, 53192600}}, {{2013, 6, 17}, {
          34.69, 35.16, 34.63, 35., 49670100}}, {{2013, 6, 18}, {
          34.97, 35.17, 34.9, 34.98, 28616500}}, {{2013, 6, 19}, {
          34.96, 35.09, 34.59, 34.59, 30816200}}, {{2013, 6, 20}, {
          34.26, 34.33, 33.37, 33.49, 54493700}}, {{2013, 6, 21}, {
          33.66, 33.73, 33.05, 33.27, 85338500}}, {{2013, 6, 24}, {
          32.94, 34.2, 32.57, 33.72, 56109000}}, {{2013, 6, 25}, {
          34.08, 34.38, 33.46, 33.67, 44073400}}, {{2013, 6, 26}, {
          34.12, 34.48, 33.89, 34.35, 48665900}}, {{2013, 6, 27}, {
          34.52, 34.78, 34.5, 34.62, 28993100}}, {{2013, 6, 28}, {
          34.38, 34.79, 34.34, 34.54, 65545500}}, {{2013, 7, 1}, {
          34.75, 34.99, 34.33, 34.36, 31055400}}, {{2013, 7, 2}, {
          34.41, 34.44, 33.63, 33.94, 37630000}}, {{2013, 7, 3}, {
          33.66, 34.37, 33.6, 34.01, 15994400}}, {{2013, 7, 5}, {
          34.09, 34.24, 33.58, 34.21, 26085900}}, {{2013, 7, 8}, {
          34.35, 34.59, 33.98, 34.33, 32396900}}, {{2013, 7, 9}, {
          34.58, 34.6, 34.14, 34.35, 25318500}}, {{2013, 7, 10}, {
          34.34, 34.81, 34.32, 34.7, 29658800}}, {{2013, 7, 11}, {
          35., 35.77, 34.9, 35.69, 53638300}}, {{2013, 7, 12}, {
          35.58, 35.73, 35.28, 35.67, 35501200}}, {{2013, 7, 15}, {
          35.66, 36.22, 35.58, 36.17, 34142600}}, {{2013, 7, 16}, {
          36.01, 36.43, 35.96, 36.27, 36378500}}, {{2013, 7, 17}, {
          36.34, 36.39, 35.49, 35.74, 37285100}}, {{2013, 7, 18}, {
          35.72, 35.89, 35.22, 35.44, 49547100}}, {{2013, 7, 19}, {
          32.4, 32.67, 31.02, 31.4, 248428500}}, {{2013, 7, 22}, {
          31.7, 32.01, 31.6, 32.01, 79040700}}, {{2013, 7, 23}, {
          31.91, 32.04, 31.71, 31.82, 65810400}}, {{2013, 7, 24}, {
          32.04, 32.19, 31.89, 31.96, 52803100}}, {{2013, 7, 25}, {
          31.62, 31.65, 31.25, 31.39, 63213000}}}, 
        System`TradingChartDump`$markerstyle$545642 = 1, 
        System`TradingChartDump`$controlmin$545642 = 0.5, 
        System`TradingChartDump`$controlmax$545642 = 250.5, 
        System`TradingChartDump`$datescope$545642 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$545642 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$545642, 
        System`TradingChartDump`$max$545642, 
        System`TradingChartDump`$ohlclabel$545642 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545642, 
              System`TradingChartDump`$opens$545642]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545642, 
              System`TradingChartDump`$highs$545642]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545642, 
              System`TradingChartDump`$lows$545642]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545642, 
              System`TradingChartDump`$closes$545642]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545642, 
              System`TradingChartDump`$visdates$545642]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$545642 = {}, 
        System`TradingChartDump`$subpricegridlines$545642 = Automatic, 
        System`TradingChartDump`$overlaypoint$545642, 
        System`TradingChartDump`$overlayvalue$545642, 
        System`TradingChartDump`$subplotvalue$545642, 
        System`TradingChartDump`$opts$545642 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "MSFT", " with ", "FullStochastic", 
            "(", 14, ",", 3, ",", 3, ",", Null, ")"}], 
         ImageSize -> {450, 310}, AlignmentPoint -> Center, AspectRatio -> 
         GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> None, AxesOrigin -> 
         Automatic, AxesStyle -> {}, Background -> None, BaselinePosition -> 
         Automatic, BaseStyle -> {}, ColorOutput -> Automatic, 
         ContentSelectable -> Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$545642 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmgtcj+f7xyNbDokp/ORUIcmhckrnO2EhOipppcO3vt/6VsKIsIVpDtGo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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyNmglYjmnUx5ssY5K1sku2bElp0d4tkvZdi9KmRW8LsnwYvJiECUOILGPN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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$545642 = 
        System`TradingChartDump`$staticindicatorpos$545642, 
        System`TradingChartDump`$length$545642 = 250, 
        System`TradingChartDump`$gridlinesflag$545642 = True, 
        System`TradingChartDump`$opens$545642 = 
        Dispatch[{
         1 -> 28.37`4., 2 -> 28.61`4., 3 -> 28.87`4., 4 -> 28.61`4., 5 -> 
          28.71`4., 6 -> 28.35`4., 7 -> 28.66`4., 8 -> 29.11`4., 9 -> 
          29.19`4., 10 -> 29.31`4., 11 -> 29.49`4., 12 -> 29.6`4., 13 -> 
          29.45`4., 14 -> 29.6`4., 15 -> 29.41`4., 16 -> 29.66`4., 17 -> 
          30.2`4., 18 -> 30.11`4., 19 -> 30.05`4., 20 -> 29.88`4., 21 -> 
          29.69`4., 22 -> 29.55`4., 23 -> 30.21`4., 24 -> 29.99`4., 25 -> 
          29.94`4., 26 -> 29.83`4., 27 -> 29.9`4., 28 -> 29.75`4., 29 -> 
          29.52`4., 30 -> 29.79`4., 31 -> 30.32`4., 32 -> 30.12`4., 33 -> 
          29.98`4., 34 -> 30.23`4., 35 -> 30.17`4., 36 -> 30.29`4., 37 -> 
          30.47`4., 38 -> 30.38`4., 39 -> 30.37`4., 40 -> 30.23`4., 41 -> 
          30.7`4., 42 -> 30.28`4., 43 -> 30.24`4., 44 -> 29.58`4., 45 -> 
          29.47`4., 46 -> 29.48`4., 47 -> 29.12`4., 48 -> 28.99`4., 49 -> 
          29.06`4., 50 -> 29.27`4., 51 -> 29.53`4., 52 -> 28.95`4., 53 -> 
          28.99`4., 54 -> 28.48`4., 55 -> 28.54`4., 56 -> 28.3`4., 57 -> 
          28.69`4., 58 -> 28.77`4., 59 -> 28.63`4., 60 -> 28.97`4., 61 -> 
          28.38`4., 62 -> 28.06`4., 63 -> 27.13`4., 64 -> 27.5`4., 65 -> 
          27.53`4., 66 -> 27.22`4., 67 -> 27.89`4., 68 -> 28.18`4., 69 -> 
          28.91`4., 70 -> 28.93`4., 71 -> 29.13`4., 72 -> 28.85`4., 73 -> 
          28.44`4., 74 -> 28.21`4., 75 -> 28.27`4., 76 -> 26.61`4., 77 -> 
          26.82`4., 78 -> 26.48`4., 79 -> 26.27`4., 80 -> 26.4`4., 81 -> 
          26.36`4., 82 -> 26.3`4., 83 -> 26.82`4., 84 -> 27.13`4., 85 -> 
          26.95`4., 86 -> 26.61`4., 87 -> 26.7`4., 88 -> 26.64`4., 89 -> 
          26.37`4., 90 -> 26.1`4., 91 -> 25.98`4., 92 -> 26.41`4., 93 -> 
          26.41`4., 94 -> 26.16`4., 95 -> 26.64`4., 96 -> 27.12`4., 97 -> 
          26.91`4., 98 -> 26.7`4., 99 -> 26.38`4., 100 -> 26.83`4., 101 -> 
          27.27`4., 102 -> 26.94`4., 103 -> 27.04`4., 104 -> 26.79`4., 105 -> 
          26.62`4., 106 -> 26.48`4., 107 -> 26.31`4., 108 -> 26.19`4., 109 -> 
          26.84`4., 110 -> 27.21`4., 111 -> 26.86`4., 112 -> 26.37`4., 113 -> 
          26.35`4., 114 -> 26.32`4., 115 -> 26.25`4., 116 -> 26.09`4., 117 -> 
          26.49`4., 118 -> 26.43`4., 119 -> 26.74`4., 120 -> 26.78`4., 121 -> 
          26.69`4., 122 -> 26.89`4., 123 -> 26.79`4., 124 -> 27.28`4., 125 -> 
          27.16`4., 126 -> 27.59`4., 127 -> 27.4`4., 128 -> 27.59`4., 129 -> 
          27.37`4., 130 -> 27.25`4., 131 -> 27.45`4., 132 -> 27.2`4., 133 -> 
          26.97`4., 134 -> 26.94`4., 135 -> 26.93`4., 136 -> 27.23`4., 137 -> 
          27.46`4., 138 -> 27.51`4., 139 -> 27.5`4., 140 -> 27.62`4., 141 -> 
          27.68`4., 142 -> 27.94`4., 143 -> 27.55`4., 144 -> 27.49`4., 145 -> 
          27.78`4., 146 -> 27.19`4., 147 -> 27.23`4., 148 -> 27.69`4., 149 -> 
          27.53`4., 150 -> 27.65`4., 151 -> 28.09`4., 152 -> 28.01`4., 153 -> 
          27.91`4., 154 -> 28.06`4., 155 -> 27.75`4., 156 -> 27.65`4., 157 -> 
          27.68`4., 158 -> 27.8`4., 159 -> 27.83`4., 160 -> 27.68`4., 161 -> 
          27.92`4., 162 -> 28.14`4., 163 -> 27.91`4., 164 -> 27.99`4., 165 -> 
          28.1`4., 166 -> 28.04`4., 167 -> 27.94`4., 168 -> 28.12`4., 169 -> 
          28.44`4., 170 -> 28.39`4., 171 -> 28.55`4., 172 -> 28.19`4., 173 -> 
          28.02`4., 174 -> 28.53`4., 175 -> 28.53`4., 176 -> 29.36`4., 177 -> 
          28.9`4., 178 -> 28.65`4., 179 -> 28.45`4., 180 -> 28.7`4., 181 -> 
          28.65`4., 182 -> 28.75`4., 183 -> 29.41`4., 184 -> 30.09`4., 185 -> 
          30.49`4., 186 -> 30.41`4., 187 -> 31.49`4., 188 -> 31.68`4., 189 -> 
          31.58`4., 190 -> 32.33`4., 191 -> 32.7`4., 192 -> 32.4`4., 193 -> 
          33.`4., 194 -> 33.18`4., 195 -> 33.42`4., 196 -> 32.84`4., 197 -> 
          32.62`4., 198 -> 32.44`4., 199 -> 32.38`4., 200 -> 32.86`4., 201 -> 
          33.45`4., 202 -> 33.64`4., 203 -> 34.13`4., 204 -> 34.73`4., 205 -> 
          35.1`4., 206 -> 34.79`4., 207 -> 34.23`4., 208 -> 33.92`4., 209 -> 
          34.42`4., 210 -> 34.74`4., 211 -> 34.85`4., 212 -> 34.82`4., 213 -> 
          34.92`4., 214 -> 35.62`4., 215 -> 34.6`4., 216 -> 34.84`4., 217 -> 
          35.25`4., 218 -> 35.51`4., 219 -> 35.05`4., 220 -> 35.14`4., 221 -> 
          34.99`4., 222 -> 34.55`4., 223 -> 34.69`4., 224 -> 34.97`4., 225 -> 
          34.96`4., 226 -> 34.26`4., 227 -> 33.66`4., 228 -> 32.94`4., 229 -> 
          34.08`4., 230 -> 34.12`4., 231 -> 34.52`4., 232 -> 34.38`4., 233 -> 
          34.75`4., 234 -> 34.41`4., 235 -> 33.66`4., 236 -> 34.09`4., 237 -> 
          34.35`4., 238 -> 34.58`4., 239 -> 34.34`4., 240 -> 35.`4., 241 -> 
          35.58`4., 242 -> 35.66`4., 243 -> 36.01`4., 244 -> 36.34`4., 245 -> 
          35.72`4., 246 -> 32.4`4., 247 -> 31.7`4., 248 -> 31.91`4., 249 -> 
          32.04`4., 250 -> 31.62`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$545642 = 
        Dispatch[{
         1 -> 28.63`4., 2 -> 28.97`4., 3 -> 28.93`4., 4 -> 28.83`4., 5 -> 
          28.77`4., 6 -> 28.66`4., 7 -> 29.05`4., 8 -> 29.22`4., 9 -> 
          29.46`4., 10 -> 29.57`4., 11 -> 29.75`4., 12 -> 29.71`4., 13 -> 
          29.56`4., 14 -> 29.68`4., 15 -> 29.58`4., 16 -> 30.23`4., 17 -> 
          30.2`4., 18 -> 30.14`4., 19 -> 30.25`4., 20 -> 30.04`4., 21 -> 
          29.7`4., 22 -> 29.92`4., 23 -> 30.24`4., 24 -> 30.09`4., 25 -> 
          30.04`4., 26 -> 29.9`4., 27 -> 30.25`4., 28 -> 29.95`4., 29 -> 
          29.83`4., 30 -> 30.63`4., 31 -> 30.35`4., 32 -> 30.19`4., 33 -> 
          30.2`4., 34 -> 30.46`4., 35 -> 30.45`4., 36 -> 30.53`4., 37 -> 
          30.54`4., 38 -> 30.49`4., 39 -> 30.47`4., 40 -> 30.75`4., 41 -> 
          30.88`4., 42 -> 30.35`4., 43 -> 30.29`4., 44 -> 29.89`4., 45 -> 
          29.69`4., 46 -> 29.56`4., 47 -> 29.29`4., 48 -> 29.19`4., 49 -> 
          29.3`4., 50 -> 29.33`4., 51 -> 29.55`4., 52 -> 29.23`4., 53 -> 
          29.05`4., 54 -> 28.63`4., 55 -> 28.57`4., 56 -> 28.64`4., 57 -> 
          29.04`4., 58 -> 29.05`4., 59 -> 28.96`4., 60 -> 29.04`4., 61 -> 
          28.41`4., 62 -> 28.16`4., 63 -> 27.55`4., 64 -> 27.54`4., 65 -> 
          27.54`4., 66 -> 27.69`4., 67 -> 28.21`4., 68 -> 28.88`4., 69 -> 
          29.08`4., 70 -> 29.05`4., 71 -> 29.5`4., 72 -> 29.14`4., 73 -> 
          28.69`4., 74 -> 28.51`4., 75 -> 28.34`4., 76 -> 26.89`4., 77 -> 
          26.87`4., 78 -> 26.57`4., 79 -> 26.3`4., 80 -> 26.4`4., 81 -> 
          26.4`4., 82 -> 26.76`4., 83 -> 27.35`4., 84 -> 27.17`4., 85 -> 
          26.97`4., 86 -> 26.98`4., 87 -> 26.94`4., 88 -> 26.72`4., 89 -> 
          26.41`4., 90 -> 26.23`4., 91 -> 26.53`4., 92 -> 26.58`4., 93 -> 
          26.41`4., 94 -> 26.56`4., 95 -> 27.08`4., 96 -> 27.2`4., 97 -> 
          27.1`4., 98 -> 26.72`4., 99 -> 26.81`4., 100 -> 27.21`4., 101 -> 
          27.31`4., 102 -> 27.26`4., 103 -> 27.08`4., 104 -> 26.84`4., 105 -> 
          26.78`4., 106 -> 26.68`4., 107 -> 26.49`4., 108 -> 26.37`4., 109 -> 
          27.31`4., 110 -> 27.23`4., 111 -> 26.93`4., 112 -> 26.48`4., 113 -> 
          26.39`4., 114 -> 26.35`4., 115 -> 26.57`4., 116 -> 26.52`4., 117 -> 
          26.67`4., 118 -> 26.88`4., 119 -> 26.82`4., 120 -> 27.06`4., 121 -> 
          26.88`4., 122 -> 27.04`4., 123 -> 27.22`4., 124 -> 27.64`4., 125 -> 
          27.8`4., 126 -> 27.81`4., 127 -> 27.71`4., 128 -> 27.76`4., 129 -> 
          27.55`4., 130 -> 27.63`4., 131 -> 27.6`4., 132 -> 27.24`4., 133 -> 
          27.13`4., 134 -> 26.98`4., 135 -> 27.29`4., 136 -> 27.5`4., 137 -> 
          27.58`4., 138 -> 27.69`4., 139 -> 27.64`4., 140 -> 27.74`4., 141 -> 
          27.89`4., 142 -> 28.01`4., 143 -> 27.55`4., 144 -> 27.57`4., 145 -> 
          27.86`4., 146 -> 27.41`4., 147 -> 27.81`4., 148 -> 27.78`4., 149 -> 
          27.79`4., 150 -> 27.95`4., 151 -> 28.34`4., 152 -> 28.03`4., 153 -> 
          28.08`4., 154 -> 28.14`4., 155 -> 27.78`4., 156 -> 27.76`4., 157 -> 
          27.83`4., 158 -> 27.96`4., 159 -> 27.96`4., 160 -> 28.08`4., 161 -> 
          28.02`4., 162 -> 28.29`4., 163 -> 28.16`4., 164 -> 28.14`4., 165 -> 
          28.15`4., 166 -> 28.14`4., 167 -> 28.25`4., 168 -> 28.46`4., 169 -> 
          28.46`4., 170 -> 28.65`4., 171 -> 28.75`4., 172 -> 28.41`4., 173 -> 
          28.58`4., 174 -> 28.53`4., 175 -> 29.61`4., 176 -> 30.11`4., 177 -> 
          29.`4., 178 -> 28.82`4., 179 -> 28.78`4., 180 -> 28.94`4., 181 -> 
          28.84`4., 182 -> 28.78`4., 183 -> 30.03`4., 184 -> 30.97`4., 185 -> 
          30.69`4., 186 -> 31.7`4., 187 -> 32.61`4., 188 -> 31.76`4., 189 -> 
          32.45`4., 190 -> 32.88`4., 191 -> 32.85`4., 192 -> 32.94`4., 193 -> 
          33.29`4., 194 -> 33.67`4., 195 -> 33.56`4., 196 -> 33.01`4., 197 -> 
          32.77`4., 198 -> 32.49`4., 199 -> 32.84`4., 200 -> 33.53`4., 201 -> 
          33.9`4., 202 -> 34.15`4., 203 -> 34.87`4., 204 -> 35.1`4., 205 -> 
          35.27`4., 206 -> 34.84`4., 207 -> 34.55`4., 208 -> 34.28`4., 209 -> 
          35.18`4., 210 -> 35.02`4., 211 -> 35.25`4., 212 -> 35.28`4., 213 -> 
          35.63`4., 214 -> 35.74`4., 215 -> 34.89`4., 216 -> 35.11`4., 217 -> 
          35.78`4., 218 -> 35.65`4., 219 -> 35.18`4., 220 -> 35.27`4., 221 -> 
          35.02`4., 222 -> 34.69`4., 223 -> 35.16`4., 224 -> 35.17`4., 225 -> 
          35.09`4., 226 -> 34.33`4., 227 -> 33.73`4., 228 -> 34.2`4., 229 -> 
          34.38`4., 230 -> 34.48`4., 231 -> 34.78`4., 232 -> 34.79`4., 233 -> 
          34.99`4., 234 -> 34.44`4., 235 -> 34.37`4., 236 -> 34.24`4., 237 -> 
          34.59`4., 238 -> 34.6`4., 239 -> 34.81`4., 240 -> 35.77`4., 241 -> 
          35.73`4., 242 -> 36.22`4., 243 -> 36.43`4., 244 -> 36.39`4., 245 -> 
          35.89`4., 246 -> 32.67`4., 247 -> 32.01`4., 248 -> 32.04`4., 249 -> 
          32.19`4., 250 -> 31.65`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$545642 = 
        Dispatch[{
         1 -> 28.23`4., 2 -> 28.32`4., 3 -> 28.59`4., 4 -> 28.46`4., 5 -> 
          28.35`4., 6 -> 28.12`4., 7 -> 28.61`4., 8 -> 28.92`4., 9 -> 
          28.99`4., 10 -> 29.22`4., 11 -> 29.41`4., 12 -> 29.36`4., 13 -> 
          29.27`4., 14 -> 29.31`4., 15 -> 29.32`4., 16 -> 29.56`4., 17 -> 
          29.88`4., 18 -> 29.87`4., 19 -> 29.9`4., 20 -> 29.76`4., 21 -> 
          29.38`4., 22 -> 29.48`4., 23 -> 29.88`4., 24 -> 29.81`4., 25 -> 
          29.73`4., 26 -> 29.52`4., 27 -> 29.68`4., 28 -> 29.46`4., 29 -> 
          29.51`4., 30 -> 29.75`4., 31 -> 30.02`4., 32 -> 29.8`4., 33 -> 
          29.9`4., 34 -> 30.02`4., 35 -> 29.69`4., 36 -> 30.1`4., 37 -> 
          30.32`4., 38 -> 30.31`4., 39 -> 30.32`4., 40 -> 30.19`4., 41 -> 
          30.37`4., 42 -> 29.93`4., 43 -> 29.66`4., 44 -> 29.34`4., 45 -> 
          29.2`4., 46 -> 29.05`4., 47 -> 28.74`4., 48 -> 28.81`4., 49 -> 
          28.98`4., 50 -> 28.88`4., 51 -> 29.05`4., 52 -> 28.87`4., 53 -> 
          28.5`4., 54 -> 28.28`4., 55 -> 28.2`4., 56 -> 28.13`4., 57 -> 
          28.58`4., 58 -> 28.64`4., 59 -> 28.42`4., 60 -> 28.59`4., 61 -> 
          27.84`4., 62 -> 27.18`4., 63 -> 27.12`4., 64 -> 27.22`4., 65 -> 
          27.21`4., 66 -> 27.2`4., 67 -> 27.84`4., 68 -> 28.16`4., 69 -> 
          28.65`4., 70 -> 28.65`4., 71 -> 28.93`4., 72 -> 28.38`4., 73 -> 
          28.13`4., 74 -> 28.14`4., 75 -> 27.56`4., 76 -> 26.35`4., 77 -> 
          26.39`4., 78 -> 26.23`4., 79 -> 25.94`4., 80 -> 26.07`4., 81 -> 
          26.06`4., 82 -> 26.26`4., 83 -> 26.79`4., 84 -> 26.76`4., 85 -> 
          26.63`4., 86 -> 26.37`4., 87 -> 26.45`4., 88 -> 26.09`4., 89 -> 
          26.`4., 90 -> 25.94`4., 91 -> 25.87`4., 92 -> 26.21`4., 93 -> 
          25.97`4., 94 -> 26.12`4., 95 -> 26.64`4., 96 -> 26.67`4., 97 -> 
          26.54`4., 98 -> 26.29`4., 99 -> 26.28`4., 100 -> 26.73`4., 101 -> 
          26.84`4., 102 -> 26.74`4., 103 -> 26.6`4., 104 -> 26.59`4., 105 -> 
          26.29`4., 106 -> 26.17`4., 107 -> 26.15`4., 108 -> 25.98`4., 109 -> 
          26.74`4., 110 -> 26.75`4., 111 -> 26.33`4., 112 -> 26.24`4., 113 -> 
          26.06`4., 114 -> 26.16`4., 115 -> 25.89`4., 116 -> 25.88`4., 117 -> 
          26.35`4., 118 -> 26.43`4., 119 -> 26.6`4., 120 -> 26.65`4., 121 -> 
          26.63`4., 122 -> 26.59`4., 123 -> 26.79`4., 124 -> 27.05`4., 125 -> 
          26.98`4., 126 -> 27.34`4., 127 -> 27.19`4., 128 -> 27.34`4., 129 -> 
          26.99`4., 130 -> 27.14`4., 131 -> 27.01`4., 132 -> 26.94`4., 133 -> 
          26.84`4., 134 -> 26.69`4., 135 -> 26.89`4., 136 -> 27.09`4., 137 -> 
          27.33`4., 138 -> 27.46`4., 139 -> 27.45`4., 140 -> 27.46`4., 141 -> 
          27.6`4., 142 -> 27.64`4., 143 -> 27.04`4., 144 -> 27.29`4., 145 -> 
          27.18`4., 146 -> 27.15`4., 147 -> 27.14`4., 148 -> 27.55`4., 149 -> 
          27.33`4., 150 -> 27.5`4., 151 -> 27.96`4., 152 -> 27.58`4., 153 -> 
          27.81`4., 154 -> 27.77`4., 155 -> 27.48`4., 156 -> 27.45`4., 157 -> 
          27.56`4., 158 -> 27.73`4., 159 -> 27.78`4., 160 -> 27.61`4., 161 -> 
          27.83`4., 162 -> 27.98`4., 163 -> 27.85`4., 164 -> 27.9`4., 165 -> 
          27.76`4., 166 -> 27.91`4., 167 -> 27.88`4., 168 -> 28.06`4., 169 -> 
          28.16`4., 170 -> 28.32`4., 171 -> 28.34`4., 172 -> 28.07`4., 173 -> 
          27.91`4., 174 -> 28.27`4., 175 -> 28.48`4., 176 -> 29.32`4., 177 -> 
          28.53`4., 178 -> 28.46`4., 179 -> 28.31`4., 180 -> 28.5`4., 181 -> 
          28.4`4., 182 -> 28.3`4., 183 -> 29.4`4., 184 -> 30.06`4., 185 -> 
          30.17`4., 186 -> 30.39`4., 187 -> 31.32`4., 188 -> 31.23`4., 189 -> 
          31.55`4., 190 -> 32.06`4., 191 -> 32.37`4., 192 -> 32.17`4., 193 -> 
          32.85`4., 194 -> 33.01`4., 195 -> 33.01`4., 196 -> 32.42`4., 197 -> 
          32.36`4., 198 -> 32.09`4., 199 -> 32.32`4., 200 -> 32.8`4., 201 -> 
          33.43`4., 202 -> 33.55`4., 203 -> 34.1`4., 204 -> 34.68`4., 205 -> 
          34.72`4., 206 -> 34.36`4., 207 -> 33.9`4., 208 -> 33.9`4., 209 -> 
          34.41`4., 210 -> 34.57`4., 211 -> 34.81`4., 212 -> 34.79`4., 213 -> 
          34.83`4., 214 -> 34.77`4., 215 -> 34.43`4., 216 -> 34.49`4., 217 -> 
          35.06`4., 218 -> 35.14`4., 219 -> 34.68`4., 220 -> 34.85`4., 221 -> 
          34.59`4., 222 -> 34.25`4., 223 -> 34.63`4., 224 -> 34.9`4., 225 -> 
          34.59`4., 226 -> 33.37`4., 227 -> 33.05`4., 228 -> 32.57`4., 229 -> 
          33.46`4., 230 -> 33.89`4., 231 -> 34.5`4., 232 -> 34.34`4., 233 -> 
          34.33`4., 234 -> 33.63`4., 235 -> 33.6`4., 236 -> 33.58`4., 237 -> 
          33.98`4., 238 -> 34.14`4., 239 -> 34.32`4., 240 -> 34.9`4., 241 -> 
          35.28`4., 242 -> 35.58`4., 243 -> 35.96`4., 244 -> 35.49`4., 245 -> 
          35.22`4., 246 -> 31.02`4., 247 -> 31.6`4., 248 -> 31.71`4., 249 -> 
          31.89`4., 250 -> 31.25`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$545642 = 
        Dispatch[{
         1 -> 28.3`4., 2 -> 28.88`4., 3 -> 28.76`4., 4 -> 28.6`4., 5 -> 
          28.54`4., 6 -> 28.33`4., 7 -> 28.87`4., 8 -> 29.06`4., 9 -> 
          29.37`4., 10 -> 29.43`4., 11 -> 29.6`4., 12 -> 29.52`4., 13 -> 
          29.49`4., 14 -> 29.43`4., 15 -> 29.5`4., 16 -> 30.07`4., 17 -> 
          30.18`4., 18 -> 30.03`4., 19 -> 30.09`4., 20 -> 29.83`4., 21 -> 
          29.56`4., 22 -> 29.85`4., 23 -> 29.98`4., 24 -> 29.92`4., 25 -> 
          29.94`4., 26 -> 29.62`4., 27 -> 30.11`4., 28 -> 29.69`4., 29 -> 
          29.69`4., 30 -> 30.62`4., 31 -> 30.23`4., 32 -> 30.01`4., 33 -> 
          30.08`4., 34 -> 30.07`4., 35 -> 30.22`4., 36 -> 30.49`4., 37 -> 
          30.49`4., 38 -> 30.46`4., 39 -> 30.33`4., 40 -> 30.72`4., 41 -> 
          30.47`4., 42 -> 30.07`4., 43 -> 29.69`4., 44 -> 29.47`4., 45 -> 
          29.46`4., 46 -> 29.07`4., 47 -> 28.81`4., 48 -> 28.97`4., 49 -> 
          29.17`4., 50 -> 29.33`4., 51 -> 29.16`4., 52 -> 29.09`4., 53 -> 
          28.6`4., 54 -> 28.31`4., 55 -> 28.28`4., 56 -> 28.52`4., 57 -> 
          28.83`4., 58 -> 28.81`4., 59 -> 28.91`4., 60 -> 28.82`4., 61 -> 
          27.98`4., 62 -> 27.35`4., 63 -> 27.4`4., 64 -> 27.25`4., 65 -> 
          27.23`4., 66 -> 27.56`4., 67 -> 27.88`4., 68 -> 28.84`4., 69 -> 
          28.82`4., 70 -> 28.94`4., 71 -> 29.17`4., 72 -> 28.41`4., 73 -> 
          28.14`4., 74 -> 28.16`4., 75 -> 27.57`4., 76 -> 26.68`4., 77 -> 
          26.43`4., 78 -> 26.26`4., 79 -> 26.12`4., 80 -> 26.33`4., 81 -> 
          26.31`4., 82 -> 26.54`4., 83 -> 27.28`4., 84 -> 26.98`4., 85 -> 
          26.67`4., 86 -> 26.95`4., 87 -> 26.54`4., 88 -> 26.22`4., 89 -> 
          26.03`4., 90 -> 25.97`4., 91 -> 26.27`4., 92 -> 26.33`4., 93 -> 
          26.06`4., 94 -> 26.53`4., 95 -> 26.91`4., 96 -> 26.83`4., 97 -> 
          26.7`4., 98 -> 26.4`4., 99 -> 26.69`4., 100 -> 27.14`4., 101 -> 
          26.9`4., 102 -> 27.26`4., 103 -> 27.04`4., 104 -> 26.65`4., 105 -> 
          26.45`4., 106 -> 26.55`4., 107 -> 26.15`4., 108 -> 26.31`4., 109 -> 
          27.2`4., 110 -> 26.84`4., 111 -> 26.34`4., 112 -> 26.29`4., 113 -> 
          26.15`4., 114 -> 26.3`4., 115 -> 26.06`4., 116 -> 26.42`4., 117 -> 
          26.48`4., 118 -> 26.8`4., 119 -> 26.63`4., 120 -> 26.84`4., 121 -> 
          26.84`4., 122 -> 26.74`4., 123 -> 27.19`4., 124 -> 27.21`4., 125 -> 
          27.46`4., 126 -> 27.49`4., 127 -> 27.59`4., 128 -> 27.43`4., 129 -> 
          27.04`4., 130 -> 27.51`4., 131 -> 27.03`4., 132 -> 27.08`4., 133 -> 
          26.93`4., 134 -> 26.87`4., 135 -> 27.13`4., 136 -> 27.44`4., 137 -> 
          27.46`4., 138 -> 27.61`4., 139 -> 27.62`4., 140 -> 27.59`4., 141 -> 
          27.85`4., 142 -> 27.68`4., 143 -> 27.3`4., 144 -> 27.57`4., 145 -> 
          27.18`4., 146 -> 27.18`4., 147 -> 27.62`4., 148 -> 27.61`4., 149 -> 
          27.76`4., 150 -> 27.95`4., 151 -> 28.15`4., 152 -> 27.89`4., 153 -> 
          27.94`4., 154 -> 27.81`4., 155 -> 27.68`4., 156 -> 27.72`4., 157 -> 
          27.73`4., 158 -> 27.94`4., 159 -> 27.84`4., 160 -> 27.9`4., 161 -> 
          27.98`4., 162 -> 28.12`4., 163 -> 27.91`4., 164 -> 28.05`4., 165 -> 
          27.96`4., 166 -> 27.96`4., 167 -> 28.17`4., 168 -> 28.41`4., 169 -> 
          28.41`4., 170 -> 28.6`4., 171 -> 28.36`4., 172 -> 28.4`4., 173 -> 
          28.5`4., 174 -> 28.39`4., 175 -> 29.4`4., 176 -> 30.07`4., 177 -> 
          28.74`4., 178 -> 28.59`4., 179 -> 28.49`4., 180 -> 28.77`4., 181 -> 
          28.63`4., 182 -> 28.59`4., 183 -> 29.56`4., 184 -> 30.62`4., 185 -> 
          30.39`4., 186 -> 31.54`4., 187 -> 31.72`4., 188 -> 31.57`4., 189 -> 
          32.38`4., 190 -> 32.87`4., 191 -> 32.49`4., 192 -> 32.93`4., 193 -> 
          33.26`4., 194 -> 33.51`4., 195 -> 33.08`4., 196 -> 32.76`4., 197 -> 
          32.43`4., 198 -> 32.46`4., 199 -> 32.8`4., 200 -> 33.53`4., 201 -> 
          33.85`4., 202 -> 34.08`4., 203 -> 34.87`4., 204 -> 35.08`4., 205 -> 
          34.85`4., 206 -> 34.61`4., 207 -> 34.15`4., 208 -> 34.27`4., 209 -> 
          35.02`4., 210 -> 34.88`4., 211 -> 35.03`4., 212 -> 34.9`4., 213 -> 
          35.59`4., 214 -> 34.99`4., 215 -> 34.78`4., 216 -> 34.96`4., 217 -> 
          35.67`4., 218 -> 35.47`4., 219 -> 34.84`4., 220 -> 35.`4., 221 -> 
          34.72`4., 222 -> 34.4`4., 223 -> 35.`4., 224 -> 34.98`4., 225 -> 
          34.59`4., 226 -> 33.49`4., 227 -> 33.27`4., 228 -> 33.72`4., 229 -> 
          33.67`4., 230 -> 34.35`4., 231 -> 34.62`4., 232 -> 34.54`4., 233 -> 
          34.36`4., 234 -> 33.94`4., 235 -> 34.01`4., 236 -> 34.21`4., 237 -> 
          34.33`4., 238 -> 34.35`4., 239 -> 34.7`4., 240 -> 35.69`4., 241 -> 
          35.67`4., 242 -> 36.17`4., 243 -> 36.27`4., 244 -> 35.74`4., 245 -> 
          35.44`4., 246 -> 31.4`4., 247 -> 32.01`4., 248 -> 31.82`4., 249 -> 
          31.96`4., 250 -> 31.39`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$545642 = True, 
        System`TradingChartDump`$gridlines$545642 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$545642, 
        System`TradingChartDump`$plotrangemin$545642 = 25.337956692913384`, 
        System`TradingChartDump`$plotrangemax$545642 = 37.48638507686539, 
        System`TradingChartDump`$layoutData$545642, 
        System`TradingChartDump`$gridlinesscope$545642 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$545642 = {True, True}, 
        System`TradingChartDump`$indicators$545642 = {
         FinancialIndicator["FullStochastic", 14, 3, 3]}, 
        System`TradingChartDump`$mouseQ$545642 = False, 
        System`TradingChartDump`$modelData$545642 = 
        System`TradingChartDump`modelData$543294, 
        System`TradingChartDump`$sy$545642 = Identity, 
        System`TradingChartDump`$isy$545642 = Identity, 
        System`TradingChartDump`$appearance$545642 = Automatic, 
        System`TradingChartDump`$perfgoal$545642 = "Quality", 
        System`TradingChartDump`$axesorigin$545642 = Automatic, 
        System`TradingChartDump`$framestyle$545642 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$545642 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$545642 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$545642 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$545642 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$545642, 
        System`TradingChartDump`$newgridlines$545642 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{25.337956692913384`, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$545642 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$545642 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$545642 = "GraphicsFrame", 
        System`TradingChartDump`$frame$545642 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$545642 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$545642 = 
              Switch[System`TradingChartDump`$highlightposition$545642, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$545642], {
                 1, System`TradingChartDump`$length$545642}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$545642], {
                 1, System`TradingChartDump`$length$545642}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$545642, 
                   Charting`nearestDate[System`TradingChartDump`$dates$545642, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$545642]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$545642]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$545642, 
                    Floor[System`TradingChartDump`$controlmin$545642] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$545642, 
                    Floor[System`TradingChartDump`$controlmax$545642]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$545642 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$545642 = 
            If[System`TradingChartDump`$fastpos$545642 =!= True, 
              System`TradingChartDump`$fastpos$545642 = 
               Clip[System`TradingChartDump`$fastpos$545642, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$545642 = (
                  Floor[System`TradingChartDump`$controlmax$545642] - Floor[
                  System`TradingChartDump`$controlmin$545642]) (
                  System`TradingChartDump`$fastpos$545642/100) + 
                Floor[System`TradingChartDump`$controlmin$545642]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$545642], {
                Floor[System`TradingChartDump`$controlmin$545642] + 1, 
                 Floor[System`TradingChartDump`$controlmax$545642]}], 
              System`TradingChartDump`$staticindicatorpos$545642]; 
           System`TradingChartDump`$mouseQ$545642 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$545642]], 
              System`TradingChartDump`$highlightposition$545642 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$545642 = If[
              And[
              System`TradingChartDump`$bouncingballQ$545642, 
               System`TradingChartDump`$mouseQ$545642, 
               System`TradingChartDump`$appearance$545642 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$545642[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$545642]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$545642[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$545642, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$545642[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$545642]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$545642[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$545642[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545642, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545642[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545642, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545642, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545642[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545642[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$545642 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$545642, 
                 System`TradingChartDump`$defaultframeticksstyle$545642, 
                 System`TradingChartDump`$defaultlabelstyle$545642, 
                 System`TradingChartDump`$framestyle$545642, 
                 System`TradingChartDump`$frameticksstyle$545642, 
                 System`TradingChartDump`$labelstyle$545642}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545642 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$545642, 
                 System`TradingChartDump`$labelstyle$545642, 
                 System`TradingChartDump`$defaultframeticksstyle$545642, 
                 System`TradingChartDump`$defaultlabelstyle$545642}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545642 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545642, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$545642 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545642, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$545642 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545642, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$545642 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$545642 = 
             Part[System`TradingChartDump`$tickstextstyle$545642, 1], 
             System`TradingChartDump`$tickstextstyle$545642 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545642[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545642, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545642[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545642[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545642[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$545642[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545642, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$545642]], 
                    Style[":", System`TradingChartDump`$textstyle$545642]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$545642[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545642]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545642[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$545642[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$545642, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$545642]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$545642[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545642, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545642[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545642, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545642, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$545642[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545642[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545642[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$545642[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$545642[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$545642], 1], 
                   Floor[System`TradingChartDump`$controlmax$545642]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$545642[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$545642[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$545642[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$545642[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$545642[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545642[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$545642[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$545642[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$545642[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545642[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$545642[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$545642[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$545642[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$545642[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$545642[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$545642, 
                  System`TradingChartDump`$mouseQ$545642], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$545642 - 0.5, 
                   System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$545642 === "Full", 
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$545642 + 0.5, 
                    System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545642, 1]}, {
                    System`TradingChartDump`$indicatorpos$545642 + 0.5, 
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$545642[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$545642, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$545642[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545642]]], {}]; 
              System`TradingChartDump`$subplotgridlines$545642[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$545642[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$545642[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545642[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$545642 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$545642, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545642, 
                   System`TradingChartDump`$opens$545642]], 12, 
                 System`TradingChartDump`$textstyle$545642, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$545642, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545642, 
                   System`TradingChartDump`$highs$545642]], 12, 
                 System`TradingChartDump`$textstyle$545642, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$545642, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545642, 
                   System`TradingChartDump`$lows$545642]], 12, 
                 System`TradingChartDump`$textstyle$545642, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$545642, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545642, 
                   System`TradingChartDump`$closes$545642]], 12, 
                 System`TradingChartDump`$textstyle$545642, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545642, 
                   System`TradingChartDump`$visdates$545642]], 12, 
                 System`TradingChartDump`$textstyle$545642, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$545642, 
                  System`TradingChartDump`$mouseQ$545642], {{
                  System`TradingChartDump`$timestampstyle$545642, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$545642 - 0.5, 
                    System`TradingChartDump`$plotrangemin$545642}, 
                    If[
                    System`TradingChartDump`$timestampdepth$545642 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$545642[1]}, {
                    System`TradingChartDump`$indicatorpos$545642 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545642}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545642, 1]}, {
                    System`TradingChartDump`$indicatorpos$545642 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545642}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$545642, {
               System`TradingChartDump`$highlightstyle$545642, 
                Dynamic[System`TradingChartDump`$ohlcpoint$545642]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$545642[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545642, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$545642[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$545642[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$545642, Length[
                    System`TradingChartDump`$layoutData$545642[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$545642}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$545642] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$545642] + 0.5}, {
                System`TradingChartDump`$plotrangemin$545642, 
                 System`TradingChartDump`$plotrangemax$545642}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$545642, Left, {
                 False, System`TradingChartDump`$frame$545642}, 
                 Blank[], {System`TradingChartDump`$frame$545642, False}], {
                False, System`TradingChartDump`$frame$545642}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$545642, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$545642]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$545642 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           387.0228610767757}, {-286.92264150943396`, -65.76792452830183}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545642 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545642, 1]], 
               Part[System`TradingChartDump`$framestyle$545642, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$545642]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$545642} -> 
                   System`TradingChartDump`$isy$545642[
                    System`TradingChartDump`$plotrangemin$545642], {
                    0, System`TradingChartDump`$plotrangemax$545642} -> 
                   System`TradingChartDump`$isy$545642[
                    System`TradingChartDump`$plotrangemax$545642]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$545642[
                   System`TradingChartDump`$plotrangemin$545642], 
                   System`TradingChartDump`$isy$545642[
                   System`TradingChartDump`$plotrangemax$545642]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$545642, 
                   System`TradingChartDump`$isy$545642}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545642, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545642 > 
                    System`TradingChartDump`$plotrangemin$545642, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545642 > 
                    System`TradingChartDump`$plotrangemin$545642, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545642, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545642 > 
                    System`TradingChartDump`$plotrangemin$545642, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545642 > 
                    System`TradingChartDump`$plotrangemin$545642, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545642, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545642, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545642 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545642,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545642], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545642 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545642, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545642]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$545642, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$545642[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$545642[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545642, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$545642[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$545642, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545642[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545642, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545642[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545642[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545642[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545642[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545642], 
                    Style[":", System`TradingChartDump`$textstyle$545642]], 
                    Style[":", System`TradingChartDump`$textstyle$545642]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$545642[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545642]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545642[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$545642}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$545642, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$545642 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$545642[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$545642, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$545642, Left, {
                    False, System`TradingChartDump`$frame$545642}, 
                    Blank[], {
                    System`TradingChartDump`$frame$545642, False}], {
                   System`TradingChartDump`$frame$545642, 
                    System`TradingChartDump`$frame$545642}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$545642, 
                    System`TradingChartDump`$controlmax$545642}] + 0.5, {
                   System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$545642]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$545642) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$545642 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$545642 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$545642, 1]], 
                   Part[System`TradingChartDump`$framestyle$545642, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$545642]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545642[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545642[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$545642[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545642, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545642, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$545642, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$545642, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$545642 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
545642, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$545642], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$545642 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$545642, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$545642]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$545642, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$545642) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$545642 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$545642[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           475.9407855006933}, {-55.989622641509406`, -0.7009433962263785}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$545642, 
              Dynamic[System`TradingChartDump`$ohlclabel$545642], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$545642}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545642 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545642, 2]], 
               Part[System`TradingChartDump`$framestyle$545642, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$545642]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$545642, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$545642, 
                    System`TradingChartDump`$controlmax$545642}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$545642] + 
                    0.5, System`TradingChartDump`$plotrangemin$545642}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$545642], 
                    System`TradingChartDump`$plotrangemin$545642}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$545642, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545642, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545642, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545642 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545642, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545642], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545642 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545642,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545642]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, \
-20.802201552843357`}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$545642] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$545642[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$545642] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$545642[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$545642] = {HoldPattern[
               System`TradingChartDump`$min$545642[1]] :> 2.86}}, {
          DownValues[System`TradingChartDump`$max$545642] = {HoldPattern[
               System`TradingChartDump`$max$545642[1]] :> 98.88}}, {
          DownValues[System`TradingChartDump`$subplotvalue$545642] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$545642[1, 1]] :> 
             Invisible[13.], HoldPattern[
               System`TradingChartDump`$subplotvalue$545642[1, 2]] :> 
             Invisible[14.4]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$545642] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$545642[1]] :> {50, 
              100}}}, {
          DownValues[System`TradingChartDump`$layoutData$545642] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$545642["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "AllValues"]] :> CompressedData["
1:eJxVVgk8VVv7Fo1Cg6GuSlKZKhS5nb323uc5XE1mGZtHXEMpypdyQyFSEn2K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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545642["AppendedAdjust"]] :> 
             9.602504996731303, HoldPattern[
               System`TradingChartDump`$layoutData$545642["AppendedBox"]] :> {
              2.4286565337483563`, 128.54698083265146`}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "AppendedMin"]] :> -1.9440095174852323`, HoldPattern[
               System`TradingChartDump`$layoutData$545642["AppendedRatio"]] :> 
             0.9999999999999999, HoldPattern[
               System`TradingChartDump`$layoutData$545642["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$545642["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$545642["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545642["DataMax"]] :> 
             36.43, HoldPattern[
               System`TradingChartDump`$layoutData$545642["DataMin"]] :> 
             25.86614923134608, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "MainChartAllValues"]] :> CompressedData["
1:eJxdlglYzdv6x1OZ0mBocEISmtBAOvZv2t9dJ1NzGs1jdRqIoiuiolJSGtwo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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "MainChartPoints"]] :> CompressedData["
1:eJxdlltoXFUUhqdFUIKgYkSRUqdVSqylVGNtmzbJTmqaNEmTTO6XSXLmfp9U
pCiRyqFShCIEn0QRGS/4IhTBlyAqscUnKyIoVRCZIoiQIgWplD6Zk/V/D+cc
CMOftf/9r9tee+9Jr4zn7onFYne3/nbob2eM71b3D9e2vuETTv9wN1ZbL/ff
AN/nrt5uS65dAT/o3ns3+MCtruX6x2c7L4EfcwF7dRK8yz1xcTOx/gc47tau
bG34QKfwXrMvgZ9yAb21Dt4nPXCbC5bvvgje7zoDB86DD0T4B+3XBx9y41vs
zYe6hJ+19QfBz7mBIAH3gttdEF7Lo+DnLb6f2e+wxbMGfsH8/Q18xL0WEO6C
j7qbgfub4GPupSCAW+AOy8cH4OMuGQjsQv+Erf8ce2cEd4nP+m7T7wA7q+dO
Yd9ZPK3Ye8L58XtcABNHsfcq39gjOHbS/Re0yznsJ9UP2F+0/daxC7+KvS+i
3xeJ75TWC/unpIe9X3zs/VafH+m/AePfEfYHrB7PwD8tf+Gfdk9vFwD7oPoB
+2DkPAyZ3ij7D1k/9WMfVv9iH1Y/YT8T9tc/Y/p/Yx+x+H7CPqL+Oi77qPkz
J+yPuvz2h33Mfp2wG1N/sH5M/Sy8MaZ5AD9h8V+XvktE/Emon4U3EpH8jls8
Rfjj7pNguyfhy94Gf9z2fxv9CTuvlzvEF64L+xPW373CGxN2HnYLxyZVX/iT
qhf8Sc0z+JOqH/pTyjf8KYvvM/hTrj34/oU/Fd4vNq3zBH9a8wa+7HeOiT9t
/dIHfybi/4zmKfwZ2+9N9GfUP/Bn1W/wZ83fL+DPql/gz+r8wZ9TveifOVv/
F/w55Z/+mbP4W8jfvK3/FP15038Z/rzbvo/eQl/r96G/EK6XWzB+O/27oP6E
LzwDP2n+DMJPhvf3k6Y/DD8Zzm9s0epdgb9o/bAKf9H41+Av2vn5EP5S2D8X
wf6SzdOv4S9Z/g+Rv2Wbd4fJv/A54l/WPCb/y7b/O/A9nRfhuBeuj/OsfheE
PU/9yf6e7gvhhvb7B3893ffCTc/i34N+yuI5i34q7L9L2X33Pvop3Wfop8Lx
NFK6b4k3pfkg3Eypnuinw/Mkntb9j34Ee+mIfjrsXyOt9xH6aZ1/9NPqL+Z3
xs7Pn+hnNC/Rz2j+o58Jx+NndH+in7H++xL9yH7NjPqL+LM6r+hnw/eHy2pe
yl8vq/mBftbyeb/sjazV7zb6EdzMav4Tfy48/+MR7HLh+9TLWb6T3A85zSf0
c/o/90XO8psRbrKe+ycffl/E8zpv6OfVX+jLfh79vM3j79DP63yjH+E385H3
YSH8PosX5K+wK+i+6JZ+QfUW9gvqX+FGQfPBSb9geivCTel1CceK5t8rwvGi
/Bd2wt8Ke0X5I+zLnhJuaL8j6Bf1nkC/qPyjX7J4r6Jfsn66iX5J86hH+iXF
I+zLfkm4IX5VeKNk52VEuFmy8/iwcKxs53WvcFz4grAraz6hXzZ/30C/rPsK
/bL19/foly3fr6Mvfgb9iu4L9Ct2Xn5Bv2L9/hX6Fd036Ff0i77WJ9Gv6D5E
P7I+VlU/o1+1/YfQr5r/31D/quXnI+pfNb3fqX9V/lP/qtXjAPpV3dfo1/Se
Qb+meYt+Te8f9GvWbzuIv2b5e5z4a9YP+4m/FtGv6T2Mft32/xX9eiT/wo/0
Sr+ufhH267rf0Nd+6+jX1e86n826/Kf/V/Relj2+onkp7FbUL93ufxyzRGk=

              "], HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545642["NewSubplot"]] :> {
               FinancialIndicator["FullStochastic", 14, 3, 3]}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545642["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "PlotRangeMin"]] :> -1.9440095174852323`, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$545642["Space"]] :> 
             3.6430000000000002`, HoldPattern[
               System`TradingChartDump`$layoutData$545642["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, 20}, {250., 20}}], 
                    Line[{{0, 80}, {250., 80}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJw9VwdUk2cXjlsE46hSVEawgKCCgAoUFB9QlmGD7JGEEEIIqIALEFKxiAOk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                    "]]}, {
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Line[CompressedData["
1:eJw9Vgs4lekW3kMuFY2GUClboUZSck943eV+v9O23bbL3qKiVNohaTISMUPS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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "SubplotIndicatorGridLines"]] :> {{50, 100}}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "FullStochastic"}]], 
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], " ", ""}]]}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["FullStochastic", 14, 3, 3]}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "SubplotIndicatorParameters"]] :> {{{14, 3, 3}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "SubplotIndicatorPoints"]] :> CompressedData["
1:eJxtmQmMnGUZxxdiWkTksC3UWsquQm+bbbvb3V7bb3fb7tGd45u72+129pju
vS1eSL0Gm2qjhmKUWFBxsHhETYUQQ8FoBlAhiFE8UjVIthqNgYaUmErTADr7
/P/PfzPGSTaT377P977vc77P907d4KFE4W01NTVXVP4uV/6u5B8+F3Ykziw7
9soN64P/zzXBr56vfHq6xefDisBEK/kqfBcjYnv+9l3k64MTT11c2fepUPzQ
4e1Xn22PkhcGq/oqEp17xLOPhyd9fHFw7sjC0x13tYufrkx3os3llwanOyoS
d3eKO2cfeKaDXAv5v8bEt1eWPxXvIr83WDQ7wUNp8S2V5c88ECffyv1nxGdP
VRSYnyIvh/yrGbHZZ5/zStgjnONZ8WX3Oq+G/C/TYrNHzsfXwv7nU2LT97TL
r4N+v02JbXydj9cHG2c/R+d45GDlc6Pzetj3tYzY5nvKxzdg/cms2OxXcvmN
WG86K4Z/nRtgn0+mxWaOZ/35RtjntVBs9rno+mwK7r+v8vlTTGz++lCC3AR9
fhET/3t2+/e6/5rxfTgUf6yi7rlxH9+M5z8Sik2fV318C9b7co/Y5i/4+FbY
4+GY2OZ/wnkb9P1jt/hqCyDPl+2wz0+7xbC3r9eC/VwbEVu8fN7jfwfsdy4u
tvX/7PJB0DK74M0JscnfRfliwP9HxIh3n681mA3HlS92i+35R5ifxVbkQzYi
Nnse9P23YT+9odj0ifrzbdDnPSmx2TPv8sz736TFtv6TScq3w14/SIlN3794
/OzE+kfSYovvBLm4k/UnJcZ6/vwu1JM7QjH85evvwvrXtIstfo+5/3dDftl6
MeKZ6xR3Ix4+Vye2eEs1Ur4D+/turdj0f2E55TuCe2b9dWKJGPXhFsp3wr6v
LBDb+ve5vPNyMeZbRvkurD+6UWz6Pr+C8l3Qr3+TGPng+nZT/0ax5cOlBsp3
o16cWi225y9soPwe6rNUbP79yRrK+/h8sfmrw/XvoT+WiSF/E+V7EA+fbhBj
/lspHwksnP8xlycW3992+Qjy443dYsuHx1w+ivr7wU5x1flYjNL/bWJb/00/
P2OoN42NYsQ3z99ijOddndjsOUR/1MQRTwtrxTi/V4GDOOa/eLMY9qN8Mc78
WS5GPeB65Tji4QubxLA3/VMTYv2GLrHF13XbuF6I+PpnKLZ4fDftVQxhn96M
2OrTNyhfDrH+0ozY9vuc528Cz48nxTbezfwPEtD3s1ExznPWy2IC+7mzQ4zz
ivJlznd/q9ief8n7jyT93yw2+/yc8kGS/r9NDHs3cb0k8/dd4qp8KSdxfp+b
J8bzi7leCv7qu1FseOIGrpeC/z9cJ8Z8lC+m2L+sEtv8l93/Pl+jGP3TWq6X
hv9/v1WM/GP+BGnEw6+3i3F+bOF6acbTdjHih1wmn9gqRn1hfNVkkI9nm8QY
5/wBx7NrxKhf1KeYoT2XiJE/7+d6Gfj30RVijNOfNVnmb4MY+er5l2U+NYnh
X9a/Ip//0Xax7fcrjKcy+6z8LjH6Ba8/Oaw3Pyq2+RaxXgU5xndcjHrN87tI
fmmPGOelx38O+u7ZI8Z54P3HXsZfXAx5jgd7kb9vJMS2fNr7k73sb9Jis88C
5nOZ8/04Jbb9Hff87+V6SbH56xTHg17s7+M9YrPvTZ7/vYjH5bvFOB+4/3Iv
4qV+qxjnpdfvffRnkxj+3MH1OP63drHtb2ML19vH+aNiO6++yf6hzPF7omLk
r/drfdBvW7sY/QTHgz7W+0ax2f8270/6UJ+6G8TIX+ZPuY/nTb0Y9cL7hf1c
r1ls+z3s+b+f8dwixv69/lH++k6x5eMWr7f7sf7RbjHOM7d/P+0dFdv2FjNe
g37E39qY2PZzh/ez/VwvLkY9p3y5H98PJ8S23h883g+gPh5Iis0eiz3eD0Df
9Wkx5vH+8gDPw5TY9t/s8X4A+21Ki7G+x38e/lyUFqN/43htHvq8Lyk2fx/x
/MjjO58Q2/rHKZ/PY/8PRsUWb1/j+VzMV7/fVxjv67Rfifv7Vls1H2O/UM4z
nlrEqCeMz5k86/UOMfoRr38DPE92i6E/46d2gP1RVIz3Sa+PA8iPpoQY+cz4
yA8w/5Jiqzdfdf0HqvuRIuf/DOVLA7D35bTY/PmM+3cA/u9Ki9EPkWc4vipR
zXe6/wf5PhEToz5TvnaQ/WanGPnn/dAg/P3Rjmo+yXzLD0K/JZ1i1CvP10H6
t0ds9hyhf0uDvD8IxegXvb4Osr4kxeb/ayg/Mwh7rUiLLZ6Tnm9D2O9oSoz7
H4//Iewnm6jm1/l8wOdXxsVmrwjl80PsdyJi+z7s9WII/nquW2z7+xLlS0PM
7y6xxc8aP0+H4I8reqr5Qc434+MRMfzr9wPD3FdMjH6P8rXD9H9UjPsV9/8w
9Q/F6LepX57z188xzhPXfxjn1Qfm2OrBSXKJ81+KiKGn19dh9l9zXFV/Z4YR
X7tCsen/lutbQP2oS4nxfkb52gLlM+Iq+aDAepEVW/mJUT5fQPz2p8Wmzxl/
XynA/1uSYpwvnu8F1odQjPsoj/cC/PP1UGzjmzzfC4ifzUkx+k2/7zkI/ntK
bPq2eL0nXzvHtt8nPP75fGNEbN/1Hv/kfKsY/Ybn+0H4a0GrGOcXz+cSny8F
YivX8/x89/XnGPFC+ZmD8Md1HWKz7+tt1HcE8bchLsb6Xu9GsL+hlNjs+XbP
9xH+PyO2+Pii1/sR3vemxeiXvF8dgX9fTolxn+T+H0E98vumEsfne73n/o5m
xHif9XrH/byQreYBv18dRX1ozYnxvkv52lHkY3NOjHpEDkbxfvXDOYa9yPlR
1res2OyxlePFUfZvGTH0oXxplPUhKbb68zPXf5T5H4ptve95vI/y/i0UWz6+
5fd1Y/g+nBSj3nn+j/H8zIjRP3j8j7Efzolt/Zfd32Os/zkxfk+gfsUx1oOc
GPfh5NIY/HE2K7b1Chwvj/3P/Qafv9v9Pcb+NClG/nq/N87+NxTb86c938fh
/2cTYpxP3u+QH02J4U+P/3HE1yMZsdnzcY/3ceRjR0aM9x2Pf+5nXVZs9njM
9R1nf5EW23c9x2eo37GE2L4veL2bYL5Hxah/ru8E9pMMxXgf9fyf4P1OUozf
ZyifJ19KiPF+5u+PE7BXTVyMfp/jJc7f2yW2/Tzt590E7PGdNjHuKyg/M1Fd
Xytc1R/XTGK9J1vFuI/x/ncSz/+uXQx7cb2AfKlZjH6b9Tc/Sb1WiNFfbOb/
J1kP68VWH77P++HSJPN3ixj1j/cfZY6f3ymuuj+c4Xzv6BZDT9d/CufDjrjY
8v8TlK+dYv8Yis0e//L+h/JvxsQ4v73fmeJ+ImLkE+WLU+z3e8S47/F+h+Pz
YmLcB3r/O8Xfy+Ji/H7k/c8U7PNiQmz7fafn+zSez6XFZo//ePxz/HhWDHv5
++g04mcgJ8bvh17vp3lflBNb/F/p9W4a++vLiHF/6/nO5x9Iis1+V3n+T/O+
oVOM34tc3+nq+5IKIz/8/uMQ72tWix+3eKZ87SGen/Vi07fO7ycO8bnVYvSD
a4P/AhOaf1g=
              "], HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "SubplotIndicatorValues"]] :> CompressedData["
1:eJw9lwtsVFUQhosmoIgg8rRC6UahFNCUsqWlQHu2pd337n3uboQgSACDRkFF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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$545642["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$545642["YRange"]] :> 36.43,
              HoldPattern[
               System`TradingChartDump`$layoutData$545642[
               "SubplotPoints", {1}]] :> CompressedData["
1:eJw9l3lsVFUUxit/gCKyyGqFQqMsBSQFprQUKHda2pnO+taZCRAECUvQKKiI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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545642[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$545642[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$545642[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$545642[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$545642[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$545642 = 
           System`TradingChartDump`$length$545642; 
          System`TradingChartDump`$layoutData$545642["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$545642; 
          System`TradingChartDump`$modelData$545642["Data"] = 
           System`TradingChartDump`$data$545642; 
          System`TradingChartDump`$modelData$545642["Indicators"] = 
           System`TradingChartDump`$indicators$545642; 
          System`TradingChartDump`$layoutData$545642[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545642["ScalingFunctions"] = {
            System`TradingChartDump`$sy$545642, 
             System`TradingChartDump`$isy$545642}; 
          System`TradingChartDump`$layoutData$545642["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545642["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545642[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545642["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$545642["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$545642, 
            System`TradingChartDump`$layoutData$545642, 
            System`TradingChartDump`$indicators$545642]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$545642, 
            System`TradingChartDump`$layoutData$545642, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$545642[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$545642["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$545642[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$545642[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$545642["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$545642[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$545642 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545642["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545642, 
                 System`TradingChartDump`$controlmax$545642}]]]; 
          System`TradingChartDump`$plotrangemax$545642 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545642["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545642, 
                 System`TradingChartDump`$controlmax$545642}]]]; {
            System`TradingChartDump`$plotrangemin$545642, 
             System`TradingChartDump`$plotrangemax$545642} = ReplaceAll[
             
             System`TradingChartDump`$sy$545642[{
              System`TradingChartDump`$plotrangemin$545642, 
               System`TradingChartDump`$plotrangemax$545642}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$545642[
                Min[System`TradingChartDump`$lows$545642]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$545642 == 
            System`TradingChartDump`$plotrangemax$545642, {
             System`TradingChartDump`$plotrangemin$545642, 
              System`TradingChartDump`$plotrangemax$545642} = {
             System`TradingChartDump`$plotrangemin$545642 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$545642], 
              System`TradingChartDump`$plotrangemax$545642 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$545642]}]; 
          System`TradingChartDump`$newgridlines$545642 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$545642, 
            Part[System`TradingChartDump`$newgridlines$545642, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$545642, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$545642], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$545642, 1]]; 
            Part[System`TradingChartDump`$newgridlines$545642, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$545642, 1] =!= None,
                 System`TradingChartDump`$length$545642 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$545642, 
                 Part[System`TradingChartDump`$newgridlines$545642, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$545642, 1]]; 
            System`TradingChartDump`$subpricegridlines$545642 = 
             Part[System`TradingChartDump`$gridlines$545642, 2]; 
            Part[System`TradingChartDump`$newgridlines$545642, 2] = 
             If[System`TradingChartDump`$sy$545642 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545642}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545642, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545642, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$545642, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$545642, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545642}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545642, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545642, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$545642 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$545642]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"MSFT\"", "\" with \"", 
           "\"FullStochastic\"", "\"(\"", "14", "\",\"", "3", "\",\"", "3", 
           "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {240., -502.20000000000005`}, 
      ImageScaled[{0.5, 0.5}], {450, 310}], InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$545658 = 
        "Full", System`TradingChartDump`$highlightposition$545658 = Automatic,
         System`TradingChartDump`$maxohlc$545658 = 36.43`4., 
        System`TradingChartDump`$timestampstyle$545658 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$545658 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$545658 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$545658, 
        System`TradingChartDump`$subplotpoint$545658, 
        System`TradingChartDump`$ndigits$545658 = 4, 
        System`TradingChartDump`$highlightstyle$545658 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$545658 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$545658 = True, 
        System`TradingChartDump`$timestampQ$545658 = True, 
        System`TradingChartDump`$data$545658 = {{{2012, 7, 26}, {
          28.367935528120714`, 28.62997256515775, 28.232064471879287`, 28.3, 
           45301400}}, {{2012, 7, 27}, {
          28.60827956989247, 28.967338709677417`, 28.317150537634404`, 28.88, 
           44242600}}, {{2012, 7, 30}, {
          28.866734143049936`, 28.934655870445347`, 28.58534412955466, 28.76, 
           28905000}}, {{2012, 7, 31}, {
          28.609704784526638`, 28.832914828639293`, 28.464133016627077`, 28.6,
            37620900}}, {{2012, 8, 1}, {
          28.714675280516833`, 28.77290037402244, 28.3459163549813, 28.54, 
           31721800}}, {{2012, 8, 2}, {
          28.349410757108597`, 28.65998287084618, 28.11648167180541, 28.33, 
           39520500}}, {{2012, 8, 3}, {
          28.65650756302521, 29.054379831932774`, 28.60798655462185, 28.87, 
           35859400}}, {{2012, 8, 6}, {
          29.108514190317194`, 29.215245409015022`, 28.924160267111848`, 
           29.06, 27471800}}, {{2012, 8, 7}, {
          29.185588235294116`, 29.457352941176467`, 28.99147058823529, 29.37, 
           28002900}}, {{2012, 8, 8}, {
          29.31356083086054, 29.56584569732938, 29.21652818991098, 29.43, 
           26257600}}, {{2012, 8, 9}, {
          29.493245901639348`, 29.745573770491806`, 29.40590163934427, 29.6, 
           24920800}}, {{2012, 8, 10}, {
          29.59763313609467, 29.714082840236685`, 29.355029585798814`, 29.52, 
           27810300}}, {{2012, 8, 13}, {
          29.451184600197433`, 29.55792694965449, 29.26681145113524, 29.49, 
           23049100}}, {{2012, 8, 14}, {
          29.596050448058413`, 29.68395950879522, 29.31278791901759, 29.43, 
           34551400}}, {{2012, 8, 15}, {
          29.412086092715235`, 29.578145695364242`, 29.324172185430466`, 29.5,
            24351000}}, {{2012, 8, 16}, {
          29.65968810916179, 30.22630929174789, 29.561994801819363`, 30.07, 
           35787200}}, {{2012, 8, 17}, {
          30.19953398058253, 30.19953398058253, 29.87722330097088, 30.18, 
           32589900}}, {{2012, 8, 20}, {
          30.108152244632407`, 30.13745933636956, 29.873695510735203`, 30.03, 
           23737700}}, {{2012, 8, 21}, {
          30.050922077922078`, 30.24631168831169, 29.90437987012987, 30.09, 
           28822700}}, {{2012, 8, 22}, {
          29.878837590045844`, 30.044885396201707`, 29.761627373935823`, 
           29.83, 33437400}}, {{2012, 8, 23}, {
          29.68699272967614, 29.696761401189683`, 29.384163912756108`, 29.56, 
           28355600}}, {{2012, 8, 24}, {
          29.547202225130892`, 29.91837369109948, 29.478828534031415`, 29.85, 
           22943300}}, {{2012, 8, 27}, {
          30.214447702834796`, 30.243753665689148`, 29.88231345715216, 29.98, 
           34691100}}, {{2012, 8, 28}, {
          29.988377407770162`, 30.08605941887039, 29.81254978778975, 29.92, 
           23947900}}, {{2012, 8, 29}, {
          29.940000000000005`, 30.037683523654167`, 29.734864600326272`, 
           29.94, 23346800}}, {{2012, 8, 30}, {
          29.82515171503958, 29.90330474934037, 29.52230870712401, 29.62, 
           23982100}}, {{2012, 8, 31}, {
          29.895068137573006`, 30.246774821544452`, 29.68013627514601, 30.11, 
           36590100}}, {{2012, 9, 4}, {
          29.748617966436328`, 29.953780848963476`, 29.45552813425469, 29.69, 
           48556700}}, {{2012, 9, 5}, {
          29.523915761763735`, 29.8267752550181, 29.51414610069102, 29.69, 
           33650000}}, {{2012, 9, 6}, {
          29.789792663476874`, 30.629767145135563`, 29.750724082934607`, 
           30.62, 48371700}}, {{2012, 9, 7}, {
          30.317906300484655`, 30.347208400646206`, 30.01511793214863, 30.23, 
           42649100}}, {{2012, 9, 10}, {
          30.11745768229167, 30.185839843750003`, 29.804853515625005`, 30.01, 
           40524000}}, {{2012, 9, 11}, {
          29.982305943488143`, 30.197232867814222`, 29.90415069827866, 30.08, 
           25191800}}, {{2012, 9, 12}, {
          30.22630929174789, 30.46077322936972, 30.021153346328784`, 30.07, 
           32775800}}, {{2012, 9, 13}, {
          30.171163542340008`, 30.454414996767934`, 29.692566257272134`, 
           30.22, 45047300}}, {{2012, 9, 14}, {
          30.29461390579942, 30.52907721884011, 30.09922781159884, 30.49, 
           51422800}}, {{2012, 9, 17}, {
          30.47046139057994, 30.53884652355014, 30.323921819929506`, 30.49, 
           36488500}}, {{2012, 9, 18}, {
          30.381847338037208`, 30.489307248236052`, 30.31346375881976, 30.46, 
           34542700}}, {{2012, 9, 19}, {
          30.369072463768113`, 30.466753623188403`, 30.320231884057968`, 
           30.33, 48871900}}, {{2012, 9, 20}, {
          30.231605723370425`, 30.74930365659777, 30.19253418124006, 30.72, 
           45543000}}, {{2012, 9, 21}, {
          30.704459762744467`, 30.88030458480282, 30.3723084321898, 30.47, 
           102348900}}, {{2012, 9, 24}, {
          30.284925276153345`, 30.353310591293045`, 29.933229369720596`, 
           30.07, 46825900}}, {{2012, 9, 25}, {
          30.23710102007239, 30.285949325435997`, 29.660691016781836`, 29.69, 
           54266400}}, {{2012, 9, 26}, {
          29.577447795823662`, 29.890023201856145`, 29.3430162412993, 29.47, 
           54672000}}, {{2012, 9, 27}, {
          29.46976790450929, 29.694429708222817`, 29.196266578249343`, 29.46, 
           47129900}}, {{2012, 9, 28}, {
          29.480262096774194`, 29.558407258064516`, 29.050463709677416`, 
           29.07, 54229300}}, {{2012, 10, 1}, {
          29.122621227534758`, 29.288701254662598`, 28.741614106476774`, 
           28.81, 54042700}}, {{2012, 10, 2}, {
          28.98953472690492, 29.194649359406608`, 28.813722184760618`, 28.97, 
           43338900}}, {{2012, 10, 3}, {
          29.062541862022776`, 29.296995981245818`, 28.98439048894843, 29.17, 
           46655900}}, {{2012, 10, 4}, {
          29.271398601398595`, 29.329999999999995`, 28.880722610722604`, 
           29.33, 43634900}}, {{2012, 10, 5}, {
          29.531216080402007`, 29.55075376884422, 29.052542713567835`, 29.16, 
           41133900}}, {{2012, 10, 8}, {
          28.953243787777033`, 29.226756212222973`, 28.865329079919412`, 
           29.09, 29752000}}, {{2012, 10, 9}, {
          28.990710382513658`, 29.049316939890705`, 28.502322404371583`, 28.6,
            45121100}}, {{2012, 10, 10}, {
          28.476069703243613`, 28.632370600414074`, 28.280693581780536`, 
           28.31, 47227100}}, {{2012, 10, 11}, {
          28.543751295336786`, 28.573056994818653`, 28.20185146804836, 28.28, 
           41488500}}, {{2012, 10, 12}, {
          28.29535616438356, 28.637205479452053`, 28.12931506849315, 28.52, 
           46464700}}, {{2012, 10, 15}, {
          28.693226025076243`, 29.03516096238563, 28.57599118942731, 28.83, 
           42440200}}, {{2012, 10, 16}, {
          28.770922346558155`, 29.054235334011526`, 28.643919972872162`, 
           28.81, 47739400}}, {{2012, 10, 17}, {
          28.626664413653266`, 28.958850963163233`, 28.421490368367696`, 
           28.91, 44206100}}, {{2012, 10, 18}, {
          28.966542372881356`, 29.044698305084747`, 28.585532203389832`, 
           28.82, 59238500}}, {{2012, 10, 19}, {
          28.380551675977653`, 28.409860335195525`, 27.843226256983236`, 
           27.98, 90470800}}, {{2012, 10, 22}, {
          28.063053571428572`, 28.16073214285714, 27.183946428571428`, 27.35, 
           83374000}}, {{2012, 10, 23}, {
          27.126488413547236`, 27.546524064171123`, 27.116720142602496`, 27.4,
            64414800}}, {{2012, 10, 24}, {
          27.503942652329755`, 27.543010752688176`, 27.220698924731188`, 
           27.25, 53320400}}, {{2012, 10, 25}, {
          27.532772596843618`, 27.542539454806313`, 27.210466284074606`, 
           27.23, 54084300}}, {{2012, 10, 26}, {
          27.21806451612903, 27.687004608294927`, 27.198525345622116`, 27.56, 
           57790000}}, {{2012, 10, 31}, {
          27.88976874562018, 28.21213735108619, 27.840925017519268`, 27.88, 
           69464100}}, {{2012, 11, 1}, {
          28.17566395663957, 28.879078590785912`, 28.15612466124662, 28.84, 
           72047900}}, {{2012, 11, 2}, {
          28.907925423728813`, 29.08377627118644, 28.653918644067797`, 28.82, 
           57131600}}, {{2012, 11, 5}, {
          28.930232872089103`, 29.047438407019914`, 28.646986162672967`, 
           28.94, 38070800}}, {{2012, 11, 6}, {
          29.13092431346283, 29.50214333556598, 28.92577695914267, 29.17, 
           43401500}}, {{2012, 11, 7}, {
          28.849632049518576`, 29.14272008253095, 28.380691196698766`, 28.41, 
           57871800}}, {{2012, 11, 8}, {
          28.442790697674425`, 28.68697674418605, 28.13023255813954, 28.14, 
           49841800}}, {{2012, 11, 9}, {
          28.2088380159556, 28.511633714880336`, 28.14046479361776, 28.16, 
           43291200}}, {{2012, 11, 12}, {
          28.273416017009215`, 28.341803685329555`, 27.560230333097095`, 
           27.57, 61112300}}, {{2012, 11, 13}, {
          26.611059431524552`, 26.88682170542636, 26.345145810262093`, 26.68, 
           131689200}}, {{2012, 11, 14}, {
          26.823889716840533`, 26.873125931445603`, 26.390611028315945`, 
           26.43, 76086100}}, {{2012, 11, 15}, {
          26.476699174793698`, 26.565348837209303`, 26.230450112528132`, 
           26.26, 50955600}}, {{2012, 11, 16}, {
          26.267737556561087`, 26.2972850678733, 25.942714932126695`, 26.12, 
           64083300}}, {{2012, 11, 19}, {
          26.398952487841374`, 26.398952487841374`, 26.07389075944631, 26.33, 
           57179300}}, {{2012, 11, 20}, {
          26.359251216772744`, 26.39865219019094, 26.06374391613628, 26.31, 
           47070400}}, {{2012, 11, 21}, {
          26.30365120593692, 26.75665306122449, 26.264259740259742`, 26.54, 
           66360300}}, {{2012, 11, 23}, {
          26.817126353790613`, 27.348938628158844`, 26.787581227436824`, 
           27.28, 57845700}}, {{2012, 11, 26}, {
          27.127754654983573`, 27.167155896312522`, 26.763293172690766`, 
           26.98, 85198700}}, {{2012, 11, 27}, {
          26.945760709010344`, 26.96545790251108, 26.630605612998526`, 26.67, 
           45018600}}, {{2012, 11, 28}, {
          26.605244883040935`, 26.97955043859649, 26.368841374269003`, 26.95, 
           53018400}}, {{2012, 11, 29}, {
          26.697565862708718`, 26.943762523191094`, 26.451369202226346`, 
           26.54, 69551400}}, {{2012, 11, 30}, {
          26.643538692712244`, 26.7223365890308, 26.09195341848234, 26.22, 
           83690200}}, {{2012, 12, 3}, {
          26.37470298902762, 26.414097616345064`, 26.000454029511918`, 26.03, 
           53173800}}, {{2012, 12, 4}, {
          26.098028062191883`, 26.226056124383767`, 25.9404550625711, 25.97, 
           49777500}}, {{2012, 12, 5}, {
          25.984349456317954`, 26.526100487439066`, 25.86614923134608, 26.27, 
           68283800}}, {{2012, 12, 6}, {
          26.408802843247283`, 26.57625888514777, 26.211795735129066`, 26.33, 
           39182300}}, {{2012, 12, 7}, {
          26.414557823129254`, 26.414557823129254`, 25.97136054421769, 26.06, 
           46162100}}, {{2012, 12, 10}, {
          26.155783221974758`, 26.559543429844098`, 26.116391982182627`, 
           26.53, 47031100}}, {{2012, 12, 11}, {
          26.64405197657394, 27.077448755490483`, 26.64405197657394, 26.91, 
           52282800}}, {{2012, 12, 12}, {
          27.11563509544787, 27.20428046989721, 26.67240822320117, 26.83, 
           43966300}}, {{2012, 12, 13}, {
          26.90682405016599, 27.10379933603836, 26.5424197713021, 26.7, 
           45080100}}, {{2012, 12, 14}, {
          26.695412159641922`, 26.71510630361805, 26.29168220813129, 26.4, 
           42077500}}, {{2012, 12, 17}, {
          26.38469003690037, 26.80818450184502, 26.27635424354244, 26.69, 
           42046100}}, {{2012, 12, 18}, {
          26.834724238026126`, 27.208933236574747`, 26.726400580551527`, 
           27.14, 50486900}}, {{2012, 12, 19}, {
          27.274295129989014`, 27.313694617356276`, 26.8409007689491, 26.9, 
           53519900}}, {{2012, 12, 20}, {
          26.94485549132948, 27.26, 26.738041907514454`, 27.26, 52607300}}, {{
          2012, 12, 21}, {
          27.04, 27.079402550091075`, 26.59672131147541, 27.04, 98776500}}, {{
          2012, 12, 24}, {
          26.78787878787879, 26.83712121212121, 26.59090909090909, 26.65, 
           20842400}}, {{2012, 12, 26}, {
          26.617405063291137`, 26.784810126582276`, 26.292442293373043`, 
           26.45, 31631100}}, {{2012, 12, 27}, {
          26.481064540059347`, 26.678022997032638`, 26.165931008902074`, 
           26.55, 39394000}}, {{2012, 12, 28}, {
          26.307589453860636`, 26.494726930320144`, 26.149999999999995`, 
           26.15, 28239900}}, {{2012, 12, 31}, {
          26.191797079745413`, 26.369101460127293`, 25.97509172594534, 26.31, 
           42749500}}, {{2013, 1, 2}, {
          26.8356263577118, 27.30832729905865, 26.737146994931205`, 27.2, 
           52899300}}, {{2013, 1, 3}, {
          27.214282568807338`, 27.233981651376148`, 26.75135412844037, 26.84, 
           48294400}}, {{2013, 1, 4}, {
          26.862071802543007`, 26.93102468212416, 26.330149588631265`, 26.34, 
           52521100}}, {{2013, 1, 7}, {
          26.36880104908205, 26.477152491569875`, 26.240749344323717`, 26.29, 
           37110400}}, {{2013, 1, 8}, {
          26.346986817325796`, 26.386384180790955`, 26.061355932203387`, 
           26.15, 44703100}}, {{2013, 1, 9}, {
          26.319700374531838`, 26.34925093632959, 26.162097378277153`, 26.3, 
           49047900}}, {{2013, 1, 10}, {
          26.247127739984883`, 26.572139077853365`, 25.89256991685563, 26.06, 
           71431300}}, {{2013, 1, 11}, {
          26.08519567648155, 26.51847185985837, 25.87840477077898, 26.42, 
           55512100}}, {{2013, 1, 14}, {
          26.489847526961693`, 26.667103012272218`, 26.351982149497953`, 
           26.48, 48324400}}, {{2013, 1, 15}, {
          26.42572583608967, 26.878794560823223`, 26.42572583608967, 26.8, 
           48244500}}, {{2013, 1, 16}, {
          26.738332100591716`, 26.817119082840236`, 26.600454881656805`, 
           26.63, 41077400}}, {{2013, 1, 17}, {
          26.78090275229358, 27.05668990825688, 26.65285871559633, 26.84, 
           51685900}}, {{2013, 1, 18}, {
          26.692256880733947`, 26.879398165137616`, 26.633159633027525`, 
           26.84, 52167700}}, {{2013, 1, 22}, {
          26.887734806629833`, 27.035469613259668`, 26.592265193370167`, 
           26.74, 58650600}}, {{2013, 1, 23}, {
          26.786236870699025`, 27.21954364360739, 26.786236870699025`, 27.19, 
           50387700}}, {{2013, 1, 24}, {
          27.27893593919653, 27.643311617806734`, 27.052432138979373`, 27.21, 
           101739300}}, {{2013, 1, 25}, {
          27.164519368723095`, 27.804727403156384`, 26.97738163558106, 27.46, 
           81847700}}, {{2013, 1, 28}, {
          27.58849516302401, 27.80518452167682, 27.342257255463995`, 27.49, 
           56056500}}, {{2013, 1, 29}, {
          27.402848982506246`, 27.708200642627627`, 27.186147804355585`, 
           27.59, 49242600}}, {{2013, 1, 30}, {
          27.58758707360862, 27.764872531418312`, 27.341357271095156`, 27.43, 
           43580500}}, {{2013, 1, 31}, {
          27.374921675774136`, 27.55223315118397, 26.990746812386156`, 27.04, 
           50530000}}, {{2013, 2, 1}, {
          27.253909774436092`, 27.628195488721804`, 27.135714285714286`, 
           27.51, 55565900}}, {{2013, 2, 4}, {
          27.453575072886295`, 27.60133381924198, 27.010298833819242`, 27.03, 
           50540000}}, {{2013, 2, 5}, {
          27.198167272727268`, 27.237556363636358`, 26.942138181818176`, 
           27.08, 35410400}}, {{2013, 2, 6}, {
          26.969400146305773`, 27.12700073152889, 26.841349670811994`, 26.93, 
           41889600}}, {{2013, 2, 7}, {
          26.938947947214075`, 26.978346774193547`, 26.692705278592374`, 
           26.87, 38028300}}, {{2013, 2, 8}, {
          26.933049001814883`, 27.287560798548096`, 26.893658802177857`, 
           27.13, 33318500}}, {{2013, 2, 11}, {
          27.23316582914573, 27.499095477386938`, 27.085427135678394`, 27.44, 
           32247700}}, {{2013, 2, 12}, {
          27.459999999999997`, 27.57819225251076, 27.33195839311334, 27.46, 
           35990900}}, {{2013, 2, 13}, {
          27.511498394577234`, 27.688801284338204`, 27.462247591865854`, 
           27.61, 41715600}}, {{2013, 2, 14}, {
          27.501797432239663`, 27.639700427960058`, 27.45254636233952, 27.62, 
           32663200}}, {{2013, 2, 15}, {
          27.619550160656903`, 27.737750803284538`, 27.46194930382006, 27.59, 
           49650900}}, {{2013, 2, 19}, {
          27.68121212121212, 27.889714795008913`, 27.6017825311943, 27.85, 
           38781400}}, {{2013, 2, 20}, {
          27.938227484750627`, 28.007750269106566`, 27.64027269465375, 27.68, 
           44110200}}, {{2013, 2, 21}, {
          27.548272098945073`, 27.548272098945073`, 27.041797017097128`, 27.3,
            49078500}}, {{2013, 2, 22}, {
          27.49054755043228, 27.570000000000004`, 27.29191642651297, 27.57, 
           31425900}}, {{2013, 2, 25}, {
          27.7758348556814, 27.85527950310559, 27.18, 27.18, 48011800}}, {{
          2013, 2, 26}, {
          27.18993058092802, 27.408403361344536`, 27.150208257215926`, 27.18, 
           49923300}}, {{2013, 2, 27}, {
          27.232664509169368`, 27.808701905789285`, 27.143279395900755`, 
           27.62, 36394700}}, {{2013, 2, 28}, {
          27.689453237410067`, 27.7788381294964, 27.55041007194244, 27.61, 
           35840200}}, {{2013, 3, 1}, {
          27.53156350626118, 27.789796064400715`, 27.332923076923077`, 27.76, 
           34849700}}, {{2013, 3, 4}, {
          27.652131438721142`, 27.950000000000003`, 27.503197158081708`, 
           27.95, 38157500}}, {{2013, 3, 5}, {
          28.090423280423277`, 28.33865961199294, 27.961340388007052`, 28.15, 
           41432200}}, {{2013, 3, 6}, {
          28.009145603417586`, 28.029003203987184`, 27.582207191171236`, 
           27.89, 51448500}}, {{2013, 3, 7}, {
          27.910213219616203`, 28.079004975124377`, 27.810923951670222`, 
           27.94, 29196700}}, {{2013, 3, 8}, {
          28.058303571428567`, 28.137760714285708`, 27.770271428571426`, 
           27.81, 37667800}}, {{2013, 3, 11}, {
          27.74952278435594, 27.779318263365624`, 27.48136347326875, 27.68, 
           36627500}}, {{2013, 3, 12}, {
          27.650476531709067`, 27.759727696166248`, 27.451838050877825`, 
           27.72, 39255200}}, {{2013, 3, 13}, {
          27.680340257879656`, 27.829319484240685`, 27.56115687679083, 27.73, 
           29093400}}, {{2013, 3, 14}, {
          27.800995024875622`, 27.959857853589195`, 27.731492537313432`, 
           27.94, 55914800}}, {{2013, 3, 15}, {
          27.83007132667618, 27.95914407988588, 27.780427960057064`, 27.84, 
           92710300}}, {{2013, 3, 18}, {
          27.681565836298926`, 28.07871886120996, 27.612064056939495`, 27.9, 
           44809400}}, {{2013, 3, 19}, {
          27.92042583392477, 28.01971611071682, 27.831064584811926`, 27.98, 
           51901600}}, {{2013, 3, 20}, {
          28.13985875706215, 28.28879943502825, 27.980988700564975`, 28.12, 
           35447800}}, {{2013, 3, 21}, {
          27.909999999999997`, 28.158221273568124`, 27.85042689434365, 27.91, 
           34233200}}, {{2013, 3, 22}, {
          27.990424778761064`, 28.13936283185841, 27.901061946902658`, 28.05, 
           28720900}}, {{2013, 3, 25}, {
          28.099005681818188`, 28.14865056818182, 27.76142045454546, 27.96, 
           44154000}}, {{2013, 3, 26}, {
          28.03943181818182, 28.138721590909096`, 27.910355113636367`, 27.96, 
           27824300}}, {{2013, 3, 27}, {
          27.941621431089178`, 28.24943602396898, 27.88204441311244, 28.17, 
           36047400}}, {{2013, 3, 28}, {
          28.12202726319469, 28.459650471862986`, 28.06244669695911, 28.41, 
           55453800}}, {{2013, 4, 1}, {
          28.439790283117794`, 28.459650471862986`, 28.16174764068508, 28.41, 
           29201100}}, {{2013, 4, 2}, {
          28.391458333333336`, 28.64965277777778, 28.321944444444448`, 28.6, 
           28456500}}, {{2013, 4, 3}, {
          28.548669467787114`, 28.747268907563026`, 28.34014005602241, 28.36, 
           35062800}}, {{2013, 4, 4}, {
          28.191468531468526`, 28.409930069930063`, 28.072307692307685`, 28.4,
            45263200}}, {{2013, 4, 5}, {
          28.02334494773519, 28.5794425087108, 27.91411149825784, 28.5, 
           50927300}}, {{2013, 4, 8}, {
          28.529020636586218`, 28.529020636586218`, 28.270839454354668`, 
           28.39, 34759500}}, {{2013, 4, 9}, {
          28.526241134751775`, 29.608510638297872`, 28.47659574468085, 29.4, 
           77733800}}, {{2013, 4, 10}, {
          29.364924042272122`, 30.109722589167763`, 29.315270805812414`, 
           30.07, 71116700}}, {{2013, 4, 11}, {
          28.89889426399447, 28.998203178991016`, 28.531451278507255`, 28.74, 
           130923200}}, {{2013, 4, 12}, {
          28.649583188607156`, 28.818402222994095`, 28.460903091351163`, 
           28.59, 62886300}}, {{2013, 4, 15}, {
          28.450278842802366`, 28.77797838968281, 28.311254792610665`, 28.49, 
           56332900}}, {{2013, 4, 16}, {
          28.700483258543322`, 28.93882637210908, 28.501863997238523`, 28.77, 
           52797300}}, {{2013, 4, 17}, {
          28.64986125563649, 28.83854318418314, 28.40159556018037, 28.63, 
           52840700}}, {{2013, 4, 18}, {
          28.74888850295241, 28.77868009725599, 28.302014588398748`, 28.59, 
           56906600}}, {{2013, 4, 19}, {
          29.411058112193484`, 30.02668458179375, 29.40112865300638, 29.56, 
           99790700}}, {{2013, 4, 22}, {
          30.093610120012976`, 30.967615958482, 30.063814466428806`, 30.62, 
           137904000}}, {{2013, 4, 23}, {
          30.489313725490195`, 30.687941176470588`, 30.17150980392157, 30.39, 
           59126900}}, {{2013, 4, 24}, {
          30.407896725440807`, 31.69889168765743, 30.388035264483626`, 31.54, 
           90946600}}, {{2013, 4, 25}, {
          31.491584220413277`, 32.61380087664371, 31.32275516593613, 31.72, 
           110700200}}, {{2013, 4, 26}, {
          31.679238754325258`, 31.758685121107266`, 31.23235294117647, 31.57, 
           47799300}}, {{2013, 4, 29}, {
          31.575712971481146`, 32.449506286415215`, 31.545924563017483`, 
           32.38, 59116400}}, {{2013, 4, 30}, {
          32.33375226586102, 32.87993051359516, 32.05569788519637, 32.87, 
           75165200}}, {{2013, 5, 1}, {
          32.69852383863081, 32.84746943765282, 32.3708435207824, 32.49, 
           54330900}}, {{2013, 5, 2}, {
          32.40367611580218, 32.939930639324494`, 32.16534077201448, 32.93, 
           46059500}}, {{2013, 5, 3}, {
          33.00178560764407, 33.28979396834876, 32.85281576590026, 33.26, 
           46784600}}, {{2013, 5, 6}, {
          33.18234666666667, 33.66886222222222, 33.013555555555556`, 33.51, 
           40978300}}, {{2013, 5, 7}, {
          33.41765235664965, 33.55668567997598, 33.01048333833683, 33.08, 
           43078300}}, {{2013, 5, 8}, {
          32.83944225522885, 33.00825704759018, 32.422370415277356`, 32.76, 
           51595700}}, {{2013, 5, 9}, {
          32.61866197183099, 32.76760563380282, 32.36049295774649, 32.43, 
           46417800}}, {{2013, 5, 10}, {
          32.44014071581524, 32.48978892627715, 32.09260324258183, 32.46, 
           36394900}}, {{2013, 5, 13}, {
          32.382924613987285`, 32.83972146533454, 32.323342415985465`, 32.8, 
           36027600}}, {{2013, 5, 14}, {
          32.86, 33.53, 32.8, 33.53, 56870100}}, {{2013, 5, 15}, {
          33.45, 33.9, 33.43, 33.85, 46303900}}, {{2013, 5, 16}, {
          33.64, 34.15, 33.55, 34.08, 59382900}}, {{2013, 5, 17}, {
          34.13, 34.87, 34.1, 34.87, 60666700}}, {{2013, 5, 20}, {
          34.73, 35.1, 34.68, 35.08, 54020800}}, {{2013, 5, 21}, {
          35.1, 35.27, 34.72, 34.85, 48702400}}, {{2013, 5, 22}, {
          34.79, 34.84, 34.36, 34.61, 66047500}}, {{2013, 5, 23}, {
          34.23, 34.55, 33.9, 34.15, 51102700}}, {{2013, 5, 24}, {
          33.92, 34.28, 33.9, 34.27, 33174400}}, {{2013, 5, 28}, {
          34.42, 35.18, 34.41, 35.02, 48212100}}, {{2013, 5, 29}, {
          34.74, 35.02, 34.57, 34.88, 38412200}}, {{2013, 5, 30}, {
          34.849999999999994`, 35.24999999999999, 34.809999999999995`, 35.03, 
           51131000}}, {{2013, 5, 31}, {
          34.82, 35.28, 34.79, 34.9, 56165700}}, {{2013, 6, 3}, {
          34.919999999999995`, 35.629999999999995`, 34.82999999999999, 35.59, 
           51252600}}, {{2013, 6, 4}, {
          35.62, 35.74, 34.77, 34.99, 65529500}}, {{2013, 6, 5}, {
          34.6, 34.89, 34.43, 34.78, 46025100}}, {{2013, 6, 6}, {
          34.84, 35.11, 34.49, 34.96, 37618500}}, {{2013, 6, 7}, {
          35.25, 35.78, 35.06, 35.67, 40757300}}, {{2013, 6, 10}, {
          35.51, 35.65, 35.14, 35.47, 35994500}}, {{2013, 6, 11}, {
          35.05, 35.18, 34.68, 34.84, 39435900}}, {{2013, 6, 12}, {
          35.14, 35.27, 34.85, 35., 37372700}}, {{2013, 6, 13}, {
          34.99, 35.02, 34.59, 34.72, 45654900}}, {{2013, 6, 14}, {
          34.55, 34.69, 34.25, 34.4, 53192600}}, {{2013, 6, 17}, {
          34.69, 35.16, 34.63, 35., 49670100}}, {{2013, 6, 18}, {
          34.97, 35.17, 34.9, 34.98, 28616500}}, {{2013, 6, 19}, {
          34.96, 35.09, 34.59, 34.59, 30816200}}, {{2013, 6, 20}, {
          34.26, 34.33, 33.37, 33.49, 54493700}}, {{2013, 6, 21}, {
          33.66, 33.73, 33.05, 33.27, 85338500}}, {{2013, 6, 24}, {
          32.94, 34.2, 32.57, 33.72, 56109000}}, {{2013, 6, 25}, {
          34.08, 34.38, 33.46, 33.67, 44073400}}, {{2013, 6, 26}, {
          34.12, 34.48, 33.89, 34.35, 48665900}}, {{2013, 6, 27}, {
          34.52, 34.78, 34.5, 34.62, 28993100}}, {{2013, 6, 28}, {
          34.38, 34.79, 34.34, 34.54, 65545500}}, {{2013, 7, 1}, {
          34.75, 34.99, 34.33, 34.36, 31055400}}, {{2013, 7, 2}, {
          34.41, 34.44, 33.63, 33.94, 37630000}}, {{2013, 7, 3}, {
          33.66, 34.37, 33.6, 34.01, 15994400}}, {{2013, 7, 5}, {
          34.09, 34.24, 33.58, 34.21, 26085900}}, {{2013, 7, 8}, {
          34.35, 34.59, 33.98, 34.33, 32396900}}, {{2013, 7, 9}, {
          34.58, 34.6, 34.14, 34.35, 25318500}}, {{2013, 7, 10}, {
          34.34, 34.81, 34.32, 34.7, 29658800}}, {{2013, 7, 11}, {
          35., 35.77, 34.9, 35.69, 53638300}}, {{2013, 7, 12}, {
          35.58, 35.73, 35.28, 35.67, 35501200}}, {{2013, 7, 15}, {
          35.66, 36.22, 35.58, 36.17, 34142600}}, {{2013, 7, 16}, {
          36.01, 36.43, 35.96, 36.27, 36378500}}, {{2013, 7, 17}, {
          36.34, 36.39, 35.49, 35.74, 37285100}}, {{2013, 7, 18}, {
          35.72, 35.89, 35.22, 35.44, 49547100}}, {{2013, 7, 19}, {
          32.4, 32.67, 31.02, 31.4, 248428500}}, {{2013, 7, 22}, {
          31.7, 32.01, 31.6, 32.01, 79040700}}, {{2013, 7, 23}, {
          31.91, 32.04, 31.71, 31.82, 65810400}}, {{2013, 7, 24}, {
          32.04, 32.19, 31.89, 31.96, 52803100}}, {{2013, 7, 25}, {
          31.62, 31.65, 31.25, 31.39, 63213000}}}, 
        System`TradingChartDump`$markerstyle$545658 = 1, 
        System`TradingChartDump`$controlmin$545658 = 0.5, 
        System`TradingChartDump`$controlmax$545658 = 250.5, 
        System`TradingChartDump`$datescope$545658 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$545658 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$545658, 
        System`TradingChartDump`$max$545658, 
        System`TradingChartDump`$ohlclabel$545658 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545658, 
              System`TradingChartDump`$opens$545658]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545658, 
              System`TradingChartDump`$highs$545658]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545658, 
              System`TradingChartDump`$lows$545658]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545658, 
              System`TradingChartDump`$closes$545658]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545658, 
              System`TradingChartDump`$visdates$545658]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$545658 = {}, 
        System`TradingChartDump`$subpricegridlines$545658 = Automatic, 
        System`TradingChartDump`$overlaypoint$545658, 
        System`TradingChartDump`$overlayvalue$545658, 
        System`TradingChartDump`$subplotvalue$545658, 
        System`TradingChartDump`$opts$545658 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "MSFT", " with ", 
            "ParabolicStopAndReversal", "(", 0.02, ",", 0.2, ",", Null, ",", 
            Null, ")"}], ImageSize -> {450, 310}, AlignmentPoint -> Center, 
         AspectRatio -> GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> 
         None, AxesOrigin -> Automatic, AxesStyle -> {}, Background -> None, 
         BaselinePosition -> Automatic, BaseStyle -> {}, ColorOutput -> 
         Automatic, ContentSelectable -> Automatic, CoordinatesToolOptions -> 
         Automatic, DisplayFunction :> $DisplayFunction, Epilog -> {}, 
         FormatType :> TraditionalForm, Frame -> True, FrameLabel -> None, 
         FrameStyle -> {}, FrameTicks -> Automatic, FrameTicksStyle -> {}, 
         GridLines -> Automatic, GridLinesStyle -> {}, ImageMargins -> 0., 
         ImagePadding -> All, ImageSize -> Automatic, ImageSizeRaw -> 
         Automatic, LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, 
         PlotRange -> All, PlotRangeClipping -> False, PlotRangePadding -> 
         Automatic, PlotRegion -> Automatic, PreserveImageOptions -> 
         Automatic, Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$545658 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmgtcj+f7xyNbDokp/ORUIcmhckrnO2EhOipppcO3vt/6VsKIsIVpDtGo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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyNmglYjmnUx5ssY5K1sku2bElp0d4tkvZdi9KmRW8LsnwYvJiECUOILGPN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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$545658 = 
        System`TradingChartDump`$staticindicatorpos$545658, 
        System`TradingChartDump`$length$545658 = 250, 
        System`TradingChartDump`$gridlinesflag$545658 = True, 
        System`TradingChartDump`$opens$545658 = 
        Dispatch[{
         1 -> 28.37`4., 2 -> 28.61`4., 3 -> 28.87`4., 4 -> 28.61`4., 5 -> 
          28.71`4., 6 -> 28.35`4., 7 -> 28.66`4., 8 -> 29.11`4., 9 -> 
          29.19`4., 10 -> 29.31`4., 11 -> 29.49`4., 12 -> 29.6`4., 13 -> 
          29.45`4., 14 -> 29.6`4., 15 -> 29.41`4., 16 -> 29.66`4., 17 -> 
          30.2`4., 18 -> 30.11`4., 19 -> 30.05`4., 20 -> 29.88`4., 21 -> 
          29.69`4., 22 -> 29.55`4., 23 -> 30.21`4., 24 -> 29.99`4., 25 -> 
          29.94`4., 26 -> 29.83`4., 27 -> 29.9`4., 28 -> 29.75`4., 29 -> 
          29.52`4., 30 -> 29.79`4., 31 -> 30.32`4., 32 -> 30.12`4., 33 -> 
          29.98`4., 34 -> 30.23`4., 35 -> 30.17`4., 36 -> 30.29`4., 37 -> 
          30.47`4., 38 -> 30.38`4., 39 -> 30.37`4., 40 -> 30.23`4., 41 -> 
          30.7`4., 42 -> 30.28`4., 43 -> 30.24`4., 44 -> 29.58`4., 45 -> 
          29.47`4., 46 -> 29.48`4., 47 -> 29.12`4., 48 -> 28.99`4., 49 -> 
          29.06`4., 50 -> 29.27`4., 51 -> 29.53`4., 52 -> 28.95`4., 53 -> 
          28.99`4., 54 -> 28.48`4., 55 -> 28.54`4., 56 -> 28.3`4., 57 -> 
          28.69`4., 58 -> 28.77`4., 59 -> 28.63`4., 60 -> 28.97`4., 61 -> 
          28.38`4., 62 -> 28.06`4., 63 -> 27.13`4., 64 -> 27.5`4., 65 -> 
          27.53`4., 66 -> 27.22`4., 67 -> 27.89`4., 68 -> 28.18`4., 69 -> 
          28.91`4., 70 -> 28.93`4., 71 -> 29.13`4., 72 -> 28.85`4., 73 -> 
          28.44`4., 74 -> 28.21`4., 75 -> 28.27`4., 76 -> 26.61`4., 77 -> 
          26.82`4., 78 -> 26.48`4., 79 -> 26.27`4., 80 -> 26.4`4., 81 -> 
          26.36`4., 82 -> 26.3`4., 83 -> 26.82`4., 84 -> 27.13`4., 85 -> 
          26.95`4., 86 -> 26.61`4., 87 -> 26.7`4., 88 -> 26.64`4., 89 -> 
          26.37`4., 90 -> 26.1`4., 91 -> 25.98`4., 92 -> 26.41`4., 93 -> 
          26.41`4., 94 -> 26.16`4., 95 -> 26.64`4., 96 -> 27.12`4., 97 -> 
          26.91`4., 98 -> 26.7`4., 99 -> 26.38`4., 100 -> 26.83`4., 101 -> 
          27.27`4., 102 -> 26.94`4., 103 -> 27.04`4., 104 -> 26.79`4., 105 -> 
          26.62`4., 106 -> 26.48`4., 107 -> 26.31`4., 108 -> 26.19`4., 109 -> 
          26.84`4., 110 -> 27.21`4., 111 -> 26.86`4., 112 -> 26.37`4., 113 -> 
          26.35`4., 114 -> 26.32`4., 115 -> 26.25`4., 116 -> 26.09`4., 117 -> 
          26.49`4., 118 -> 26.43`4., 119 -> 26.74`4., 120 -> 26.78`4., 121 -> 
          26.69`4., 122 -> 26.89`4., 123 -> 26.79`4., 124 -> 27.28`4., 125 -> 
          27.16`4., 126 -> 27.59`4., 127 -> 27.4`4., 128 -> 27.59`4., 129 -> 
          27.37`4., 130 -> 27.25`4., 131 -> 27.45`4., 132 -> 27.2`4., 133 -> 
          26.97`4., 134 -> 26.94`4., 135 -> 26.93`4., 136 -> 27.23`4., 137 -> 
          27.46`4., 138 -> 27.51`4., 139 -> 27.5`4., 140 -> 27.62`4., 141 -> 
          27.68`4., 142 -> 27.94`4., 143 -> 27.55`4., 144 -> 27.49`4., 145 -> 
          27.78`4., 146 -> 27.19`4., 147 -> 27.23`4., 148 -> 27.69`4., 149 -> 
          27.53`4., 150 -> 27.65`4., 151 -> 28.09`4., 152 -> 28.01`4., 153 -> 
          27.91`4., 154 -> 28.06`4., 155 -> 27.75`4., 156 -> 27.65`4., 157 -> 
          27.68`4., 158 -> 27.8`4., 159 -> 27.83`4., 160 -> 27.68`4., 161 -> 
          27.92`4., 162 -> 28.14`4., 163 -> 27.91`4., 164 -> 27.99`4., 165 -> 
          28.1`4., 166 -> 28.04`4., 167 -> 27.94`4., 168 -> 28.12`4., 169 -> 
          28.44`4., 170 -> 28.39`4., 171 -> 28.55`4., 172 -> 28.19`4., 173 -> 
          28.02`4., 174 -> 28.53`4., 175 -> 28.53`4., 176 -> 29.36`4., 177 -> 
          28.9`4., 178 -> 28.65`4., 179 -> 28.45`4., 180 -> 28.7`4., 181 -> 
          28.65`4., 182 -> 28.75`4., 183 -> 29.41`4., 184 -> 30.09`4., 185 -> 
          30.49`4., 186 -> 30.41`4., 187 -> 31.49`4., 188 -> 31.68`4., 189 -> 
          31.58`4., 190 -> 32.33`4., 191 -> 32.7`4., 192 -> 32.4`4., 193 -> 
          33.`4., 194 -> 33.18`4., 195 -> 33.42`4., 196 -> 32.84`4., 197 -> 
          32.62`4., 198 -> 32.44`4., 199 -> 32.38`4., 200 -> 32.86`4., 201 -> 
          33.45`4., 202 -> 33.64`4., 203 -> 34.13`4., 204 -> 34.73`4., 205 -> 
          35.1`4., 206 -> 34.79`4., 207 -> 34.23`4., 208 -> 33.92`4., 209 -> 
          34.42`4., 210 -> 34.74`4., 211 -> 34.85`4., 212 -> 34.82`4., 213 -> 
          34.92`4., 214 -> 35.62`4., 215 -> 34.6`4., 216 -> 34.84`4., 217 -> 
          35.25`4., 218 -> 35.51`4., 219 -> 35.05`4., 220 -> 35.14`4., 221 -> 
          34.99`4., 222 -> 34.55`4., 223 -> 34.69`4., 224 -> 34.97`4., 225 -> 
          34.96`4., 226 -> 34.26`4., 227 -> 33.66`4., 228 -> 32.94`4., 229 -> 
          34.08`4., 230 -> 34.12`4., 231 -> 34.52`4., 232 -> 34.38`4., 233 -> 
          34.75`4., 234 -> 34.41`4., 235 -> 33.66`4., 236 -> 34.09`4., 237 -> 
          34.35`4., 238 -> 34.58`4., 239 -> 34.34`4., 240 -> 35.`4., 241 -> 
          35.58`4., 242 -> 35.66`4., 243 -> 36.01`4., 244 -> 36.34`4., 245 -> 
          35.72`4., 246 -> 32.4`4., 247 -> 31.7`4., 248 -> 31.91`4., 249 -> 
          32.04`4., 250 -> 31.62`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$545658 = 
        Dispatch[{
         1 -> 28.63`4., 2 -> 28.97`4., 3 -> 28.93`4., 4 -> 28.83`4., 5 -> 
          28.77`4., 6 -> 28.66`4., 7 -> 29.05`4., 8 -> 29.22`4., 9 -> 
          29.46`4., 10 -> 29.57`4., 11 -> 29.75`4., 12 -> 29.71`4., 13 -> 
          29.56`4., 14 -> 29.68`4., 15 -> 29.58`4., 16 -> 30.23`4., 17 -> 
          30.2`4., 18 -> 30.14`4., 19 -> 30.25`4., 20 -> 30.04`4., 21 -> 
          29.7`4., 22 -> 29.92`4., 23 -> 30.24`4., 24 -> 30.09`4., 25 -> 
          30.04`4., 26 -> 29.9`4., 27 -> 30.25`4., 28 -> 29.95`4., 29 -> 
          29.83`4., 30 -> 30.63`4., 31 -> 30.35`4., 32 -> 30.19`4., 33 -> 
          30.2`4., 34 -> 30.46`4., 35 -> 30.45`4., 36 -> 30.53`4., 37 -> 
          30.54`4., 38 -> 30.49`4., 39 -> 30.47`4., 40 -> 30.75`4., 41 -> 
          30.88`4., 42 -> 30.35`4., 43 -> 30.29`4., 44 -> 29.89`4., 45 -> 
          29.69`4., 46 -> 29.56`4., 47 -> 29.29`4., 48 -> 29.19`4., 49 -> 
          29.3`4., 50 -> 29.33`4., 51 -> 29.55`4., 52 -> 29.23`4., 53 -> 
          29.05`4., 54 -> 28.63`4., 55 -> 28.57`4., 56 -> 28.64`4., 57 -> 
          29.04`4., 58 -> 29.05`4., 59 -> 28.96`4., 60 -> 29.04`4., 61 -> 
          28.41`4., 62 -> 28.16`4., 63 -> 27.55`4., 64 -> 27.54`4., 65 -> 
          27.54`4., 66 -> 27.69`4., 67 -> 28.21`4., 68 -> 28.88`4., 69 -> 
          29.08`4., 70 -> 29.05`4., 71 -> 29.5`4., 72 -> 29.14`4., 73 -> 
          28.69`4., 74 -> 28.51`4., 75 -> 28.34`4., 76 -> 26.89`4., 77 -> 
          26.87`4., 78 -> 26.57`4., 79 -> 26.3`4., 80 -> 26.4`4., 81 -> 
          26.4`4., 82 -> 26.76`4., 83 -> 27.35`4., 84 -> 27.17`4., 85 -> 
          26.97`4., 86 -> 26.98`4., 87 -> 26.94`4., 88 -> 26.72`4., 89 -> 
          26.41`4., 90 -> 26.23`4., 91 -> 26.53`4., 92 -> 26.58`4., 93 -> 
          26.41`4., 94 -> 26.56`4., 95 -> 27.08`4., 96 -> 27.2`4., 97 -> 
          27.1`4., 98 -> 26.72`4., 99 -> 26.81`4., 100 -> 27.21`4., 101 -> 
          27.31`4., 102 -> 27.26`4., 103 -> 27.08`4., 104 -> 26.84`4., 105 -> 
          26.78`4., 106 -> 26.68`4., 107 -> 26.49`4., 108 -> 26.37`4., 109 -> 
          27.31`4., 110 -> 27.23`4., 111 -> 26.93`4., 112 -> 26.48`4., 113 -> 
          26.39`4., 114 -> 26.35`4., 115 -> 26.57`4., 116 -> 26.52`4., 117 -> 
          26.67`4., 118 -> 26.88`4., 119 -> 26.82`4., 120 -> 27.06`4., 121 -> 
          26.88`4., 122 -> 27.04`4., 123 -> 27.22`4., 124 -> 27.64`4., 125 -> 
          27.8`4., 126 -> 27.81`4., 127 -> 27.71`4., 128 -> 27.76`4., 129 -> 
          27.55`4., 130 -> 27.63`4., 131 -> 27.6`4., 132 -> 27.24`4., 133 -> 
          27.13`4., 134 -> 26.98`4., 135 -> 27.29`4., 136 -> 27.5`4., 137 -> 
          27.58`4., 138 -> 27.69`4., 139 -> 27.64`4., 140 -> 27.74`4., 141 -> 
          27.89`4., 142 -> 28.01`4., 143 -> 27.55`4., 144 -> 27.57`4., 145 -> 
          27.86`4., 146 -> 27.41`4., 147 -> 27.81`4., 148 -> 27.78`4., 149 -> 
          27.79`4., 150 -> 27.95`4., 151 -> 28.34`4., 152 -> 28.03`4., 153 -> 
          28.08`4., 154 -> 28.14`4., 155 -> 27.78`4., 156 -> 27.76`4., 157 -> 
          27.83`4., 158 -> 27.96`4., 159 -> 27.96`4., 160 -> 28.08`4., 161 -> 
          28.02`4., 162 -> 28.29`4., 163 -> 28.16`4., 164 -> 28.14`4., 165 -> 
          28.15`4., 166 -> 28.14`4., 167 -> 28.25`4., 168 -> 28.46`4., 169 -> 
          28.46`4., 170 -> 28.65`4., 171 -> 28.75`4., 172 -> 28.41`4., 173 -> 
          28.58`4., 174 -> 28.53`4., 175 -> 29.61`4., 176 -> 30.11`4., 177 -> 
          29.`4., 178 -> 28.82`4., 179 -> 28.78`4., 180 -> 28.94`4., 181 -> 
          28.84`4., 182 -> 28.78`4., 183 -> 30.03`4., 184 -> 30.97`4., 185 -> 
          30.69`4., 186 -> 31.7`4., 187 -> 32.61`4., 188 -> 31.76`4., 189 -> 
          32.45`4., 190 -> 32.88`4., 191 -> 32.85`4., 192 -> 32.94`4., 193 -> 
          33.29`4., 194 -> 33.67`4., 195 -> 33.56`4., 196 -> 33.01`4., 197 -> 
          32.77`4., 198 -> 32.49`4., 199 -> 32.84`4., 200 -> 33.53`4., 201 -> 
          33.9`4., 202 -> 34.15`4., 203 -> 34.87`4., 204 -> 35.1`4., 205 -> 
          35.27`4., 206 -> 34.84`4., 207 -> 34.55`4., 208 -> 34.28`4., 209 -> 
          35.18`4., 210 -> 35.02`4., 211 -> 35.25`4., 212 -> 35.28`4., 213 -> 
          35.63`4., 214 -> 35.74`4., 215 -> 34.89`4., 216 -> 35.11`4., 217 -> 
          35.78`4., 218 -> 35.65`4., 219 -> 35.18`4., 220 -> 35.27`4., 221 -> 
          35.02`4., 222 -> 34.69`4., 223 -> 35.16`4., 224 -> 35.17`4., 225 -> 
          35.09`4., 226 -> 34.33`4., 227 -> 33.73`4., 228 -> 34.2`4., 229 -> 
          34.38`4., 230 -> 34.48`4., 231 -> 34.78`4., 232 -> 34.79`4., 233 -> 
          34.99`4., 234 -> 34.44`4., 235 -> 34.37`4., 236 -> 34.24`4., 237 -> 
          34.59`4., 238 -> 34.6`4., 239 -> 34.81`4., 240 -> 35.77`4., 241 -> 
          35.73`4., 242 -> 36.22`4., 243 -> 36.43`4., 244 -> 36.39`4., 245 -> 
          35.89`4., 246 -> 32.67`4., 247 -> 32.01`4., 248 -> 32.04`4., 249 -> 
          32.19`4., 250 -> 31.65`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$545658 = 
        Dispatch[{
         1 -> 28.23`4., 2 -> 28.32`4., 3 -> 28.59`4., 4 -> 28.46`4., 5 -> 
          28.35`4., 6 -> 28.12`4., 7 -> 28.61`4., 8 -> 28.92`4., 9 -> 
          28.99`4., 10 -> 29.22`4., 11 -> 29.41`4., 12 -> 29.36`4., 13 -> 
          29.27`4., 14 -> 29.31`4., 15 -> 29.32`4., 16 -> 29.56`4., 17 -> 
          29.88`4., 18 -> 29.87`4., 19 -> 29.9`4., 20 -> 29.76`4., 21 -> 
          29.38`4., 22 -> 29.48`4., 23 -> 29.88`4., 24 -> 29.81`4., 25 -> 
          29.73`4., 26 -> 29.52`4., 27 -> 29.68`4., 28 -> 29.46`4., 29 -> 
          29.51`4., 30 -> 29.75`4., 31 -> 30.02`4., 32 -> 29.8`4., 33 -> 
          29.9`4., 34 -> 30.02`4., 35 -> 29.69`4., 36 -> 30.1`4., 37 -> 
          30.32`4., 38 -> 30.31`4., 39 -> 30.32`4., 40 -> 30.19`4., 41 -> 
          30.37`4., 42 -> 29.93`4., 43 -> 29.66`4., 44 -> 29.34`4., 45 -> 
          29.2`4., 46 -> 29.05`4., 47 -> 28.74`4., 48 -> 28.81`4., 49 -> 
          28.98`4., 50 -> 28.88`4., 51 -> 29.05`4., 52 -> 28.87`4., 53 -> 
          28.5`4., 54 -> 28.28`4., 55 -> 28.2`4., 56 -> 28.13`4., 57 -> 
          28.58`4., 58 -> 28.64`4., 59 -> 28.42`4., 60 -> 28.59`4., 61 -> 
          27.84`4., 62 -> 27.18`4., 63 -> 27.12`4., 64 -> 27.22`4., 65 -> 
          27.21`4., 66 -> 27.2`4., 67 -> 27.84`4., 68 -> 28.16`4., 69 -> 
          28.65`4., 70 -> 28.65`4., 71 -> 28.93`4., 72 -> 28.38`4., 73 -> 
          28.13`4., 74 -> 28.14`4., 75 -> 27.56`4., 76 -> 26.35`4., 77 -> 
          26.39`4., 78 -> 26.23`4., 79 -> 25.94`4., 80 -> 26.07`4., 81 -> 
          26.06`4., 82 -> 26.26`4., 83 -> 26.79`4., 84 -> 26.76`4., 85 -> 
          26.63`4., 86 -> 26.37`4., 87 -> 26.45`4., 88 -> 26.09`4., 89 -> 
          26.`4., 90 -> 25.94`4., 91 -> 25.87`4., 92 -> 26.21`4., 93 -> 
          25.97`4., 94 -> 26.12`4., 95 -> 26.64`4., 96 -> 26.67`4., 97 -> 
          26.54`4., 98 -> 26.29`4., 99 -> 26.28`4., 100 -> 26.73`4., 101 -> 
          26.84`4., 102 -> 26.74`4., 103 -> 26.6`4., 104 -> 26.59`4., 105 -> 
          26.29`4., 106 -> 26.17`4., 107 -> 26.15`4., 108 -> 25.98`4., 109 -> 
          26.74`4., 110 -> 26.75`4., 111 -> 26.33`4., 112 -> 26.24`4., 113 -> 
          26.06`4., 114 -> 26.16`4., 115 -> 25.89`4., 116 -> 25.88`4., 117 -> 
          26.35`4., 118 -> 26.43`4., 119 -> 26.6`4., 120 -> 26.65`4., 121 -> 
          26.63`4., 122 -> 26.59`4., 123 -> 26.79`4., 124 -> 27.05`4., 125 -> 
          26.98`4., 126 -> 27.34`4., 127 -> 27.19`4., 128 -> 27.34`4., 129 -> 
          26.99`4., 130 -> 27.14`4., 131 -> 27.01`4., 132 -> 26.94`4., 133 -> 
          26.84`4., 134 -> 26.69`4., 135 -> 26.89`4., 136 -> 27.09`4., 137 -> 
          27.33`4., 138 -> 27.46`4., 139 -> 27.45`4., 140 -> 27.46`4., 141 -> 
          27.6`4., 142 -> 27.64`4., 143 -> 27.04`4., 144 -> 27.29`4., 145 -> 
          27.18`4., 146 -> 27.15`4., 147 -> 27.14`4., 148 -> 27.55`4., 149 -> 
          27.33`4., 150 -> 27.5`4., 151 -> 27.96`4., 152 -> 27.58`4., 153 -> 
          27.81`4., 154 -> 27.77`4., 155 -> 27.48`4., 156 -> 27.45`4., 157 -> 
          27.56`4., 158 -> 27.73`4., 159 -> 27.78`4., 160 -> 27.61`4., 161 -> 
          27.83`4., 162 -> 27.98`4., 163 -> 27.85`4., 164 -> 27.9`4., 165 -> 
          27.76`4., 166 -> 27.91`4., 167 -> 27.88`4., 168 -> 28.06`4., 169 -> 
          28.16`4., 170 -> 28.32`4., 171 -> 28.34`4., 172 -> 28.07`4., 173 -> 
          27.91`4., 174 -> 28.27`4., 175 -> 28.48`4., 176 -> 29.32`4., 177 -> 
          28.53`4., 178 -> 28.46`4., 179 -> 28.31`4., 180 -> 28.5`4., 181 -> 
          28.4`4., 182 -> 28.3`4., 183 -> 29.4`4., 184 -> 30.06`4., 185 -> 
          30.17`4., 186 -> 30.39`4., 187 -> 31.32`4., 188 -> 31.23`4., 189 -> 
          31.55`4., 190 -> 32.06`4., 191 -> 32.37`4., 192 -> 32.17`4., 193 -> 
          32.85`4., 194 -> 33.01`4., 195 -> 33.01`4., 196 -> 32.42`4., 197 -> 
          32.36`4., 198 -> 32.09`4., 199 -> 32.32`4., 200 -> 32.8`4., 201 -> 
          33.43`4., 202 -> 33.55`4., 203 -> 34.1`4., 204 -> 34.68`4., 205 -> 
          34.72`4., 206 -> 34.36`4., 207 -> 33.9`4., 208 -> 33.9`4., 209 -> 
          34.41`4., 210 -> 34.57`4., 211 -> 34.81`4., 212 -> 34.79`4., 213 -> 
          34.83`4., 214 -> 34.77`4., 215 -> 34.43`4., 216 -> 34.49`4., 217 -> 
          35.06`4., 218 -> 35.14`4., 219 -> 34.68`4., 220 -> 34.85`4., 221 -> 
          34.59`4., 222 -> 34.25`4., 223 -> 34.63`4., 224 -> 34.9`4., 225 -> 
          34.59`4., 226 -> 33.37`4., 227 -> 33.05`4., 228 -> 32.57`4., 229 -> 
          33.46`4., 230 -> 33.89`4., 231 -> 34.5`4., 232 -> 34.34`4., 233 -> 
          34.33`4., 234 -> 33.63`4., 235 -> 33.6`4., 236 -> 33.58`4., 237 -> 
          33.98`4., 238 -> 34.14`4., 239 -> 34.32`4., 240 -> 34.9`4., 241 -> 
          35.28`4., 242 -> 35.58`4., 243 -> 35.96`4., 244 -> 35.49`4., 245 -> 
          35.22`4., 246 -> 31.02`4., 247 -> 31.6`4., 248 -> 31.71`4., 249 -> 
          31.89`4., 250 -> 31.25`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$545658 = 
        Dispatch[{
         1 -> 28.3`4., 2 -> 28.88`4., 3 -> 28.76`4., 4 -> 28.6`4., 5 -> 
          28.54`4., 6 -> 28.33`4., 7 -> 28.87`4., 8 -> 29.06`4., 9 -> 
          29.37`4., 10 -> 29.43`4., 11 -> 29.6`4., 12 -> 29.52`4., 13 -> 
          29.49`4., 14 -> 29.43`4., 15 -> 29.5`4., 16 -> 30.07`4., 17 -> 
          30.18`4., 18 -> 30.03`4., 19 -> 30.09`4., 20 -> 29.83`4., 21 -> 
          29.56`4., 22 -> 29.85`4., 23 -> 29.98`4., 24 -> 29.92`4., 25 -> 
          29.94`4., 26 -> 29.62`4., 27 -> 30.11`4., 28 -> 29.69`4., 29 -> 
          29.69`4., 30 -> 30.62`4., 31 -> 30.23`4., 32 -> 30.01`4., 33 -> 
          30.08`4., 34 -> 30.07`4., 35 -> 30.22`4., 36 -> 30.49`4., 37 -> 
          30.49`4., 38 -> 30.46`4., 39 -> 30.33`4., 40 -> 30.72`4., 41 -> 
          30.47`4., 42 -> 30.07`4., 43 -> 29.69`4., 44 -> 29.47`4., 45 -> 
          29.46`4., 46 -> 29.07`4., 47 -> 28.81`4., 48 -> 28.97`4., 49 -> 
          29.17`4., 50 -> 29.33`4., 51 -> 29.16`4., 52 -> 29.09`4., 53 -> 
          28.6`4., 54 -> 28.31`4., 55 -> 28.28`4., 56 -> 28.52`4., 57 -> 
          28.83`4., 58 -> 28.81`4., 59 -> 28.91`4., 60 -> 28.82`4., 61 -> 
          27.98`4., 62 -> 27.35`4., 63 -> 27.4`4., 64 -> 27.25`4., 65 -> 
          27.23`4., 66 -> 27.56`4., 67 -> 27.88`4., 68 -> 28.84`4., 69 -> 
          28.82`4., 70 -> 28.94`4., 71 -> 29.17`4., 72 -> 28.41`4., 73 -> 
          28.14`4., 74 -> 28.16`4., 75 -> 27.57`4., 76 -> 26.68`4., 77 -> 
          26.43`4., 78 -> 26.26`4., 79 -> 26.12`4., 80 -> 26.33`4., 81 -> 
          26.31`4., 82 -> 26.54`4., 83 -> 27.28`4., 84 -> 26.98`4., 85 -> 
          26.67`4., 86 -> 26.95`4., 87 -> 26.54`4., 88 -> 26.22`4., 89 -> 
          26.03`4., 90 -> 25.97`4., 91 -> 26.27`4., 92 -> 26.33`4., 93 -> 
          26.06`4., 94 -> 26.53`4., 95 -> 26.91`4., 96 -> 26.83`4., 97 -> 
          26.7`4., 98 -> 26.4`4., 99 -> 26.69`4., 100 -> 27.14`4., 101 -> 
          26.9`4., 102 -> 27.26`4., 103 -> 27.04`4., 104 -> 26.65`4., 105 -> 
          26.45`4., 106 -> 26.55`4., 107 -> 26.15`4., 108 -> 26.31`4., 109 -> 
          27.2`4., 110 -> 26.84`4., 111 -> 26.34`4., 112 -> 26.29`4., 113 -> 
          26.15`4., 114 -> 26.3`4., 115 -> 26.06`4., 116 -> 26.42`4., 117 -> 
          26.48`4., 118 -> 26.8`4., 119 -> 26.63`4., 120 -> 26.84`4., 121 -> 
          26.84`4., 122 -> 26.74`4., 123 -> 27.19`4., 124 -> 27.21`4., 125 -> 
          27.46`4., 126 -> 27.49`4., 127 -> 27.59`4., 128 -> 27.43`4., 129 -> 
          27.04`4., 130 -> 27.51`4., 131 -> 27.03`4., 132 -> 27.08`4., 133 -> 
          26.93`4., 134 -> 26.87`4., 135 -> 27.13`4., 136 -> 27.44`4., 137 -> 
          27.46`4., 138 -> 27.61`4., 139 -> 27.62`4., 140 -> 27.59`4., 141 -> 
          27.85`4., 142 -> 27.68`4., 143 -> 27.3`4., 144 -> 27.57`4., 145 -> 
          27.18`4., 146 -> 27.18`4., 147 -> 27.62`4., 148 -> 27.61`4., 149 -> 
          27.76`4., 150 -> 27.95`4., 151 -> 28.15`4., 152 -> 27.89`4., 153 -> 
          27.94`4., 154 -> 27.81`4., 155 -> 27.68`4., 156 -> 27.72`4., 157 -> 
          27.73`4., 158 -> 27.94`4., 159 -> 27.84`4., 160 -> 27.9`4., 161 -> 
          27.98`4., 162 -> 28.12`4., 163 -> 27.91`4., 164 -> 28.05`4., 165 -> 
          27.96`4., 166 -> 27.96`4., 167 -> 28.17`4., 168 -> 28.41`4., 169 -> 
          28.41`4., 170 -> 28.6`4., 171 -> 28.36`4., 172 -> 28.4`4., 173 -> 
          28.5`4., 174 -> 28.39`4., 175 -> 29.4`4., 176 -> 30.07`4., 177 -> 
          28.74`4., 178 -> 28.59`4., 179 -> 28.49`4., 180 -> 28.77`4., 181 -> 
          28.63`4., 182 -> 28.59`4., 183 -> 29.56`4., 184 -> 30.62`4., 185 -> 
          30.39`4., 186 -> 31.54`4., 187 -> 31.72`4., 188 -> 31.57`4., 189 -> 
          32.38`4., 190 -> 32.87`4., 191 -> 32.49`4., 192 -> 32.93`4., 193 -> 
          33.26`4., 194 -> 33.51`4., 195 -> 33.08`4., 196 -> 32.76`4., 197 -> 
          32.43`4., 198 -> 32.46`4., 199 -> 32.8`4., 200 -> 33.53`4., 201 -> 
          33.85`4., 202 -> 34.08`4., 203 -> 34.87`4., 204 -> 35.08`4., 205 -> 
          34.85`4., 206 -> 34.61`4., 207 -> 34.15`4., 208 -> 34.27`4., 209 -> 
          35.02`4., 210 -> 34.88`4., 211 -> 35.03`4., 212 -> 34.9`4., 213 -> 
          35.59`4., 214 -> 34.99`4., 215 -> 34.78`4., 216 -> 34.96`4., 217 -> 
          35.67`4., 218 -> 35.47`4., 219 -> 34.84`4., 220 -> 35.`4., 221 -> 
          34.72`4., 222 -> 34.4`4., 223 -> 35.`4., 224 -> 34.98`4., 225 -> 
          34.59`4., 226 -> 33.49`4., 227 -> 33.27`4., 228 -> 33.72`4., 229 -> 
          33.67`4., 230 -> 34.35`4., 231 -> 34.62`4., 232 -> 34.54`4., 233 -> 
          34.36`4., 234 -> 33.94`4., 235 -> 34.01`4., 236 -> 34.21`4., 237 -> 
          34.33`4., 238 -> 34.35`4., 239 -> 34.7`4., 240 -> 35.69`4., 241 -> 
          35.67`4., 242 -> 36.17`4., 243 -> 36.27`4., 244 -> 35.74`4., 245 -> 
          35.44`4., 246 -> 31.4`4., 247 -> 32.01`4., 248 -> 31.82`4., 249 -> 
          31.96`4., 250 -> 31.39`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$545658 = True, 
        System`TradingChartDump`$gridlines$545658 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$545658, 
        System`TradingChartDump`$plotrangemin$545658 = 25.3378, 
        System`TradingChartDump`$plotrangemax$545658 = 37.4864, 
        System`TradingChartDump`$layoutData$545658, 
        System`TradingChartDump`$gridlinesscope$545658 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$545658 = {True, True}, 
        System`TradingChartDump`$indicators$545658 = {
         FinancialIndicator["ParabolicStopAndReversal", 0.02, 0.2]}, 
        System`TradingChartDump`$mouseQ$545658 = False, 
        System`TradingChartDump`$modelData$545658 = 
        System`TradingChartDump`modelData$543602, 
        System`TradingChartDump`$sy$545658 = Identity, 
        System`TradingChartDump`$isy$545658 = Identity, 
        System`TradingChartDump`$appearance$545658 = Automatic, 
        System`TradingChartDump`$perfgoal$545658 = "Quality", 
        System`TradingChartDump`$axesorigin$545658 = Automatic, 
        System`TradingChartDump`$framestyle$545658 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$545658 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$545658 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$545658 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$545658 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$545658, 
        System`TradingChartDump`$newgridlines$545658 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{25.3378, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$545658 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$545658 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$545658 = "GraphicsFrame", 
        System`TradingChartDump`$frame$545658 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$545658 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$545658 = 
              Switch[System`TradingChartDump`$highlightposition$545658, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$545658], {
                 1, System`TradingChartDump`$length$545658}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$545658], {
                 1, System`TradingChartDump`$length$545658}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$545658, 
                   Charting`nearestDate[System`TradingChartDump`$dates$545658, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$545658]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$545658]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$545658, 
                    Floor[System`TradingChartDump`$controlmin$545658] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$545658, 
                    Floor[System`TradingChartDump`$controlmax$545658]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$545658 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$545658 = 
            If[System`TradingChartDump`$fastpos$545658 =!= True, 
              System`TradingChartDump`$fastpos$545658 = 
               Clip[System`TradingChartDump`$fastpos$545658, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$545658 = (
                  Floor[System`TradingChartDump`$controlmax$545658] - Floor[
                  System`TradingChartDump`$controlmin$545658]) (
                  System`TradingChartDump`$fastpos$545658/100) + 
                Floor[System`TradingChartDump`$controlmin$545658]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$545658], {
                Floor[System`TradingChartDump`$controlmin$545658] + 1, 
                 Floor[System`TradingChartDump`$controlmax$545658]}], 
              System`TradingChartDump`$staticindicatorpos$545658]; 
           System`TradingChartDump`$mouseQ$545658 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$545658]], 
              System`TradingChartDump`$highlightposition$545658 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$545658 = If[
              And[
              System`TradingChartDump`$bouncingballQ$545658, 
               System`TradingChartDump`$mouseQ$545658, 
               System`TradingChartDump`$appearance$545658 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$545658[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$545658]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$545658[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$545658, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$545658[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$545658]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$545658[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$545658[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545658, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545658[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545658, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545658, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545658[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545658[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$545658 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$545658, 
                 System`TradingChartDump`$defaultframeticksstyle$545658, 
                 System`TradingChartDump`$defaultlabelstyle$545658, 
                 System`TradingChartDump`$framestyle$545658, 
                 System`TradingChartDump`$frameticksstyle$545658, 
                 System`TradingChartDump`$labelstyle$545658}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545658 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$545658, 
                 System`TradingChartDump`$labelstyle$545658, 
                 System`TradingChartDump`$defaultframeticksstyle$545658, 
                 System`TradingChartDump`$defaultlabelstyle$545658}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545658 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545658, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$545658 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545658, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$545658 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545658, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$545658 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$545658 = 
             Part[System`TradingChartDump`$tickstextstyle$545658, 1], 
             System`TradingChartDump`$tickstextstyle$545658 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545658[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545658, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545658[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545658[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545658[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$545658[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545658, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$545658]], 
                    Style[":", System`TradingChartDump`$textstyle$545658]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$545658[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545658]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545658[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$545658[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$545658, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$545658]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$545658[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545658, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545658[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545658, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545658, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$545658[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545658[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545658[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$545658[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$545658[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$545658], 1], 
                   Floor[System`TradingChartDump`$controlmax$545658]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$545658[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$545658[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$545658[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$545658[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$545658[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545658[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$545658[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$545658[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$545658[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545658[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$545658[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$545658[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$545658[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$545658[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$545658[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$545658, 
                  System`TradingChartDump`$mouseQ$545658], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$545658 - 0.5, 
                   System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$545658 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$545658 + 0.5, 
                    System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545658, 1]}, {
                    System`TradingChartDump`$indicatorpos$545658 + 0.5, 
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$545658[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$545658, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$545658[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545658]]], {}]; 
              System`TradingChartDump`$subplotgridlines$545658[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$545658[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$545658[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545658[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$545658 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$545658, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545658, 
                   System`TradingChartDump`$opens$545658]], 12, 
                 System`TradingChartDump`$textstyle$545658, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$545658, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545658, 
                   System`TradingChartDump`$highs$545658]], 12, 
                 System`TradingChartDump`$textstyle$545658, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$545658, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545658, 
                   System`TradingChartDump`$lows$545658]], 12, 
                 System`TradingChartDump`$textstyle$545658, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$545658, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545658, 
                   System`TradingChartDump`$closes$545658]], 12, 
                 System`TradingChartDump`$textstyle$545658, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545658, 
                   System`TradingChartDump`$visdates$545658]], 12, 
                 System`TradingChartDump`$textstyle$545658, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False]
             ; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$545658, 
                  System`TradingChartDump`$mouseQ$545658], {{
                  System`TradingChartDump`$timestampstyle$545658, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$545658 - 0.5, 
                    System`TradingChartDump`$plotrangemin$545658}, 
                    If[
                    System`TradingChartDump`$timestampdepth$545658 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$545658[1]}, {
                    System`TradingChartDump`$indicatorpos$545658 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545658}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545658, 1]}, {
                    System`TradingChartDump`$indicatorpos$545658 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545658}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$545658, {
               System`TradingChartDump`$highlightstyle$545658, 
                Dynamic[System`TradingChartDump`$ohlcpoint$545658]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$545658[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545658, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$545658[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$545658[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$545658, Length[
                    System`TradingChartDump`$layoutData$545658[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$545658}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$545658] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$545658] + 0.5}, {
                System`TradingChartDump`$plotrangemin$545658, 
                 System`TradingChartDump`$plotrangemax$545658}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$545658, Left, {
                 False, System`TradingChartDump`$frame$545658}, 
                 Blank[], {System`TradingChartDump`$frame$545658, False}], {
                False, System`TradingChartDump`$frame$545658}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$545658, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$545658]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$545658 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{5.252189972793673, 
           411.14299847591394`}, {-286.9271576880515, -36.072842311948435`}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545658 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545658, 1]], 
               Part[System`TradingChartDump`$framestyle$545658, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$545658]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$545658} -> S\
ystem`TradingChartDump`$isy$545658[
                    System`TradingChartDump`$plotrangemin$545658], {
                    0, System`TradingChartDump`$plotrangemax$545658} -> 
                   System`TradingChartDump`$isy$545658[
                    System`TradingChartDump`$plotrangemax$545658]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$545658[
                   System`TradingChartDump`$plotrangemin$545658], 
                   System`TradingChartDump`$isy$545658[
                   System`TradingChartDump`$plotrangemax$545658]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$545658, 
                   System`TradingChartDump`$isy$545658}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545658, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545658 > 
                    System`TradingChartDump`$plotrangemin$545658, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545658 > 
                    System`TradingChartDump`$plotrangemin$545658, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545658, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545658 > 
                    System`TradingChartDump`$plotrangemin$545658, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545658 > 
                    System`TradingChartDump`$plotrangemin$545658, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545658, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545658, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545658 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545658,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545658], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545658 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545658, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545658]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 251.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$545658, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$545658[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$545658[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545658, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$545658[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$545658, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545658[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545658, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545658[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545658[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545658[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545658[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545658], 
                    Style[":", System`TradingChartDump`$textstyle$545658]], 
                    Style[":", System`TradingChartDump`$textstyle$545658]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$545658[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545658]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545658[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$545658}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$545658, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$545658 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$545658[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$545658, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$545658, Left, {
                    False, System`TradingChartDump`$frame$545658}, 
                    Blank[], {
                    System`TradingChartDump`$frame$545658, False}], {
                   System`TradingChartDump`$frame$545658, 
                    System`TradingChartDump`$frame$545658}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$545658, 
                    System`TradingChartDump`$controlmax$545658}] + 0.5, {
                   System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$545658]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$545658) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$545658 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$545658 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$545658, 1]], 
                   Part[System`TradingChartDump`$framestyle$545658, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$545658]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545658[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545658[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$545658[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545658, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545658, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$545658, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$545658, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$545658 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
545658, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$545658], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$545658 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$545658, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$545658]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$545658, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$545658) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$545658 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$545658[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$545658, 
              Dynamic[System`TradingChartDump`$ohlclabel$545658], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$545658}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545658 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545658, 2]], 
               Part[System`TradingChartDump`$framestyle$545658, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$545658]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$545658, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$545658, 
                    System`TradingChartDump`$controlmax$545658}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$545658] + 
                    0.5, System`TradingChartDump`$plotrangemin$545658}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$545658], 
                    System`TradingChartDump`$plotrangemin$545658}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$545658, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545658, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545658, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545658 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545658, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545658], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545658 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545658,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545658]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              406.4142135623731}, {-41.414213562373114`, \
-24.996705587314885`}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$overlaypoint$545658] = {
            HoldPattern[
               System`TradingChartDump`$overlaypoint$545658[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$overlayvalue$545658] = {
            HoldPattern[
               System`TradingChartDump`$overlayvalue$545658[1, 1]] :> {}}}, {
          DownValues[System`TradingChartDump`$layoutData$545658] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$545658["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545658["AllValues"]] :> {{
               28.232064471879287`, 28.62997256515775, {28.232}}, {
               28.317150537634404`, 28.967338709677417`, {28.317}}, {
               28.58534412955466, 28.934655870445347`, {28.447}}, {
               28.464133016627077`, 28.832914828639293`, {
                28.967000000000002`}}, {
               28.3459163549813, 28.77290037402244, {28.955000000000002`}}, {
               28.11648167180541, 28.65998287084618, {28.116}}, {
               28.60798655462185, 29.054379831932774`, {28.135}}, {
               28.924160267111848`, 29.215245409015022`, {28.178}}, {
               28.99147058823529, 29.457352941176467`, {28.255}}, {
               29.21652818991098, 29.56584569732938, {28.36}}, {
               29.40590163934427, 29.745573770491806`, {
                28.499000000000002`}}, {
               29.355029585798814`, 29.714082840236685`, {28.623}}, {
               29.26681145113524, 29.55792694965449, {28.736}}, {
               29.31278791901759, 29.68395950879522, {28.837}}, {
               29.324172185430466`, 29.578145695364242`, {28.927}}, {
               29.561994801819363`, 30.22630929174789, {
                29.083000000000002`}}, {
               29.87722330097088, 30.19953398058253, {29.22}}, {
               29.873695510735203`, 30.13745933636956, {29.341}}, {
               29.90437987012987, 30.24631168831169, {29.468}}, {
               29.761627373935823`, 30.044885396201707`, {
                30.246000000000002`}}, {
               29.384163912756108`, 29.696761401189683`, {30.229}}, {
               29.478828534031415`, 29.91837369109948, {29.384}}, {
               29.88231345715216, 30.243753665689148`, {29.401}}, {
               29.81254978778975, 30.08605941887039, {29.418}}, {
               29.734864600326272`, 30.037683523654167`, {
                29.435000000000002`}}, {
               29.52230870712401, 29.90330474934037, {29.451}}, {
               29.68013627514601, 30.246774821544452`, {30.247}}, {
               29.45552813425469, 29.953780848963476`, {30.231}}, {
               29.51414610069102, 29.8267752550181, {29.456}}, {
               29.750724082934607`, 30.629767145135563`, {29.479}}, {
               30.01511793214863, 30.347208400646206`, {29.502}}, {
               29.804853515625005`, 30.185839843750003`, {
                29.525000000000002`}}, {
               29.90415069827866, 30.197232867814222`, {29.547}}, {
               30.021153346328784`, 30.46077322936972, {29.568}}, {
               29.692566257272134`, 30.454414996767934`, {29.59}}, {
               30.09922781159884, 30.52907721884011, {29.61}}, {
               30.323921819929506`, 30.53884652355014, {29.631}}, {
               30.31346375881976, 30.489307248236052`, {29.651}}, {
               30.320231884057968`, 30.466753623188403`, {29.67}}, {
               30.19253418124006, 30.74930365659777, {29.713}}, {
               30.3723084321898, 30.88030458480282, {29.783}}, {
               29.933229369720596`, 30.353310591293045`, {30.88}}, {
               29.660691016781836`, 30.285949325435997`, {30.856}}, {
               29.3430162412993, 29.890023201856145`, {30.795}}, {
               29.196266578249343`, 29.694429708222817`, {30.699}}, {
               29.050463709677416`, 29.558407258064516`, {30.568}}, {
               28.741614106476774`, 29.288701254662598`, {30.385}}, {
               28.813722184760618`, 29.194649359406608`, {30.221}}, {
               28.98439048894843, 29.296995981245818`, {30.073}}, {
               28.880722610722604`, 29.329999999999995`, {29.94}}, {
               29.052542713567835`, 29.55075376884422, {29.82}}, {
               28.865329079919412`, 29.226756212222973`, {29.712}}, {
               28.502322404371583`, 29.049316939890705`, {29.567}}, {
               28.280693581780536`, 28.632370600414074`, {29.387}}, {
               28.20185146804836, 28.573056994818653`, {29.197}}, {
               28.12931506849315, 28.637205479452053`, {28.129}}, {
               28.57599118942731, 29.03516096238563, {28.147000000000002`}}, {
               28.643919972872162`, 29.054235334011526`, {28.184}}, {
               28.421490368367696`, 28.958850963163233`, {28.219}}, {
               28.585532203389832`, 29.044698305084747`, {
                29.054000000000002`}}, {
               27.843226256983236`, 28.409860335195525`, {29.03}}, {
               27.183946428571428`, 28.16073214285714, {28.956}}, {
               27.116720142602496`, 27.546524064171123`, {28.846}}, {
               27.220698924731188`, 27.543010752688176`, {28.742}}, {
               27.210466284074606`, 27.542539454806313`, {28.645}}, {
               27.198525345622116`, 27.687004608294927`, {28.553}}, {
               27.840925017519268`, 28.21213735108619, {27.117}}, {
               28.15612466124662, 28.879078590785912`, {27.152}}, {
               28.653918644067797`, 29.08377627118644, {27.229}}, {
               28.646986162672967`, 29.047438407019914`, {27.303}}, {
               28.92577695914267, 29.50214333556598, {27.435000000000002`}}, {
               28.380691196698766`, 29.14272008253095, {27.559}}, {
               28.13023255813954, 28.68697674418605, {27.676000000000002`}}, {
               28.14046479361776, 28.511633714880336`, {29.502}}, {
               27.560230333097095`, 28.341803685329555`, {29.463}}, {
               26.345145810262093`, 26.88682170542636, {
                29.339000000000002`}}, {
               26.390611028315945`, 26.873125931445603`, {29.219}}, {
               26.230450112528132`, 26.565348837209303`, {29.04}}, {
               25.942714932126695`, 26.2972850678733, {28.792}}, {
               26.07389075944631, 26.398952487841374`, {28.564}}, {
               26.06374391613628, 26.39865219019094, {28.354}}, {
               26.264259740259742`, 26.75665306122449, {28.161}}, {
               26.787581227436824`, 27.348938628158844`, {27.984}}, {
               26.763293172690766`, 27.167155896312522`, {27.82}}, {
               26.630605612998526`, 26.96545790251108, {27.67}}, {
               26.368841374269003`, 26.97955043859649, {27.532}}, {
               26.451369202226346`, 26.943762523191094`, {27.405}}, {
               26.09195341848234, 26.7223365890308, {27.288}}, {
               26.000454029511918`, 26.414097616345064`, {27.18}}, {
               25.9404550625711, 26.226056124383767`, {27.056}}, {
               25.86614923134608, 26.526100487439066`, {26.914}}, {
               26.211795735129066`, 26.57625888514777, {26.788}}, {
               25.97136054421769, 26.414557823129254`, {26.677}}, {
               26.116391982182627`, 26.559543429844098`, {25.866}}, {
               26.64405197657394, 27.077448755490483`, {25.89}}, {
               26.67240822320117, 27.20428046989721, {25.943}}, {
               26.5424197713021, 27.10379933603836, {25.993000000000002`}}, {
               26.29168220813129, 26.71510630361805, {26.042}}, {
               26.27635424354244, 26.80818450184502, {26.088}}, {
               26.726400580551527`, 27.208933236574747`, {26.156}}, {
               26.8409007689491, 27.313694617356276`, {26.248}}, {
               26.738041907514454`, 27.26, {26.333000000000002`}}, {
               26.59672131147541, 27.079402550091075`, {26.412}}, {
               26.59090909090909, 26.83712121212121, {27.314}}, {
               26.292442293373043`, 26.784810126582276`, {27.293}}, {
               26.165931008902074`, 26.678022997032638`, {27.248}}, {
               26.149999999999995`, 26.494726930320144`, {
                27.182000000000002`}}, {
               25.97509172594534, 26.369101460127293`, {25.975}}, {
               26.737146994931205`, 27.30832729905865, {26.002}}, {
               26.75135412844037, 27.233981651376148`, {
                26.028000000000002`}}, {
               26.330149588631265`, 26.93102468212416, {26.053}}, {
               26.240749344323717`, 26.477152491569875`, {27.308}}, {
               26.061355932203387`, 26.386384180790955`, {27.283}}, {
               26.162097378277153`, 26.34925093632959, {27.259}}, {
               25.89256991685563, 26.572139077853365`, {27.204}}, {
               25.87840477077898, 26.51847185985837, {27.125}}, {
               26.351982149497953`, 26.667103012272218`, {27.05}}, {
               26.42572583608967, 26.878794560823223`, {26.98}}, {
               26.600454881656805`, 26.817119082840236`, {25.878}}, {
               26.65285871559633, 27.05668990825688, {25.902}}, {
               26.633159633027525`, 26.879398165137616`, {25.925}}, {
               26.592265193370167`, 27.035469613259668`, {25.948}}, {
               26.786236870699025`, 27.21954364360739, {25.999}}, {
               27.052432138979373`, 27.643311617806734`, {26.097}}, {
               26.97738163558106, 27.804727403156384`, {26.234}}, {
               27.342257255463995`, 27.80518452167682, {
                26.391000000000002`}}, {
               27.186147804355585`, 27.708200642627627`, {26.532}}, {
               27.341357271095156`, 27.764872531418312`, {26.66}}, {
               26.990746812386156`, 27.55223315118397, {26.774}}, {
               27.135714285714286`, 27.628195488721804`, {26.877}}, {
               27.010298833819242`, 27.60133381924198, {27.805}}, {
               26.942138181818176`, 27.237556363636358`, {27.788}}, {
               26.841349670811994`, 27.12700073152889, {27.75}}, {
               26.692705278592374`, 26.978346774193547`, {27.687}}, {
               26.893658802177857`, 27.287560798548096`, {27.627}}, {
               27.085427135678394`, 27.499095477386938`, {26.693}}, {
               27.33195839311334, 27.57819225251076, {26.71}}, {
               27.462247591865854`, 27.688801284338204`, {26.75}}, {
               27.45254636233952, 27.639700427960058`, {26.787}}, {
               27.46194930382006, 27.737750803284538`, {26.844}}, {
               27.6017825311943, 27.889714795008913`, {26.928}}, {
               27.64027269465375, 28.007750269106566`, {27.036}}, {
               27.041797017097128`, 27.548272098945073`, {27.042}}, {
               27.29191642651297, 27.570000000000004`, {27.138}}, {
               27.18, 27.85527950310559, {28.008}}, {
               27.150208257215926`, 27.408403361344536`, {27.991}}, {
               27.143279395900755`, 27.808701905789285`, {27.957}}, {
               27.55041007194244, 27.7788381294964, {27.924}}, {
               27.332923076923077`, 27.789796064400715`, {27.143}}, {
               27.503197158081708`, 27.950000000000003`, {27.159}}, {
               27.961340388007052`, 28.33865961199294, {27.207}}, {
               27.582207191171236`, 28.029003203987184`, {27.252}}, {
               27.810923951670222`, 28.079004975124377`, {27.295}}, {
               27.770271428571426`, 28.137760714285708`, {27.337}}, {
               27.48136347326875, 27.779318263365624`, {27.377}}, {
               27.451838050877825`, 27.759727696166248`, {27.416}}, {
               27.56115687679083, 27.829319484240685`, {27.453}}, {
               27.731492537313432`, 27.959857853589195`, {27.488}}, {
               27.780427960057064`, 27.95914407988588, {
                27.522000000000002`}}, {
               27.612064056939495`, 28.07871886120996, {27.555}}, {
               27.831064584811926`, 28.01971611071682, {
                27.586000000000002`}}, {
               27.980988700564975`, 28.28879943502825, {27.616}}, {
               27.85042689434365, 28.158221273568124`, {27.645}}, {
               27.901061946902658`, 28.13936283185841, {
                27.673000000000002`}}, {
               27.76142045454546, 28.14865056818182, {27.699}}, {
               27.910355113636367`, 28.138721590909096`, {27.725}}, {
               27.88204441311244, 28.24943602396898, {27.75}}, {
               28.06244669695911, 28.459650471862986`, {27.792}}, {
               28.16174764068508, 28.459650471862986`, {27.832}}, {
               28.321944444444448`, 28.64965277777778, {27.898}}, {
               28.34014005602241, 28.747268907563026`, {27.983}}, {
               28.072307692307685`, 28.409930069930063`, {28.747}}, {
               27.91411149825784, 28.5794425087108, {28.731}}, {
               28.270839454354668`, 28.529020636586218`, {27.914}}, {
               28.47659574468085, 29.608510638297872`, {27.948}}, {
               29.315270805812414`, 30.109722589167763`, {28.034}}, {
               28.531451278507255`, 28.998203178991016`, {28.117}}, {
               28.460903091351163`, 28.818402222994095`, {28.197}}, {
               28.311254792610665`, 28.77797838968281, {28.274}}, {
               28.501863997238523`, 28.93882637210908, {28.347}}, {
               28.40159556018037, 28.83854318418314, {30.11}}, {
               28.302014588398748`, 28.77868009725599, {30.074}}, {
               29.40112865300638, 30.02668458179375, {28.302}}, {
               30.063814466428806`, 30.967615958482, {28.355}}, {
               30.17150980392157, 30.687941176470588`, {28.408}}, {
               30.388035264483626`, 31.69889168765743, {28.539}}, {
               31.32275516593613, 32.61380087664371, {28.784}}, {
               31.23235294117647, 31.758685121107266`, {29.014}}, {
               31.545924563017483`, 32.449506286415215`, {29.23}}, {
               32.05569788519637, 32.87993051359516, {29.522000000000002`}}, {
               32.3708435207824, 32.84746943765282, {29.79}}, {
               32.16534077201448, 32.939930639324494`, {30.105}}, {
               32.85281576590026, 33.28979396834876, {30.487000000000002`}}, {
               33.013555555555556`, 33.66886222222222, {30.933}}, {
               33.01048333833683, 33.55668567997598, {31.316}}, {
               32.422370415277356`, 33.00825704759018, {31.645}}, {
               32.36049295774649, 32.76760563380282, {31.929000000000002`}}, {
               32.09260324258183, 32.48978892627715, {32.093}}, {
               32.323342415985465`, 32.83972146533454, {32.313}}, {
               32.8, 33.53, {32.503}}, {33.43, 33.9, {32.727000000000004`}}, {
               33.55, 34.15, {32.983000000000004`}}, {34.1, 34.87, {33.36}}, {
               34.68, 35.1, {33.708}}, {34.72, 35.27, {34.021}}, {
               34.36, 34.84, {35.27}}, {33.9, 34.55, {35.243}}, {
               33.9, 34.28, {35.216}}, {34.41, 35.18, {35.189}}, {
               34.57, 35.02, {33.9}}, {
               34.809999999999995`, 35.24999999999999, {33.927}}, {
               34.79, 35.28, {33.981}}, {
               34.82999999999999, 35.629999999999995`, {34.08}}, {
               34.77, 35.74, {34.213}}, {34.43, 34.89, {34.335}}, {
               34.49, 35.11, {34.447}}, {35.06, 35.78, {34.581}}, {
               35.14, 35.65, {35.78}}, {34.68, 35.18, {35.758}}, {
               34.85, 35.27, {35.736000000000004`}}, {
               34.59, 35.02, {35.691}}, {34.25, 34.69, {35.604}}, {
               34.63, 35.16, {35.523}}, {34.9, 35.17, {35.447}}, {
               34.59, 35.09, {35.375}}, {33.37, 34.33, {35.214}}, {
               33.05, 33.73, {34.998}}, {32.57, 34.2, {34.707}}, {
               33.46, 34.38, {32.57}}, {
               33.89, 34.48, {32.608000000000004`}}, {
               34.5, 34.78, {32.695}}, {34.34, 34.79, {32.821}}, {
               34.33, 34.99, {32.994}}, {33.63, 34.44, {33.154}}, {
               33.6, 34.37, {33.301}}, {33.58, 34.24, {33.436}}, {
               33.98, 34.59, {33.56}}, {34.14, 34.6, {33.675}}, {
               34.32, 34.81, {33.78}}, {34.9, 35.77, {33.979}}, {
               35.28, 35.73, {34.158}}, {35.58, 36.22, {34.405}}, {
               35.96, 36.43, {34.689}}, {35.49, 36.39, {34.933}}, {
               35.22, 35.89, {36.43}}, {31.02, 32.67, {36.322}}, {
               31.6, 32.01, {36.216}}, {31.71, 32.04, {36.112}}, {
               31.89, 32.19, {36.01}}, {31.25, 31.65, {35.910000000000004`}}},
              HoldPattern[
               System`TradingChartDump`$layoutData$545658["AppendedAdjust"]] :> 
             1.0563850768653922`, HoldPattern[
               System`TradingChartDump`$layoutData$545658["AppendedBox"]] :> {
              21.986226846644165`, 47.359}, HoldPattern[
               System`TradingChartDump`$layoutData$545658["AppendedMin"]] :> 
             25.337956692913384`, HoldPattern[
               System`TradingChartDump`$layoutData$545658["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$545658["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$545658["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$545658["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545658["DataMax"]] :> 
             36.43, HoldPattern[
               System`TradingChartDump`$layoutData$545658["DataMin"]] :> 
             25.86614923134608, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "MainChartAllValues"]] :> CompressedData["
1:eJxdlglYzdv6x1OZ0mBocEISmtBAOvZv2t9dJ1NzGs1jdRqIoiuiolJSGtwo
HZqJUhQKTaJjOJTIWKlMKZEkUty19fv/PfeuZ+/nfdb6rXdY7xo+75S1m+w2
SEpISIj/feT/deG1eHeagY/suGoDWwbXnF5OfHyIgcC9ybN2G4P7t9y+HnBm
UN+vW1o7iYFhSPmQzGQGciGeVYc6GKR4/C5dO8DAw954/cbfWaxYHTCjzY2F
uZrsvNalLPrvOVdY/sHi3NWAxrE2LJadvf6x346FgqPei8YYFuE9twtjn7OQ
NbMMyWli4bTS2yf0NYsPNz9L9lWy+COx66DzWhYB8qXBCQEsRi32NW9qZlH+
zsJUqobYXTdFWf0yi6A9P4aeDyV+42f/OSmPxdQRrwNT/Fj4P9BXPLaHxbiw
8X765SxcdGqqGqU4KOctaJa5w2LW1RjPbcRfU56JlcdQDtIWBUMtClgUnPL+
7vobh6fyTpEddhzOHTXQEdpwWKobeKHPlkP1jf3tiww5XFnQn2S9ikNDynm1
N50squtfjpp6ksWR1XFtd51YfH5+PYybzWLEuWiDdlkWHbFyXk+uMEiMfzre
pobB67BnUkP6GVx5tX2kfzORHn4+vnIsVPe1GIU1MPh0L2DO4SAGt7oe73u6
gOzH29yI03MYNMrX31SdwuDpqiPafvEMNEv+9eFhBoOmC903X3ky8LKBz0uy
j6pNsrkND2lodX6eqKJPQ8101KrmSTSSvoUX755Ho17SWq15Lo2qpqToe7Np
zEw78Ww+mS/U0r3Rq8VAYa+jsVs2sZN5pOV4JoPtbyQv/iD7Ljq7qc9vDTk3
SpXtjiSOljq9oJ6pDBSbrUSeMTScvO9uX+ZMoWPsYaUf6yh8ybGp/k5RWPFe
psqhSwBPCzr47VgKtZN9Q21HU8geXRqWZUqh5e+VHX/doLCv11vP7SqFgqCE
lZtSKWS9dFvntZLCo29HOqN8KShPXWESqUKh6LVLxSQJCpd+Kz5Z8UEAE+XS
T5caBLh+9xY3z5jCTJkcpVNfBDg74NVwaxIFXWv1xOcZFFrnSnzUOE3BZEvO
0GeRFC6XuZ85tZiClnq9Ztl8Chmmm9f1FFOwrX1gZvaQwuQnu20+XKbQc9Sh
pPIwBZUVfrVmiRSmDQnb3UD0Nh1f7RegS2GDK2maFMZGBB899lWAH3HLcoqI
Xv6K4FLncgqRPT15e+0prHYrL0tlKZykSoYWKRD//iXGu3Uo1C1avG33CwHc
psdrND0XILExKmjCUgoYY72y34tCqI/wzwtHiP0N+WVTsiloSrwrU06jEKSk
WPAXiedWzJ3a+SR/AzPtDL3kaHKOavLm9pG8j3w94y8nGh/eta/JJudAMvmU
wTrS/3eN2aHUAZKn0pYZpRo0bvpUdqVJ0qibV92r30XBIl27YC1Z/xQ7JQ2H
AgrvNCruXX9B4fu74AONSjQ+yeUIvtnT+Hyh4KnDNhojZo5VfOJLQ98W1iak
n/x3iKd8Eg0zBYu2N+k0MoMOzT0nQ+P+yK4RlxbTINcwQFGPRrP9alk/TXIu
D63qyZ1G48qanNOvo2i0+q/aQjnQyHX9M7w2iMaWGkc31c80EuL/CR91iMb2
XvPzh+/SeFuhEWJwjUbarN40ageNmuT4E6dIHN+uTOnLJucxcLjleNNL5Fzb
b1W/WU2j5GgrlX+URlSqbFb5fRoKp+3GaXyjMf/R2fiix2RdKW3fT72iMa96
o29HJY3wmtUj5Npo9L9PP/lPM40yveLgfgUGCR9Vzd11GERL7+z2sGMwNNfA
c5wTg+6iaxUhYxkwb+WMpd7S8G8fdtnBjIF2bfksyQByr1zc/11E3kPN5BcG
cvsYhPRdKB3YymBTf8v6PGsGr2ad0Q4g936f4dbeO64M3JX762wsGWRoyq/M
d2Vxy055uuNoDi43ho15M4NDS9aWBY7rOERZaygdtxNih7jRQog4m/MV+4X4
eqZ4wpThwL1HHbf99YECYUeLjhIgPVx7jI43oPmSNbgcDKRmp+x1IlJ67iN6
tDFQ0zchbZoewM229HoyCkgaUb1wnQ7g+rMBD9N9WJkLfP868M9t0mRFg+NO
IiyPqezRXi7i91mEOeLWjf+XiuIPRiLoiCcuFEE8Lc9NhNB224tqG0QYKTbk
IcJVYiVmLW/3dxEmiydwIiwUzw8Xwe6iWmh77C+/P+PwEqGDmAk1F0FC3NRF
2MzKPEy34ePw/fX9Z5hn+HWEgY8H2CEOsASD9rswaAe83gwRZMQOdXm7Nfz6
b2Nw/CYgHvYZ4PXH8OvU/uU/w0c8g7dzUzTor49fXymfv6N8PoYKkXRE3IT4
TNJRWSQc1G8V8nEJca/kdrNZKgOteQEh6b0MKuO9ks3eM+hZNvBa8IDB+F2h
t59dY7DcSC/90wnCofP69e2EN54OF+1UCb8VlUjbyuL00Z2mTw+yiJA27Ggo
ZRHlK6dx5zyLIruPFvejWViN9viicobF8ba5y4YksIiub3R7L+DQIVNwQnEO
h0Kmb5/BVA4P2zcslBdymFjRnxw4ikO0IPzTyrMsNlf/HaHazoLzeJXuynHI
iNk6MFyZg31ByvHMkRyGXXnRxxEub5fcmTaT6Ls/tv2m+4lF4+aR+7PrWDz2
9fKcl8pB6rRDVoszByOSznh9Ds49Xk8CZ3N4I/WD7tnKYWrngUh7Pw4qfdVJ
m8M5yBvvfdQVweGvxvWsaSAHqoUQ3Z/DkmfmK+6VcRAIdTOWNXNQe696cMtS
DocUjnyds4iDSXZQzKNWFkoGxtOvk/rAl9Gv7iZ5kFWxXvJmEYsL9c6R9w1Z
hO4qeTfcgtQb4nNtzyLXoWv29ygWSSe7C2QpFjpfukccJ3VAb4mWTCvZpx2B
356di2MwSbH35eR0wvlIBWuJkSwGGtpWtJB9MQy7KPLvYRATpuayeRSLrMRV
yR3uDKr7n1+ZTt6dKJX5Em37acjOzC+XJPKW3rGG1kgaX+oK9zWdodE4UyfN
ypjUazKu5qNIfTH33eHlW5RYxBa7dkwjcQzVMfKPCmLR2Z1lGTGNhel6QVHD
GQY6Xc7efSEMIqaZbAki75m3gVXZsFYKho+d9UKbKJhlRp8rOUihSfV2k6oF
hYr3CuVTXClYu7weI09k2upHUoUVFJ7isoy9C+HO9/iSm7o0dLqrhNq9pC44
sLj2KuFSnXmhZxLhjGdin2z7RQrFB7QsJT0odC7yrmkUUHjesyc0L4zC3Cs3
zoXGEw5nTNumTr6j6RvDxVCI/bg7r24ceZ89Y4vNjQhvUpsT41QJj+a0G425
QOFT9KdZL+9QuKshk7WT1Dlfti9dbGVDD74nJjSMnl0qXqJIw/jx+njLemKP
lbJt+5tCu8H8t3G5hHcz47yydlFQ0OrYGEjqj4r2gohOKxpWYYXzXtHEXqBh
mlMnhZW7PXI0AygsN3g29u1aCjJpG0LcXSjUTHtR6B9H7PSviSvZS+HcNXvT
6hwKPum6eV+eE25fdrmgV0vhx9cH1B55GvnevYx6M8lD9/IIxZE00h2nSBmR
Ou1lSu+Y/AwaG8u3pUjeodHxKD1Oncg9KlrpFkU0XsmePnPnKg1t1Weaqw7Q
kIt286w9TiPk2CqpriM0ll/32lXD0Bi3s1BtjzqNj1Za7/1I/vVXpx5KWURj
ac/xi1W7CVcdrN2lE4i90+8WOOTTWLlE5H6VcHtTYQLTcJlGhr25S1UrjdEu
H9q/DWFgumBjzDLC6SU/319iv/rz4e4nNCYfcCc/Gp3xB5SHEz4njQ5/v4Zw
13rijHEGN+mf93VONw2X/q0bzjoyOJUkXeE1nHBuzb5TAkUGDeEmi/4g9WSh
fb1rMNEzfXViTyDh8P0ytYVWhNebvkZwxT00ZEzd/COJTN/u2K5J9HIubZkk
O5TBuaigys5FDPKCdxgEa5P7NdFhYS6x59WU/1lOk8FUo/Eme0h/wno5madC
UrdyyD619ZfMsu7LsM5iIG3ZJGVZxkDjx5JZXeTeCerUnR0TGEjKBr70Dmfw
psJjaXUyi8wJCdXKEzkkhjtzkT8YXL7UeCeklsSRtzNRp5pBwf37HY4fGOS6
qFfl1DMoqtRPcCLjsRO/374/jENC1Yfcol4ONnvOt03M5+D4/p+Db88KsfFi
17BYK0BJTctAUCnEl7LhXhECYIPd9IOpPsCIyNfPt3sBE4zyMq3/BbjbSnxR
yQTO9/fPT3kADNz7uF1UDSBPI1aecH1RYeUrrAXqNK3cCjjg97w533d4YpAj
V/HffB7Hc3ETz9MonsNpPP88RYO8nM9zbCrP30R+XogIP8Tt2C/O/RQ1PN8a
eW5v5uuDaH5eK8/Huv+xl/bLrljN1lk0WD8kiAZ5eIiPa/8vLv/kbwMGufkb
z2kDfpzl/a37VW/8jGsXb38ev359flztV73wMx8WfP3hxsfV8n/+eG5PNOHr
FZPBdRrysouP1wEQqy8YAp7vGPQ7nq9DsoT4Dzzd0Ro=
              "], HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "MainChartPoints"]] :> CompressedData["
1:eJxdlltoXFUUhqdFUIKgYkSRUqdVSqylVGNtmzbJTmqaNEmTTO6XSXLmfp9U
pCiRyqFShCIEn0QRGS/4IhTBlyAqscUnKyIoVRCZIoiQIgWplD6Zk/V/D+cc
CMOftf/9r9tee+9Jr4zn7onFYne3/nbob2eM71b3D9e2vuETTv9wN1ZbL/ff
AN/nrt5uS65dAT/o3ns3+MCtruX6x2c7L4EfcwF7dRK8yz1xcTOx/gc47tau
bG34QKfwXrMvgZ9yAb21Dt4nPXCbC5bvvgje7zoDB86DD0T4B+3XBx9y41vs
zYe6hJ+19QfBz7mBIAH3gttdEF7Lo+DnLb6f2e+wxbMGfsH8/Q18xL0WEO6C
j7qbgfub4GPupSCAW+AOy8cH4OMuGQjsQv+Erf8ce2cEd4nP+m7T7wA7q+dO
Yd9ZPK3Ye8L58XtcABNHsfcq39gjOHbS/Re0yznsJ9UP2F+0/daxC7+KvS+i
3xeJ75TWC/unpIe9X3zs/VafH+m/AePfEfYHrB7PwD8tf+Gfdk9vFwD7oPoB
+2DkPAyZ3ij7D1k/9WMfVv9iH1Y/YT8T9tc/Y/p/Yx+x+H7CPqL+Oi77qPkz
J+yPuvz2h33Mfp2wG1N/sH5M/Sy8MaZ5AD9h8V+XvktE/Emon4U3EpH8jls8
Rfjj7pNguyfhy94Gf9z2fxv9CTuvlzvEF64L+xPW373CGxN2HnYLxyZVX/iT
qhf8Sc0z+JOqH/pTyjf8KYvvM/hTrj34/oU/Fd4vNq3zBH9a8wa+7HeOiT9t
/dIHfybi/4zmKfwZ2+9N9GfUP/Bn1W/wZ83fL+DPql/gz+r8wZ9TveifOVv/
F/w55Z/+mbP4W8jfvK3/FP15038Z/rzbvo/eQl/r96G/EK6XWzB+O/27oP6E
LzwDP2n+DMJPhvf3k6Y/DD8Zzm9s0epdgb9o/bAKf9H41+Av2vn5EP5S2D8X
wf6SzdOv4S9Z/g+Rv2Wbd4fJv/A54l/WPCb/y7b/O/A9nRfhuBeuj/OsfheE
PU/9yf6e7gvhhvb7B3893ffCTc/i34N+yuI5i34q7L9L2X33Pvop3Wfop8Lx
NFK6b4k3pfkg3Eypnuinw/Mkntb9j34Ee+mIfjrsXyOt9xH6aZ1/9NPqL+Z3
xs7Pn+hnNC/Rz2j+o58Jx+NndH+in7H++xL9yH7NjPqL+LM6r+hnw/eHy2pe
yl8vq/mBftbyeb/sjazV7zb6EdzMav4Tfy48/+MR7HLh+9TLWb6T3A85zSf0
c/o/90XO8psRbrKe+ycffl/E8zpv6OfVX+jLfh79vM3j79DP63yjH+E385H3
YSH8PosX5K+wK+i+6JZ+QfUW9gvqX+FGQfPBSb9geivCTel1CceK5t8rwvGi
/Bd2wt8Ke0X5I+zLnhJuaL8j6Bf1nkC/qPyjX7J4r6Jfsn66iX5J86hH+iXF
I+zLfkm4IX5VeKNk52VEuFmy8/iwcKxs53WvcFz4grAraz6hXzZ/30C/rPsK
/bL19/foly3fr6Mvfgb9iu4L9Ct2Xn5Bv2L9/hX6Fd036Ff0i77WJ9Gv6D5E
P7I+VlU/o1+1/YfQr5r/31D/quXnI+pfNb3fqX9V/lP/qtXjAPpV3dfo1/Se
Qb+meYt+Te8f9GvWbzuIv2b5e5z4a9YP+4m/FtGv6T2Mft32/xX9eiT/wo/0
Sr+ufhH267rf0Nd+6+jX1e86n826/Kf/V/Relj2+onkp7FbUL93ufxyzRGk=

              "], HoldPattern[
               System`TradingChartDump`$layoutData$545658["NewOverlay"]] :> {
               FinancialIndicator["ParabolicStopAndReversal", 0.02, 0.2]}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "NewSubplot"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "OverlayIndicator"]] :> {{{{}, {Antialiasing -> False, 
                  GrayLevel[0.5], {{}}}, {{
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Point[CompressedData["
1:eJw9lgs01Hkbx8kqy1JWurjUJOWykVXKfb50k4z7LdcxZsyMmaF3pTbZ19Rq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                    "]]}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "OverlayIndicatorCount"]] :> 1, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "OverlayIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "PSAR"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "OverlayIndicatorNames"]] :> {
               FinancialIndicator["ParabolicStopAndReversal", 0.02, 0.2]}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "OverlayIndicatorParameters"]] :> {{{0.02, 0.2}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "OverlayIndicatorPoints"]] :> CompressedData["
1:eJxVVwlwTWcUflJDmmJUQzO2eWJpUNSSZhM5SUgikX172W9e3r4kLUqr1DMd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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "OverlayIndicatorValues"]] :> CompressedData["
1:eJxFVQuQjlUYXpdBG0ZCxm1Yl8jIuM36znvO9z/frxCzrqWdHRmzuUYpRG20
GSMZsSSXWnLLrZCMRFKbpEWEkUtG7Bikdt1WhFa953vf6pvZ+f/9z/nO+7zP
87zPaZI9pt/QCikpKeX4745+VlnfIGsIWdw7+sqlFn0tzvSetfCFsRZDib/d
sqi9sVtRzg2LigOqt9nc0OLbP1oOzEuzaLJp7Ii5bSyKcmpt7BZZDMzbxSsW
ZkvhhK9yLcaNmFsyaalF01O3X3/uS4upBfuWP37Mgoud6V1iMZKXE7UdtjWa
9nvfzg4fXFmzp+fTDq2n1zl5cKLDhUNpp26HIfxxS02Iv9ZdO5KR7dBm85Ir
a4Y5DPriiarlRznM8WXHONzhKuPHOcTtJEIkB58/lEYh4vLjnZyT48Dd1Zz6
hsPwYfy86fDqpRbtqrzt8F1j35DD8ZUvutSFTvpZ7LB2T8/0Gcu17mqH4r6M
+GOHHlXLt56+1WHxbn6x0AkPRVr3VCj79od4/uLdddc2h3p+KPxlh8hlVPM6
h1idzwfUDPGSSz2+8qpDP0/IYSd88fmxLoyrjwf+rBN92jvUb3u6WaUmFg/6
jc0t9nJ79dpaXGeWanS2+JXLHqnm0N0Dq+yEB9YxrnvCYj+fXrrTgtnf1miV
6jlLf29IuFHmC5PyT7KeQco3Sb08wrt12Rkb6D9eY14mODyQGWwpHOAUj0Nq
TKzDIt5WsM/iIy/nHCvnZ1lcZfnTW1ks6DJz9MW7pDyQ8k34idG0e4ukn+GE
yYlObAGCt2etRwkvz/NACI/51y8ZWd9rxG8bjPj3dIAPGcXxc4HocS3AO2zD
TvcCwZVqBH8dg+pe8IeN+DhhxK9PGWwtZWJGGsHfh8SHPUn3EawXiPG8/x4/
twPhJcVgB29rXdkIj9UMfJWTvUj8053E30lCr+wamUFHQop/GhMO/MBPVcJr
3l53DJ48typ/99lA9LkQyHpxID66HiDwhP4doKsHWtcIn2QwimWvO8Qojwat
vMHXGiyrx0baYwTnWSN8HlR+9yqOAkJDT+QnqvMyEv4+NbjJdt71mdF9yg/z
Hut+QvstMaLvfaQ8Ex46efBW/6aETjGBmi9lhBVsv7IbhEpT5neZWUz4sz83
3IzgadnSUtc7Kg6oP5j/eF4G6O+DCYfTvOMJPk5ujSPEMCaRzMs09c1swk6m
peICkvpLSOeBEANbTzq/quf2//kQHyueowTfzrnzhB/5YxX7N86hr63kwQ6r
viTVSfup8u+8ae62t6JHVyv6ZWquNtAc4ZyI/ZxhxQ88N7F/Ruj5M6ycW2jB
6TBlfgUn+4zTvnUO9+nv9UL8xvG3flIofrwcIn1GNPh8n4TykJAcKUmIj+6H
6NoS4n9A5v8ZyL7JEF43Qub6Z0i/5SPJvRWR5MbSSHjKj8SPiyJ08E8pJGdv
QnxTBs2NCM29IepHgvuRSPwURLjM4zuoR6RzHUkuFkUy179Ews+JSHg7EAmP
u/T97ZHouSlCfA8ynnh+ciPxT1Ykc9Jd+8uA/J8JxDExEqJzLvCNj+t5kPxY
DbnHPofk1feAv26GHYPihODh/uJ5r6X4OygfmRG8/UdPjOQ+Sk9qPiaFt/pJ
zbuk3DvlknpPR/gH9ndt1w==
              "], HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "OverlayState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$545658["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545658["PlotRangeMin"]] :> 
             25.337956692913384`, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$545658["Space"]] :> 
             3.6430000000000002`, HoldPattern[
               System`TradingChartDump`$layoutData$545658["Style"]] :> 
             RGBColor[0.24720000000000014`, 0.24, 0.6], HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "SubplotIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "SubplotIndicatorGridLines"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "SubplotIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "SubplotIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "SubplotIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "SubplotIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545658[
               "SubplotIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545658["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$545658["YRange"]] :> 36.43,
              HoldPattern[
               System`TradingChartDump`$layoutData$545658[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$545658[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$545658[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$545658[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$545658[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$545658 = 
           System`TradingChartDump`$length$545658; 
          System`TradingChartDump`$layoutData$545658["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$545658; 
          System`TradingChartDump`$modelData$545658["Data"] = 
           System`TradingChartDump`$data$545658; 
          System`TradingChartDump`$modelData$545658["Indicators"] = 
           System`TradingChartDump`$indicators$545658; 
          System`TradingChartDump`$layoutData$545658[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545658["ScalingFunctions"] = {
            System`TradingChartDump`$sy$545658, 
             System`TradingChartDump`$isy$545658}; 
          System`TradingChartDump`$layoutData$545658["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545658["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545658[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545658["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$545658["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$545658, 
            System`TradingChartDump`$layoutData$545658, 
            System`TradingChartDump`$indicators$545658]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$545658, 
            System`TradingChartDump`$layoutData$545658, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$545658[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$545658["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$545658[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$545658[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$545658["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$545658[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$545658 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545658["AllValues"], {1, 0} + 
              Map[
               IntegerPart, {
                System`TradingChartDump`$controlmin$545658, 
                 System`TradingChartDump`$controlmax$545658}]]]; 
          System`TradingChartDump`$plotrangemax$545658 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545658["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545658, 
                 System`TradingChartDump`$controlmax$545658}]]]; {
            System`TradingChartDump`$plotrangemin$545658, 
             System`TradingChartDump`$plotrangemax$545658} = ReplaceAll[
             
             System`TradingChartDump`$sy$545658[{
              System`TradingChartDump`$plotrangemin$545658, 
               System`TradingChartDump`$plotrangemax$545658}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$545658[
                Min[System`TradingChartDump`$lows$545658]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$545658 == 
            System`TradingChartDump`$plotrangemax$545658, {
             System`TradingChartDump`$plotrangemin$545658, 
              System`TradingChartDump`$plotrangemax$545658} = {
             System`TradingChartDump`$plotrangemin$545658 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$545658], 
              System`TradingChartDump`$plotrangemax$545658 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$545658]}]; 
          System`TradingChartDump`$newgridlines$545658 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$545658, 
            Part[System`TradingChartDump`$newgridlines$545658, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$545658, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$545658], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$545658, 1]]; 
            Part[System`TradingChartDump`$newgridlines$545658, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$545658, 1] =!= None,
                 System`TradingChartDump`$length$545658 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$545658, 
                 Part[System`TradingChartDump`$newgridlines$545658, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$545658, 1]]; 
            System`TradingChartDump`$subpricegridlines$545658 = 
             Part[System`TradingChartDump`$gridlines$545658, 2]; 
            Part[System`TradingChartDump`$newgridlines$545658, 2] = 
             If[System`TradingChartDump`$sy$545658 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545658}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545658, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545658, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$545658, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$545658, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545658}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545658, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545658, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$545658 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$545658]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"MSFT\"", "\" with \"", 
           "\"ParabolicStopAndReversal\"", "\"(\"", "0.02`", "\",\"", "0.2`", 
           "\",\"", "", "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {720., -502.20000000000005`}, 
      ImageScaled[{0.5, 0.5}], {450, 310}]}, {InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$545673 = 
        "Full", System`TradingChartDump`$highlightposition$545673 = Automatic,
         System`TradingChartDump`$maxohlc$545673 = 36.43`4., 
        System`TradingChartDump`$timestampstyle$545673 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$545673 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$545673 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$545673, 
        System`TradingChartDump`$subplotpoint$545673, 
        System`TradingChartDump`$ndigits$545673 = 4, 
        System`TradingChartDump`$highlightstyle$545673 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$545673 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$545673 = True, 
        System`TradingChartDump`$timestampQ$545673 = True, 
        System`TradingChartDump`$data$545673 = {{{2012, 7, 26}, {
          28.367935528120714`, 28.62997256515775, 28.232064471879287`, 28.3, 
           45301400}}, {{2012, 7, 27}, {
          28.60827956989247, 28.967338709677417`, 28.317150537634404`, 28.88, 
           44242600}}, {{2012, 7, 30}, {
          28.866734143049936`, 28.934655870445347`, 28.58534412955466, 28.76, 
           28905000}}, {{2012, 7, 31}, {
          28.609704784526638`, 28.832914828639293`, 28.464133016627077`, 28.6,
            37620900}}, {{2012, 8, 1}, {
          28.714675280516833`, 28.77290037402244, 28.3459163549813, 28.54, 
           31721800}}, {{2012, 8, 2}, {
          28.349410757108597`, 28.65998287084618, 28.11648167180541, 28.33, 
           39520500}}, {{2012, 8, 3}, {
          28.65650756302521, 29.054379831932774`, 28.60798655462185, 28.87, 
           35859400}}, {{2012, 8, 6}, {
          29.108514190317194`, 29.215245409015022`, 28.924160267111848`, 
           29.06, 27471800}}, {{2012, 8, 7}, {
          29.185588235294116`, 29.457352941176467`, 28.99147058823529, 29.37, 
           28002900}}, {{2012, 8, 8}, {
          29.31356083086054, 29.56584569732938, 29.21652818991098, 29.43, 
           26257600}}, {{2012, 8, 9}, {
          29.493245901639348`, 29.745573770491806`, 29.40590163934427, 29.6, 
           24920800}}, {{2012, 8, 10}, {
          29.59763313609467, 29.714082840236685`, 29.355029585798814`, 29.52, 
           27810300}}, {{2012, 8, 13}, {
          29.451184600197433`, 29.55792694965449, 29.26681145113524, 29.49, 
           23049100}}, {{2012, 8, 14}, {
          29.596050448058413`, 29.68395950879522, 29.31278791901759, 29.43, 
           34551400}}, {{2012, 8, 15}, {
          29.412086092715235`, 29.578145695364242`, 29.324172185430466`, 29.5,
            24351000}}, {{2012, 8, 16}, {
          29.65968810916179, 30.22630929174789, 29.561994801819363`, 30.07, 
           35787200}}, {{2012, 8, 17}, {
          30.19953398058253, 30.19953398058253, 29.87722330097088, 30.18, 
           32589900}}, {{2012, 8, 20}, {
          30.108152244632407`, 30.13745933636956, 29.873695510735203`, 30.03, 
           23737700}}, {{2012, 8, 21}, {
          30.050922077922078`, 30.24631168831169, 29.90437987012987, 30.09, 
           28822700}}, {{2012, 8, 22}, {
          29.878837590045844`, 30.044885396201707`, 29.761627373935823`, 
           29.83, 33437400}}, {{2012, 8, 23}, {
          29.68699272967614, 29.696761401189683`, 29.384163912756108`, 29.56, 
           28355600}}, {{2012, 8, 24}, {
          29.547202225130892`, 29.91837369109948, 29.478828534031415`, 29.85, 
           22943300}}, {{2012, 8, 27}, {
          30.214447702834796`, 30.243753665689148`, 29.88231345715216, 29.98, 
           34691100}}, {{2012, 8, 28}, {
          29.988377407770162`, 30.08605941887039, 29.81254978778975, 29.92, 
           23947900}}, {{2012, 8, 29}, {
          29.940000000000005`, 30.037683523654167`, 29.734864600326272`, 
           29.94, 23346800}}, {{2012, 8, 30}, {
          29.82515171503958, 29.90330474934037, 29.52230870712401, 29.62, 
           23982100}}, {{2012, 8, 31}, {
          29.895068137573006`, 30.246774821544452`, 29.68013627514601, 30.11, 
           36590100}}, {{2012, 9, 4}, {
          29.748617966436328`, 29.953780848963476`, 29.45552813425469, 29.69, 
           48556700}}, {{2012, 9, 5}, {
          29.523915761763735`, 29.8267752550181, 29.51414610069102, 29.69, 
           33650000}}, {{2012, 9, 6}, {
          29.789792663476874`, 30.629767145135563`, 29.750724082934607`, 
           30.62, 48371700}}, {{2012, 9, 7}, {
          30.317906300484655`, 30.347208400646206`, 30.01511793214863, 30.23, 
           42649100}}, {{2012, 9, 10}, {
          30.11745768229167, 30.185839843750003`, 29.804853515625005`, 30.01, 
           40524000}}, {{2012, 9, 11}, {
          29.982305943488143`, 30.197232867814222`, 29.90415069827866, 30.08, 
           25191800}}, {{2012, 9, 12}, {
          30.22630929174789, 30.46077322936972, 30.021153346328784`, 30.07, 
           32775800}}, {{2012, 9, 13}, {
          30.171163542340008`, 30.454414996767934`, 29.692566257272134`, 
           30.22, 45047300}}, {{2012, 9, 14}, {
          30.29461390579942, 30.52907721884011, 30.09922781159884, 30.49, 
           51422800}}, {{2012, 9, 17}, {
          30.47046139057994, 30.53884652355014, 30.323921819929506`, 30.49, 
           36488500}}, {{2012, 9, 18}, {
          30.381847338037208`, 30.489307248236052`, 30.31346375881976, 30.46, 
           34542700}}, {{2012, 9, 19}, {
          30.369072463768113`, 30.466753623188403`, 30.320231884057968`, 
           30.33, 48871900}}, {{2012, 9, 20}, {
          30.231605723370425`, 30.74930365659777, 30.19253418124006, 30.72, 
           45543000}}, {{2012, 9, 21}, {
          30.704459762744467`, 30.88030458480282, 30.3723084321898, 30.47, 
           102348900}}, {{2012, 9, 24}, {
          30.284925276153345`, 30.353310591293045`, 29.933229369720596`, 
           30.07, 46825900}}, {{2012, 9, 25}, {
          30.23710102007239, 30.285949325435997`, 29.660691016781836`, 29.69, 
           54266400}}, {{2012, 9, 26}, {
          29.577447795823662`, 29.890023201856145`, 29.3430162412993, 29.47, 
           54672000}}, {{2012, 9, 27}, {
          29.46976790450929, 29.694429708222817`, 29.196266578249343`, 29.46, 
           47129900}}, {{2012, 9, 28}, {
          29.480262096774194`, 29.558407258064516`, 29.050463709677416`, 
           29.07, 54229300}}, {{2012, 10, 1}, {
          29.122621227534758`, 29.288701254662598`, 28.741614106476774`, 
           28.81, 54042700}}, {{2012, 10, 2}, {
          28.98953472690492, 29.194649359406608`, 28.813722184760618`, 28.97, 
           43338900}}, {{2012, 10, 3}, {
          29.062541862022776`, 29.296995981245818`, 28.98439048894843, 29.17, 
           46655900}}, {{2012, 10, 4}, {
          29.271398601398595`, 29.329999999999995`, 28.880722610722604`, 
           29.33, 43634900}}, {{2012, 10, 5}, {
          29.531216080402007`, 29.55075376884422, 29.052542713567835`, 29.16, 
           41133900}}, {{2012, 10, 8}, {
          28.953243787777033`, 29.226756212222973`, 28.865329079919412`, 
           29.09, 29752000}}, {{2012, 10, 9}, {
          28.990710382513658`, 29.049316939890705`, 28.502322404371583`, 28.6,
            45121100}}, {{2012, 10, 10}, {
          28.476069703243613`, 28.632370600414074`, 28.280693581780536`, 
           28.31, 47227100}}, {{2012, 10, 11}, {
          28.543751295336786`, 28.573056994818653`, 28.20185146804836, 28.28, 
           41488500}}, {{2012, 10, 12}, {
          28.29535616438356, 28.637205479452053`, 28.12931506849315, 28.52, 
           46464700}}, {{2012, 10, 15}, {
          28.693226025076243`, 29.03516096238563, 28.57599118942731, 28.83, 
           42440200}}, {{2012, 10, 16}, {
          28.770922346558155`, 29.054235334011526`, 28.643919972872162`, 
           28.81, 47739400}}, {{2012, 10, 17}, {
          28.626664413653266`, 28.958850963163233`, 28.421490368367696`, 
           28.91, 44206100}}, {{2012, 10, 18}, {
          28.966542372881356`, 29.044698305084747`, 28.585532203389832`, 
           28.82, 59238500}}, {{2012, 10, 19}, {
          28.380551675977653`, 28.409860335195525`, 27.843226256983236`, 
           27.98, 90470800}}, {{2012, 10, 22}, {
          28.063053571428572`, 28.16073214285714, 27.183946428571428`, 27.35, 
           83374000}}, {{2012, 10, 23}, {
          27.126488413547236`, 27.546524064171123`, 27.116720142602496`, 27.4,
            64414800}}, {{2012, 10, 24}, {
          27.503942652329755`, 27.543010752688176`, 27.220698924731188`, 
           27.25, 53320400}}, {{2012, 10, 25}, {
          27.532772596843618`, 27.542539454806313`, 27.210466284074606`, 
           27.23, 54084300}}, {{2012, 10, 26}, {
          27.21806451612903, 27.687004608294927`, 27.198525345622116`, 27.56, 
           57790000}}, {{2012, 10, 31}, {
          27.88976874562018, 28.21213735108619, 27.840925017519268`, 27.88, 
           69464100}}, {{2012, 11, 1}, {
          28.17566395663957, 28.879078590785912`, 28.15612466124662, 28.84, 
           72047900}}, {{2012, 11, 2}, {
          28.907925423728813`, 29.08377627118644, 28.653918644067797`, 28.82, 
           57131600}}, {{2012, 11, 5}, {
          28.930232872089103`, 29.047438407019914`, 28.646986162672967`, 
           28.94, 38070800}}, {{2012, 11, 6}, {
          29.13092431346283, 29.50214333556598, 28.92577695914267, 29.17, 
           43401500}}, {{2012, 11, 7}, {
          28.849632049518576`, 29.14272008253095, 28.380691196698766`, 28.41, 
           57871800}}, {{2012, 11, 8}, {
          28.442790697674425`, 28.68697674418605, 28.13023255813954, 28.14, 
           49841800}}, {{2012, 11, 9}, {
          28.2088380159556, 28.511633714880336`, 28.14046479361776, 28.16, 
           43291200}}, {{2012, 11, 12}, {
          28.273416017009215`, 28.341803685329555`, 27.560230333097095`, 
           27.57, 61112300}}, {{2012, 11, 13}, {
          26.611059431524552`, 26.88682170542636, 26.345145810262093`, 26.68, 
           131689200}}, {{2012, 11, 14}, {
          26.823889716840533`, 26.873125931445603`, 26.390611028315945`, 
           26.43, 76086100}}, {{2012, 11, 15}, {
          26.476699174793698`, 26.565348837209303`, 26.230450112528132`, 
           26.26, 50955600}}, {{2012, 11, 16}, {
          26.267737556561087`, 26.2972850678733, 25.942714932126695`, 26.12, 
           64083300}}, {{2012, 11, 19}, {
          26.398952487841374`, 26.398952487841374`, 26.07389075944631, 26.33, 
           57179300}}, {{2012, 11, 20}, {
          26.359251216772744`, 26.39865219019094, 26.06374391613628, 26.31, 
           47070400}}, {{2012, 11, 21}, {
          26.30365120593692, 26.75665306122449, 26.264259740259742`, 26.54, 
           66360300}}, {{2012, 11, 23}, {
          26.817126353790613`, 27.348938628158844`, 26.787581227436824`, 
           27.28, 57845700}}, {{2012, 11, 26}, {
          27.127754654983573`, 27.167155896312522`, 26.763293172690766`, 
           26.98, 85198700}}, {{2012, 11, 27}, {
          26.945760709010344`, 26.96545790251108, 26.630605612998526`, 26.67, 
           45018600}}, {{2012, 11, 28}, {
          26.605244883040935`, 26.97955043859649, 26.368841374269003`, 26.95, 
           53018400}}, {{2012, 11, 29}, {
          26.697565862708718`, 26.943762523191094`, 26.451369202226346`, 
           26.54, 69551400}}, {{2012, 11, 30}, {
          26.643538692712244`, 26.7223365890308, 26.09195341848234, 26.22, 
           83690200}}, {{2012, 12, 3}, {
          26.37470298902762, 26.414097616345064`, 26.000454029511918`, 26.03, 
           53173800}}, {{2012, 12, 4}, {
          26.098028062191883`, 26.226056124383767`, 25.9404550625711, 25.97, 
           49777500}}, {{2012, 12, 5}, {
          25.984349456317954`, 26.526100487439066`, 25.86614923134608, 26.27, 
           68283800}}, {{2012, 12, 6}, {
          26.408802843247283`, 26.57625888514777, 26.211795735129066`, 26.33, 
           39182300}}, {{2012, 12, 7}, {
          26.414557823129254`, 26.414557823129254`, 25.97136054421769, 26.06, 
           46162100}}, {{2012, 12, 10}, {
          26.155783221974758`, 26.559543429844098`, 26.116391982182627`, 
           26.53, 47031100}}, {{2012, 12, 11}, {
          26.64405197657394, 27.077448755490483`, 26.64405197657394, 26.91, 
           52282800}}, {{2012, 12, 12}, {
          27.11563509544787, 27.20428046989721, 26.67240822320117, 26.83, 
           43966300}}, {{2012, 12, 13}, {
          26.90682405016599, 27.10379933603836, 26.5424197713021, 26.7, 
           45080100}}, {{2012, 12, 14}, {
          26.695412159641922`, 26.71510630361805, 26.29168220813129, 26.4, 
           42077500}}, {{2012, 12, 17}, {
          26.38469003690037, 26.80818450184502, 26.27635424354244, 26.69, 
           42046100}}, {{2012, 12, 18}, {
          26.834724238026126`, 27.208933236574747`, 26.726400580551527`, 
           27.14, 50486900}}, {{2012, 12, 19}, {
          27.274295129989014`, 27.313694617356276`, 26.8409007689491, 26.9, 
           53519900}}, {{2012, 12, 20}, {
          26.94485549132948, 27.26, 26.738041907514454`, 27.26, 52607300}}, {{
          2012, 12, 21}, {
          27.04, 27.079402550091075`, 26.59672131147541, 27.04, 98776500}}, {{
          2012, 12, 24}, {
          26.78787878787879, 26.83712121212121, 26.59090909090909, 26.65, 
           20842400}}, {{2012, 12, 26}, {
          26.617405063291137`, 26.784810126582276`, 26.292442293373043`, 
           26.45, 31631100}}, {{2012, 12, 27}, {
          26.481064540059347`, 26.678022997032638`, 26.165931008902074`, 
           26.55, 39394000}}, {{2012, 12, 28}, {
          26.307589453860636`, 26.494726930320144`, 26.149999999999995`, 
           26.15, 28239900}}, {{2012, 12, 31}, {
          26.191797079745413`, 26.369101460127293`, 25.97509172594534, 26.31, 
           42749500}}, {{2013, 1, 2}, {
          26.8356263577118, 27.30832729905865, 26.737146994931205`, 27.2, 
           52899300}}, {{2013, 1, 3}, {
          27.214282568807338`, 27.233981651376148`, 26.75135412844037, 26.84, 
           48294400}}, {{2013, 1, 4}, {
          26.862071802543007`, 26.93102468212416, 26.330149588631265`, 26.34, 
           52521100}}, {{2013, 1, 7}, {
          26.36880104908205, 26.477152491569875`, 26.240749344323717`, 26.29, 
           37110400}}, {{2013, 1, 8}, {
          26.346986817325796`, 26.386384180790955`, 26.061355932203387`, 
           26.15, 44703100}}, {{2013, 1, 9}, {
          26.319700374531838`, 26.34925093632959, 26.162097378277153`, 26.3, 
           49047900}}, {{2013, 1, 10}, {
          26.247127739984883`, 26.572139077853365`, 25.89256991685563, 26.06, 
           71431300}}, {{2013, 1, 11}, {
          26.08519567648155, 26.51847185985837, 25.87840477077898, 26.42, 
           55512100}}, {{2013, 1, 14}, {
          26.489847526961693`, 26.667103012272218`, 26.351982149497953`, 
           26.48, 48324400}}, {{2013, 1, 15}, {
          26.42572583608967, 26.878794560823223`, 26.42572583608967, 26.8, 
           48244500}}, {{2013, 1, 16}, {
          26.738332100591716`, 26.817119082840236`, 26.600454881656805`, 
           26.63, 41077400}}, {{2013, 1, 17}, {
          26.78090275229358, 27.05668990825688, 26.65285871559633, 26.84, 
           51685900}}, {{2013, 1, 18}, {
          26.692256880733947`, 26.879398165137616`, 26.633159633027525`, 
           26.84, 52167700}}, {{2013, 1, 22}, {
          26.887734806629833`, 27.035469613259668`, 26.592265193370167`, 
           26.74, 58650600}}, {{2013, 1, 23}, {
          26.786236870699025`, 27.21954364360739, 26.786236870699025`, 27.19, 
           50387700}}, {{2013, 1, 24}, {
          27.27893593919653, 27.643311617806734`, 27.052432138979373`, 27.21, 
           101739300}}, {{2013, 1, 25}, {
          27.164519368723095`, 27.804727403156384`, 26.97738163558106, 27.46, 
           81847700}}, {{2013, 1, 28}, {
          27.58849516302401, 27.80518452167682, 27.342257255463995`, 27.49, 
           56056500}}, {{2013, 1, 29}, {
          27.402848982506246`, 27.708200642627627`, 27.186147804355585`, 
           27.59, 49242600}}, {{2013, 1, 30}, {
          27.58758707360862, 27.764872531418312`, 27.341357271095156`, 27.43, 
           43580500}}, {{2013, 1, 31}, {
          27.374921675774136`, 27.55223315118397, 26.990746812386156`, 27.04, 
           50530000}}, {{2013, 2, 1}, {
          27.253909774436092`, 27.628195488721804`, 27.135714285714286`, 
           27.51, 55565900}}, {{2013, 2, 4}, {
          27.453575072886295`, 27.60133381924198, 27.010298833819242`, 27.03, 
           50540000}}, {{2013, 2, 5}, {
          27.198167272727268`, 27.237556363636358`, 26.942138181818176`, 
           27.08, 35410400}}, {{2013, 2, 6}, {
          26.969400146305773`, 27.12700073152889, 26.841349670811994`, 26.93, 
           41889600}}, {{2013, 2, 7}, {
          26.938947947214075`, 26.978346774193547`, 26.692705278592374`, 
           26.87, 38028300}}, {{2013, 2, 8}, {
          26.933049001814883`, 27.287560798548096`, 26.893658802177857`, 
           27.13, 33318500}}, {{2013, 2, 11}, {
          27.23316582914573, 27.499095477386938`, 27.085427135678394`, 27.44, 
           32247700}}, {{2013, 2, 12}, {
          27.459999999999997`, 27.57819225251076, 27.33195839311334, 27.46, 
           35990900}}, {{2013, 2, 13}, {
          27.511498394577234`, 27.688801284338204`, 27.462247591865854`, 
           27.61, 41715600}}, {{2013, 2, 14}, {
          27.501797432239663`, 27.639700427960058`, 27.45254636233952, 27.62, 
           32663200}}, {{2013, 2, 15}, {
          27.619550160656903`, 27.737750803284538`, 27.46194930382006, 27.59, 
           49650900}}, {{2013, 2, 19}, {
          27.68121212121212, 27.889714795008913`, 27.6017825311943, 27.85, 
           38781400}}, {{2013, 2, 20}, {
          27.938227484750627`, 28.007750269106566`, 27.64027269465375, 27.68, 
           44110200}}, {{2013, 2, 21}, {
          27.548272098945073`, 27.548272098945073`, 27.041797017097128`, 27.3,
            49078500}}, {{2013, 2, 22}, {
          27.49054755043228, 27.570000000000004`, 27.29191642651297, 27.57, 
           31425900}}, {{2013, 2, 25}, {
          27.7758348556814, 27.85527950310559, 27.18, 27.18, 48011800}}, {{
          2013, 2, 26}, {
          27.18993058092802, 27.408403361344536`, 27.150208257215926`, 27.18, 
           49923300}}, {{2013, 2, 27}, {
          27.232664509169368`, 27.808701905789285`, 27.143279395900755`, 
           27.62, 36394700}}, {{2013, 2, 28}, {
          27.689453237410067`, 27.7788381294964, 27.55041007194244, 27.61, 
           35840200}}, {{2013, 3, 1}, {
          27.53156350626118, 27.789796064400715`, 27.332923076923077`, 27.76, 
           34849700}}, {{2013, 3, 4}, {
          27.652131438721142`, 27.950000000000003`, 27.503197158081708`, 
           27.95, 38157500}}, {{2013, 3, 5}, {
          28.090423280423277`, 28.33865961199294, 27.961340388007052`, 28.15, 
           41432200}}, {{2013, 3, 6}, {
          28.009145603417586`, 28.029003203987184`, 27.582207191171236`, 
           27.89, 51448500}}, {{2013, 3, 7}, {
          27.910213219616203`, 28.079004975124377`, 27.810923951670222`, 
           27.94, 29196700}}, {{2013, 3, 8}, {
          28.058303571428567`, 28.137760714285708`, 27.770271428571426`, 
           27.81, 37667800}}, {{2013, 3, 11}, {
          27.74952278435594, 27.779318263365624`, 27.48136347326875, 27.68, 
           36627500}}, {{2013, 3, 12}, {
          27.650476531709067`, 27.759727696166248`, 27.451838050877825`, 
           27.72, 39255200}}, {{2013, 3, 13}, {
          27.680340257879656`, 27.829319484240685`, 27.56115687679083, 27.73, 
           29093400}}, {{2013, 3, 14}, {
          27.800995024875622`, 27.959857853589195`, 27.731492537313432`, 
           27.94, 55914800}}, {{2013, 3, 15}, {
          27.83007132667618, 27.95914407988588, 27.780427960057064`, 27.84, 
           92710300}}, {{2013, 3, 18}, {
          27.681565836298926`, 28.07871886120996, 27.612064056939495`, 27.9, 
           44809400}}, {{2013, 3, 19}, {
          27.92042583392477, 28.01971611071682, 27.831064584811926`, 27.98, 
           51901600}}, {{2013, 3, 20}, {
          28.13985875706215, 28.28879943502825, 27.980988700564975`, 28.12, 
           35447800}}, {{2013, 3, 21}, {
          27.909999999999997`, 28.158221273568124`, 27.85042689434365, 27.91, 
           34233200}}, {{2013, 3, 22}, {
          27.990424778761064`, 28.13936283185841, 27.901061946902658`, 28.05, 
           28720900}}, {{2013, 3, 25}, {
          28.099005681818188`, 28.14865056818182, 27.76142045454546, 27.96, 
           44154000}}, {{2013, 3, 26}, {
          28.03943181818182, 28.138721590909096`, 27.910355113636367`, 27.96, 
           27824300}}, {{2013, 3, 27}, {
          27.941621431089178`, 28.24943602396898, 27.88204441311244, 28.17, 
           36047400}}, {{2013, 3, 28}, {
          28.12202726319469, 28.459650471862986`, 28.06244669695911, 28.41, 
           55453800}}, {{2013, 4, 1}, {
          28.439790283117794`, 28.459650471862986`, 28.16174764068508, 28.41, 
           29201100}}, {{2013, 4, 2}, {
          28.391458333333336`, 28.64965277777778, 28.321944444444448`, 28.6, 
           28456500}}, {{2013, 4, 3}, {
          28.548669467787114`, 28.747268907563026`, 28.34014005602241, 28.36, 
           35062800}}, {{2013, 4, 4}, {
          28.191468531468526`, 28.409930069930063`, 28.072307692307685`, 28.4,
            45263200}}, {{2013, 4, 5}, {
          28.02334494773519, 28.5794425087108, 27.91411149825784, 28.5, 
           50927300}}, {{2013, 4, 8}, {
          28.529020636586218`, 28.529020636586218`, 28.270839454354668`, 
           28.39, 34759500}}, {{2013, 4, 9}, {
          28.526241134751775`, 29.608510638297872`, 28.47659574468085, 29.4, 
           77733800}}, {{2013, 4, 10}, {
          29.364924042272122`, 30.109722589167763`, 29.315270805812414`, 
           30.07, 71116700}}, {{2013, 4, 11}, {
          28.89889426399447, 28.998203178991016`, 28.531451278507255`, 28.74, 
           130923200}}, {{2013, 4, 12}, {
          28.649583188607156`, 28.818402222994095`, 28.460903091351163`, 
           28.59, 62886300}}, {{2013, 4, 15}, {
          28.450278842802366`, 28.77797838968281, 28.311254792610665`, 28.49, 
           56332900}}, {{2013, 4, 16}, {
          28.700483258543322`, 28.93882637210908, 28.501863997238523`, 28.77, 
           52797300}}, {{2013, 4, 17}, {
          28.64986125563649, 28.83854318418314, 28.40159556018037, 28.63, 
           52840700}}, {{2013, 4, 18}, {
          28.74888850295241, 28.77868009725599, 28.302014588398748`, 28.59, 
           56906600}}, {{2013, 4, 19}, {
          29.411058112193484`, 30.02668458179375, 29.40112865300638, 29.56, 
           99790700}}, {{2013, 4, 22}, {
          30.093610120012976`, 30.967615958482, 30.063814466428806`, 30.62, 
           137904000}}, {{2013, 4, 23}, {
          30.489313725490195`, 30.687941176470588`, 30.17150980392157, 30.39, 
           59126900}}, {{2013, 4, 24}, {
          30.407896725440807`, 31.69889168765743, 30.388035264483626`, 31.54, 
           90946600}}, {{2013, 4, 25}, {
          31.491584220413277`, 32.61380087664371, 31.32275516593613, 31.72, 
           110700200}}, {{2013, 4, 26}, {
          31.679238754325258`, 31.758685121107266`, 31.23235294117647, 31.57, 
           47799300}}, {{2013, 4, 29}, {
          31.575712971481146`, 32.449506286415215`, 31.545924563017483`, 
           32.38, 59116400}}, {{2013, 4, 30}, {
          32.33375226586102, 32.87993051359516, 32.05569788519637, 32.87, 
           75165200}}, {{2013, 5, 1}, {
          32.69852383863081, 32.84746943765282, 32.3708435207824, 32.49, 
           54330900}}, {{2013, 5, 2}, {
          32.40367611580218, 32.939930639324494`, 32.16534077201448, 32.93, 
           46059500}}, {{2013, 5, 3}, {
          33.00178560764407, 33.28979396834876, 32.85281576590026, 33.26, 
           46784600}}, {{2013, 5, 6}, {
          33.18234666666667, 33.66886222222222, 33.013555555555556`, 33.51, 
           40978300}}, {{2013, 5, 7}, {
          33.41765235664965, 33.55668567997598, 33.01048333833683, 33.08, 
           43078300}}, {{2013, 5, 8}, {
          32.83944225522885, 33.00825704759018, 32.422370415277356`, 32.76, 
           51595700}}, {{2013, 5, 9}, {
          32.61866197183099, 32.76760563380282, 32.36049295774649, 32.43, 
           46417800}}, {{2013, 5, 10}, {
          32.44014071581524, 32.48978892627715, 32.09260324258183, 32.46, 
           36394900}}, {{2013, 5, 13}, {
          32.382924613987285`, 32.83972146533454, 32.323342415985465`, 32.8, 
           36027600}}, {{2013, 5, 14}, {
          32.86, 33.53, 32.8, 33.53, 56870100}}, {{2013, 5, 15}, {
          33.45, 33.9, 33.43, 33.85, 46303900}}, {{2013, 5, 16}, {
          33.64, 34.15, 33.55, 34.08, 59382900}}, {{2013, 5, 17}, {
          34.13, 34.87, 34.1, 34.87, 60666700}}, {{2013, 5, 20}, {
          34.73, 35.1, 34.68, 35.08, 54020800}}, {{2013, 5, 21}, {
          35.1, 35.27, 34.72, 34.85, 48702400}}, {{2013, 5, 22}, {
          34.79, 34.84, 34.36, 34.61, 66047500}}, {{2013, 5, 23}, {
          34.23, 34.55, 33.9, 34.15, 51102700}}, {{2013, 5, 24}, {
          33.92, 34.28, 33.9, 34.27, 33174400}}, {{2013, 5, 28}, {
          34.42, 35.18, 34.41, 35.02, 48212100}}, {{2013, 5, 29}, {
          34.74, 35.02, 34.57, 34.88, 38412200}}, {{2013, 5, 30}, {
          34.849999999999994`, 35.24999999999999, 34.809999999999995`, 35.03, 
           51131000}}, {{2013, 5, 31}, {
          34.82, 35.28, 34.79, 34.9, 56165700}}, {{2013, 6, 3}, {
          34.919999999999995`, 35.629999999999995`, 34.82999999999999, 35.59, 
           51252600}}, {{2013, 6, 4}, {
          35.62, 35.74, 34.77, 34.99, 65529500}}, {{2013, 6, 5}, {
          34.6, 34.89, 34.43, 34.78, 46025100}}, {{2013, 6, 6}, {
          34.84, 35.11, 34.49, 34.96, 37618500}}, {{2013, 6, 7}, {
          35.25, 35.78, 35.06, 35.67, 40757300}}, {{2013, 6, 10}, {
          35.51, 35.65, 35.14, 35.47, 35994500}}, {{2013, 6, 11}, {
          35.05, 35.18, 34.68, 34.84, 39435900}}, {{2013, 6, 12}, {
          35.14, 35.27, 34.85, 35., 37372700}}, {{2013, 6, 13}, {
          34.99, 35.02, 34.59, 34.72, 45654900}}, {{2013, 6, 14}, {
          34.55, 34.69, 34.25, 34.4, 53192600}}, {{2013, 6, 17}, {
          34.69, 35.16, 34.63, 35., 49670100}}, {{2013, 6, 18}, {
          34.97, 35.17, 34.9, 34.98, 28616500}}, {{2013, 6, 19}, {
          34.96, 35.09, 34.59, 34.59, 30816200}}, {{2013, 6, 20}, {
          34.26, 34.33, 33.37, 33.49, 54493700}}, {{2013, 6, 21}, {
          33.66, 33.73, 33.05, 33.27, 85338500}}, {{2013, 6, 24}, {
          32.94, 34.2, 32.57, 33.72, 56109000}}, {{2013, 6, 25}, {
          34.08, 34.38, 33.46, 33.67, 44073400}}, {{2013, 6, 26}, {
          34.12, 34.48, 33.89, 34.35, 48665900}}, {{2013, 6, 27}, {
          34.52, 34.78, 34.5, 34.62, 28993100}}, {{2013, 6, 28}, {
          34.38, 34.79, 34.34, 34.54, 65545500}}, {{2013, 7, 1}, {
          34.75, 34.99, 34.33, 34.36, 31055400}}, {{2013, 7, 2}, {
          34.41, 34.44, 33.63, 33.94, 37630000}}, {{2013, 7, 3}, {
          33.66, 34.37, 33.6, 34.01, 15994400}}, {{2013, 7, 5}, {
          34.09, 34.24, 33.58, 34.21, 26085900}}, {{2013, 7, 8}, {
          34.35, 34.59, 33.98, 34.33, 32396900}}, {{2013, 7, 9}, {
          34.58, 34.6, 34.14, 34.35, 25318500}}, {{2013, 7, 10}, {
          34.34, 34.81, 34.32, 34.7, 29658800}}, {{2013, 7, 11}, {
          35., 35.77, 34.9, 35.69, 53638300}}, {{2013, 7, 12}, {
          35.58, 35.73, 35.28, 35.67, 35501200}}, {{2013, 7, 15}, {
          35.66, 36.22, 35.58, 36.17, 34142600}}, {{2013, 7, 16}, {
          36.01, 36.43, 35.96, 36.27, 36378500}}, {{2013, 7, 17}, {
          36.34, 36.39, 35.49, 35.74, 37285100}}, {{2013, 7, 18}, {
          35.72, 35.89, 35.22, 35.44, 49547100}}, {{2013, 7, 19}, {
          32.4, 32.67, 31.02, 31.4, 248428500}}, {{2013, 7, 22}, {
          31.7, 32.01, 31.6, 32.01, 79040700}}, {{2013, 7, 23}, {
          31.91, 32.04, 31.71, 31.82, 65810400}}, {{2013, 7, 24}, {
          32.04, 32.19, 31.89, 31.96, 52803100}}, {{2013, 7, 25}, {
          31.62, 31.65, 31.25, 31.39, 63213000}}}, 
        System`TradingChartDump`$markerstyle$545673 = 1, 
        System`TradingChartDump`$controlmin$545673 = 0.5, 
        System`TradingChartDump`$controlmax$545673 = 250.5, 
        System`TradingChartDump`$datescope$545673 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$545673 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$545673, 
        System`TradingChartDump`$max$545673, 
        System`TradingChartDump`$ohlclabel$545673 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545673, 
              System`TradingChartDump`$opens$545673]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545673, 
              System`TradingChartDump`$highs$545673]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545673, 
              System`TradingChartDump`$lows$545673]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545673, 
              System`TradingChartDump`$closes$545673]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545673, 
              System`TradingChartDump`$visdates$545673]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$545673 = {}, 
        System`TradingChartDump`$subpricegridlines$545673 = Automatic, 
        System`TradingChartDump`$overlaypoint$545673, 
        System`TradingChartDump`$overlayvalue$545673, 
        System`TradingChartDump`$subplotvalue$545673, 
        System`TradingChartDump`$opts$545673 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "MSFT", " with ", 
            "PolarizedFractalEfficiency", "(", 10, ",", 5, ",", Null, ",", 
            Null, ")"}], ImageSize -> {450, 310}, AlignmentPoint -> Center, 
         AspectRatio -> GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> 
         None, AxesOrigin -> Automatic, AxesStyle -> {}, Background -> None, 
         BaselinePosition -> Automatic, BaseStyle -> {}, ColorOutput -> 
         Automatic, ContentSelectable -> Automatic, CoordinatesToolOptions -> 
         Automatic, DisplayFunction :> $DisplayFunction, Epilog -> {}, 
         FormatType :> TraditionalForm, Frame -> True, FrameLabel -> None, 
         FrameStyle -> {}, FrameTicks -> Automatic, FrameTicksStyle -> {}, 
         GridLines -> Automatic, GridLinesStyle -> {}, ImageMargins -> 0., 
         ImagePadding -> All, ImageSize -> Automatic, ImageSizeRaw -> 
         Automatic, LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, 
         PlotRange -> All, PlotRangeClipping -> False, PlotRangePadding -> 
         Automatic, PlotRegion -> Automatic, PreserveImageOptions -> 
         Automatic, Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$545673 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmgtcj+f7xyNbDokp/ORUIcmhckrnO2EhOipppcO3vt/6VsKIsIVpDtGo
/f3ntCxiTCvWlmM1szY2lnIYk+SnSYWkEeFXz3Vf9zV339drr73ePs99Pdd9
Xdd93c9zP5mGL/CJ1NXR0dF00NHpqAP/7fii7dfsErT25ISCnY5MB34MeZzy
02V3koxy3r9DuswJ+oYl1t7Ewyclrcl65siilJ8x63/O+k7Pg6gPEAz3H8gG
r6v1LqggXWabNUUd9u8k3v691dXa7k7cP1PmOaAmf42VE9fNBP/+W9vPDOyF
kC7z7hjbTqWvHAUb9W79LUH7Q9iUG7+um+qF1w8VDPaHstZgJBnFky5zjN9E
Vbwt8Te7Vrrd/AztD2M+cZ2Dp36EurlgsG/O40S6zMGhSSNr1MQbOtnU3TqD
9kewTbM/upK8GHVLwWDfkjl1vZaVsIp0mVsuzy2eNYU43+eJR/kWtD+ajQmM
WP5RNOpjBIP9MfDvyaTLHHT05yctPsSZNROCOmSgfSv2VFPtfecg6taCob6s
mU/BoHW17zkLXeYe/mP+W5FG47dcrVA/snPmcRzLrnkfs+/SHa8fJxjst3JW
glPXvv/SJQ4IiUtY97cT6bWR7gYuaH8C83asX9g7FfWJgsH+RLjuT9JlTjI4
szojiXhhyS8bjGuduH175rc1yWrIPdQdBIN9B/ZB2o9NFgOchS7zzPSx0QNz
aPzyjiu/GiX8d2SBX1UHDE5B3Ukw2HdiC9sKJpd0mROvWBl9uZa4YmGXTQfK
nKiOXQfcsDqPurNgsO8M63WPs9BlNkz5z4dWRTT+z8Wx2kl7naH+PBjLffIq
atlLricTK+V1jDEjZcE6C13m0WfTtEv/pvFzm2JvrBqL9l3ZyD0F80tH4vXE
YN+VtZWj9yTSZe7kkfeOR56T4CEPN2/0+5Db/82VPZtnVqqdifOdLBjWx2S+
XkmXOe9w3OuofsR9X5TsWPgp+j+ZeW4LsUhYhv4Qg/+SveT2fNMgYGOdD7HB
xE+uN2xA/yczu0dTCovC8P5ugsF/N/aPRWtFLiFd5mO7rEe4eBHvqVA5ua1C
+27MdaHL2hkOqE8RDPanQLwLSJe55NdNtdNtiH3/mhl8uRDj484udvI707En
5ocY4uPO6rxbLY4kXea/U/7S7dDiKHjdRyfq9TywP7qzaqum0KSpWL/TBYP/
06Ee/UiX+XT18i6JYj+ezgy5Dvansz576n/Re4r6DMFgfwbvZ05Cl9l4fdX4
lFs0fsfXjXn69mh/Jut2zHLprpmoewgG+x6sLdqD1pEuc4XB1fPGpsQDjZ7d
G5zlyOPvwaYk/Dg5MQ/jRwzx94B4lJMu8835X1h8mE58YWMPT50u6L8H6253
wjLoHN5/lmDwfxZra5cfXCJdZvMTyx5f20f86lZNcFV3bt9jFhs7wd4oLhPv
Twz+z2Ij2hryfdJlvv1D4/lqLbFNSoFrYhPGx5OZrFmwKczEgevEYN9T7AOo
yzzIrdv8OwOJU/tO06nZ5MCv82K2NqsMy2xRJ4b+7QXxSCNd5p9u79hyeSzx
87Lv1t/+ltuv9mKBN4Z6PR+F8fMWrNjv5w31eI10mV2GW/76bDhx965RM7vd
wedPb7ZgetnpIQ8xfsTgvzfsV49Jl9l4/xdVmfuJtx6Pqhuqz/enbG/WvG2l
6yemfL0UEcM+7v12Pyhqz8vvdyx4U+co+J0R4xNTk7n9ah+W4NlLFb/Lns/P
VzDExxeeN3NIlzkg7tLyoLnEcdazC9+9a8/j48f+vFvR+9QsricTQ3z8WFu7
d9pIuswHep5JyXYj/ir0uu53xdx+th9rsfe3sSrlehExxMePuSsvFA5Cl7nq
l5C6Pb/S+JvsVFe/QKzPOWzBSTO/hh14f2Lwfw6sg0bSZc6+p46IDSGu2zyj
9OwL9N+fpRcs8n390o7fnxj894d+NtVe6DJP7nPm6clbNL6yae26nBSMfwA7
uP+s5s5wvD8x+B8A8fiUdJmPvoq9dWEgMbv90tE5Df0PYJaeJtsr96E/xOB/
AO83pMssj9/65OOcMkMe/+y5bMPn17qtCEedGOzP5c+DpMs83OSqeeE04qdb
no6+d5H7Xz2XWSdfW5l7Bes3UDDUfyDb19YOhjgIvR27LYxoOk7jL5l1zV45
AesnkJ377pB+VQPGjxjiH8jOtrWzyQ5Cl3nwjY+9Hp+yb6eD/XnsWenRbsNX
oE4M9udBH08lXeYFmaEfJlkS11pPe7DtCMZnHvusufPufjY4vyDBEJ8g6Mee
pMvca8PqXV822wnuMbwuflUIt28exBz0q3fWYvwZsWI/MIjvkw5Cl/nNtqBD
+adofHFt3oaHs7H/f8DyXaaEX+qN/gQLBv+DoV9qSZdZPSzd7HalneD6lrBt
Jz7B9RXM2HueIS2xGD9iiH8wfw4gXWZ5fEKWZc7zSox/MDNcYu5cU4L+hAgG
/0P4fkW6zL0icwtNDxC/ab5iv9aAx8c8hNWOsS20zcP4EUP8JXusPZvr1Bf2
+Yo4N+6Zo8kd7A8h7ELaxdJpor8Sw/oNgfVq7SB0meXxWf6muuMnof/zWbRd
y+OBllgPxOD/fP68T7rMxuv/yJnwwl5wfNHS3R0vYv+ZzwL7Rg4wVaM/xOD/
fIjHdtJlflxfG3bAinht3+FZHvn8+WlcKEv0N3XQcUV/iOH5KxTW+xrSZR51
pmrkGTPi7lvU2tJMbr8slLl+sM/jr4d8fpXEiv26UDhvM3UQusz1ZsWXf/4v
jbcK3fv57uncfmOrP8eTinMdsB+GCVbs64dBPhNIl/l1/erNFb2J5zVlFvz0
MbdvGMaa/p0vE2LF/qiwt/Np0p6fdj9k99KPOGOOp6ZTBsY/jMUd0k9rEPEk
hviHwXnGLtJl/ueHvJtzlhJXf1P//pxcbt83jGV/e//CkmSuhxIr9mPD+HkD
6TJ3HtXL6MZi4hBfV83ZLG4/PYzlOFc/iMjheiaxYv+bMF6npMu885c1WoMd
xPv8Zgb+dBfzG8Z8nSamZKzC/IQLhvyGw3nYVtJlLu/S0PnkjH+N5zrEJ5x9
cvl4dRrWTygxxCdcikd73vH5/KYjQ4kfpm/uo3cJ4xPOUoec3WS0HudHDPEJ
h/X0I+ky302cv8h+DrHngJGG1ufx/SecWet07PMkG9c3MfT5cB5H0mU+EhX9
aWky8Xiuw/oNZ91s778Y1pc/v1cSw/oN532QdJkX/eGvNv7HQXBgy5LIo/78
/dAwgi3KOn9StwbXBzGsrwj+vkK6zMufzfz+/y8Ra8LWH7Yz4vYXR7CU1dP2
rsP4JBPDc0gEPy8hXeY/dqYfPLyY2K364NpVP2J+I9jFM0tKLEX9E0N+I9iK
thf2E6TL/PK06YsDacTlhYPcZ5djflvn1y+1o8HvmB9iyK8Uj6L2vEpv1n/c
ThIvaN7gfLwJ8xvBarQNmz8ux/wQQ34j+H5LuswufktMzpcQd3VTJ25E+40R
bFMz67cC46OjEgzrV8WfM0iX+cSuu/a5u4izlvvXmmN+DVUsv5+e3t5azD8x
1I8K4v2CdJlT9+pnF5UTHzq5aKD+O9y+r4pZKO8LuL6JoT+o+PsE6TJPu340
Pf9P4pzVK6xXW2B9qphb/cKk1FdYX8RQnyoeJ0ehy/x0d83rw9U0fuCAOe5H
hnD7ZSq29/QQY4MGzA8x5FfF39cdhS5zy6Osr3+/Q+P7q7p3venC7TeqmPO+
otFOg/F8IlIw+BkJ8dCQLnPhmOOrW3oQGzmzA4eX4PlUJCuN1t09UcV1Rgz7
Y6Q4x0dd5i2dVjbG+BBne77Y55mN8Y9k1yruG3WywXgSQ/wj+XM26TI35p8r
XtOL2OyN7+gGDbefHskO6Ts8an6H65nE0B8i+TjSZXZ80H2i7gMHwXZlJnP9
MzC/kWz3VqvTP6Rgvoghv+ivk9BltigtGt0xicbfL46ZV7KTn882RrJJvVd8
rQ3G89IowZDfKOl7VHvuEaj5v3wvGr+/f0ZJnwH8/No3ih1/oF4+dTG/fygx
rK8ofh5PuswLWqpUOZ7Ex3JWbh9RgvmNYhevPqzwOYb5IYb8RsF5xjnSZa4e
/a1FUjJxXnl5nf9jjH8Ui8g8ZeyA3wcriSH+Ufy8kHSZ95kbhORGEW8d8Pq3
8nd5fBqj2M9646/8I77HqQVD/NXS96L2fMGnzzD/nsQZPz0+kv8Mvx+oWV1N
Yq1Ww3VGDOtLzc/DXIQuc1X2ovf9I2i8/6PfP3tw1IXnV82++Hv/0uur+PWh
xJBfNd9vSZc51dOsd6YPcXxBw7tbZzO+vtTstaqyLiyd65nEsL7U/H2OCV1m
V2ev74s30fjnhXqxG+y4/WNqptLWqwos+fVFxLD/qiGfC0iXufnb4/1N9Ygj
fYZ9tjeB229s1c/lHTw8jus6GsGQXw3st4mky5znUlc1ojdx//E5+z2XcfuG
GpZte3aNfTLXTYhhf9TA+9Ze0mXupGfx3og4Yo23zvO++7n9cRrW79F3ZgHb
uc6IoX64vWLSZTa/52R9ajXx9y0t03ZfwfhrmGvnh5/6T8L4EUP8NbCf25Mu
s/PYWbE3uhGXmc9W5zlz+2Ua5vc06RtdG65XEsP61fB+SbrMOzqXuEeMILbN
Gfd6hRbzq+F/L4H5iRYM+Y2G87yzpMv81v3+pUN+o2G/O475IYb8RvN5kC6z
Uk8/EIPfmN9o6OelmB9iyG809IOurkKXWXH/ZxoPfrvy/hAN67Envz6UGPpD
NF9PpMsMcWyvQ/+Phv0imOvJxND/ub8bSZdZmU4AMYzj9huj4X2/CfMTIxj8
ioH3OTNXocuM8UaG811u35Dbm8CvNyGG/HJ7a0iXWfleOJ4Yzoe4/XEx/O+F
MF/EkN8Yfl5CuszK85w7Md4f8hvDlGUai/khhvzy+a4lXWblc4+a+E3b70vM
L7+/BvNDDHni8V1MuszKfh9JrNw/i9tPj+HnPVzPJIb9JQaely+QLnOXtoDH
ECvm/+D2y2LE31koeiUxrFPuTwTpMiv5tCVW1udCrE/ujxbrTSsY6lML/TKJ
dJmVenAmVvrXFqxPLZ8X1hcx1KcW6vUK6TLD9x5iZX53MT5aeB6Yi/Mjhvjw
+yWTLrNSr17EyvQyMD5aOE9bifOLFQzxieXPm6TL/FY9tbIyv8+xPmPB32V8
fScTQ33y+/1Fusywvojh3J3bPxYL/a4Hv38RMeyPsTwPpMus1EsDE6zMzwnj
H8u/92D8iCH+/H6epMus/J8RY/1C/GP58xjGL04wxD+Of28kXWZ4X5X0SOw/
cfzvJfj8Qomh/8TB80gHV6HLDHGk8cr8rDC//P7dsH8QQ37jYD0Zky6zEu7z
TLCy3gZh/KX5VRJD/OP4dwbSZVbqx4LYnfdTiH8cvy/GL14wxD8e6vU66TK/
Xf/xUB9V2B/i+fxwfRNDHcZL/aA9Yz9GVurzFu5f8TyfuP8QQx/l9npPFrrM
b/nXyvD3g5N5/cTzeuDXhxJD/fD5mpEuM5w3uQqGfs3tl/H4HePvH5XEkF+8
HxO6zHDe4dJO/x/FX9dz
             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyNmglYjmnUx5ssY5K1sku2bElp0d4tkvZdi9KmRW8LsnwYvJiECUOILGPN
THaFYURlaRZjsmUZlSzZkpIsJfPVe+7zHN3vXNf3vRdX16//85z7PP/7POe5
n7u3f3iiV2QrFRWVZV+pqKiqwH8jxeeR7S6Pm20Mp1gxFcWnWuIoxeed7V9X
mj4upIv8ceKltBhL4utnrpTb77JiiuOutGZlp6scH5ag3k5iGL89u1A3NGht
AekiX/J70ufuRuKCtLit9q8xvjrLzi/ZprUN9c4SZ2xp/nThP0kX2TymTHZt
DnHd5Man5rfw+rsyX83VdW9Poq4pMcTRYmq390y3XkW6yDf/jP642p+4x6Lk
K/cvYfxu7GXmuYaZAaj3kBji92Sahx3K5/uQLnLxp+HnrvUlDjLW3/P2J4yv
zWb9oLqpsLc113UkBv902NqCJsM7kS5yh6WyixsrrSSW+f7i1WuMNZ+/Icxn
hem3nzfj8UMlhvhDWfJLz1+0k0kX2Vlb3exRIHFqUocBV09i/BHMa2TfC5uk
+HoSQ3w91myHZgLpImdfmF/a1YPYrXPsh+5HrLm/BqxS7dhPmkY2XDeUGPwz
hHj6pIucUnclZ90Da6XzIb4hizmyruRIbzx+tMQQfzSb2BTu8Neki6xu77o0
q8xa4hyr+hUGAzG+EWt/TkPeII1vLDHEN4Z6uUm6yNV/vFOtLyDuk/9p68L2
GN+YLUyNzS89grqJxBDfBOplLekij0+v+cE/nHiNecrbKcfRf1N2MjShfYUp
Xu8YiSH+GLagOeF6a0kXub1TknNZObFNbMWeKBvMfwyLnG/n2rYRdTOJIb4Z
q2wux5eki5z3ymVcqyLivWtnN37dDeObsZnWTXd8NermEkN8czZD0EXOjujf
Tecssc+x7Tv3fYPxm9h3zSDrG6hbSAzxLVi/5htqB+kiy5f92+ZkMnHb3Mf1
Nk/Rf0t2Uc07ft951K0khvhWkO9R0kUe2O7pwu2ziGPuejYMf4vxbVj/ywfc
wj1xfm0lhvi2MJ8WpIscMKzoYmkr4lYHfTMf+qM/tsy997OcLtqoM4mhfzB4
nqiSLnK3puHUrlpLbNx0VtooG95fGFtTXBr92hyPHysxxB/LvJrLpQvpIpcd
tnOLbUP8rNW/lnWzeXyXcaz+7IwVC6ZwXU6sCJ89jvd70kUOHL7wVL0nscXD
pt/MxfjjWYlvxjy/HNSJIf541pyu5/+QLnKuw6cM9xBic9vheyeXoz/j2ePy
ivvVE/H67CUGf+wFP5S5ZPtJ7WdV1hJrv+71w8xAzN+eDe709f7jVjg+MeRv
37Ie5cpcWPyk/cCfiTd22vLRyBHzt2e5JlE7bqTh+BMkhvwncD9IF3lL6Prn
f/sR2+2Xr73ziD+fXCawqrSME3Z4vJwY8p/A3jUvd2aTrsQPLi+3GU2sZWA6
+PIxfP5NYO5DXs96Mx/Hd5AY8nfgfpMucrvsNQYv1YmTrEYV1q7B/B3Y7o7X
e03th+MTQ/4O0O//tpJ0kSvXdYi7l0us3t3d+5kj5u/A+njcG+zViOuLiRJD
/hPB7w+ki5ye9k8PjyLiU8X+q24aYv6ObEti5eXGFMyfGPJ3ZMOCmjMmXeTc
2FnTkzoQH/KtGf05FeM7sZE5mqN/xPzlxBDfqeV6U67Mb6/PN9osJx72obbd
TnX0x4mZq9vklM3D63OWGPxxBr/dSRf5z5q7K/5xIH5/ZojaI1yfuzizTruq
Jhp9j+MTQ/7OsB5xIF3kmy8OrTxoRLxgYcP97PW4PndldqeHeSW+x/HdJIb8
3aAer5EucpwHm/5kI/Ha5doBM9qj/25M40LWLVkYjk8M+bvx9YKlpIvcq0z9
UMlt4sz0kK2VMZi/G0vWj3AY1BnHd5cY8neH+QywlHSRh1S969N9FHHhpwe5
g4dhfHd2p+hMuOoS1D0kVsTp6QG/Z6SLnNGQcnqxGbG63tE81e8t4fmq68E+
7nv9W8QKrjNiyNODP29JF7lY1V273IT4T/0fSx6t4vEzPVjHGYkPCx9xPY9Y
Ef+uB1OUSznpIuvt/un+hNvEpXrDdruZ8vcXXU82sd+bK/HPuP+MGPL3bFkv
TJk7fTfJNHo/scmrzUEztfj6psKT3fSI/XbJXZxfL4nBfy/oBzGkizz2eGL9
rDDiqtpM15WDeHxdL6b57chfA2fg+MSQvxfbO73pgTWQdJGnaxW8nNSfeNxU
8xMlR/D9zovdOyqPmWOC9U8MfYbnO5R0kR/e0JfXDfxCr/GPr1/K42d6sVtj
09I/23M9jxjm1wv8Xmcp6SJrlruNla0lXjnIbqbcD+fXm9n45Sa+uG7Br48Y
/PHm73Oki1zZdbPWvxHEhnf99ZPLLLg/3uzJxTZ17eZzXU4M/njDetCOdJE/
ZHkUfrYgtt+3JvvMDzx+pjdjftdmrhrP9Txi8Mcb1uPapIsc/Frtom+NucRl
va6U9XLh8Su8Wf7rTnn9o/jxKj4SQ3368PUg6SLLXCyXvOiqfD7478Pcu417
9H4y+kcM/vvw5wnpIl/rl5Ts2fmL8wOedumI8St8WG3nGSk5OtiffCWG/H15
P7aQdJFXvI/Xj75AXP057cwfw7G/+bJUteyQvm9wfGLI3xfe5w6QLvIx+YYp
ibuIh9VetB36HufXl90aOORQ2nGcL2KYX1++30O6yHcatlSlJhHfcM6RZdSg
P76s/Flm7bm9eH2TJAZ/JsF6x4x0kbsNDLZb1Z1Yll6v/vIXnN9JzHlTw4rK
ELw+YvBnEt9vIF3kE08D8vuqEJ9ePcRVNRbvr0nM2/hjcI+eeH8Qw/3F8/1g
Luki/9rz9M/51cRVjvFFpebozyTmYJfhuj8Gr89PYvDHT6h3Zb789582ZqbE
Jrm/ZyenoT9+rN/eQXN0YvH6iMEfP74fRrrIempZWgfwer44H/L3Y5VjPtpl
9MX695cY8vfn+zEWki7yIxOVNwMOEqfI1p12Nsb692eJR9/tGPwM8yGG/P35
Ooh0ke1mZrW5v4p4667y9PW9ePwof9b3qeqKtlj/cmKYX39pHwJ1kc+ejzly
wIn4ndFL4y6n0P8AxvL3GptNwPUFMeQfwH20kHSRPa/dsre/TfxhXqCTmwfP
vyKA/aG7Ne747+hfoMTgfyC/z0kXuXvwrGv26cSmd6emuRZj/oEs3Ky3Xccd
OD4x5B8IfieRLvKgr5YvLnEiXmfdyvP5b9h/Apnaqxz9c27YP4ih//B8dUkX
OVLgV3rr4zIX4f07mYX1rzH7xxTXv8Qwv5NZcztTQ3/lynw0eMk5/zxit+U5
ZhWWuD6czO6dLj579D6OTwz583h+pIu8qq7u8Hc+xB8WGu72q8L7azLLWXn/
3LQpOD9BEsP8BkE/diJd5NDovPO7rImnLI7N0p2P8xvEstf8pnPTH+eHGOY3
qKXfTJl/tjjT5kQn4iCD+11fhKP/QaznAOuHtz3RP2LwP4i/55Au8tm5Z0wX
DyNW2x25NCYA6yeIhY+Yd2GcLfpHDP4Htexnecp8w9FpzuLH5hIXDXqcM3c9
+hPMsr0v7otaiNdHDP4Ew/N8Pukip5emynsHfnH+JZ9xhVmYfzAr29nft1Uu
5kMM+QfD+8Qu0kVOnm477dQWYvnZgFP619D/Kazh85ZNdo/QP2Lwfwpr3k6a
nku6yHItzWM70olP1wat1PwG+88UZpwi949xwP4fIjHUZwjs95iQLnKjnpdh
XAfiJ9vfdzm6F/tzCLulNnfH/k14/xJD/iGQ70LSRQ7+5umIHX7ElXf2rNe5
ivmHsNXZrHccxlcJlVhRh+qhfD1OusiqWw8YRPgRV6gfPHL1giX0QY1Q9kq1
uqQ+hOs6xIr4eqFwv6qRLvKmIvuNuxotJB7a675uyGoe3zuU3fT+sKjvLH58
KLEiflwoX++QLvIf0wtqdqsSL/0xpFXNFh4/KZQ5yQd2/3U0+kesiJ8aCs9z
TdJFvmFW+H5UjYXEQZfjFhVZ8fhpoeyt9r6twz9wfSexIv5B7ncV6SK77Bl6
LPw2sca3OdrLdHj87KbrrUp+PKUa7w9i2J8IhfeVUtJF7u+lNcD3GPEbtyGv
ZzWt38GfMJbPSoszduD1EoM/YdDv00kXeZQnc7ebQ5yYs8Gq5CzmH8b8TUcc
GlWN75fEkH8Y+HGYdJHtO7k8f7aHuHNA9cuGr/j+zo0wNs4hYe3kVK4/IFbE
rwzj/Zh0kffJN5pkqymfD/Ufzrbbvu2z/TLWMzHUfzj/eyPp/xdrFL7bXHuP
xzcKZ9s2hzn9aIDrK2LIUzifKXO5T6j6LF3ifqtjmv5h/YezkVcefiU/ivND
DPMbzhTbDdtIFzk3LOvg01TijM4pr8MKefzacJa14UKwnyrur0RIDP0nAvZL
cP9JRZk3pP2V0n4j8YGM1vlxX+P+XZO+fFtDZUfcXyEGfyL4fralpIv8In/A
UoNLxCUpdo7jB/L43hEsKjbz9IPz2D+Iof9EtKzHUGXePfL9bosFxDk+xVFL
0B+jqWzA3rTf/pL2i4gh/6l8v4F0kTsd9NIY0GApcXaqvKDKkeefNpU1Lj+R
6N+TH7+TGPrPVHhe1VlKushmhQlJlQXEcWVH33XQxf3ZqWzcsv7GPdRwf4kY
7l8hXp4ypxSFtuvwnHigcQ+7Zei/RiR70S2tx6bpPL4OMdxfkS3383SUecOb
Xs4xw4g1bdj+A7NxfiNZxmy9jNmpXA8lhvmNhHoPIl3kNocMZBp+xK1dy1q5
nkd/Ipmq+sIn8SnoDzH4Ewn1HkG6yHNftj3ra698PvgTxbrKLF73rcDrIwZ/
ovh6h3SRdbc+Nuiwgjg9xd9m1b94f0WxsJ5ztZwzsd6IoT6jeL8nXeSl9afO
Nc4mPvtr6dWl17A+o1jik/1uwRh/JzHUZxRfD5Iu8grD2e+vRhEfCtC5mFWM
/kex6hS9oafOo3/E4L+Qb54yx3T7dMPDlfhEwagNfoXofzQrmdM5a9xC/vdN
HWLwP5rPJ+kiB/zetsuzEcQey04+73OU/300KZqdUHFJf3jIFnQ5MfTnaL5f
S7rIC5o/lsRa2kMMzAts+fMxmu0f/bPFtKbXdoX+gBiej9HQb2xIF/n6ncor
c0cRt1v19MG8OMbvrxg2YlbFrtknuB5KDPdXDN9vI13kXfu3f+e3hLjx+pt5
Ywt5/KQY5vl96zszZVyXE4M/MVAvYaSL3NrkjmVnU2J2eMC6jkt4/LQYJh98
0cPAnes7iaE+Y6BexpAuclF9792D9Ikdcwoqmh7DPP40nudYrhNDfM5xgv4F
Qz8iVux/7x7L638afF8rkut5xFD/0+B55Ub6f7I+sWL/Vcbj35gG/aQv1x8Q
Q/1M4/cJ6f/JtUxixXvLBMw/lj+vcXxiyD8W6nER6SIr/AgX9FIe30gG9ZDP
dUYM/U0G/p4lXWS434jBFx7fWwbXs5zrocQwjzLJT9RFhv0UgdN5/CRhfDkx
1JGM/550kVvUUxO3qJ80WUs/dxJDfcqE+lNmxfU4EyviL8X5lUnzDfNDDPMr
k76ng7rIip86xIr9aX8eXyOO71dwXYcY+nNcy/x0/p/8PdZPHNRLf5x/Yqif
OPDrHJN0kRV2HSFW9L/hWD9xfD8Z+x8xzFscny/SRYZ6I1bcnyXYf/h4ajg/
xDC/cbBeu8UkXWSFn2eIFd/fMUD/4/m46B8x+B/fsr/oKDP6gYz1B/7Hgx/G
6D8x+B/P/17BJF1kRb5Fgm6G9R/P80R/iMEfIb+dyqzwu5FJjPUE9c+Pd8L6
JYb6F8bPU2b4PpCgu2B/SIDxRtiBLieG/pAg9UPU/5PPESvGM7Tj/iTA/X4f
r5cY/EkAP38hXWR4nyRWxK9BfxKk7wHC9RGDPwnS9xBRF1nxvGtDrKhfX17/
tQnwvvCM6yqJEsP7aSL/PgLpIivinSCG8Xh8DWKoX2KYR35+na2kiwzvw8QK
/3rw+EaJ/PuiXGfEUAf8/AjSRYafxLBva8v+F7bn6oQ=
             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$545673 = 
        System`TradingChartDump`$staticindicatorpos$545673, 
        System`TradingChartDump`$length$545673 = 250, 
        System`TradingChartDump`$gridlinesflag$545673 = True, 
        System`TradingChartDump`$opens$545673 = 
        Dispatch[{
         1 -> 28.37`4., 2 -> 28.61`4., 3 -> 28.87`4., 4 -> 28.61`4., 5 -> 
          28.71`4., 6 -> 28.35`4., 7 -> 28.66`4., 8 -> 29.11`4., 9 -> 
          29.19`4., 10 -> 29.31`4., 11 -> 29.49`4., 12 -> 29.6`4., 13 -> 
          29.45`4., 14 -> 29.6`4., 15 -> 29.41`4., 16 -> 29.66`4., 17 -> 
          30.2`4., 18 -> 30.11`4., 19 -> 30.05`4., 20 -> 29.88`4., 21 -> 
          29.69`4., 22 -> 29.55`4., 23 -> 30.21`4., 24 -> 29.99`4., 25 -> 
          29.94`4., 26 -> 29.83`4., 27 -> 29.9`4., 28 -> 29.75`4., 29 -> 
          29.52`4., 30 -> 29.79`4., 31 -> 30.32`4., 32 -> 30.12`4., 33 -> 
          29.98`4., 34 -> 30.23`4., 35 -> 30.17`4., 36 -> 30.29`4., 37 -> 
          30.47`4., 38 -> 30.38`4., 39 -> 30.37`4., 40 -> 30.23`4., 41 -> 
          30.7`4., 42 -> 30.28`4., 43 -> 30.24`4., 44 -> 29.58`4., 45 -> 
          29.47`4., 46 -> 29.48`4., 47 -> 29.12`4., 48 -> 28.99`4., 49 -> 
          29.06`4., 50 -> 29.27`4., 51 -> 29.53`4., 52 -> 28.95`4., 53 -> 
          28.99`4., 54 -> 28.48`4., 55 -> 28.54`4., 56 -> 28.3`4., 57 -> 
          28.69`4., 58 -> 28.77`4., 59 -> 28.63`4., 60 -> 28.97`4., 61 -> 
          28.38`4., 62 -> 28.06`4., 63 -> 27.13`4., 64 -> 27.5`4., 65 -> 
          27.53`4., 66 -> 27.22`4., 67 -> 27.89`4., 68 -> 28.18`4., 69 -> 
          28.91`4., 70 -> 28.93`4., 71 -> 29.13`4., 72 -> 28.85`4., 73 -> 
          28.44`4., 74 -> 28.21`4., 75 -> 28.27`4., 76 -> 26.61`4., 77 -> 
          26.82`4., 78 -> 26.48`4., 79 -> 26.27`4., 80 -> 26.4`4., 81 -> 
          26.36`4., 82 -> 26.3`4., 83 -> 26.82`4., 84 -> 27.13`4., 85 -> 
          26.95`4., 86 -> 26.61`4., 87 -> 26.7`4., 88 -> 26.64`4., 89 -> 
          26.37`4., 90 -> 26.1`4., 91 -> 25.98`4., 92 -> 26.41`4., 93 -> 
          26.41`4., 94 -> 26.16`4., 95 -> 26.64`4., 96 -> 27.12`4., 97 -> 
          26.91`4., 98 -> 26.7`4., 99 -> 26.38`4., 100 -> 26.83`4., 101 -> 
          27.27`4., 102 -> 26.94`4., 103 -> 27.04`4., 104 -> 26.79`4., 105 -> 
          26.62`4., 106 -> 26.48`4., 107 -> 26.31`4., 108 -> 26.19`4., 109 -> 
          26.84`4., 110 -> 27.21`4., 111 -> 26.86`4., 112 -> 26.37`4., 113 -> 
          26.35`4., 114 -> 26.32`4., 115 -> 26.25`4., 116 -> 26.09`4., 117 -> 
          26.49`4., 118 -> 26.43`4., 119 -> 26.74`4., 120 -> 26.78`4., 121 -> 
          26.69`4., 122 -> 26.89`4., 123 -> 26.79`4., 124 -> 27.28`4., 125 -> 
          27.16`4., 126 -> 27.59`4., 127 -> 27.4`4., 128 -> 27.59`4., 129 -> 
          27.37`4., 130 -> 27.25`4., 131 -> 27.45`4., 132 -> 27.2`4., 133 -> 
          26.97`4., 134 -> 26.94`4., 135 -> 26.93`4., 136 -> 27.23`4., 137 -> 
          27.46`4., 138 -> 27.51`4., 139 -> 27.5`4., 140 -> 27.62`4., 141 -> 
          27.68`4., 142 -> 27.94`4., 143 -> 27.55`4., 144 -> 27.49`4., 145 -> 
          27.78`4., 146 -> 27.19`4., 147 -> 27.23`4., 148 -> 27.69`4., 149 -> 
          27.53`4., 150 -> 27.65`4., 151 -> 28.09`4., 152 -> 28.01`4., 153 -> 
          27.91`4., 154 -> 28.06`4., 155 -> 27.75`4., 156 -> 27.65`4., 157 -> 
          27.68`4., 158 -> 27.8`4., 159 -> 27.83`4., 160 -> 27.68`4., 161 -> 
          27.92`4., 162 -> 28.14`4., 163 -> 27.91`4., 164 -> 27.99`4., 165 -> 
          28.1`4., 166 -> 28.04`4., 167 -> 27.94`4., 168 -> 28.12`4., 169 -> 
          28.44`4., 170 -> 28.39`4., 171 -> 28.55`4., 172 -> 28.19`4., 173 -> 
          28.02`4., 174 -> 28.53`4., 175 -> 28.53`4., 176 -> 29.36`4., 177 -> 
          28.9`4., 178 -> 28.65`4., 179 -> 28.45`4., 180 -> 28.7`4., 181 -> 
          28.65`4., 182 -> 28.75`4., 183 -> 29.41`4., 184 -> 30.09`4., 185 -> 
          30.49`4., 186 -> 30.41`4., 187 -> 31.49`4., 188 -> 31.68`4., 189 -> 
          31.58`4., 190 -> 32.33`4., 191 -> 32.7`4., 192 -> 32.4`4., 193 -> 
          33.`4., 194 -> 33.18`4., 195 -> 33.42`4., 196 -> 32.84`4., 197 -> 
          32.62`4., 198 -> 32.44`4., 199 -> 32.38`4., 200 -> 32.86`4., 201 -> 
          33.45`4., 202 -> 33.64`4., 203 -> 34.13`4., 204 -> 34.73`4., 205 -> 
          35.1`4., 206 -> 34.79`4., 207 -> 34.23`4., 208 -> 33.92`4., 209 -> 
          34.42`4., 210 -> 34.74`4., 211 -> 34.85`4., 212 -> 34.82`4., 213 -> 
          34.92`4., 214 -> 35.62`4., 215 -> 34.6`4., 216 -> 34.84`4., 217 -> 
          35.25`4., 218 -> 35.51`4., 219 -> 35.05`4., 220 -> 35.14`4., 221 -> 
          34.99`4., 222 -> 34.55`4., 223 -> 34.69`4., 224 -> 34.97`4., 225 -> 
          34.96`4., 226 -> 34.26`4., 227 -> 33.66`4., 228 -> 32.94`4., 229 -> 
          34.08`4., 230 -> 34.12`4., 231 -> 34.52`4., 232 -> 34.38`4., 233 -> 
          34.75`4., 234 -> 34.41`4., 235 -> 33.66`4., 236 -> 34.09`4., 237 -> 
          34.35`4., 238 -> 34.58`4., 239 -> 34.34`4., 240 -> 35.`4., 241 -> 
          35.58`4., 242 -> 35.66`4., 243 -> 36.01`4., 244 -> 36.34`4., 245 -> 
          35.72`4., 246 -> 32.4`4., 247 -> 31.7`4., 248 -> 31.91`4., 249 -> 
          32.04`4., 250 -> 31.62`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$545673 = 
        Dispatch[{
         1 -> 28.63`4., 2 -> 28.97`4., 3 -> 28.93`4., 4 -> 28.83`4., 5 -> 
          28.77`4., 6 -> 28.66`4., 7 -> 29.05`4., 8 -> 29.22`4., 9 -> 
          29.46`4., 10 -> 29.57`4., 11 -> 29.75`4., 12 -> 29.71`4., 13 -> 
          29.56`4., 14 -> 29.68`4., 15 -> 29.58`4., 16 -> 30.23`4., 17 -> 
          30.2`4., 18 -> 30.14`4., 19 -> 30.25`4., 20 -> 30.04`4., 21 -> 
          29.7`4., 22 -> 29.92`4., 23 -> 30.24`4., 24 -> 30.09`4., 25 -> 
          30.04`4., 26 -> 29.9`4., 27 -> 30.25`4., 28 -> 29.95`4., 29 -> 
          29.83`4., 30 -> 30.63`4., 31 -> 30.35`4., 32 -> 30.19`4., 33 -> 
          30.2`4., 34 -> 30.46`4., 35 -> 30.45`4., 36 -> 30.53`4., 37 -> 
          30.54`4., 38 -> 30.49`4., 39 -> 30.47`4., 40 -> 30.75`4., 41 -> 
          30.88`4., 42 -> 30.35`4., 43 -> 30.29`4., 44 -> 29.89`4., 45 -> 
          29.69`4., 46 -> 29.56`4., 47 -> 29.29`4., 48 -> 29.19`4., 49 -> 
          29.3`4., 50 -> 29.33`4., 51 -> 29.55`4., 52 -> 29.23`4., 53 -> 
          29.05`4., 54 -> 28.63`4., 55 -> 28.57`4., 56 -> 28.64`4., 57 -> 
          29.04`4., 58 -> 29.05`4., 59 -> 28.96`4., 60 -> 29.04`4., 61 -> 
          28.41`4., 62 -> 28.16`4., 63 -> 27.55`4., 64 -> 27.54`4., 65 -> 
          27.54`4., 66 -> 27.69`4., 67 -> 28.21`4., 68 -> 28.88`4., 69 -> 
          29.08`4., 70 -> 29.05`4., 71 -> 29.5`4., 72 -> 29.14`4., 73 -> 
          28.69`4., 74 -> 28.51`4., 75 -> 28.34`4., 76 -> 26.89`4., 77 -> 
          26.87`4., 78 -> 26.57`4., 79 -> 26.3`4., 80 -> 26.4`4., 81 -> 
          26.4`4., 82 -> 26.76`4., 83 -> 27.35`4., 84 -> 27.17`4., 85 -> 
          26.97`4., 86 -> 26.98`4., 87 -> 26.94`4., 88 -> 26.72`4., 89 -> 
          26.41`4., 90 -> 26.23`4., 91 -> 26.53`4., 92 -> 26.58`4., 93 -> 
          26.41`4., 94 -> 26.56`4., 95 -> 27.08`4., 96 -> 27.2`4., 97 -> 
          27.1`4., 98 -> 26.72`4., 99 -> 26.81`4., 100 -> 27.21`4., 101 -> 
          27.31`4., 102 -> 27.26`4., 103 -> 27.08`4., 104 -> 26.84`4., 105 -> 
          26.78`4., 106 -> 26.68`4., 107 -> 26.49`4., 108 -> 26.37`4., 109 -> 
          27.31`4., 110 -> 27.23`4., 111 -> 26.93`4., 112 -> 26.48`4., 113 -> 
          26.39`4., 114 -> 26.35`4., 115 -> 26.57`4., 116 -> 26.52`4., 117 -> 
          26.67`4., 118 -> 26.88`4., 119 -> 26.82`4., 120 -> 27.06`4., 121 -> 
          26.88`4., 122 -> 27.04`4., 123 -> 27.22`4., 124 -> 27.64`4., 125 -> 
          27.8`4., 126 -> 27.81`4., 127 -> 27.71`4., 128 -> 27.76`4., 129 -> 
          27.55`4., 130 -> 27.63`4., 131 -> 27.6`4., 132 -> 27.24`4., 133 -> 
          27.13`4., 134 -> 26.98`4., 135 -> 27.29`4., 136 -> 27.5`4., 137 -> 
          27.58`4., 138 -> 27.69`4., 139 -> 27.64`4., 140 -> 27.74`4., 141 -> 
          27.89`4., 142 -> 28.01`4., 143 -> 27.55`4., 144 -> 27.57`4., 145 -> 
          27.86`4., 146 -> 27.41`4., 147 -> 27.81`4., 148 -> 27.78`4., 149 -> 
          27.79`4., 150 -> 27.95`4., 151 -> 28.34`4., 152 -> 28.03`4., 153 -> 
          28.08`4., 154 -> 28.14`4., 155 -> 27.78`4., 156 -> 27.76`4., 157 -> 
          27.83`4., 158 -> 27.96`4., 159 -> 27.96`4., 160 -> 28.08`4., 161 -> 
          28.02`4., 162 -> 28.29`4., 163 -> 28.16`4., 164 -> 28.14`4., 165 -> 
          28.15`4., 166 -> 28.14`4., 167 -> 28.25`4., 168 -> 28.46`4., 169 -> 
          28.46`4., 170 -> 28.65`4., 171 -> 28.75`4., 172 -> 28.41`4., 173 -> 
          28.58`4., 174 -> 28.53`4., 175 -> 29.61`4., 176 -> 30.11`4., 177 -> 
          29.`4., 178 -> 28.82`4., 179 -> 28.78`4., 180 -> 28.94`4., 181 -> 
          28.84`4., 182 -> 28.78`4., 183 -> 30.03`4., 184 -> 30.97`4., 185 -> 
          30.69`4., 186 -> 31.7`4., 187 -> 32.61`4., 188 -> 31.76`4., 189 -> 
          32.45`4., 190 -> 32.88`4., 191 -> 32.85`4., 192 -> 32.94`4., 193 -> 
          33.29`4., 194 -> 33.67`4., 195 -> 33.56`4., 196 -> 33.01`4., 197 -> 
          32.77`4., 198 -> 32.49`4., 199 -> 32.84`4., 200 -> 33.53`4., 201 -> 
          33.9`4., 202 -> 34.15`4., 203 -> 34.87`4., 204 -> 35.1`4., 205 -> 
          35.27`4., 206 -> 34.84`4., 207 -> 34.55`4., 208 -> 34.28`4., 209 -> 
          35.18`4., 210 -> 35.02`4., 211 -> 35.25`4., 212 -> 35.28`4., 213 -> 
          35.63`4., 214 -> 35.74`4., 215 -> 34.89`4., 216 -> 35.11`4., 217 -> 
          35.78`4., 218 -> 35.65`4., 219 -> 35.18`4., 220 -> 35.27`4., 221 -> 
          35.02`4., 222 -> 34.69`4., 223 -> 35.16`4., 224 -> 35.17`4., 225 -> 
          35.09`4., 226 -> 34.33`4., 227 -> 33.73`4., 228 -> 34.2`4., 229 -> 
          34.38`4., 230 -> 34.48`4., 231 -> 34.78`4., 232 -> 34.79`4., 233 -> 
          34.99`4., 234 -> 34.44`4., 235 -> 34.37`4., 236 -> 34.24`4., 237 -> 
          34.59`4., 238 -> 34.6`4., 239 -> 34.81`4., 240 -> 35.77`4., 241 -> 
          35.73`4., 242 -> 36.22`4., 243 -> 36.43`4., 244 -> 36.39`4., 245 -> 
          35.89`4., 246 -> 32.67`4., 247 -> 32.01`4., 248 -> 32.04`4., 249 -> 
          32.19`4., 250 -> 31.65`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$545673 = 
        Dispatch[{
         1 -> 28.23`4., 2 -> 28.32`4., 3 -> 28.59`4., 4 -> 28.46`4., 5 -> 
          28.35`4., 6 -> 28.12`4., 7 -> 28.61`4., 8 -> 28.92`4., 9 -> 
          28.99`4., 10 -> 29.22`4., 11 -> 29.41`4., 12 -> 29.36`4., 13 -> 
          29.27`4., 14 -> 29.31`4., 15 -> 29.32`4., 16 -> 29.56`4., 17 -> 
          29.88`4., 18 -> 29.87`4., 19 -> 29.9`4., 20 -> 29.76`4., 21 -> 
          29.38`4., 22 -> 29.48`4., 23 -> 29.88`4., 24 -> 29.81`4., 25 -> 
          29.73`4., 26 -> 29.52`4., 27 -> 29.68`4., 28 -> 29.46`4., 29 -> 
          29.51`4., 30 -> 29.75`4., 31 -> 30.02`4., 32 -> 29.8`4., 33 -> 
          29.9`4., 34 -> 30.02`4., 35 -> 29.69`4., 36 -> 30.1`4., 37 -> 
          30.32`4., 38 -> 30.31`4., 39 -> 30.32`4., 40 -> 30.19`4., 41 -> 
          30.37`4., 42 -> 29.93`4., 43 -> 29.66`4., 44 -> 29.34`4., 45 -> 
          29.2`4., 46 -> 29.05`4., 47 -> 28.74`4., 48 -> 28.81`4., 49 -> 
          28.98`4., 50 -> 28.88`4., 51 -> 29.05`4., 52 -> 28.87`4., 53 -> 
          28.5`4., 54 -> 28.28`4., 55 -> 28.2`4., 56 -> 28.13`4., 57 -> 
          28.58`4., 58 -> 28.64`4., 59 -> 28.42`4., 60 -> 28.59`4., 61 -> 
          27.84`4., 62 -> 27.18`4., 63 -> 27.12`4., 64 -> 27.22`4., 65 -> 
          27.21`4., 66 -> 27.2`4., 67 -> 27.84`4., 68 -> 28.16`4., 69 -> 
          28.65`4., 70 -> 28.65`4., 71 -> 28.93`4., 72 -> 28.38`4., 73 -> 
          28.13`4., 74 -> 28.14`4., 75 -> 27.56`4., 76 -> 26.35`4., 77 -> 
          26.39`4., 78 -> 26.23`4., 79 -> 25.94`4., 80 -> 26.07`4., 81 -> 
          26.06`4., 82 -> 26.26`4., 83 -> 26.79`4., 84 -> 26.76`4., 85 -> 
          26.63`4., 86 -> 26.37`4., 87 -> 26.45`4., 88 -> 26.09`4., 89 -> 
          26.`4., 90 -> 25.94`4., 91 -> 25.87`4., 92 -> 26.21`4., 93 -> 
          25.97`4., 94 -> 26.12`4., 95 -> 26.64`4., 96 -> 26.67`4., 97 -> 
          26.54`4., 98 -> 26.29`4., 99 -> 26.28`4., 100 -> 26.73`4., 101 -> 
          26.84`4., 102 -> 26.74`4., 103 -> 26.6`4., 104 -> 26.59`4., 105 -> 
          26.29`4., 106 -> 26.17`4., 107 -> 26.15`4., 108 -> 25.98`4., 109 -> 
          26.74`4., 110 -> 26.75`4., 111 -> 26.33`4., 112 -> 26.24`4., 113 -> 
          26.06`4., 114 -> 26.16`4., 115 -> 25.89`4., 116 -> 25.88`4., 117 -> 
          26.35`4., 118 -> 26.43`4., 119 -> 26.6`4., 120 -> 26.65`4., 121 -> 
          26.63`4., 122 -> 26.59`4., 123 -> 26.79`4., 124 -> 27.05`4., 125 -> 
          26.98`4., 126 -> 27.34`4., 127 -> 27.19`4., 128 -> 27.34`4., 129 -> 
          26.99`4., 130 -> 27.14`4., 131 -> 27.01`4., 132 -> 26.94`4., 133 -> 
          26.84`4., 134 -> 26.69`4., 135 -> 26.89`4., 136 -> 27.09`4., 137 -> 
          27.33`4., 138 -> 27.46`4., 139 -> 27.45`4., 140 -> 27.46`4., 141 -> 
          27.6`4., 142 -> 27.64`4., 143 -> 27.04`4., 144 -> 27.29`4., 145 -> 
          27.18`4., 146 -> 27.15`4., 147 -> 27.14`4., 148 -> 27.55`4., 149 -> 
          27.33`4., 150 -> 27.5`4., 151 -> 27.96`4., 152 -> 27.58`4., 153 -> 
          27.81`4., 154 -> 27.77`4., 155 -> 27.48`4., 156 -> 27.45`4., 157 -> 
          27.56`4., 158 -> 27.73`4., 159 -> 27.78`4., 160 -> 27.61`4., 161 -> 
          27.83`4., 162 -> 27.98`4., 163 -> 27.85`4., 164 -> 27.9`4., 165 -> 
          27.76`4., 166 -> 27.91`4., 167 -> 27.88`4., 168 -> 28.06`4., 169 -> 
          28.16`4., 170 -> 28.32`4., 171 -> 28.34`4., 172 -> 28.07`4., 173 -> 
          27.91`4., 174 -> 28.27`4., 175 -> 28.48`4., 176 -> 29.32`4., 177 -> 
          28.53`4., 178 -> 28.46`4., 179 -> 28.31`4., 180 -> 28.5`4., 181 -> 
          28.4`4., 182 -> 28.3`4., 183 -> 29.4`4., 184 -> 30.06`4., 185 -> 
          30.17`4., 186 -> 30.39`4., 187 -> 31.32`4., 188 -> 31.23`4., 189 -> 
          31.55`4., 190 -> 32.06`4., 191 -> 32.37`4., 192 -> 32.17`4., 193 -> 
          32.85`4., 194 -> 33.01`4., 195 -> 33.01`4., 196 -> 32.42`4., 197 -> 
          32.36`4., 198 -> 32.09`4., 199 -> 32.32`4., 200 -> 32.8`4., 201 -> 
          33.43`4., 202 -> 33.55`4., 203 -> 34.1`4., 204 -> 34.68`4., 205 -> 
          34.72`4., 206 -> 34.36`4., 207 -> 33.9`4., 208 -> 33.9`4., 209 -> 
          34.41`4., 210 -> 34.57`4., 211 -> 34.81`4., 212 -> 34.79`4., 213 -> 
          34.83`4., 214 -> 34.77`4., 215 -> 34.43`4., 216 -> 34.49`4., 217 -> 
          35.06`4., 218 -> 35.14`4., 219 -> 34.68`4., 220 -> 34.85`4., 221 -> 
          34.59`4., 222 -> 34.25`4., 223 -> 34.63`4., 224 -> 34.9`4., 225 -> 
          34.59`4., 226 -> 33.37`4., 227 -> 33.05`4., 228 -> 32.57`4., 229 -> 
          33.46`4., 230 -> 33.89`4., 231 -> 34.5`4., 232 -> 34.34`4., 233 -> 
          34.33`4., 234 -> 33.63`4., 235 -> 33.6`4., 236 -> 33.58`4., 237 -> 
          33.98`4., 238 -> 34.14`4., 239 -> 34.32`4., 240 -> 34.9`4., 241 -> 
          35.28`4., 242 -> 35.58`4., 243 -> 35.96`4., 244 -> 35.49`4., 245 -> 
          35.22`4., 246 -> 31.02`4., 247 -> 31.6`4., 248 -> 31.71`4., 249 -> 
          31.89`4., 250 -> 31.25`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$545673 = 
        Dispatch[{
         1 -> 28.3`4., 2 -> 28.88`4., 3 -> 28.76`4., 4 -> 28.6`4., 5 -> 
          28.54`4., 6 -> 28.33`4., 7 -> 28.87`4., 8 -> 29.06`4., 9 -> 
          29.37`4., 10 -> 29.43`4., 11 -> 29.6`4., 12 -> 29.52`4., 13 -> 
          29.49`4., 14 -> 29.43`4., 15 -> 29.5`4., 16 -> 30.07`4., 17 -> 
          30.18`4., 18 -> 30.03`4., 19 -> 30.09`4., 20 -> 29.83`4., 21 -> 
          29.56`4., 22 -> 29.85`4., 23 -> 29.98`4., 24 -> 29.92`4., 25 -> 
          29.94`4., 26 -> 29.62`4., 27 -> 30.11`4., 28 -> 29.69`4., 29 -> 
          29.69`4., 30 -> 30.62`4., 31 -> 30.23`4., 32 -> 30.01`4., 33 -> 
          30.08`4., 34 -> 30.07`4., 35 -> 30.22`4., 36 -> 30.49`4., 37 -> 
          30.49`4., 38 -> 30.46`4., 39 -> 30.33`4., 40 -> 30.72`4., 41 -> 
          30.47`4., 42 -> 30.07`4., 43 -> 29.69`4., 44 -> 29.47`4., 45 -> 
          29.46`4., 46 -> 29.07`4., 47 -> 28.81`4., 48 -> 28.97`4., 49 -> 
          29.17`4., 50 -> 29.33`4., 51 -> 29.16`4., 52 -> 29.09`4., 53 -> 
          28.6`4., 54 -> 28.31`4., 55 -> 28.28`4., 56 -> 28.52`4., 57 -> 
          28.83`4., 58 -> 28.81`4., 59 -> 28.91`4., 60 -> 28.82`4., 61 -> 
          27.98`4., 62 -> 27.35`4., 63 -> 27.4`4., 64 -> 27.25`4., 65 -> 
          27.23`4., 66 -> 27.56`4., 67 -> 27.88`4., 68 -> 28.84`4., 69 -> 
          28.82`4., 70 -> 28.94`4., 71 -> 29.17`4., 72 -> 28.41`4., 73 -> 
          28.14`4., 74 -> 28.16`4., 75 -> 27.57`4., 76 -> 26.68`4., 77 -> 
          26.43`4., 78 -> 26.26`4., 79 -> 26.12`4., 80 -> 26.33`4., 81 -> 
          26.31`4., 82 -> 26.54`4., 83 -> 27.28`4., 84 -> 26.98`4., 85 -> 
          26.67`4., 86 -> 26.95`4., 87 -> 26.54`4., 88 -> 26.22`4., 89 -> 
          26.03`4., 90 -> 25.97`4., 91 -> 26.27`4., 92 -> 26.33`4., 93 -> 
          26.06`4., 94 -> 26.53`4., 95 -> 26.91`4., 96 -> 26.83`4., 97 -> 
          26.7`4., 98 -> 26.4`4., 99 -> 26.69`4., 100 -> 27.14`4., 101 -> 
          26.9`4., 102 -> 27.26`4., 103 -> 27.04`4., 104 -> 26.65`4., 105 -> 
          26.45`4., 106 -> 26.55`4., 107 -> 26.15`4., 108 -> 26.31`4., 109 -> 
          27.2`4., 110 -> 26.84`4., 111 -> 26.34`4., 112 -> 26.29`4., 113 -> 
          26.15`4., 114 -> 26.3`4., 115 -> 26.06`4., 116 -> 26.42`4., 117 -> 
          26.48`4., 118 -> 26.8`4., 119 -> 26.63`4., 120 -> 26.84`4., 121 -> 
          26.84`4., 122 -> 26.74`4., 123 -> 27.19`4., 124 -> 27.21`4., 125 -> 
          27.46`4., 126 -> 27.49`4., 127 -> 27.59`4., 128 -> 27.43`4., 129 -> 
          27.04`4., 130 -> 27.51`4., 131 -> 27.03`4., 132 -> 27.08`4., 133 -> 
          26.93`4., 134 -> 26.87`4., 135 -> 27.13`4., 136 -> 27.44`4., 137 -> 
          27.46`4., 138 -> 27.61`4., 139 -> 27.62`4., 140 -> 27.59`4., 141 -> 
          27.85`4., 142 -> 27.68`4., 143 -> 27.3`4., 144 -> 27.57`4., 145 -> 
          27.18`4., 146 -> 27.18`4., 147 -> 27.62`4., 148 -> 27.61`4., 149 -> 
          27.76`4., 150 -> 27.95`4., 151 -> 28.15`4., 152 -> 27.89`4., 153 -> 
          27.94`4., 154 -> 27.81`4., 155 -> 27.68`4., 156 -> 27.72`4., 157 -> 
          27.73`4., 158 -> 27.94`4., 159 -> 27.84`4., 160 -> 27.9`4., 161 -> 
          27.98`4., 162 -> 28.12`4., 163 -> 27.91`4., 164 -> 28.05`4., 165 -> 
          27.96`4., 166 -> 27.96`4., 167 -> 28.17`4., 168 -> 28.41`4., 169 -> 
          28.41`4., 170 -> 28.6`4., 171 -> 28.36`4., 172 -> 28.4`4., 173 -> 
          28.5`4., 174 -> 28.39`4., 175 -> 29.4`4., 176 -> 30.07`4., 177 -> 
          28.74`4., 178 -> 28.59`4., 179 -> 28.49`4., 180 -> 28.77`4., 181 -> 
          28.63`4., 182 -> 28.59`4., 183 -> 29.56`4., 184 -> 30.62`4., 185 -> 
          30.39`4., 186 -> 31.54`4., 187 -> 31.72`4., 188 -> 31.57`4., 189 -> 
          32.38`4., 190 -> 32.87`4., 191 -> 32.49`4., 192 -> 32.93`4., 193 -> 
          33.26`4., 194 -> 33.51`4., 195 -> 33.08`4., 196 -> 32.76`4., 197 -> 
          32.43`4., 198 -> 32.46`4., 199 -> 32.8`4., 200 -> 33.53`4., 201 -> 
          33.85`4., 202 -> 34.08`4., 203 -> 34.87`4., 204 -> 35.08`4., 205 -> 
          34.85`4., 206 -> 34.61`4., 207 -> 34.15`4., 208 -> 34.27`4., 209 -> 
          35.02`4., 210 -> 34.88`4., 211 -> 35.03`4., 212 -> 34.9`4., 213 -> 
          35.59`4., 214 -> 34.99`4., 215 -> 34.78`4., 216 -> 34.96`4., 217 -> 
          35.67`4., 218 -> 35.47`4., 219 -> 34.84`4., 220 -> 35.`4., 221 -> 
          34.72`4., 222 -> 34.4`4., 223 -> 35.`4., 224 -> 34.98`4., 225 -> 
          34.59`4., 226 -> 33.49`4., 227 -> 33.27`4., 228 -> 33.72`4., 229 -> 
          33.67`4., 230 -> 34.35`4., 231 -> 34.62`4., 232 -> 34.54`4., 233 -> 
          34.36`4., 234 -> 33.94`4., 235 -> 34.01`4., 236 -> 34.21`4., 237 -> 
          34.33`4., 238 -> 34.35`4., 239 -> 34.7`4., 240 -> 35.69`4., 241 -> 
          35.67`4., 242 -> 36.17`4., 243 -> 36.27`4., 244 -> 35.74`4., 245 -> 
          35.44`4., 246 -> 31.4`4., 247 -> 32.01`4., 248 -> 31.82`4., 249 -> 
          31.96`4., 250 -> 31.39`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$545673 = True, 
        System`TradingChartDump`$gridlines$545673 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$545673, 
        System`TradingChartDump`$plotrangemin$545673 = 25.337956692913384`, 
        System`TradingChartDump`$plotrangemax$545673 = 37.48638507686539, 
        System`TradingChartDump`$layoutData$545673, 
        System`TradingChartDump`$gridlinesscope$545673 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$545673 = {True, True}, 
        System`TradingChartDump`$indicators$545673 = {
         FinancialIndicator["PolarizedFractalEfficiency", 10, 5]}, 
        System`TradingChartDump`$mouseQ$545673 = False, 
        System`TradingChartDump`$modelData$545673 = 
        System`TradingChartDump`modelData$543910, 
        System`TradingChartDump`$sy$545673 = Identity, 
        System`TradingChartDump`$isy$545673 = Identity, 
        System`TradingChartDump`$appearance$545673 = Automatic, 
        System`TradingChartDump`$perfgoal$545673 = "Quality", 
        System`TradingChartDump`$axesorigin$545673 = Automatic, 
        System`TradingChartDump`$framestyle$545673 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$545673 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$545673 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$545673 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$545673 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$545673, 
        System`TradingChartDump`$newgridlines$545673 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{25.337956692913384`, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$545673 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$545673 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$545673 = "GraphicsFrame", 
        System`TradingChartDump`$frame$545673 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$545673 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$545673 = 
              Switch[System`TradingChartDump`$highlightposition$545673, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$545673], {
                 1, System`TradingChartDump`$length$545673}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$545673], {
                 1, System`TradingChartDump`$length$545673}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$545673, 
                   Charting`nearestDate[System`TradingChartDump`$dates$545673, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$545673]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$545673]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$545673, 
                    Floor[System`TradingChartDump`$controlmin$545673] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$545673, 
                    Floor[System`TradingChartDump`$controlmax$545673]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$545673 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$545673 = 
            If[System`TradingChartDump`$fastpos$545673 =!= True, 
              System`TradingChartDump`$fastpos$545673 = 
               Clip[System`TradingChartDump`$fastpos$545673, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$545673 = (
                  Floor[System`TradingChartDump`$controlmax$545673] - Floor[
                  System`TradingChartDump`$controlmin$545673]) (
                  System`TradingChartDump`$fastpos$545673/100) + 
                Floor[System`TradingChartDump`$controlmin$545673]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$545673], {
                Floor[System`TradingChartDump`$controlmin$545673] + 1, 
                 Floor[System`TradingChartDump`$controlmax$545673]}], 
              System`TradingChartDump`$staticindicatorpos$545673]; 
           System`TradingChartDump`$mouseQ$545673 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$545673]], 
              System`TradingChartDump`$highlightposition$545673 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$545673 = If[
              And[
              System`TradingChartDump`$bouncingballQ$545673, 
               System`TradingChartDump`$mouseQ$545673, 
               System`TradingChartDump`$appearance$545673 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$545673[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$545673]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$545673[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$545673, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$545673[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$545673]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$545673[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$545673[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545673, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545673[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545673, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545673, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545673[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545673[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$545673 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$545673, 
                 System`TradingChartDump`$defaultframeticksstyle$545673, 
                 System`TradingChartDump`$defaultlabelstyle$545673, 
                 System`TradingChartDump`$framestyle$545673, 
                 System`TradingChartDump`$frameticksstyle$545673, 
                 System`TradingChartDump`$labelstyle$545673}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545673 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$545673, 
                 System`TradingChartDump`$labelstyle$545673, 
                 System`TradingChartDump`$defaultframeticksstyle$545673, 
                 System`TradingChartDump`$defaultlabelstyle$545673}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545673 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545673, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$545673 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545673, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$545673 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545673, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$545673 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$545673 = 
             Part[System`TradingChartDump`$tickstextstyle$545673, 1], 
             System`TradingChartDump`$tickstextstyle$545673 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545673[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545673, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545673[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545673[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545673[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$545673[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545673, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$545673]], 
                    Style[":", System`TradingChartDump`$textstyle$545673]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$545673[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545673]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545673[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$545673[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$545673, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$545673]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$545673[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545673, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545673[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545673, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545673, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$545673[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545673[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545673[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$545673[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$545673[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$545673], 1], 
                   Floor[System`TradingChartDump`$controlmax$545673]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$545673[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$545673[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$545673[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$545673[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$545673[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545673[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$545673[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$545673[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$545673[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545673[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$545673[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$545673[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$545673[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$545673[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$545673[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$545673, 
                  System`TradingChartDump`$mouseQ$545673], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$545673 - 0.5, 
                   System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$545673 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$545673 + 0.5, 
                    System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545673, 1]}, {
                    System`TradingChartDump`$indicatorpos$545673 + 0.5, 
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$545673[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$545673, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$545673[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545673]]], {}]; 
              System`TradingChartDump`$subplotgridlines$545673[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$545673[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$545673[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545673[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$545673 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$545673, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545673, 
                   System`TradingChartDump`$opens$545673]], 12, 
                 System`TradingChartDump`$textstyle$545673, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$545673, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545673, 
                   System`TradingChartDump`$highs$545673]], 12, 
                 System`TradingChartDump`$textstyle$545673, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$545673, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545673, 
                   System`TradingChartDump`$lows$545673]], 12, 
                 System`TradingChartDump`$textstyle$545673, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$545673, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545673, 
                   System`TradingChartDump`$closes$545673]], 12, 
                 System`TradingChartDump`$textstyle$545673, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545673, 
                   System`TradingChartDump`$visdates$545673]], 12, 
                 System`TradingChartDump`$textstyle$545673, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$545673, 
                  System`TradingChartDump`$mouseQ$545673], {{
                  System`TradingChartDump`$timestampstyle$545673, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$545673 - 0.5, 
                    System`TradingChartDump`$plotrangemin$545673}, 
                    If[
                    System`TradingChartDump`$timestampdepth$545673 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$545673[1]}, {
                    System`TradingChartDump`$indicatorpos$545673 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545673}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545673, 1]}, {
                    System`TradingChartDump`$indicatorpos$545673 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545673}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$545673, {
               System`TradingChartDump`$highlightstyle$545673, 
                Dynamic[System`TradingChartDump`$ohlcpoint$545673]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$545673[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545673, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$545673[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$545673[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$545673, Length[
                    System`TradingChartDump`$layoutData$545673[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$545673}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$545673] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$545673] + 0.5}, {
                System`TradingChartDump`$plotrangemin$545673, 
                 System`TradingChartDump`$plotrangemax$545673}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$545673, Left, {
                 False, System`TradingChartDump`$frame$545673}, 
                 Blank[], {System`TradingChartDump`$frame$545673, False}], {
                False, System`TradingChartDump`$frame$545673}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$545673, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$545673]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$545673 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           387.0228610767757}, {-286.9226415094339, -65.7679245283018}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545673 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545673, 1]], 
               Part[System`TradingChartDump`$framestyle$545673, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$545673]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$545673} -> 
                   System`TradingChartDump`$isy$545673[
                    System`TradingChartDump`$plotrangemin$545673], {
                    0, System`TradingChartDump`$plotrangemax$545673} -> 
                   System`TradingChartDump`$isy$545673[
                    System`TradingChartDump`$plotrangemax$545673]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$545673[
                   System`TradingChartDump`$plotrangemin$545673], 
                   System`TradingChartDump`$isy$545673[
                   System`TradingChartDump`$plotrangemax$545673]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$545673, 
                   System`TradingChartDump`$isy$545673}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545673, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545673 > 
                    System`TradingChartDump`$plotrangemin$545673, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545673 > 
                    System`TradingChartDump`$plotrangemin$545673, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545673, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545673 > 
                    System`TradingChartDump`$plotrangemin$545673, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545673 > 
                    System`TradingChartDump`$plotrangemin$545673, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545673, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545673, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545673 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545673,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545673], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545673 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545673, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545673]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$545673, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$545673[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$545673[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545673, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$545673[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$545673, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545673[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545673, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545673[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545673[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545673[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545673[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545673], 
                    Style[":", System`TradingChartDump`$textstyle$545673]], 
                    Style[":", System`TradingChartDump`$textstyle$545673]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$545673[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545673]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545673[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$545673}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$545673, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$545673 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$545673[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$545673, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$545673, Left, {
                    False, System`TradingChartDump`$frame$545673}, 
                    Blank[], {
                    System`TradingChartDump`$frame$545673, False}], {
                   System`TradingChartDump`$frame$545673, 
                    System`TradingChartDump`$frame$545673}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$545673, 
                    System`TradingChartDump`$controlmax$545673}] + 0.5, {
                   System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$545673]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$545673) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$545673 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$545673 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$545673, 1]], 
                   Part[System`TradingChartDump`$framestyle$545673, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$545673]]], {}, 
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545673[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545673[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$545673[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545673, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545673, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$545673, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$545673, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$545673 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
545673, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$545673], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$545673 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$545673, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$545673]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$545673, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$545673) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$545673 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$545673[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           475.9407855006933}, {-55.98962264150938, -0.70094339622635}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$545673, 
              Dynamic[System`TradingChartDump`$ohlclabel$545673], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$545673}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545673 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545673, 2]], 
               Part[System`TradingChartDump`$framestyle$545673, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$545673]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$545673, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$545673, 
                    System`TradingChartDump`$controlmax$545673}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$545673] + 
                    0.5, System`TradingChartDump`$plotrangemin$545673}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$545673], 
                    System`TradingChartDump`$plotrangemin$545673}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$545673, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545673, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545673, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545673 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545673, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545673], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545673 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545673,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545673]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$545673] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$545673[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$545673] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$545673[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$545673] = {HoldPattern[
               System`TradingChartDump`$min$545673[1]] :> -108.08}}, {
          DownValues[System`TradingChartDump`$max$545673] = {HoldPattern[
               System`TradingChartDump`$max$545673[1]] :> 109.47}}, {
          DownValues[System`TradingChartDump`$subplotvalue$545673] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$545673[1, 1]] :> 
             Invisible[-58.410000000000004`]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$545673] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$545673[1]] :> {-100, 
              0, 100}}}, {
          DownValues[System`TradingChartDump`$layoutData$545673] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$545673["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "AllValues"]] :> CompressedData["
1:eJxVVgk8VVv7Fo1Cg6GuSlKZKhS5nb323uc5XE1mGZtHXEMpypdyQyFSEn2K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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545673["AppendedAdjust"]] :> 
             21.755324171487445`, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "AppendedBox"]] :> {-124.29122932226596`, 142.31608543025348`},
              HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "AppendedMin"]] :> -118.95699193119239`, HoldPattern[
               System`TradingChartDump`$layoutData$545673["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$545673["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$545673["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$545673["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545673["DataMax"]] :> 
             36.43, HoldPattern[
               System`TradingChartDump`$layoutData$545673["DataMin"]] :> 
             25.86614923134608, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "MainChartAllValues"]] :> CompressedData["
1:eJxdlglYzdv6x1OZ0mBocEISmtBAOvZv2t9dJ1NzGs1jdRqIoiuiolJSGtwo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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "MainChartPoints"]] :> CompressedData["
1:eJxdlltoXFUUhqdFUIKgYkSRUqdVSqylVGNtmzbJTmqaNEmTTO6XSXLmfp9U
pCiRyqFShCIEn0QRGS/4IhTBlyAqscUnKyIoVRCZIoiQIgWplD6Zk/V/D+cc
CMOftf/9r9tee+9Jr4zn7onFYne3/nbob2eM71b3D9e2vuETTv9wN1ZbL/ff
AN/nrt5uS65dAT/o3ns3+MCtruX6x2c7L4EfcwF7dRK8yz1xcTOx/gc47tau
bG34QKfwXrMvgZ9yAb21Dt4nPXCbC5bvvgje7zoDB86DD0T4B+3XBx9y41vs
zYe6hJ+19QfBz7mBIAH3gttdEF7Lo+DnLb6f2e+wxbMGfsH8/Q18xL0WEO6C
j7qbgfub4GPupSCAW+AOy8cH4OMuGQjsQv+Erf8ce2cEd4nP+m7T7wA7q+dO
Yd9ZPK3Ye8L58XtcABNHsfcq39gjOHbS/Re0yznsJ9UP2F+0/daxC7+KvS+i
3xeJ75TWC/unpIe9X3zs/VafH+m/AePfEfYHrB7PwD8tf+Gfdk9vFwD7oPoB
+2DkPAyZ3ij7D1k/9WMfVv9iH1Y/YT8T9tc/Y/p/Yx+x+H7CPqL+Oi77qPkz
J+yPuvz2h33Mfp2wG1N/sH5M/Sy8MaZ5AD9h8V+XvktE/Emon4U3EpH8jls8
Rfjj7pNguyfhy94Gf9z2fxv9CTuvlzvEF64L+xPW373CGxN2HnYLxyZVX/iT
qhf8Sc0z+JOqH/pTyjf8KYvvM/hTrj34/oU/Fd4vNq3zBH9a8wa+7HeOiT9t
/dIHfybi/4zmKfwZ2+9N9GfUP/Bn1W/wZ83fL+DPql/gz+r8wZ9TveifOVv/
F/w55Z/+mbP4W8jfvK3/FP15038Z/rzbvo/eQl/r96G/EK6XWzB+O/27oP6E
LzwDP2n+DMJPhvf3k6Y/DD8Zzm9s0epdgb9o/bAKf9H41+Av2vn5EP5S2D8X
wf6SzdOv4S9Z/g+Rv2Wbd4fJv/A54l/WPCb/y7b/O/A9nRfhuBeuj/OsfheE
PU/9yf6e7gvhhvb7B3893ffCTc/i34N+yuI5i34q7L9L2X33Pvop3Wfop8Lx
NFK6b4k3pfkg3Eypnuinw/Mkntb9j34Ee+mIfjrsXyOt9xH6aZ1/9NPqL+Z3
xs7Pn+hnNC/Rz2j+o58Jx+NndH+in7H++xL9yH7NjPqL+LM6r+hnw/eHy2pe
yl8vq/mBftbyeb/sjazV7zb6EdzMav4Tfy48/+MR7HLh+9TLWb6T3A85zSf0
c/o/90XO8psRbrKe+ycffl/E8zpv6OfVX+jLfh79vM3j79DP63yjH+E385H3
YSH8PosX5K+wK+i+6JZ+QfUW9gvqX+FGQfPBSb9geivCTel1CceK5t8rwvGi
/Bd2wt8Ke0X5I+zLnhJuaL8j6Bf1nkC/qPyjX7J4r6Jfsn66iX5J86hH+iXF
I+zLfkm4IX5VeKNk52VEuFmy8/iwcKxs53WvcFz4grAraz6hXzZ/30C/rPsK
/bL19/foly3fr6Mvfgb9iu4L9Ct2Xn5Bv2L9/hX6Fd036Ff0i77WJ9Gv6D5E
P7I+VlU/o1+1/YfQr5r/31D/quXnI+pfNb3fqX9V/lP/qtXjAPpV3dfo1/Se
Qb+meYt+Te8f9GvWbzuIv2b5e5z4a9YP+4m/FtGv6T2Mft32/xX9eiT/wo/0
Sr+ufhH267rf0Nd+6+jX1e86n826/Kf/V/Relj2+onkp7FbUL93ufxyzRGk=

              "], HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545673["NewSubplot"]] :> {
               FinancialIndicator["PolarizedFractalEfficiency", 10, 5]}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545673["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "PlotRangeMin"]] :> -118.95699193119239`, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$545673["Space"]] :> 
             3.6430000000000002`, HoldPattern[
               System`TradingChartDump`$layoutData$545673["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, -50}, {250., -50}}], 
                    Line[{{0, 0}, {250., 0}}], 
                    Line[{{0, 50}, {250., 50}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJw9lglQE9YWhoMOID6holTLpuGVoqJQLYuooL/s+xoCAYEESEhICFRw4YES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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "SubplotIndicatorGridLines"]] :> {{-100, 0, 100}}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "PFE"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["PolarizedFractalEfficiency", 10, 5]}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "SubplotIndicatorParameters"]] :> {{{10, 5}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "SubplotIndicatorPoints"]] :> {{{}, {}, {}, {}, {}, {}, {}, \
{}, {}, {{10., 107.03}}, {{11., 107.44}}, {{12., 107.74000000000001`}}, {{13.,
                 108.03}}, {{14., 108.22}}, {{15., 108.52}}, {{16., 
                108.68}}, {{17., 108.8}}, {{18., 108.88}}, {{19., 108.93}}, {{
                20., 108.81}}, {{21., 108.60000000000001`}}, {{22., 
                108.33}}, {{23., 108.15}}, {{24., 108.01}}, {{25., 35.53}}, {{
                26., -12.67}}, {{27., 27.45}}, {{28., -17.3}}, {{
                29., -47.25}}, {{30., 3.18}}, {{31., 36.52}}, {{32., 
                58.660000000000004`}}, {{33., 73.43}}, {{34., 83.27}}, {{35., 
                90.03}}, {{36., 94.78}}, {{37., 98.34}}, {{38., 100.7}}, {{
                39., 30.71}}, {{40., 56.93}}, {{41., 74.37}}, {{42., 
                13.49}}, {{43., -26.85}}, {{44., -53.77}}, {{45., -71.94}}, {{
                46., -83.94}}, {{47., -91.94}}, {{
                48., -97.10000000000001}}, {{49., -100.85000000000001`}}, {{
                50., -103.22}}, {{51., -104.96000000000001`}}, {{
                52., -106.3}}, {{53., -106.91}}, {{54., -107.26}}, {{
                55., -107.65}}, {{56., -107.84}}, {{
                57., -107.82000000000001`}}, {{58., -107.9}}, {{
                59., -107.99000000000001`}}, {{60., -108.08}}, {{
                61., -107.19}}, {{62., -106.4}}, {{63., -105.89}}, {{
                64., -105.56}}, {{65., -105.54}}, {{66., -105.5}}, {{
                67., -105.16}}, {{68., -103.46000000000001`}}, {{
                69., -68.97}}, {{70., -11.43}}, {{71., 27.91}}, {{72., 
                52.83}}, {{73., 69.32000000000001}}, {{74., 
                80.32000000000001}}, {{75., 87.14}}, {{76., 25.22}}, {{
                77., -17.98}}, {{78., -46.85}}, {{79., -66.31}}, {{
                80., -79.32000000000001}}, {{81., -88.31}}, {{
                82., -94.03}}, {{83., -96.67}}, {{84., -98.76}}, {{
                85., -101.16}}, {{86., -32.1}}, {{87., 13.65}}, {{88., 
                44.}}, {{89., -5.59}}, {{90., -38.65}}, {{
                91., -60.620000000000005`}}, {{92., -76.32000000000001}}, {{
                93., -86.8}}, {{94., -93.43}}, {{95., -97.72}}, {{
                96., -29.400000000000002`}}, {{97., 16.330000000000002`}}, {{
                98., 46.7}}, {{99., 66.86}}, {{100., 80.15}}, {{101., 
                88.83}}, {{102., 94.71000000000001}}, {{103., 98.73}}, {{104.,
                 30.28}}, {{105., -15.31}}, {{106., -45.69}}, {{
                107., -65.82000000000001}}, {{108., -79.37}}, {{
                109., -18.34}}, {{110., -46.68}}, {{111., -65.52}}, {{
                112., -78.11}}, {{113., -86.67}}, {{114., -92.38}}, {{
                115., -96.13}}, {{116., -29.52}}, {{117., 14.92}}, {{
                118., -25.75}}, {{119., -53.02}}, {{120., 0.92}}, {{121., 
                36.9}}, {{122., 60.910000000000004`}}, {{123., 76.67}}, {{
                124., 87.38}}, {{125., 94.60000000000001}}, {{126., 
                99.41}}, {{127., 102.72}}, {{128., 104.93}}, {{129., 
                106.10000000000001`}}, {{130., 106.55}}, {{131., 106.38}}, {{
                132., 35.22}}, {{133., -12.19}}, {{134., -43.95}}, {{
                135., -64.97}}, {{136., -78.8}}, {{137., -17.}}, {{138., 
                24.490000000000002`}}, {{139., 52.5}}, {{140., 71.66}}, {{
                141., 84.36}}, {{142., 92.81}}, {{143., 
                98.10000000000001}}, {{144., 101.62}}, {{145., 
                31.650000000000002`}}, {{146., -14.99}}, {{147., 25.77}}, {{
                148., -18.59}}, {{149., 23.34}}, {{150., 51.35}}, {{151., 
                70.03}}, {{152., 82.66}}, {{153., 91.17}}, {{154., 97.14}}, {{
                155., 101.07000000000001`}}, {{156., 104.01}}, {{157., 
                105.97}}, {{158., 107.23}}, {{159., 34.85}}, {{
                160., -13.48}}, {{161., 27.84}}, {{162., 55.36}}, {{163., 
                73.65}}, {{164., 85.86}}, {{165., 93.97}}, {{166., 99.38}}, {{
                167., 102.99000000000001`}}, {{168., 105.34}}, {{169., 
                106.91}}, {{170., 107.92}}, {{171., 108.46000000000001`}}, {{
                172., 108.94}}, {{173., 109.27}}, {{174., 109.47}}, {{175., 
                108.32000000000001`}}, {{176., 107.15}}, {{177., 103.67}}, {{
                178., 101.3}}, {{179., 35.31}}, {{180., 55.76}}, {{181., 
                69.34}}, {{182., 78.4}}, {{183., 83.5}}, {{184., 86.8}}, {{
                185., 89.32000000000001}}, {{186., 92.62}}, {{187., 
                95.10000000000001}}, {{188., 96.69}}, {{189., 97.51}}, {{190.,
                 98.44}}, {{191., 98.46000000000001}}, {{192., 98.83}}, {{
                193., 99.71000000000001}}, {{194., 100.71000000000001`}}, {{
                195., 101.69}}, {{196., 102.}}, {{197., 102.01}}, {{198., 
                102.9}}, {{199., 33.49}}, {{200., 57.01}}, {{201., 72.8}}, {{
                202., 83.4}}, {{203., 89.8}}, {{204., 94.66}}, {{205., 
                98.05}}, {{206., 100.46000000000001`}}, {{207., 101.39}}, {{
                208., 102.07000000000001`}}, {{209., 102.49000000000001`}}, {{
                210., 102.71000000000001`}}, {{211., 102.89}}, {{212., 
                103.82000000000001`}}, {{213., 103.77}}, {{214., 
                103.21000000000001`}}, {{215., 102.86}}, {{216., 103.03}}, {{
                217., 102.60000000000001`}}, {{218., 102.82000000000001`}}, {{
                219., 34.76}}, {{220., -10.6}}, {{221., -40.75}}, {{
                222., -61.660000000000004`}}, {{223., -6.86}}, {{224., 
                29.76}}, {{225., -14.31}}, {{226., -43.550000000000004`}}, {{
                227., -63.050000000000004`}}, {{228., -75.75}}, {{
                229., -84.34}}, {{230., -89.23}}, {{231., -26.45}}, {{
                232., -51.24}}, {{233., -67.74}}, {{
                234., -78.71000000000001}}, {{235., -17.240000000000002`}}, {{
                236., 23.87}}, {{237., 51.52}}, {{238., 69.97}}, {{239., 
                82.79}}, {{240., 90.11}}, {{241., 95.03}}, {{242., 98.28}}, {{
                243., 101.10000000000001`}}, {{244., 102.10000000000001`}}, {{
                245., 102.43}}, {{246., 41.42}}, {{247., 1.48}}, {{
                248., -25.580000000000002`}}, {{
                249., -45.160000000000004`}}, {{
                250., -58.410000000000004`}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "SubplotIndicatorValues"]] :> {{{""}, {""}, {""}, {""}, {""}, {
                ""}, {""}, {""}, {""}, {107.03}, {107.44}, {
                107.74000000000001`}, {108.03}, {108.22}, {108.52}, {
                108.68}, {108.8}, {108.88}, {108.93}, {108.81}, {
                108.60000000000001`}, {108.33}, {108.15}, {108.01}, {
                35.53}, {-12.67}, {27.45}, {-17.3}, {-47.25}, {3.18}, {
                36.52}, {58.660000000000004`}, {73.43}, {83.27}, {90.03}, {
                94.78}, {98.34}, {100.7}, {30.71}, {56.93}, {74.37}, {
                13.49}, {-26.85}, {-53.77}, {-71.94}, {-83.94}, {-91.94}, \
{-97.10000000000001}, {-100.85000000000001`}, {-103.22}, \
{-104.96000000000001`}, {-106.3}, {-106.91}, {-107.26}, {-107.65}, {-107.84}, \
{-107.82000000000001`}, {-107.9}, {-107.99000000000001`}, {-108.08}, \
{-107.19}, {-106.4}, {-105.89}, {-105.56}, {-105.54}, {-105.5}, {-105.16}, \
{-103.46000000000001`}, {-68.97}, {-11.43}, {27.91}, {52.83}, {
                69.32000000000001}, {80.32000000000001}, {87.14}, {
                25.22}, {-17.98}, {-46.85}, {-66.31}, {-79.32000000000001}, \
{-88.31}, {-94.03}, {-96.67}, {-98.76}, {-101.16}, {-32.1}, {13.65}, {
                44.}, {-5.59}, {-38.65}, {-60.620000000000005`}, \
{-76.32000000000001}, {-86.8}, {-93.43}, {-97.72}, {-29.400000000000002`}, {
                16.330000000000002`}, {46.7}, {66.86}, {80.15}, {88.83}, {
                94.71000000000001}, {98.73}, {
                30.28}, {-15.31}, {-45.69}, {-65.82000000000001}, {-79.37}, \
{-18.34}, {-46.68}, {-65.52}, {-78.11}, {-86.67}, {-92.38}, {-96.13}, \
{-29.52}, {14.92}, {-25.75}, {-53.02}, {0.92}, {36.9}, {
                60.910000000000004`}, {76.67}, {87.38}, {94.60000000000001}, {
                99.41}, {102.72}, {104.93}, {106.10000000000001`}, {106.55}, {
                106.38}, {
                35.22}, {-12.19}, {-43.95}, {-64.97}, {-78.8}, {-17.}, {
                24.490000000000002`}, {52.5}, {71.66}, {84.36}, {92.81}, {
                98.10000000000001}, {101.62}, {
                31.650000000000002`}, {-14.99}, {25.77}, {-18.59}, {23.34}, {
                51.35}, {70.03}, {82.66}, {91.17}, {97.14}, {
                101.07000000000001`}, {104.01}, {105.97}, {107.23}, {
                34.85}, {-13.48}, {27.84}, {55.36}, {73.65}, {85.86}, {93.97},
                 {99.38}, {102.99000000000001`}, {105.34}, {106.91}, {
                107.92}, {108.46000000000001`}, {108.94}, {109.27}, {
                109.47}, {108.32000000000001`}, {107.15}, {103.67}, {101.3}, {
                35.31}, {55.76}, {69.34}, {78.4}, {83.5}, {86.8}, {
                89.32000000000001}, {92.62}, {95.10000000000001}, {96.69}, {
                97.51}, {98.44}, {98.46000000000001}, {98.83}, {
                99.71000000000001}, {100.71000000000001`}, {101.69}, {102.}, {
                102.01}, {102.9}, {33.49}, {57.01}, {72.8}, {83.4}, {89.8}, {
                94.66}, {98.05}, {100.46000000000001`}, {101.39}, {
                102.07000000000001`}, {102.49000000000001`}, {
                102.71000000000001`}, {102.89}, {103.82000000000001`}, {
                103.77}, {103.21000000000001`}, {102.86}, {103.03}, {
                102.60000000000001`}, {102.82000000000001`}, {
                34.76}, {-10.6}, {-40.75}, {-61.660000000000004`}, {-6.86}, {
                29.76}, {-14.31}, {-43.550000000000004`}, \
{-63.050000000000004`}, {-75.75}, {-84.34}, {-89.23}, {-26.45}, {-51.24}, \
{-67.74}, {-78.71000000000001}, {-17.240000000000002`}, {23.87}, {51.52}, {
                69.97}, {82.79}, {90.11}, {95.03}, {98.28}, {
                101.10000000000001`}, {102.10000000000001`}, {102.43}, {
                41.42}, {
                1.48}, {-25.580000000000002`}, {-45.160000000000004`}, \
{-58.410000000000004`}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$545673["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$545673["YRange"]] :> 36.43,
              HoldPattern[
               System`TradingChartDump`$layoutData$545673[
               "SubplotPoints", {
                1}]] :> {{}, {}, {}, {}, {}, {}, {}, {}, {}, {107.03}, {
               107.44}, {107.74000000000001`}, {108.03}, {108.22}, {108.52}, {
               108.68}, {108.8}, {108.88}, {108.93}, {108.81}, {
               108.60000000000001`}, {108.33}, {108.15}, {108.01}, {
               35.53}, {-12.67}, {27.45}, {-17.3}, {-47.25}, {3.18}, {
               36.52}, {58.660000000000004`}, {73.43}, {83.27}, {90.03}, {
               94.78}, {98.34}, {100.7}, {30.71}, {56.93}, {74.37}, {
               13.49}, {-26.85}, {-53.77}, {-71.94}, {-83.94}, {-91.94}, \
{-97.10000000000001}, {-100.85000000000001`}, {-103.22}, \
{-104.96000000000001`}, {-106.3}, {-106.91}, {-107.26}, {-107.65}, {-107.84}, \
{-107.82000000000001`}, {-107.9}, {-107.99000000000001`}, {-108.08}, \
{-107.19}, {-106.4}, {-105.89}, {-105.56}, {-105.54}, {-105.5}, {-105.16}, \
{-103.46000000000001`}, {-68.97}, {-11.43}, {27.91}, {52.83}, {
               69.32000000000001}, {80.32000000000001}, {87.14}, {
               25.22}, {-17.98}, {-46.85}, {-66.31}, {-79.32000000000001}, \
{-88.31}, {-94.03}, {-96.67}, {-98.76}, {-101.16}, {-32.1}, {13.65}, {
               44.}, {-5.59}, {-38.65}, {-60.620000000000005`}, \
{-76.32000000000001}, {-86.8}, {-93.43}, {-97.72}, {-29.400000000000002`}, {
               16.330000000000002`}, {46.7}, {66.86}, {80.15}, {88.83}, {
               94.71000000000001}, {98.73}, {
               30.28}, {-15.31}, {-45.69}, {-65.82000000000001}, {-79.37}, \
{-18.34}, {-46.68}, {-65.52}, {-78.11}, {-86.67}, {-92.38}, {-96.13}, \
{-29.52}, {14.92}, {-25.75}, {-53.02}, {0.92}, {36.9}, {
               60.910000000000004`}, {76.67}, {87.38}, {94.60000000000001}, {
               99.41}, {102.72}, {104.93}, {106.10000000000001`}, {106.55}, {
               106.38}, {
               35.22}, {-12.19}, {-43.95}, {-64.97}, {-78.8}, {-17.}, {
               24.490000000000002`}, {52.5}, {71.66}, {84.36}, {92.81}, {
               98.10000000000001}, {101.62}, {
               31.650000000000002`}, {-14.99}, {25.77}, {-18.59}, {23.34}, {
               51.35}, {70.03}, {82.66}, {91.17}, {97.14}, {
               101.07000000000001`}, {104.01}, {105.97}, {107.23}, {
               34.85}, {-13.48}, {27.84}, {55.36}, {73.65}, {85.86}, {
               93.97}, {99.38}, {102.99000000000001`}, {105.34}, {106.91}, {
               107.92}, {108.46000000000001`}, {108.94}, {109.27}, {109.47}, {
               108.32000000000001`}, {107.15}, {103.67}, {101.3}, {35.31}, {
               55.76}, {69.34}, {78.4}, {83.5}, {86.8}, {89.32000000000001}, {
               92.62}, {95.10000000000001}, {96.69}, {97.51}, {98.44}, {
               98.46000000000001}, {98.83}, {99.71000000000001}, {
               100.71000000000001`}, {101.69}, {102.}, {102.01}, {102.9}, {
               33.49}, {57.01}, {72.8}, {83.4}, {89.8}, {94.66}, {98.05}, {
               100.46000000000001`}, {101.39}, {102.07000000000001`}, {
               102.49000000000001`}, {102.71000000000001`}, {102.89}, {
               103.82000000000001`}, {103.77}, {103.21000000000001`}, {
               102.86}, {103.03}, {102.60000000000001`}, {
               102.82000000000001`}, {
               34.76}, {-10.6}, {-40.75}, {-61.660000000000004`}, {-6.86}, {
               29.76}, {-14.31}, {-43.550000000000004`}, \
{-63.050000000000004`}, {-75.75}, {-84.34}, {-89.23}, {-26.45}, {-51.24}, \
{-67.74}, {-78.71000000000001}, {-17.240000000000002`}, {23.87}, {51.52}, {
               69.97}, {82.79}, {90.11}, {95.03}, {98.28}, {
               101.10000000000001`}, {102.10000000000001`}, {102.43}, {
               41.42}, {
               1.48}, {-25.580000000000002`}, {-45.160000000000004`}, \
{-58.410000000000004`}}, HoldPattern[
               System`TradingChartDump`$layoutData$545673[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$545673[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$545673[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$545673[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$545673[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$545673 = 
           System`TradingChartDump`$length$545673; 
          System`TradingChartDump`$layoutData$545673["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$545673; 
          System`TradingChartDump`$modelData$545673["Data"] = 
           System`TradingChartDump`$data$545673; 
          System`TradingChartDump`$modelData$545673["Indicators"] = 
           System`TradingChartDump`$indicators$545673; 
          System`TradingChartDump`$layoutData$545673[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545673["ScalingFunctions"] = {
            System`TradingChartDump`$sy$545673, 
             System`TradingChartDump`$isy$545673}; 
          System`TradingChartDump`$layoutData$545673["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545673["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545673[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545673["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$545673["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$545673, 
            System`TradingChartDump`$layoutData$545673, 
            System`TradingChartDump`$indicators$545673]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$545673, 
            System`TradingChartDump`$layoutData$545673, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$545673[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$545673["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$545673[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$545673[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$545673["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$545673[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$545673 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545673["AllValues"], {1, 0} + 
              Map[
               IntegerPart, {
                System`TradingChartDump`$controlmin$545673, 
                 System`TradingChartDump`$controlmax$545673}]]]; 
          System`TradingChartDump`$plotrangemax$545673 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545673["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545673, 
                 System`TradingChartDump`$controlmax$545673}]]]; {
            System`TradingChartDump`$plotrangemin$545673, 
             System`TradingChartDump`$plotrangemax$545673} = ReplaceAll[
             
             System`TradingChartDump`$sy$545673[{
              System`TradingChartDump`$plotrangemin$545673, 
               System`TradingChartDump`$plotrangemax$545673}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$545673[
                Min[System`TradingChartDump`$lows$545673]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$545673 == 
            System`TradingChartDump`$plotrangemax$545673, {
             System`TradingChartDump`$plotrangemin$545673, 
              System`TradingChartDump`$plotrangemax$545673} = {
             System`TradingChartDump`$plotrangemin$545673 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$545673], 
              System`TradingChartDump`$plotrangemax$545673 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$545673]}]; 
          System`TradingChartDump`$newgridlines$545673 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$545673, 
            Part[System`TradingChartDump`$newgridlines$545673, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$545673, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$545673], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$545673, 1]]; 
            Part[System`TradingChartDump`$newgridlines$545673, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$545673, 1] =!= None,
                 System`TradingChartDump`$length$545673 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$545673, 
                 Part[System`TradingChartDump`$newgridlines$545673, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$545673, 1]]; 
            System`TradingChartDump`$subpricegridlines$545673 = 
             Part[System`TradingChartDump`$gridlines$545673, 2]; 
            Part[System`TradingChartDump`$newgridlines$545673, 2] = 
             If[System`TradingChartDump`$sy$545673 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545673}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545673, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545673, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$545673, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$545673, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545673}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545673, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545673, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$545673 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$545673]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"MSFT\"", "\" with \"", 
           "\"PolarizedFractalEfficiency\"", "\"(\"", "10", "\",\"", "5", 
           "\",\"", "", "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {240., -837.}, ImageScaled[{0.5, 0.5}], {450, 310}], 
     InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$545688 = 
        "Full", System`TradingChartDump`$highlightposition$545688 = Automatic,
         System`TradingChartDump`$maxohlc$545688 = 36.43`4., 
        System`TradingChartDump`$timestampstyle$545688 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$545688 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$545688 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$545688, 
        System`TradingChartDump`$subplotpoint$545688, 
        System`TradingChartDump`$ndigits$545688 = 4, 
        System`TradingChartDump`$highlightstyle$545688 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$545688 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$545688 = True, 
        System`TradingChartDump`$timestampQ$545688 = True, 
        System`TradingChartDump`$data$545688 = {{{2012, 7, 26}, {
          28.367935528120714`, 28.62997256515775, 28.232064471879287`, 28.3, 
           45301400}}, {{2012, 7, 27}, {
          28.60827956989247, 28.967338709677417`, 28.317150537634404`, 28.88, 
           44242600}}, {{2012, 7, 30}, {
          28.866734143049936`, 28.934655870445347`, 28.58534412955466, 28.76, 
           28905000}}, {{2012, 7, 31}, {
          28.609704784526638`, 28.832914828639293`, 28.464133016627077`, 28.6,
            37620900}}, {{2012, 8, 1}, {
          28.714675280516833`, 28.77290037402244, 28.3459163549813, 28.54, 
           31721800}}, {{2012, 8, 2}, {
          28.349410757108597`, 28.65998287084618, 28.11648167180541, 28.33, 
           39520500}}, {{2012, 8, 3}, {
          28.65650756302521, 29.054379831932774`, 28.60798655462185, 28.87, 
           35859400}}, {{2012, 8, 6}, {
          29.108514190317194`, 29.215245409015022`, 28.924160267111848`, 
           29.06, 27471800}}, {{2012, 8, 7}, {
          29.185588235294116`, 29.457352941176467`, 28.99147058823529, 29.37, 
           28002900}}, {{2012, 8, 8}, {
          29.31356083086054, 29.56584569732938, 29.21652818991098, 29.43, 
           26257600}}, {{2012, 8, 9}, {
          29.493245901639348`, 29.745573770491806`, 29.40590163934427, 29.6, 
           24920800}}, {{2012, 8, 10}, {
          29.59763313609467, 29.714082840236685`, 29.355029585798814`, 29.52, 
           27810300}}, {{2012, 8, 13}, {
          29.451184600197433`, 29.55792694965449, 29.26681145113524, 29.49, 
           23049100}}, {{2012, 8, 14}, {
          29.596050448058413`, 29.68395950879522, 29.31278791901759, 29.43, 
           34551400}}, {{2012, 8, 15}, {
          29.412086092715235`, 29.578145695364242`, 29.324172185430466`, 29.5,
            24351000}}, {{2012, 8, 16}, {
          29.65968810916179, 30.22630929174789, 29.561994801819363`, 30.07, 
           35787200}}, {{2012, 8, 17}, {
          30.19953398058253, 30.19953398058253, 29.87722330097088, 30.18, 
           32589900}}, {{2012, 8, 20}, {
          30.108152244632407`, 30.13745933636956, 29.873695510735203`, 30.03, 
           23737700}}, {{2012, 8, 21}, {
          30.050922077922078`, 30.24631168831169, 29.90437987012987, 30.09, 
           28822700}}, {{2012, 8, 22}, {
          29.878837590045844`, 30.044885396201707`, 29.761627373935823`, 
           29.83, 33437400}}, {{2012, 8, 23}, {
          29.68699272967614, 29.696761401189683`, 29.384163912756108`, 29.56, 
           28355600}}, {{2012, 8, 24}, {
          29.547202225130892`, 29.91837369109948, 29.478828534031415`, 29.85, 
           22943300}}, {{2012, 8, 27}, {
          30.214447702834796`, 30.243753665689148`, 29.88231345715216, 29.98, 
           34691100}}, {{2012, 8, 28}, {
          29.988377407770162`, 30.08605941887039, 29.81254978778975, 29.92, 
           23947900}}, {{2012, 8, 29}, {
          29.940000000000005`, 30.037683523654167`, 29.734864600326272`, 
           29.94, 23346800}}, {{2012, 8, 30}, {
          29.82515171503958, 29.90330474934037, 29.52230870712401, 29.62, 
           23982100}}, {{2012, 8, 31}, {
          29.895068137573006`, 30.246774821544452`, 29.68013627514601, 30.11, 
           36590100}}, {{2012, 9, 4}, {
          29.748617966436328`, 29.953780848963476`, 29.45552813425469, 29.69, 
           48556700}}, {{2012, 9, 5}, {
          29.523915761763735`, 29.8267752550181, 29.51414610069102, 29.69, 
           33650000}}, {{2012, 9, 6}, {
          29.789792663476874`, 30.629767145135563`, 29.750724082934607`, 
           30.62, 48371700}}, {{2012, 9, 7}, {
          30.317906300484655`, 30.347208400646206`, 30.01511793214863, 30.23, 
           42649100}}, {{2012, 9, 10}, {
          30.11745768229167, 30.185839843750003`, 29.804853515625005`, 30.01, 
           40524000}}, {{2012, 9, 11}, {
          29.982305943488143`, 30.197232867814222`, 29.90415069827866, 30.08, 
           25191800}}, {{2012, 9, 12}, {
          30.22630929174789, 30.46077322936972, 30.021153346328784`, 30.07, 
           32775800}}, {{2012, 9, 13}, {
          30.171163542340008`, 30.454414996767934`, 29.692566257272134`, 
           30.22, 45047300}}, {{2012, 9, 14}, {
          30.29461390579942, 30.52907721884011, 30.09922781159884, 30.49, 
           51422800}}, {{2012, 9, 17}, {
          30.47046139057994, 30.53884652355014, 30.323921819929506`, 30.49, 
           36488500}}, {{2012, 9, 18}, {
          30.381847338037208`, 30.489307248236052`, 30.31346375881976, 30.46, 
           34542700}}, {{2012, 9, 19}, {
          30.369072463768113`, 30.466753623188403`, 30.320231884057968`, 
           30.33, 48871900}}, {{2012, 9, 20}, {
          30.231605723370425`, 30.74930365659777, 30.19253418124006, 30.72, 
           45543000}}, {{2012, 9, 21}, {
          30.704459762744467`, 30.88030458480282, 30.3723084321898, 30.47, 
           102348900}}, {{2012, 9, 24}, {
          30.284925276153345`, 30.353310591293045`, 29.933229369720596`, 
           30.07, 46825900}}, {{2012, 9, 25}, {
          30.23710102007239, 30.285949325435997`, 29.660691016781836`, 29.69, 
           54266400}}, {{2012, 9, 26}, {
          29.577447795823662`, 29.890023201856145`, 29.3430162412993, 29.47, 
           54672000}}, {{2012, 9, 27}, {
          29.46976790450929, 29.694429708222817`, 29.196266578249343`, 29.46, 
           47129900}}, {{2012, 9, 28}, {
          29.480262096774194`, 29.558407258064516`, 29.050463709677416`, 
           29.07, 54229300}}, {{2012, 10, 1}, {
          29.122621227534758`, 29.288701254662598`, 28.741614106476774`, 
           28.81, 54042700}}, {{2012, 10, 2}, {
          28.98953472690492, 29.194649359406608`, 28.813722184760618`, 28.97, 
           43338900}}, {{2012, 10, 3}, {
          29.062541862022776`, 29.296995981245818`, 28.98439048894843, 29.17, 
           46655900}}, {{2012, 10, 4}, {
          29.271398601398595`, 29.329999999999995`, 28.880722610722604`, 
           29.33, 43634900}}, {{2012, 10, 5}, {
          29.531216080402007`, 29.55075376884422, 29.052542713567835`, 29.16, 
           41133900}}, {{2012, 10, 8}, {
          28.953243787777033`, 29.226756212222973`, 28.865329079919412`, 
           29.09, 29752000}}, {{2012, 10, 9}, {
          28.990710382513658`, 29.049316939890705`, 28.502322404371583`, 28.6,
            45121100}}, {{2012, 10, 10}, {
          28.476069703243613`, 28.632370600414074`, 28.280693581780536`, 
           28.31, 47227100}}, {{2012, 10, 11}, {
          28.543751295336786`, 28.573056994818653`, 28.20185146804836, 28.28, 
           41488500}}, {{2012, 10, 12}, {
          28.29535616438356, 28.637205479452053`, 28.12931506849315, 28.52, 
           46464700}}, {{2012, 10, 15}, {
          28.693226025076243`, 29.03516096238563, 28.57599118942731, 28.83, 
           42440200}}, {{2012, 10, 16}, {
          28.770922346558155`, 29.054235334011526`, 28.643919972872162`, 
           28.81, 47739400}}, {{2012, 10, 17}, {
          28.626664413653266`, 28.958850963163233`, 28.421490368367696`, 
           28.91, 44206100}}, {{2012, 10, 18}, {
          28.966542372881356`, 29.044698305084747`, 28.585532203389832`, 
           28.82, 59238500}}, {{2012, 10, 19}, {
          28.380551675977653`, 28.409860335195525`, 27.843226256983236`, 
           27.98, 90470800}}, {{2012, 10, 22}, {
          28.063053571428572`, 28.16073214285714, 27.183946428571428`, 27.35, 
           83374000}}, {{2012, 10, 23}, {
          27.126488413547236`, 27.546524064171123`, 27.116720142602496`, 27.4,
            64414800}}, {{2012, 10, 24}, {
          27.503942652329755`, 27.543010752688176`, 27.220698924731188`, 
           27.25, 53320400}}, {{2012, 10, 25}, {
          27.532772596843618`, 27.542539454806313`, 27.210466284074606`, 
           27.23, 54084300}}, {{2012, 10, 26}, {
          27.21806451612903, 27.687004608294927`, 27.198525345622116`, 27.56, 
           57790000}}, {{2012, 10, 31}, {
          27.88976874562018, 28.21213735108619, 27.840925017519268`, 27.88, 
           69464100}}, {{2012, 11, 1}, {
          28.17566395663957, 28.879078590785912`, 28.15612466124662, 28.84, 
           72047900}}, {{2012, 11, 2}, {
          28.907925423728813`, 29.08377627118644, 28.653918644067797`, 28.82, 
           57131600}}, {{2012, 11, 5}, {
          28.930232872089103`, 29.047438407019914`, 28.646986162672967`, 
           28.94, 38070800}}, {{2012, 11, 6}, {
          29.13092431346283, 29.50214333556598, 28.92577695914267, 29.17, 
           43401500}}, {{2012, 11, 7}, {
          28.849632049518576`, 29.14272008253095, 28.380691196698766`, 28.41, 
           57871800}}, {{2012, 11, 8}, {
          28.442790697674425`, 28.68697674418605, 28.13023255813954, 28.14, 
           49841800}}, {{2012, 11, 9}, {
          28.2088380159556, 28.511633714880336`, 28.14046479361776, 28.16, 
           43291200}}, {{2012, 11, 12}, {
          28.273416017009215`, 28.341803685329555`, 27.560230333097095`, 
           27.57, 61112300}}, {{2012, 11, 13}, {
          26.611059431524552`, 26.88682170542636, 26.345145810262093`, 26.68, 
           131689200}}, {{2012, 11, 14}, {
          26.823889716840533`, 26.873125931445603`, 26.390611028315945`, 
           26.43, 76086100}}, {{2012, 11, 15}, {
          26.476699174793698`, 26.565348837209303`, 26.230450112528132`, 
           26.26, 50955600}}, {{2012, 11, 16}, {
          26.267737556561087`, 26.2972850678733, 25.942714932126695`, 26.12, 
           64083300}}, {{2012, 11, 19}, {
          26.398952487841374`, 26.398952487841374`, 26.07389075944631, 26.33, 
           57179300}}, {{2012, 11, 20}, {
          26.359251216772744`, 26.39865219019094, 26.06374391613628, 26.31, 
           47070400}}, {{2012, 11, 21}, {
          26.30365120593692, 26.75665306122449, 26.264259740259742`, 26.54, 
           66360300}}, {{2012, 11, 23}, {
          26.817126353790613`, 27.348938628158844`, 26.787581227436824`, 
           27.28, 57845700}}, {{2012, 11, 26}, {
          27.127754654983573`, 27.167155896312522`, 26.763293172690766`, 
           26.98, 85198700}}, {{2012, 11, 27}, {
          26.945760709010344`, 26.96545790251108, 26.630605612998526`, 26.67, 
           45018600}}, {{2012, 11, 28}, {
          26.605244883040935`, 26.97955043859649, 26.368841374269003`, 26.95, 
           53018400}}, {{2012, 11, 29}, {
          26.697565862708718`, 26.943762523191094`, 26.451369202226346`, 
           26.54, 69551400}}, {{2012, 11, 30}, {
          26.643538692712244`, 26.7223365890308, 26.09195341848234, 26.22, 
           83690200}}, {{2012, 12, 3}, {
          26.37470298902762, 26.414097616345064`, 26.000454029511918`, 26.03, 
           53173800}}, {{2012, 12, 4}, {
          26.098028062191883`, 26.226056124383767`, 25.9404550625711, 25.97, 
           49777500}}, {{2012, 12, 5}, {
          25.984349456317954`, 26.526100487439066`, 25.86614923134608, 26.27, 
           68283800}}, {{2012, 12, 6}, {
          26.408802843247283`, 26.57625888514777, 26.211795735129066`, 26.33, 
           39182300}}, {{2012, 12, 7}, {
          26.414557823129254`, 26.414557823129254`, 25.97136054421769, 26.06, 
           46162100}}, {{2012, 12, 10}, {
          26.155783221974758`, 26.559543429844098`, 26.116391982182627`, 
           26.53, 47031100}}, {{2012, 12, 11}, {
          26.64405197657394, 27.077448755490483`, 26.64405197657394, 26.91, 
           52282800}}, {{2012, 12, 12}, {
          27.11563509544787, 27.20428046989721, 26.67240822320117, 26.83, 
           43966300}}, {{2012, 12, 13}, {
          26.90682405016599, 27.10379933603836, 26.5424197713021, 26.7, 
           45080100}}, {{2012, 12, 14}, {
          26.695412159641922`, 26.71510630361805, 26.29168220813129, 26.4, 
           42077500}}, {{2012, 12, 17}, {
          26.38469003690037, 26.80818450184502, 26.27635424354244, 26.69, 
           42046100}}, {{2012, 12, 18}, {
          26.834724238026126`, 27.208933236574747`, 26.726400580551527`, 
           27.14, 50486900}}, {{2012, 12, 19}, {
          27.274295129989014`, 27.313694617356276`, 26.8409007689491, 26.9, 
           53519900}}, {{2012, 12, 20}, {
          26.94485549132948, 27.26, 26.738041907514454`, 27.26, 52607300}}, {{
          2012, 12, 21}, {
          27.04, 27.079402550091075`, 26.59672131147541, 27.04, 98776500}}, {{
          2012, 12, 24}, {
          26.78787878787879, 26.83712121212121, 26.59090909090909, 26.65, 
           20842400}}, {{2012, 12, 26}, {
          26.617405063291137`, 26.784810126582276`, 26.292442293373043`, 
           26.45, 31631100}}, {{2012, 12, 27}, {
          26.481064540059347`, 26.678022997032638`, 26.165931008902074`, 
           26.55, 39394000}}, {{2012, 12, 28}, {
          26.307589453860636`, 26.494726930320144`, 26.149999999999995`, 
           26.15, 28239900}}, {{2012, 12, 31}, {
          26.191797079745413`, 26.369101460127293`, 25.97509172594534, 26.31, 
           42749500}}, {{2013, 1, 2}, {
          26.8356263577118, 27.30832729905865, 26.737146994931205`, 27.2, 
           52899300}}, {{2013, 1, 3}, {
          27.214282568807338`, 27.233981651376148`, 26.75135412844037, 26.84, 
           48294400}}, {{2013, 1, 4}, {
          26.862071802543007`, 26.93102468212416, 26.330149588631265`, 26.34, 
           52521100}}, {{2013, 1, 7}, {
          26.36880104908205, 26.477152491569875`, 26.240749344323717`, 26.29, 
           37110400}}, {{2013, 1, 8}, {
          26.346986817325796`, 26.386384180790955`, 26.061355932203387`, 
           26.15, 44703100}}, {{2013, 1, 9}, {
          26.319700374531838`, 26.34925093632959, 26.162097378277153`, 26.3, 
           49047900}}, {{2013, 1, 10}, {
          26.247127739984883`, 26.572139077853365`, 25.89256991685563, 26.06, 
           71431300}}, {{2013, 1, 11}, {
          26.08519567648155, 26.51847185985837, 25.87840477077898, 26.42, 
           55512100}}, {{2013, 1, 14}, {
          26.489847526961693`, 26.667103012272218`, 26.351982149497953`, 
           26.48, 48324400}}, {{2013, 1, 15}, {
          26.42572583608967, 26.878794560823223`, 26.42572583608967, 26.8, 
           48244500}}, {{2013, 1, 16}, {
          26.738332100591716`, 26.817119082840236`, 26.600454881656805`, 
           26.63, 41077400}}, {{2013, 1, 17}, {
          26.78090275229358, 27.05668990825688, 26.65285871559633, 26.84, 
           51685900}}, {{2013, 1, 18}, {
          26.692256880733947`, 26.879398165137616`, 26.633159633027525`, 
           26.84, 52167700}}, {{2013, 1, 22}, {
          26.887734806629833`, 27.035469613259668`, 26.592265193370167`, 
           26.74, 58650600}}, {{2013, 1, 23}, {
          26.786236870699025`, 27.21954364360739, 26.786236870699025`, 27.19, 
           50387700}}, {{2013, 1, 24}, {
          27.27893593919653, 27.643311617806734`, 27.052432138979373`, 27.21, 
           101739300}}, {{2013, 1, 25}, {
          27.164519368723095`, 27.804727403156384`, 26.97738163558106, 27.46, 
           81847700}}, {{2013, 1, 28}, {
          27.58849516302401, 27.80518452167682, 27.342257255463995`, 27.49, 
           56056500}}, {{2013, 1, 29}, {
          27.402848982506246`, 27.708200642627627`, 27.186147804355585`, 
           27.59, 49242600}}, {{2013, 1, 30}, {
          27.58758707360862, 27.764872531418312`, 27.341357271095156`, 27.43, 
           43580500}}, {{2013, 1, 31}, {
          27.374921675774136`, 27.55223315118397, 26.990746812386156`, 27.04, 
           50530000}}, {{2013, 2, 1}, {
          27.253909774436092`, 27.628195488721804`, 27.135714285714286`, 
           27.51, 55565900}}, {{2013, 2, 4}, {
          27.453575072886295`, 27.60133381924198, 27.010298833819242`, 27.03, 
           50540000}}, {{2013, 2, 5}, {
          27.198167272727268`, 27.237556363636358`, 26.942138181818176`, 
           27.08, 35410400}}, {{2013, 2, 6}, {
          26.969400146305773`, 27.12700073152889, 26.841349670811994`, 26.93, 
           41889600}}, {{2013, 2, 7}, {
          26.938947947214075`, 26.978346774193547`, 26.692705278592374`, 
           26.87, 38028300}}, {{2013, 2, 8}, {
          26.933049001814883`, 27.287560798548096`, 26.893658802177857`, 
           27.13, 33318500}}, {{2013, 2, 11}, {
          27.23316582914573, 27.499095477386938`, 27.085427135678394`, 27.44, 
           32247700}}, {{2013, 2, 12}, {
          27.459999999999997`, 27.57819225251076, 27.33195839311334, 27.46, 
           35990900}}, {{2013, 2, 13}, {
          27.511498394577234`, 27.688801284338204`, 27.462247591865854`, 
           27.61, 41715600}}, {{2013, 2, 14}, {
          27.501797432239663`, 27.639700427960058`, 27.45254636233952, 27.62, 
           32663200}}, {{2013, 2, 15}, {
          27.619550160656903`, 27.737750803284538`, 27.46194930382006, 27.59, 
           49650900}}, {{2013, 2, 19}, {
          27.68121212121212, 27.889714795008913`, 27.6017825311943, 27.85, 
           38781400}}, {{2013, 2, 20}, {
          27.938227484750627`, 28.007750269106566`, 27.64027269465375, 27.68, 
           44110200}}, {{2013, 2, 21}, {
          27.548272098945073`, 27.548272098945073`, 27.041797017097128`, 27.3,
            49078500}}, {{2013, 2, 22}, {
          27.49054755043228, 27.570000000000004`, 27.29191642651297, 27.57, 
           31425900}}, {{2013, 2, 25}, {
          27.7758348556814, 27.85527950310559, 27.18, 27.18, 48011800}}, {{
          2013, 2, 26}, {
          27.18993058092802, 27.408403361344536`, 27.150208257215926`, 27.18, 
           49923300}}, {{2013, 2, 27}, {
          27.232664509169368`, 27.808701905789285`, 27.143279395900755`, 
           27.62, 36394700}}, {{2013, 2, 28}, {
          27.689453237410067`, 27.7788381294964, 27.55041007194244, 27.61, 
           35840200}}, {{2013, 3, 1}, {
          27.53156350626118, 27.789796064400715`, 27.332923076923077`, 27.76, 
           34849700}}, {{2013, 3, 4}, {
          27.652131438721142`, 27.950000000000003`, 27.503197158081708`, 
           27.95, 38157500}}, {{2013, 3, 5}, {
          28.090423280423277`, 28.33865961199294, 27.961340388007052`, 28.15, 
           41432200}}, {{2013, 3, 6}, {
          28.009145603417586`, 28.029003203987184`, 27.582207191171236`, 
           27.89, 51448500}}, {{2013, 3, 7}, {
          27.910213219616203`, 28.079004975124377`, 27.810923951670222`, 
           27.94, 29196700}}, {{2013, 3, 8}, {
          28.058303571428567`, 28.137760714285708`, 27.770271428571426`, 
           27.81, 37667800}}, {{2013, 3, 11}, {
          27.74952278435594, 27.779318263365624`, 27.48136347326875, 27.68, 
           36627500}}, {{2013, 3, 12}, {
          27.650476531709067`, 27.759727696166248`, 27.451838050877825`, 
           27.72, 39255200}}, {{2013, 3, 13}, {
          27.680340257879656`, 27.829319484240685`, 27.56115687679083, 27.73, 
           29093400}}, {{2013, 3, 14}, {
          27.800995024875622`, 27.959857853589195`, 27.731492537313432`, 
           27.94, 55914800}}, {{2013, 3, 15}, {
          27.83007132667618, 27.95914407988588, 27.780427960057064`, 27.84, 
           92710300}}, {{2013, 3, 18}, {
          27.681565836298926`, 28.07871886120996, 27.612064056939495`, 27.9, 
           44809400}}, {{2013, 3, 19}, {
          27.92042583392477, 28.01971611071682, 27.831064584811926`, 27.98, 
           51901600}}, {{2013, 3, 20}, {
          28.13985875706215, 28.28879943502825, 27.980988700564975`, 28.12, 
           35447800}}, {{2013, 3, 21}, {
          27.909999999999997`, 28.158221273568124`, 27.85042689434365, 27.91, 
           34233200}}, {{2013, 3, 22}, {
          27.990424778761064`, 28.13936283185841, 27.901061946902658`, 28.05, 
           28720900}}, {{2013, 3, 25}, {
          28.099005681818188`, 28.14865056818182, 27.76142045454546, 27.96, 
           44154000}}, {{2013, 3, 26}, {
          28.03943181818182, 28.138721590909096`, 27.910355113636367`, 27.96, 
           27824300}}, {{2013, 3, 27}, {
          27.941621431089178`, 28.24943602396898, 27.88204441311244, 28.17, 
           36047400}}, {{2013, 3, 28}, {
          28.12202726319469, 28.459650471862986`, 28.06244669695911, 28.41, 
           55453800}}, {{2013, 4, 1}, {
          28.439790283117794`, 28.459650471862986`, 28.16174764068508, 28.41, 
           29201100}}, {{2013, 4, 2}, {
          28.391458333333336`, 28.64965277777778, 28.321944444444448`, 28.6, 
           28456500}}, {{2013, 4, 3}, {
          28.548669467787114`, 28.747268907563026`, 28.34014005602241, 28.36, 
           35062800}}, {{2013, 4, 4}, {
          28.191468531468526`, 28.409930069930063`, 28.072307692307685`, 28.4,
            45263200}}, {{2013, 4, 5}, {
          28.02334494773519, 28.5794425087108, 27.91411149825784, 28.5, 
           50927300}}, {{2013, 4, 8}, {
          28.529020636586218`, 28.529020636586218`, 28.270839454354668`, 
           28.39, 34759500}}, {{2013, 4, 9}, {
          28.526241134751775`, 29.608510638297872`, 28.47659574468085, 29.4, 
           77733800}}, {{2013, 4, 10}, {
          29.364924042272122`, 30.109722589167763`, 29.315270805812414`, 
           30.07, 71116700}}, {{2013, 4, 11}, {
          28.89889426399447, 28.998203178991016`, 28.531451278507255`, 28.74, 
           130923200}}, {{2013, 4, 12}, {
          28.649583188607156`, 28.818402222994095`, 28.460903091351163`, 
           28.59, 62886300}}, {{2013, 4, 15}, {
          28.450278842802366`, 28.77797838968281, 28.311254792610665`, 28.49, 
           56332900}}, {{2013, 4, 16}, {
          28.700483258543322`, 28.93882637210908, 28.501863997238523`, 28.77, 
           52797300}}, {{2013, 4, 17}, {
          28.64986125563649, 28.83854318418314, 28.40159556018037, 28.63, 
           52840700}}, {{2013, 4, 18}, {
          28.74888850295241, 28.77868009725599, 28.302014588398748`, 28.59, 
           56906600}}, {{2013, 4, 19}, {
          29.411058112193484`, 30.02668458179375, 29.40112865300638, 29.56, 
           99790700}}, {{2013, 4, 22}, {
          30.093610120012976`, 30.967615958482, 30.063814466428806`, 30.62, 
           137904000}}, {{2013, 4, 23}, {
          30.489313725490195`, 30.687941176470588`, 30.17150980392157, 30.39, 
           59126900}}, {{2013, 4, 24}, {
          30.407896725440807`, 31.69889168765743, 30.388035264483626`, 31.54, 
           90946600}}, {{2013, 4, 25}, {
          31.491584220413277`, 32.61380087664371, 31.32275516593613, 31.72, 
           110700200}}, {{2013, 4, 26}, {
          31.679238754325258`, 31.758685121107266`, 31.23235294117647, 31.57, 
           47799300}}, {{2013, 4, 29}, {
          31.575712971481146`, 32.449506286415215`, 31.545924563017483`, 
           32.38, 59116400}}, {{2013, 4, 30}, {
          32.33375226586102, 32.87993051359516, 32.05569788519637, 32.87, 
           75165200}}, {{2013, 5, 1}, {
          32.69852383863081, 32.84746943765282, 32.3708435207824, 32.49, 
           54330900}}, {{2013, 5, 2}, {
          32.40367611580218, 32.939930639324494`, 32.16534077201448, 32.93, 
           46059500}}, {{2013, 5, 3}, {
          33.00178560764407, 33.28979396834876, 32.85281576590026, 33.26, 
           46784600}}, {{2013, 5, 6}, {
          33.18234666666667, 33.66886222222222, 33.013555555555556`, 33.51, 
           40978300}}, {{2013, 5, 7}, {
          33.41765235664965, 33.55668567997598, 33.01048333833683, 33.08, 
           43078300}}, {{2013, 5, 8}, {
          32.83944225522885, 33.00825704759018, 32.422370415277356`, 32.76, 
           51595700}}, {{2013, 5, 9}, {
          32.61866197183099, 32.76760563380282, 32.36049295774649, 32.43, 
           46417800}}, {{2013, 5, 10}, {
          32.44014071581524, 32.48978892627715, 32.09260324258183, 32.46, 
           36394900}}, {{2013, 5, 13}, {
          32.382924613987285`, 32.83972146533454, 32.323342415985465`, 32.8, 
           36027600}}, {{2013, 5, 14}, {
          32.86, 33.53, 32.8, 33.53, 56870100}}, {{2013, 5, 15}, {
          33.45, 33.9, 33.43, 33.85, 46303900}}, {{2013, 5, 16}, {
          33.64, 34.15, 33.55, 34.08, 59382900}}, {{2013, 5, 17}, {
          34.13, 34.87, 34.1, 34.87, 60666700}}, {{2013, 5, 20}, {
          34.73, 35.1, 34.68, 35.08, 54020800}}, {{2013, 5, 21}, {
          35.1, 35.27, 34.72, 34.85, 48702400}}, {{2013, 5, 22}, {
          34.79, 34.84, 34.36, 34.61, 66047500}}, {{2013, 5, 23}, {
          34.23, 34.55, 33.9, 34.15, 51102700}}, {{2013, 5, 24}, {
          33.92, 34.28, 33.9, 34.27, 33174400}}, {{2013, 5, 28}, {
          34.42, 35.18, 34.41, 35.02, 48212100}}, {{2013, 5, 29}, {
          34.74, 35.02, 34.57, 34.88, 38412200}}, {{2013, 5, 30}, {
          34.849999999999994`, 35.24999999999999, 34.809999999999995`, 35.03, 
           51131000}}, {{2013, 5, 31}, {
          34.82, 35.28, 34.79, 34.9, 56165700}}, {{2013, 6, 3}, {
          34.919999999999995`, 35.629999999999995`, 34.82999999999999, 35.59, 
           51252600}}, {{2013, 6, 4}, {
          35.62, 35.74, 34.77, 34.99, 65529500}}, {{2013, 6, 5}, {
          34.6, 34.89, 34.43, 34.78, 46025100}}, {{2013, 6, 6}, {
          34.84, 35.11, 34.49, 34.96, 37618500}}, {{2013, 6, 7}, {
          35.25, 35.78, 35.06, 35.67, 40757300}}, {{2013, 6, 10}, {
          35.51, 35.65, 35.14, 35.47, 35994500}}, {{2013, 6, 11}, {
          35.05, 35.18, 34.68, 34.84, 39435900}}, {{2013, 6, 12}, {
          35.14, 35.27, 34.85, 35., 37372700}}, {{2013, 6, 13}, {
          34.99, 35.02, 34.59, 34.72, 45654900}}, {{2013, 6, 14}, {
          34.55, 34.69, 34.25, 34.4, 53192600}}, {{2013, 6, 17}, {
          34.69, 35.16, 34.63, 35., 49670100}}, {{2013, 6, 18}, {
          34.97, 35.17, 34.9, 34.98, 28616500}}, {{2013, 6, 19}, {
          34.96, 35.09, 34.59, 34.59, 30816200}}, {{2013, 6, 20}, {
          34.26, 34.33, 33.37, 33.49, 54493700}}, {{2013, 6, 21}, {
          33.66, 33.73, 33.05, 33.27, 85338500}}, {{2013, 6, 24}, {
          32.94, 34.2, 32.57, 33.72, 56109000}}, {{2013, 6, 25}, {
          34.08, 34.38, 33.46, 33.67, 44073400}}, {{2013, 6, 26}, {
          34.12, 34.48, 33.89, 34.35, 48665900}}, {{2013, 6, 27}, {
          34.52, 34.78, 34.5, 34.62, 28993100}}, {{2013, 6, 28}, {
          34.38, 34.79, 34.34, 34.54, 65545500}}, {{2013, 7, 1}, {
          34.75, 34.99, 34.33, 34.36, 31055400}}, {{2013, 7, 2}, {
          34.41, 34.44, 33.63, 33.94, 37630000}}, {{2013, 7, 3}, {
          33.66, 34.37, 33.6, 34.01, 15994400}}, {{2013, 7, 5}, {
          34.09, 34.24, 33.58, 34.21, 26085900}}, {{2013, 7, 8}, {
          34.35, 34.59, 33.98, 34.33, 32396900}}, {{2013, 7, 9}, {
          34.58, 34.6, 34.14, 34.35, 25318500}}, {{2013, 7, 10}, {
          34.34, 34.81, 34.32, 34.7, 29658800}}, {{2013, 7, 11}, {
          35., 35.77, 34.9, 35.69, 53638300}}, {{2013, 7, 12}, {
          35.58, 35.73, 35.28, 35.67, 35501200}}, {{2013, 7, 15}, {
          35.66, 36.22, 35.58, 36.17, 34142600}}, {{2013, 7, 16}, {
          36.01, 36.43, 35.96, 36.27, 36378500}}, {{2013, 7, 17}, {
          36.34, 36.39, 35.49, 35.74, 37285100}}, {{2013, 7, 18}, {
          35.72, 35.89, 35.22, 35.44, 49547100}}, {{2013, 7, 19}, {
          32.4, 32.67, 31.02, 31.4, 248428500}}, {{2013, 7, 22}, {
          31.7, 32.01, 31.6, 32.01, 79040700}}, {{2013, 7, 23}, {
          31.91, 32.04, 31.71, 31.82, 65810400}}, {{2013, 7, 24}, {
          32.04, 32.19, 31.89, 31.96, 52803100}}, {{2013, 7, 25}, {
          31.62, 31.65, 31.25, 31.39, 63213000}}}, 
        System`TradingChartDump`$markerstyle$545688 = 1, 
        System`TradingChartDump`$controlmin$545688 = 0.5, 
        System`TradingChartDump`$controlmax$545688 = 250.5, 
        System`TradingChartDump`$datescope$545688 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$545688 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$545688, 
        System`TradingChartDump`$max$545688, 
        System`TradingChartDump`$ohlclabel$545688 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545688, 
              System`TradingChartDump`$opens$545688]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545688, 
              System`TradingChartDump`$highs$545688]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545688, 
              System`TradingChartDump`$lows$545688]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545688, 
              System`TradingChartDump`$closes$545688]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545688, 
              System`TradingChartDump`$visdates$545688]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$545688 = {}, 
        System`TradingChartDump`$subpricegridlines$545688 = Automatic, 
        System`TradingChartDump`$overlaypoint$545688, 
        System`TradingChartDump`$overlayvalue$545688, 
        System`TradingChartDump`$subplotvalue$545688, 
        System`TradingChartDump`$opts$545688 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "MSFT", " with ", 
            "RelativeStrengthIndex", "(", 14, ",", Null, ",", Null, ",", Null,
             ")"}], ImageSize -> {450, 310}, AlignmentPoint -> Center, 
         AspectRatio -> GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> 
         None, AxesOrigin -> Automatic, AxesStyle -> {}, Background -> None, 
         BaselinePosition -> Automatic, BaseStyle -> {}, ColorOutput -> 
         Automatic, ContentSelectable -> Automatic, CoordinatesToolOptions -> 
         Automatic, DisplayFunction :> $DisplayFunction, Epilog -> {}, 
         FormatType :> TraditionalForm, Frame -> True, FrameLabel -> None, 
         FrameStyle -> {}, FrameTicks -> Automatic, FrameTicksStyle -> {}, 
         GridLines -> Automatic, GridLinesStyle -> {}, ImageMargins -> 0., 
         ImagePadding -> All, ImageSize -> Automatic, ImageSizeRaw -> 
         Automatic, LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, 
         PlotRange -> All, PlotRangeClipping -> False, PlotRangePadding -> 
         Automatic, PlotRegion -> Automatic, PreserveImageOptions -> 
         Automatic, Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$545688 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmgtcj+f7xyNbDokp/ORUIcmhckrnO2EhOipppcO3vt/6VsKIsIVpDtGo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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyNmglYjmnUx5ssY5K1sku2bElp0d4tkvZdi9KmRW8LsnwYvJiECUOILGPN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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$545688 = 
        System`TradingChartDump`$staticindicatorpos$545688, 
        System`TradingChartDump`$length$545688 = 250, 
        System`TradingChartDump`$gridlinesflag$545688 = True, 
        System`TradingChartDump`$opens$545688 = 
        Dispatch[{
         1 -> 28.37`4., 2 -> 28.61`4., 3 -> 28.87`4., 4 -> 28.61`4., 5 -> 
          28.71`4., 6 -> 28.35`4., 7 -> 28.66`4., 8 -> 29.11`4., 9 -> 
          29.19`4., 10 -> 29.31`4., 11 -> 29.49`4., 12 -> 29.6`4., 13 -> 
          29.45`4., 14 -> 29.6`4., 15 -> 29.41`4., 16 -> 29.66`4., 17 -> 
          30.2`4., 18 -> 30.11`4., 19 -> 30.05`4., 20 -> 29.88`4., 21 -> 
          29.69`4., 22 -> 29.55`4., 23 -> 30.21`4., 24 -> 29.99`4., 25 -> 
          29.94`4., 26 -> 29.83`4., 27 -> 29.9`4., 28 -> 29.75`4., 29 -> 
          29.52`4., 30 -> 29.79`4., 31 -> 30.32`4., 32 -> 30.12`4., 33 -> 
          29.98`4., 34 -> 30.23`4., 35 -> 30.17`4., 36 -> 30.29`4., 37 -> 
          30.47`4., 38 -> 30.38`4., 39 -> 30.37`4., 40 -> 30.23`4., 41 -> 
          30.7`4., 42 -> 30.28`4., 43 -> 30.24`4., 44 -> 29.58`4., 45 -> 
          29.47`4., 46 -> 29.48`4., 47 -> 29.12`4., 48 -> 28.99`4., 49 -> 
          29.06`4., 50 -> 29.27`4., 51 -> 29.53`4., 52 -> 28.95`4., 53 -> 
          28.99`4., 54 -> 28.48`4., 55 -> 28.54`4., 56 -> 28.3`4., 57 -> 
          28.69`4., 58 -> 28.77`4., 59 -> 28.63`4., 60 -> 28.97`4., 61 -> 
          28.38`4., 62 -> 28.06`4., 63 -> 27.13`4., 64 -> 27.5`4., 65 -> 
          27.53`4., 66 -> 27.22`4., 67 -> 27.89`4., 68 -> 28.18`4., 69 -> 
          28.91`4., 70 -> 28.93`4., 71 -> 29.13`4., 72 -> 28.85`4., 73 -> 
          28.44`4., 74 -> 28.21`4., 75 -> 28.27`4., 76 -> 26.61`4., 77 -> 
          26.82`4., 78 -> 26.48`4., 79 -> 26.27`4., 80 -> 26.4`4., 81 -> 
          26.36`4., 82 -> 26.3`4., 83 -> 26.82`4., 84 -> 27.13`4., 85 -> 
          26.95`4., 86 -> 26.61`4., 87 -> 26.7`4., 88 -> 26.64`4., 89 -> 
          26.37`4., 90 -> 26.1`4., 91 -> 25.98`4., 92 -> 26.41`4., 93 -> 
          26.41`4., 94 -> 26.16`4., 95 -> 26.64`4., 96 -> 27.12`4., 97 -> 
          26.91`4., 98 -> 26.7`4., 99 -> 26.38`4., 100 -> 26.83`4., 101 -> 
          27.27`4., 102 -> 26.94`4., 103 -> 27.04`4., 104 -> 26.79`4., 105 -> 
          26.62`4., 106 -> 26.48`4., 107 -> 26.31`4., 108 -> 26.19`4., 109 -> 
          26.84`4., 110 -> 27.21`4., 111 -> 26.86`4., 112 -> 26.37`4., 113 -> 
          26.35`4., 114 -> 26.32`4., 115 -> 26.25`4., 116 -> 26.09`4., 117 -> 
          26.49`4., 118 -> 26.43`4., 119 -> 26.74`4., 120 -> 26.78`4., 121 -> 
          26.69`4., 122 -> 26.89`4., 123 -> 26.79`4., 124 -> 27.28`4., 125 -> 
          27.16`4., 126 -> 27.59`4., 127 -> 27.4`4., 128 -> 27.59`4., 129 -> 
          27.37`4., 130 -> 27.25`4., 131 -> 27.45`4., 132 -> 27.2`4., 133 -> 
          26.97`4., 134 -> 26.94`4., 135 -> 26.93`4., 136 -> 27.23`4., 137 -> 
          27.46`4., 138 -> 27.51`4., 139 -> 27.5`4., 140 -> 27.62`4., 141 -> 
          27.68`4., 142 -> 27.94`4., 143 -> 27.55`4., 144 -> 27.49`4., 145 -> 
          27.78`4., 146 -> 27.19`4., 147 -> 27.23`4., 148 -> 27.69`4., 149 -> 
          27.53`4., 150 -> 27.65`4., 151 -> 28.09`4., 152 -> 28.01`4., 153 -> 
          27.91`4., 154 -> 28.06`4., 155 -> 27.75`4., 156 -> 27.65`4., 157 -> 
          27.68`4., 158 -> 27.8`4., 159 -> 27.83`4., 160 -> 27.68`4., 161 -> 
          27.92`4., 162 -> 28.14`4., 163 -> 27.91`4., 164 -> 27.99`4., 165 -> 
          28.1`4., 166 -> 28.04`4., 167 -> 27.94`4., 168 -> 28.12`4., 169 -> 
          28.44`4., 170 -> 28.39`4., 171 -> 28.55`4., 172 -> 28.19`4., 173 -> 
          28.02`4., 174 -> 28.53`4., 175 -> 28.53`4., 176 -> 29.36`4., 177 -> 
          28.9`4., 178 -> 28.65`4., 179 -> 28.45`4., 180 -> 28.7`4., 181 -> 
          28.65`4., 182 -> 28.75`4., 183 -> 29.41`4., 184 -> 30.09`4., 185 -> 
          30.49`4., 186 -> 30.41`4., 187 -> 31.49`4., 188 -> 31.68`4., 189 -> 
          31.58`4., 190 -> 32.33`4., 191 -> 32.7`4., 192 -> 32.4`4., 193 -> 
          33.`4., 194 -> 33.18`4., 195 -> 33.42`4., 196 -> 32.84`4., 197 -> 
          32.62`4., 198 -> 32.44`4., 199 -> 32.38`4., 200 -> 32.86`4., 201 -> 
          33.45`4., 202 -> 33.64`4., 203 -> 34.13`4., 204 -> 34.73`4., 205 -> 
          35.1`4., 206 -> 34.79`4., 207 -> 34.23`4., 208 -> 33.92`4., 209 -> 
          34.42`4., 210 -> 34.74`4., 211 -> 34.85`4., 212 -> 34.82`4., 213 -> 
          34.92`4., 214 -> 35.62`4., 215 -> 34.6`4., 216 -> 34.84`4., 217 -> 
          35.25`4., 218 -> 35.51`4., 219 -> 35.05`4., 220 -> 35.14`4., 221 -> 
          34.99`4., 222 -> 34.55`4., 223 -> 34.69`4., 224 -> 34.97`4., 225 -> 
          34.96`4., 226 -> 34.26`4., 227 -> 33.66`4., 228 -> 32.94`4., 229 -> 
          34.08`4., 230 -> 34.12`4., 231 -> 34.52`4., 232 -> 34.38`4., 233 -> 
          34.75`4., 234 -> 34.41`4., 235 -> 33.66`4., 236 -> 34.09`4., 237 -> 
          34.35`4., 238 -> 34.58`4., 239 -> 34.34`4., 240 -> 35.`4., 241 -> 
          35.58`4., 242 -> 35.66`4., 243 -> 36.01`4., 244 -> 36.34`4., 245 -> 
          35.72`4., 246 -> 32.4`4., 247 -> 31.7`4., 248 -> 31.91`4., 249 -> 
          32.04`4., 250 -> 31.62`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {183}, {},
             {155}, {140}, {}, {190}, {}, {}, {}, {}, {}, {}, {}, {}, {
            64}, {}, {114}, {99, 151}, {}, {}}]}], 
        System`TradingChartDump`$highs$545688 = 
        Dispatch[{
         1 -> 28.63`4., 2 -> 28.97`4., 3 -> 28.93`4., 4 -> 28.83`4., 5 -> 
          28.77`4., 6 -> 28.66`4., 7 -> 29.05`4., 8 -> 29.22`4., 9 -> 
          29.46`4., 10 -> 29.57`4., 11 -> 29.75`4., 12 -> 29.71`4., 13 -> 
          29.56`4., 14 -> 29.68`4., 15 -> 29.58`4., 16 -> 30.23`4., 17 -> 
          30.2`4., 18 -> 30.14`4., 19 -> 30.25`4., 20 -> 30.04`4., 21 -> 
          29.7`4., 22 -> 29.92`4., 23 -> 30.24`4., 24 -> 30.09`4., 25 -> 
          30.04`4., 26 -> 29.9`4., 27 -> 30.25`4., 28 -> 29.95`4., 29 -> 
          29.83`4., 30 -> 30.63`4., 31 -> 30.35`4., 32 -> 30.19`4., 33 -> 
          30.2`4., 34 -> 30.46`4., 35 -> 30.45`4., 36 -> 30.53`4., 37 -> 
          30.54`4., 38 -> 30.49`4., 39 -> 30.47`4., 40 -> 30.75`4., 41 -> 
          30.88`4., 42 -> 30.35`4., 43 -> 30.29`4., 44 -> 29.89`4., 45 -> 
          29.69`4., 46 -> 29.56`4., 47 -> 29.29`4., 48 -> 29.19`4., 49 -> 
          29.3`4., 50 -> 29.33`4., 51 -> 29.55`4., 52 -> 29.23`4., 53 -> 
          29.05`4., 54 -> 28.63`4., 55 -> 28.57`4., 56 -> 28.64`4., 57 -> 
          29.04`4., 58 -> 29.05`4., 59 -> 28.96`4., 60 -> 29.04`4., 61 -> 
          28.41`4., 62 -> 28.16`4., 63 -> 27.55`4., 64 -> 27.54`4., 65 -> 
          27.54`4., 66 -> 27.69`4., 67 -> 28.21`4., 68 -> 28.88`4., 69 -> 
          29.08`4., 70 -> 29.05`4., 71 -> 29.5`4., 72 -> 29.14`4., 73 -> 
          28.69`4., 74 -> 28.51`4., 75 -> 28.34`4., 76 -> 26.89`4., 77 -> 
          26.87`4., 78 -> 26.57`4., 79 -> 26.3`4., 80 -> 26.4`4., 81 -> 
          26.4`4., 82 -> 26.76`4., 83 -> 27.35`4., 84 -> 27.17`4., 85 -> 
          26.97`4., 86 -> 26.98`4., 87 -> 26.94`4., 88 -> 26.72`4., 89 -> 
          26.41`4., 90 -> 26.23`4., 91 -> 26.53`4., 92 -> 26.58`4., 93 -> 
          26.41`4., 94 -> 26.56`4., 95 -> 27.08`4., 96 -> 27.2`4., 97 -> 
          27.1`4., 98 -> 26.72`4., 99 -> 26.81`4., 100 -> 27.21`4., 101 -> 
          27.31`4., 102 -> 27.26`4., 103 -> 27.08`4., 104 -> 26.84`4., 105 -> 
          26.78`4., 106 -> 26.68`4., 107 -> 26.49`4., 108 -> 26.37`4., 109 -> 
          27.31`4., 110 -> 27.23`4., 111 -> 26.93`4., 112 -> 26.48`4., 113 -> 
          26.39`4., 114 -> 26.35`4., 115 -> 26.57`4., 116 -> 26.52`4., 117 -> 
          26.67`4., 118 -> 26.88`4., 119 -> 26.82`4., 120 -> 27.06`4., 121 -> 
          26.88`4., 122 -> 27.04`4., 123 -> 27.22`4., 124 -> 27.64`4., 125 -> 
          27.8`4., 126 -> 27.81`4., 127 -> 27.71`4., 128 -> 27.76`4., 129 -> 
          27.55`4., 130 -> 27.63`4., 131 -> 27.6`4., 132 -> 27.24`4., 133 -> 
          27.13`4., 134 -> 26.98`4., 135 -> 27.29`4., 136 -> 27.5`4., 137 -> 
          27.58`4., 138 -> 27.69`4., 139 -> 27.64`4., 140 -> 27.74`4., 141 -> 
          27.89`4., 142 -> 28.01`4., 143 -> 27.55`4., 144 -> 27.57`4., 145 -> 
          27.86`4., 146 -> 27.41`4., 147 -> 27.81`4., 148 -> 27.78`4., 149 -> 
          27.79`4., 150 -> 27.95`4., 151 -> 28.34`4., 152 -> 28.03`4., 153 -> 
          28.08`4., 154 -> 28.14`4., 155 -> 27.78`4., 156 -> 27.76`4., 157 -> 
          27.83`4., 158 -> 27.96`4., 159 -> 27.96`4., 160 -> 28.08`4., 161 -> 
          28.02`4., 162 -> 28.29`4., 163 -> 28.16`4., 164 -> 28.14`4., 165 -> 
          28.15`4., 166 -> 28.14`4., 167 -> 28.25`4., 168 -> 28.46`4., 169 -> 
          28.46`4., 170 -> 28.65`4., 171 -> 28.75`4., 172 -> 28.41`4., 173 -> 
          28.58`4., 174 -> 28.53`4., 175 -> 29.61`4., 176 -> 30.11`4., 177 -> 
          29.`4., 178 -> 28.82`4., 179 -> 28.78`4., 180 -> 28.94`4., 181 -> 
          28.84`4., 182 -> 28.78`4., 183 -> 30.03`4., 184 -> 30.97`4., 185 -> 
          30.69`4., 186 -> 31.7`4., 187 -> 32.61`4., 188 -> 31.76`4., 189 -> 
          32.45`4., 190 -> 32.88`4., 191 -> 32.85`4., 192 -> 32.94`4., 193 -> 
          33.29`4., 194 -> 33.67`4., 195 -> 33.56`4., 196 -> 33.01`4., 197 -> 
          32.77`4., 198 -> 32.49`4., 199 -> 32.84`4., 200 -> 33.53`4., 201 -> 
          33.9`4., 202 -> 34.15`4., 203 -> 34.87`4., 204 -> 35.1`4., 205 -> 
          35.27`4., 206 -> 34.84`4., 207 -> 34.55`4., 208 -> 34.28`4., 209 -> 
          35.18`4., 210 -> 35.02`4., 211 -> 35.25`4., 212 -> 35.28`4., 213 -> 
          35.63`4., 214 -> 35.74`4., 215 -> 34.89`4., 216 -> 35.11`4., 217 -> 
          35.78`4., 218 -> 35.65`4., 219 -> 35.18`4., 220 -> 35.27`4., 221 -> 
          35.02`4., 222 -> 34.69`4., 223 -> 35.16`4., 224 -> 35.17`4., 225 -> 
          35.09`4., 226 -> 34.33`4., 227 -> 33.73`4., 228 -> 34.2`4., 229 -> 
          34.38`4., 230 -> 34.48`4., 231 -> 34.78`4., 232 -> 34.79`4., 233 -> 
          34.99`4., 234 -> 34.44`4., 235 -> 34.37`4., 236 -> 34.24`4., 237 -> 
          34.59`4., 238 -> 34.6`4., 239 -> 34.81`4., 240 -> 35.77`4., 241 -> 
          35.73`4., 242 -> 36.22`4., 243 -> 36.43`4., 244 -> 36.39`4., 245 -> 
          35.89`4., 246 -> 32.67`4., 247 -> 32.01`4., 248 -> 32.04`4., 249 -> 
          32.19`4., 250 -> 31.65`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$545688 = 
        Dispatch[{
         1 -> 28.23`4., 2 -> 28.32`4., 3 -> 28.59`4., 4 -> 28.46`4., 5 -> 
          28.35`4., 6 -> 28.12`4., 7 -> 28.61`4., 8 -> 28.92`4., 9 -> 
          28.99`4., 10 -> 29.22`4., 11 -> 29.41`4., 12 -> 29.36`4., 13 -> 
          29.27`4., 14 -> 29.31`4., 15 -> 29.32`4., 16 -> 29.56`4., 17 -> 
          29.88`4., 18 -> 29.87`4., 19 -> 29.9`4., 20 -> 29.76`4., 21 -> 
          29.38`4., 22 -> 29.48`4., 23 -> 29.88`4., 24 -> 29.81`4., 25 -> 
          29.73`4., 26 -> 29.52`4., 27 -> 29.68`4., 28 -> 29.46`4., 29 -> 
          29.51`4., 30 -> 29.75`4., 31 -> 30.02`4., 32 -> 29.8`4., 33 -> 
          29.9`4., 34 -> 30.02`4., 35 -> 29.69`4., 36 -> 30.1`4., 37 -> 
          30.32`4., 38 -> 30.31`4., 39 -> 30.32`4., 40 -> 30.19`4., 41 -> 
          30.37`4., 42 -> 29.93`4., 43 -> 29.66`4., 44 -> 29.34`4., 45 -> 
          29.2`4., 46 -> 29.05`4., 47 -> 28.74`4., 48 -> 28.81`4., 49 -> 
          28.98`4., 50 -> 28.88`4., 51 -> 29.05`4., 52 -> 28.87`4., 53 -> 
          28.5`4., 54 -> 28.28`4., 55 -> 28.2`4., 56 -> 28.13`4., 57 -> 
          28.58`4., 58 -> 28.64`4., 59 -> 28.42`4., 60 -> 28.59`4., 61 -> 
          27.84`4., 62 -> 27.18`4., 63 -> 27.12`4., 64 -> 27.22`4., 65 -> 
          27.21`4., 66 -> 27.2`4., 67 -> 27.84`4., 68 -> 28.16`4., 69 -> 
          28.65`4., 70 -> 28.65`4., 71 -> 28.93`4., 72 -> 28.38`4., 73 -> 
          28.13`4., 74 -> 28.14`4., 75 -> 27.56`4., 76 -> 26.35`4., 77 -> 
          26.39`4., 78 -> 26.23`4., 79 -> 25.94`4., 80 -> 26.07`4., 81 -> 
          26.06`4., 82 -> 26.26`4., 83 -> 26.79`4., 84 -> 26.76`4., 85 -> 
          26.63`4., 86 -> 26.37`4., 87 -> 26.45`4., 88 -> 26.09`4., 89 -> 
          26.`4., 90 -> 25.94`4., 91 -> 25.87`4., 92 -> 26.21`4., 93 -> 
          25.97`4., 94 -> 26.12`4., 95 -> 26.64`4., 96 -> 26.67`4., 97 -> 
          26.54`4., 98 -> 26.29`4., 99 -> 26.28`4., 100 -> 26.73`4., 101 -> 
          26.84`4., 102 -> 26.74`4., 103 -> 26.6`4., 104 -> 26.59`4., 105 -> 
          26.29`4., 106 -> 26.17`4., 107 -> 26.15`4., 108 -> 25.98`4., 109 -> 
          26.74`4., 110 -> 26.75`4., 111 -> 26.33`4., 112 -> 26.24`4., 113 -> 
          26.06`4., 114 -> 26.16`4., 115 -> 25.89`4., 116 -> 25.88`4., 117 -> 
          26.35`4., 118 -> 26.43`4., 119 -> 26.6`4., 120 -> 26.65`4., 121 -> 
          26.63`4., 122 -> 26.59`4., 123 -> 26.79`4., 124 -> 27.05`4., 125 -> 
          26.98`4., 126 -> 27.34`4., 127 -> 27.19`4., 128 -> 27.34`4., 129 -> 
          26.99`4., 130 -> 27.14`4., 131 -> 27.01`4., 132 -> 26.94`4., 133 -> 
          26.84`4., 134 -> 26.69`4., 135 -> 26.89`4., 136 -> 27.09`4., 137 -> 
          27.33`4., 138 -> 27.46`4., 139 -> 27.45`4., 140 -> 27.46`4., 141 -> 
          27.6`4., 142 -> 27.64`4., 143 -> 27.04`4., 144 -> 27.29`4., 145 -> 
          27.18`4., 146 -> 27.15`4., 147 -> 27.14`4., 148 -> 27.55`4., 149 -> 
          27.33`4., 150 -> 27.5`4., 151 -> 27.96`4., 152 -> 27.58`4., 153 -> 
          27.81`4., 154 -> 27.77`4., 155 -> 27.48`4., 156 -> 27.45`4., 157 -> 
          27.56`4., 158 -> 27.73`4., 159 -> 27.78`4., 160 -> 27.61`4., 161 -> 
          27.83`4., 162 -> 27.98`4., 163 -> 27.85`4., 164 -> 27.9`4., 165 -> 
          27.76`4., 166 -> 27.91`4., 167 -> 27.88`4., 168 -> 28.06`4., 169 -> 
          28.16`4., 170 -> 28.32`4., 171 -> 28.34`4., 172 -> 28.07`4., 173 -> 
          27.91`4., 174 -> 28.27`4., 175 -> 28.48`4., 176 -> 29.32`4., 177 -> 
          28.53`4., 178 -> 28.46`4., 179 -> 28.31`4., 180 -> 28.5`4., 181 -> 
          28.4`4., 182 -> 28.3`4., 183 -> 29.4`4., 184 -> 30.06`4., 185 -> 
          30.17`4., 186 -> 30.39`4., 187 -> 31.32`4., 188 -> 31.23`4., 189 -> 
          31.55`4., 190 -> 32.06`4., 191 -> 32.37`4., 192 -> 32.17`4., 193 -> 
          32.85`4., 194 -> 33.01`4., 195 -> 33.01`4., 196 -> 32.42`4., 197 -> 
          32.36`4., 198 -> 32.09`4., 199 -> 32.32`4., 200 -> 32.8`4., 201 -> 
          33.43`4., 202 -> 33.55`4., 203 -> 34.1`4., 204 -> 34.68`4., 205 -> 
          34.72`4., 206 -> 34.36`4., 207 -> 33.9`4., 208 -> 33.9`4., 209 -> 
          34.41`4., 210 -> 34.57`4., 211 -> 34.81`4., 212 -> 34.79`4., 213 -> 
          34.83`4., 214 -> 34.77`4., 215 -> 34.43`4., 216 -> 34.49`4., 217 -> 
          35.06`4., 218 -> 35.14`4., 219 -> 34.68`4., 220 -> 34.85`4., 221 -> 
          34.59`4., 222 -> 34.25`4., 223 -> 34.63`4., 224 -> 34.9`4., 225 -> 
          34.59`4., 226 -> 33.37`4., 227 -> 33.05`4., 228 -> 32.57`4., 229 -> 
          33.46`4., 230 -> 33.89`4., 231 -> 34.5`4., 232 -> 34.34`4., 233 -> 
          34.33`4., 234 -> 33.63`4., 235 -> 33.6`4., 236 -> 33.58`4., 237 -> 
          33.98`4., 238 -> 34.14`4., 239 -> 34.32`4., 240 -> 34.9`4., 241 -> 
          35.28`4., 242 -> 35.58`4., 243 -> 35.96`4., 244 -> 35.49`4., 245 -> 
          35.22`4., 246 -> 31.02`4., 247 -> 31.6`4., 248 -> 31.71`4., 249 -> 
          31.89`4., 250 -> 31.25`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$545688 = 
        Dispatch[{
         1 -> 28.3`4., 2 -> 28.88`4., 3 -> 28.76`4., 4 -> 28.6`4., 5 -> 
          28.54`4., 6 -> 28.33`4., 7 -> 28.87`4., 8 -> 29.06`4., 9 -> 
          29.37`4., 10 -> 29.43`4., 11 -> 29.6`4., 12 -> 29.52`4., 13 -> 
          29.49`4., 14 -> 29.43`4., 15 -> 29.5`4., 16 -> 30.07`4., 17 -> 
          30.18`4., 18 -> 30.03`4., 19 -> 30.09`4., 20 -> 29.83`4., 21 -> 
          29.56`4., 22 -> 29.85`4., 23 -> 29.98`4., 24 -> 29.92`4., 25 -> 
          29.94`4., 26 -> 29.62`4., 27 -> 30.11`4., 28 -> 29.69`4., 29 -> 
          29.69`4., 30 -> 30.62`4., 31 -> 30.23`4., 32 -> 30.01`4., 33 -> 
          30.08`4., 34 -> 30.07`4., 35 -> 30.22`4., 36 -> 30.49`4., 37 -> 
          30.49`4., 38 -> 30.46`4., 39 -> 30.33`4., 40 -> 30.72`4., 41 -> 
          30.47`4., 42 -> 30.07`4., 43 -> 29.69`4., 44 -> 29.47`4., 45 -> 
          29.46`4., 46 -> 29.07`4., 47 -> 28.81`4., 48 -> 28.97`4., 49 -> 
          29.17`4., 50 -> 29.33`4., 51 -> 29.16`4., 52 -> 29.09`4., 53 -> 
          28.6`4., 54 -> 28.31`4., 55 -> 28.28`4., 56 -> 28.52`4., 57 -> 
          28.83`4., 58 -> 28.81`4., 59 -> 28.91`4., 60 -> 28.82`4., 61 -> 
          27.98`4., 62 -> 27.35`4., 63 -> 27.4`4., 64 -> 27.25`4., 65 -> 
          27.23`4., 66 -> 27.56`4., 67 -> 27.88`4., 68 -> 28.84`4., 69 -> 
          28.82`4., 70 -> 28.94`4., 71 -> 29.17`4., 72 -> 28.41`4., 73 -> 
          28.14`4., 74 -> 28.16`4., 75 -> 27.57`4., 76 -> 26.68`4., 77 -> 
          26.43`4., 78 -> 26.26`4., 79 -> 26.12`4., 80 -> 26.33`4., 81 -> 
          26.31`4., 82 -> 26.54`4., 83 -> 27.28`4., 84 -> 26.98`4., 85 -> 
          26.67`4., 86 -> 26.95`4., 87 -> 26.54`4., 88 -> 26.22`4., 89 -> 
          26.03`4., 90 -> 25.97`4., 91 -> 26.27`4., 92 -> 26.33`4., 93 -> 
          26.06`4., 94 -> 26.53`4., 95 -> 26.91`4., 96 -> 26.83`4., 97 -> 
          26.7`4., 98 -> 26.4`4., 99 -> 26.69`4., 100 -> 27.14`4., 101 -> 
          26.9`4., 102 -> 27.26`4., 103 -> 27.04`4., 104 -> 26.65`4., 105 -> 
          26.45`4., 106 -> 26.55`4., 107 -> 26.15`4., 108 -> 26.31`4., 109 -> 
          27.2`4., 110 -> 26.84`4., 111 -> 26.34`4., 112 -> 26.29`4., 113 -> 
          26.15`4., 114 -> 26.3`4., 115 -> 26.06`4., 116 -> 26.42`4., 117 -> 
          26.48`4., 118 -> 26.8`4., 119 -> 26.63`4., 120 -> 26.84`4., 121 -> 
          26.84`4., 122 -> 26.74`4., 123 -> 27.19`4., 124 -> 27.21`4., 125 -> 
          27.46`4., 126 -> 27.49`4., 127 -> 27.59`4., 128 -> 27.43`4., 129 -> 
          27.04`4., 130 -> 27.51`4., 131 -> 27.03`4., 132 -> 27.08`4., 133 -> 
          26.93`4., 134 -> 26.87`4., 135 -> 27.13`4., 136 -> 27.44`4., 137 -> 
          27.46`4., 138 -> 27.61`4., 139 -> 27.62`4., 140 -> 27.59`4., 141 -> 
          27.85`4., 142 -> 27.68`4., 143 -> 27.3`4., 144 -> 27.57`4., 145 -> 
          27.18`4., 146 -> 27.18`4., 147 -> 27.62`4., 148 -> 27.61`4., 149 -> 
          27.76`4., 150 -> 27.95`4., 151 -> 28.15`4., 152 -> 27.89`4., 153 -> 
          27.94`4., 154 -> 27.81`4., 155 -> 27.68`4., 156 -> 27.72`4., 157 -> 
          27.73`4., 158 -> 27.94`4., 159 -> 27.84`4., 160 -> 27.9`4., 161 -> 
          27.98`4., 162 -> 28.12`4., 163 -> 27.91`4., 164 -> 28.05`4., 165 -> 
          27.96`4., 166 -> 27.96`4., 167 -> 28.17`4., 168 -> 28.41`4., 169 -> 
          28.41`4., 170 -> 28.6`4., 171 -> 28.36`4., 172 -> 28.4`4., 173 -> 
          28.5`4., 174 -> 28.39`4., 175 -> 29.4`4., 176 -> 30.07`4., 177 -> 
          28.74`4., 178 -> 28.59`4., 179 -> 28.49`4., 180 -> 28.77`4., 181 -> 
          28.63`4., 182 -> 28.59`4., 183 -> 29.56`4., 184 -> 30.62`4., 185 -> 
          30.39`4., 186 -> 31.54`4., 187 -> 31.72`4., 188 -> 31.57`4., 189 -> 
          32.38`4., 190 -> 32.87`4., 191 -> 32.49`4., 192 -> 32.93`4., 193 -> 
          33.26`4., 194 -> 33.51`4., 195 -> 33.08`4., 196 -> 32.76`4., 197 -> 
          32.43`4., 198 -> 32.46`4., 199 -> 32.8`4., 200 -> 33.53`4., 201 -> 
          33.85`4., 202 -> 34.08`4., 203 -> 34.87`4., 204 -> 35.08`4., 205 -> 
          34.85`4., 206 -> 34.61`4., 207 -> 34.15`4., 208 -> 34.27`4., 209 -> 
          35.02`4., 210 -> 34.88`4., 211 -> 35.03`4., 212 -> 34.9`4., 213 -> 
          35.59`4., 214 -> 34.99`4., 215 -> 34.78`4., 216 -> 34.96`4., 217 -> 
          35.67`4., 218 -> 35.47`4., 219 -> 34.84`4., 220 -> 35.`4., 221 -> 
          34.72`4., 222 -> 34.4`4., 223 -> 35.`4., 224 -> 34.98`4., 225 -> 
          34.59`4., 226 -> 33.49`4., 227 -> 33.27`4., 228 -> 33.72`4., 229 -> 
          33.67`4., 230 -> 34.35`4., 231 -> 34.62`4., 232 -> 34.54`4., 233 -> 
          34.36`4., 234 -> 33.94`4., 235 -> 34.01`4., 236 -> 34.21`4., 237 -> 
          34.33`4., 238 -> 34.35`4., 239 -> 34.7`4., 240 -> 35.69`4., 241 -> 
          35.67`4., 242 -> 36.17`4., 243 -> 36.27`4., 244 -> 35.74`4., 245 -> 
          35.44`4., 246 -> 31.4`4., 247 -> 32.01`4., 248 -> 31.82`4., 249 -> 
          31.96`4., 250 -> 31.39`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$545688 = True, 
        System`TradingChartDump`$gridlines$545688 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$545688, 
        System`TradingChartDump`$plotrangemin$545688 = 25.337956692913384`, 
        System`TradingChartDump`$plotrangemax$545688 = 37.48638507686539, 
        System`TradingChartDump`$layoutData$545688, 
        System`TradingChartDump`$gridlinesscope$545688 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$545688 = {True, True}, 
        System`TradingChartDump`$indicators$545688 = {
         FinancialIndicator["RelativeStrengthIndex", 14]}, 
        System`TradingChartDump`$mouseQ$545688 = False, 
        System`TradingChartDump`$modelData$545688 = 
        System`TradingChartDump`modelData$544218, 
        System`TradingChartDump`$sy$545688 = Identity, 
        System`TradingChartDump`$isy$545688 = Identity, 
        System`TradingChartDump`$appearance$545688 = Automatic, 
        System`TradingChartDump`$perfgoal$545688 = "Quality", 
        System`TradingChartDump`$axesorigin$545688 = Automatic, 
        System`TradingChartDump`$framestyle$545688 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$545688 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$545688 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$545688 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$545688 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$545688, 
        System`TradingChartDump`$newgridlines$545688 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{25.337956692913384`, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$545688 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$545688 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$545688 = "GraphicsFrame", 
        System`TradingChartDump`$frame$545688 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$545688 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$545688 = 
              Switch[System`TradingChartDump`$highlightposition$545688, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$545688], {
                 1, System`TradingChartDump`$length$545688}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$545688], {
                 1, System`TradingChartDump`$length$545688}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$545688, 
                   Charting`nearestDate[System`TradingChartDump`$dates$545688, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$545688]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$545688]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$545688, 
                    Floor[System`TradingChartDump`$controlmin$545688] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$545688, 
                    Floor[System`TradingChartDump`$controlmax$545688]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$545688 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$545688 = 
            If[System`TradingChartDump`$fastpos$545688 =!= True, 
              System`TradingChartDump`$fastpos$545688 = 
               Clip[System`TradingChartDump`$fastpos$545688, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$545688 = (
                  Floor[System`TradingChartDump`$controlmax$545688] - Floor[
                  System`TradingChartDump`$controlmin$545688]) (
                  System`TradingChartDump`$fastpos$545688/100) + 
                Floor[System`TradingChartDump`$controlmin$545688]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$545688], {
                Floor[System`TradingChartDump`$controlmin$545688] + 1, 
                 Floor[System`TradingChartDump`$controlmax$545688]}], 
              System`TradingChartDump`$staticindicatorpos$545688]; 
           System`TradingChartDump`$mouseQ$545688 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$545688]], 
              System`TradingChartDump`$highlightposition$545688 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$545688 = If[
              And[
              System`TradingChartDump`$bouncingballQ$545688, 
               System`TradingChartDump`$mouseQ$545688, 
               System`TradingChartDump`$appearance$545688 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$545688[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$545688]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$545688[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$545688, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$545688[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$545688]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$545688[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$545688[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545688, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545688[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545688, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545688, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545688[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545688[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$545688 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$545688, 
                 System`TradingChartDump`$defaultframeticksstyle$545688, 
                 System`TradingChartDump`$defaultlabelstyle$545688, 
                 System`TradingChartDump`$framestyle$545688, 
                 System`TradingChartDump`$frameticksstyle$545688, 
                 System`TradingChartDump`$labelstyle$545688}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545688 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$545688, 
                 System`TradingChartDump`$labelstyle$545688, 
                 System`TradingChartDump`$defaultframeticksstyle$545688, 
                 System`TradingChartDump`$defaultlabelstyle$545688}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545688 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545688, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$545688 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545688, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$545688 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545688, {}, Infinity]; 
           If[
            System`TradingChartDump`$tickstextstyle$545688 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$545688 = 
             Part[System`TradingChartDump`$tickstextstyle$545688, 1], 
             System`TradingChartDump`$tickstextstyle$545688 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545688[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545688, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545688[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545688[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545688[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$545688[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545688, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$545688]], 
                    Style[":", System`TradingChartDump`$textstyle$545688]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$545688[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545688]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545688[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$545688[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$545688, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$545688]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$545688[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545688, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545688[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545688, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545688, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$545688[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545688[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545688[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$545688[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$545688[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$545688], 1], 
                   Floor[System`TradingChartDump`$controlmax$545688]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$545688[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$545688[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$545688[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$545688[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$545688[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545688[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$545688[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$545688[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$545688[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545688[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$545688[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$545688[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$545688[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$545688[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$545688[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$545688, 
                  System`TradingChartDump`$mouseQ$545688], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$545688 - 0.5, 
                   System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$545688 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$545688 + 0.5, 
                    System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545688, 1]}, {
                    System`TradingChartDump`$indicatorpos$545688 + 0.5, 
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$545688[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$545688, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$545688[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545688]]], {}]; 
              System`TradingChartDump`$subplotgridlines$545688[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$545688[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$545688[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545688[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$545688 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$545688, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545688, 
                   System`TradingChartDump`$opens$545688]], 12, 
                 System`TradingChartDump`$textstyle$545688, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$545688, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545688, 
                   System`TradingChartDump`$highs$545688]], 12, 
                 System`TradingChartDump`$textstyle$545688, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$545688, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545688, 
                   System`TradingChartDump`$lows$545688]], 12, 
                 System`TradingChartDump`$textstyle$545688, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$545688, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545688, 
                   System`TradingChartDump`$closes$545688]], 12, 
                 System`TradingChartDump`$textstyle$545688, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545688, 
                   System`TradingChartDump`$visdates$545688]], 12, 
                 System`TradingChartDump`$textstyle$545688, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$545688, 
                  System`TradingChartDump`$mouseQ$545688], {{
                  System`TradingChartDump`$timestampstyle$545688, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$545688 - 0.5, 
                    System`TradingChartDump`$plotrangemin$545688}, 
                    If[
                    System`TradingChartDump`$timestampdepth$545688 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$545688[1]}, {
                    System`TradingChartDump`$indicatorpos$545688 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545688}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545688, 1]}, {
                    System`TradingChartDump`$indicatorpos$545688 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545688}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$545688, {
               System`TradingChartDump`$highlightstyle$545688, 
                Dynamic[System`TradingChartDump`$ohlcpoint$545688]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$545688[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545688, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$545688[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$545688[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$545688, Length[
                    System`TradingChartDump`$layoutData$545688[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$545688}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$545688] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$545688] + 0.5}, {
                System`TradingChartDump`$plotrangemin$545688, 
                 System`TradingChartDump`$plotrangemax$545688}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$545688, Left, {
                 False, System`TradingChartDump`$frame$545688}, 
                 Blank[], {System`TradingChartDump`$frame$545688, False}], {
                False, System`TradingChartDump`$frame$545688}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$545688, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$545688]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$545688 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           387.02286107677577`}, {-286.9226415094339, -65.7679245283018}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545688 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545688, 1]], 
               Part[System`TradingChartDump`$framestyle$545688, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$545688]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$545688} -> 
                   System`TradingChartDump`$isy$545688[
                    System`TradingChartDump`$plotrangemin$545688], {
                    0, System`TradingChartDump`$plotrangemax$545688} -> 
                   System`TradingChartDump`$isy$545688[
                    System`TradingChartDump`$plotrangemax$545688]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$545688[
                   System`TradingChartDump`$plotrangemin$545688], 
                   System`TradingChartDump`$isy$545688[
                   System`TradingChartDump`$plotrangemax$545688]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$545688, 
                   System`TradingChartDump`$isy$545688}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545688, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545688 > 
                    System`TradingChartDump`$plotrangemin$545688, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545688 > 
                    System`TradingChartDump`$plotrangemin$545688, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545688, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545688 > 
                    System`TradingChartDump`$plotrangemin$545688, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545688 > 
                    System`TradingChartDump`$plotrangemin$545688, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545688, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545688, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545688 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545688,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545688], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545688 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545688, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545688]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$545688, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$545688[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$545688[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545688, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$545688[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$545688, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545688[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545688, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545688[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545688[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545688[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545688[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545688], 
                    Style[":", System`TradingChartDump`$textstyle$545688]], 
                    Style[":", System`TradingChartDump`$textstyle$545688]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$545688[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545688]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545688[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$545688}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$545688, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$545688 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$545688[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$545688, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$545688, Left, {
                    False, System`TradingChartDump`$frame$545688}, 
                    Blank[], {
                    System`TradingChartDump`$frame$545688, False}], {
                   System`TradingChartDump`$frame$545688, 
                    System`TradingChartDump`$frame$545688}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$545688, 
                    System`TradingChartDump`$controlmax$545688}] + 0.5, {
                   System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$545688]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$545688) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$545688 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$545688 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$545688, 1]], 
                   Part[System`TradingChartDump`$framestyle$545688, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$545688]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545688[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545688[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$545688[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545688, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545688, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$545688, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$545688, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$545688 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
545688, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$545688], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$545688 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$545688, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$545688]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$545688, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$545688) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$545688 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$545688[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           475.9407855006933}, {-55.98962264150938, -0.70094339622635}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$545688, 
              Dynamic[System`TradingChartDump`$ohlclabel$545688], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$545688}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545688 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545688, 2]], 
               Part[System`TradingChartDump`$framestyle$545688, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$545688]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$545688, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$545688, 
                    System`TradingChartDump`$controlmax$545688}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$545688] + 
                    0.5, System`TradingChartDump`$plotrangemin$545688}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$545688], 
                    System`TradingChartDump`$plotrangemin$545688}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$545688, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545688, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545688, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545688 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545688, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545688], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545688 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545688,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545688]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$545688] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$545688[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$545688] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$545688[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$545688] = {HoldPattern[
               System`TradingChartDump`$min$545688[1]] :> 
             26.740000000000002`}}, {
          DownValues[System`TradingChartDump`$max$545688] = {HoldPattern[
               System`TradingChartDump`$max$545688[1]] :> 79.53}}, {
          DownValues[System`TradingChartDump`$subplotvalue$545688] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$545688[1, 1]] :> 
             Invisible[32.43]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$545688] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$545688[1]] :> {
              50}}}, {DownValues[
            System`TradingChartDump`$layoutData$545688] = {HoldPattern[
               System`TradingChartDump`$layoutData$545688["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "AllValues"]] :> CompressedData["
1:eJxVVgk8VVv7Fo1Cg6GuSlKZKhS5nb323uc5XE1mGZtHXEMpypdyQyFSEn2K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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545688["AppendedAdjust"]] :> 
             5.278008600398912, HoldPattern[
               System`TradingChartDump`$layoutData$545688["AppendedBox"]] :> {
              22.733204194004696`, 103.38254174895773`}, HoldPattern[
               System`TradingChartDump`$layoutData$545688["AppendedMin"]] :> 
             24.105941810394302`, HoldPattern[
               System`TradingChartDump`$layoutData$545688["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$545688["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$545688["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$545688["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545688["DataMax"]] :> 
             36.43, HoldPattern[
               System`TradingChartDump`$layoutData$545688["DataMin"]] :> 
             25.86614923134608, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "MainChartAllValues"]] :> CompressedData["
1:eJxdlglYzdv6x1OZ0mBocEISmtBAOvZv2t9dJ1NzGs1jdRqIoiuiolJSGtwo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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "MainChartPoints"]] :> CompressedData["
1:eJxdlltoXFUUhqdFUIKgYkSRUqdVSqylVGNtmzbJTmqaNEmTTO6XSXLmfp9U
pCiRyqFShCIEn0QRGS/4IhTBlyAqscUnKyIoVRCZIoiQIgWplD6Zk/V/D+cc
CMOftf/9r9tee+9Jr4zn7onFYne3/nbob2eM71b3D9e2vuETTv9wN1ZbL/ff
AN/nrt5uS65dAT/o3ns3+MCtruX6x2c7L4EfcwF7dRK8yz1xcTOx/gc47tau
bG34QKfwXrMvgZ9yAb21Dt4nPXCbC5bvvgje7zoDB86DD0T4B+3XBx9y41vs
zYe6hJ+19QfBz7mBIAH3gttdEF7Lo+DnLb6f2e+wxbMGfsH8/Q18xL0WEO6C
j7qbgfub4GPupSCAW+AOy8cH4OMuGQjsQv+Erf8ce2cEd4nP+m7T7wA7q+dO
Yd9ZPK3Ye8L58XtcABNHsfcq39gjOHbS/Re0yznsJ9UP2F+0/daxC7+KvS+i
3xeJ75TWC/unpIe9X3zs/VafH+m/AePfEfYHrB7PwD8tf+Gfdk9vFwD7oPoB
+2DkPAyZ3ij7D1k/9WMfVv9iH1Y/YT8T9tc/Y/p/Yx+x+H7CPqL+Oi77qPkz
J+yPuvz2h33Mfp2wG1N/sH5M/Sy8MaZ5AD9h8V+XvktE/Emon4U3EpH8jls8
Rfjj7pNguyfhy94Gf9z2fxv9CTuvlzvEF64L+xPW373CGxN2HnYLxyZVX/iT
qhf8Sc0z+JOqH/pTyjf8KYvvM/hTrj34/oU/Fd4vNq3zBH9a8wa+7HeOiT9t
/dIHfybi/4zmKfwZ2+9N9GfUP/Bn1W/wZ83fL+DPql/gz+r8wZ9TveifOVv/
F/w55Z/+mbP4W8jfvK3/FP15038Z/rzbvo/eQl/r96G/EK6XWzB+O/27oP6E
LzwDP2n+DMJPhvf3k6Y/DD8Zzm9s0epdgb9o/bAKf9H41+Av2vn5EP5S2D8X
wf6SzdOv4S9Z/g+Rv2Wbd4fJv/A54l/WPCb/y7b/O/A9nRfhuBeuj/OsfheE
PU/9yf6e7gvhhvb7B3893ffCTc/i34N+yuI5i34q7L9L2X33Pvop3Wfop8Lx
NFK6b4k3pfkg3Eypnuinw/Mkntb9j34Ee+mIfjrsXyOt9xH6aZ1/9NPqL+Z3
xs7Pn+hnNC/Rz2j+o58Jx+NndH+in7H++xL9yH7NjPqL+LM6r+hnw/eHy2pe
yl8vq/mBftbyeb/sjazV7zb6EdzMav4Tfy48/+MR7HLh+9TLWb6T3A85zSf0
c/o/90XO8psRbrKe+ycffl/E8zpv6OfVX+jLfh79vM3j79DP63yjH+E385H3
YSH8PosX5K+wK+i+6JZ+QfUW9gvqX+FGQfPBSb9geivCTel1CceK5t8rwvGi
/Bd2wt8Ke0X5I+zLnhJuaL8j6Bf1nkC/qPyjX7J4r6Jfsn66iX5J86hH+iXF
I+zLfkm4IX5VeKNk52VEuFmy8/iwcKxs53WvcFz4grAraz6hXzZ/30C/rPsK
/bL19/foly3fr6Mvfgb9iu4L9Ct2Xn5Bv2L9/hX6Fd036Ff0i77WJ9Gv6D5E
P7I+VlU/o1+1/YfQr5r/31D/quXnI+pfNb3fqX9V/lP/qtXjAPpV3dfo1/Se
Qb+meYt+Te8f9GvWbzuIv2b5e5z4a9YP+4m/FtGv6T2Mft32/xX9eiT/wo/0
Sr+ufhH267rf0Nd+6+jX1e86n826/Kf/V/Relj2+onkp7FbUL93ufxyzRGk=

              "], HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545688["NewSubplot"]] :> {
               FinancialIndicator["RelativeStrengthIndex", 14]}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545688["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545688["PlotRangeMin"]] :> 
             24.105941810394302`, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$545688["Space"]] :> 
             3.6430000000000002`, HoldPattern[
               System`TradingChartDump`$layoutData$545688["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, 30}, {250., 30}}], 
                    Line[{{0, 50}, {250., 50}}], 
                    Line[{{0, 70}, {250., 70}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJxdV3lU02cWjSJzcJ8qLq2AQauoIBjFxgXxyhoQFAg7SH5ZCIRAcKkr1kYH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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "SubplotIndicatorGridLines"]] :> {{25, 50, 75, 100}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "RSI"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["RelativeStrengthIndex", 14]}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "SubplotIndicatorParameters"]] :> {{{14}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "SubplotIndicatorPoints"]] :> {{{}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {{29., 56.31}}, {{30., 67.36}}, {{31., 60.46}}, {{32., 
                56.910000000000004`}}, {{33., 57.76}}, {{34., 57.59}}, {{35., 
                59.56}}, {{36., 62.910000000000004`}}, {{37., 
                62.910000000000004`}}, {{38., 62.24}}, {{39., 59.32}}, {{40., 
                64.68}}, {{41., 59.29}}, {{42., 51.85}}, {{43., 45.95}}, {{
                44., 42.9}}, {{45., 42.76}}, {{46., 37.65}}, {{47., 
                34.67}}, {{48., 37.93}}, {{49., 41.82}}, {{50., 44.81}}, {{
                51., 42.32}}, {{52., 41.31}}, {{53., 34.980000000000004`}}, {{
                54., 31.87}}, {{55., 31.55}}, {{56., 36.89}}, {{57., 
                43.07}}, {{58., 42.77}}, {{59., 44.78}}, {{60., 43.31}}, {{
                61., 32.55}}, {{62., 27.11}}, {{63., 28.14}}, {{64., 
                26.91}}, {{65., 26.740000000000002`}}, {{66., 34.03}}, {{67., 
                40.230000000000004`}}, {{68., 54.15}}, {{69., 
                53.870000000000005`}}, {{70., 55.370000000000005`}}, {{71., 
                58.18}}, {{72., 47.54}}, {{73., 44.43}}, {{74., 44.72}}, {{
                75., 38.39}}, {{76., 31.220000000000002`}}, {{77., 29.55}}, {{
                78., 28.43}}, {{79., 27.51}}, {{80., 31.11}}, {{81., 
                30.95}}, {{82., 35.03}}, {{83., 46.07}}, {{84., 42.89}}, {{
                85., 39.83}}, {{86., 43.74}}, {{87., 39.67}}, {{88., 
                36.800000000000004`}}, {{89., 35.17}}, {{90., 34.65}}, {{91., 
                39.480000000000004`}}, {{92., 40.43}}, {{93., 37.58}}, {{94., 
                44.87}}, {{95., 49.96}}, {{96., 48.94}}, {{97., 47.24}}, {{
                98., 43.5}}, {{99., 47.81}}, {{100., 53.7}}, {{101., 
                50.43}}, {{102., 54.870000000000005`}}, {{103., 51.82}}, {{
                104., 46.84}}, {{105., 44.480000000000004`}}, {{106., 
                45.94}}, {{107., 41.25}}, {{108., 43.72}}, {{109., 55.07}}, {{
                110., 50.63}}, {{111., 45.17}}, {{112., 44.65}}, {{113., 
                43.160000000000004`}}, {{114., 45.27}}, {{115., 
                42.550000000000004`}}, {{116., 47.64}}, {{117., 48.46}}, {{
                118., 52.71}}, {{119., 50.33}}, {{120., 53.14}}, {{121., 
                53.14}}, {{122., 51.53}}, {{123., 57.730000000000004`}}, {{
                124., 57.99}}, {{125., 61.17}}, {{126., 
                61.550000000000004`}}, {{127., 62.84}}, {{128., 59.4}}, {{
                129., 51.93}}, {{130., 58.68}}, {{131., 50.83}}, {{132., 
                51.56}}, {{133., 49.21}}, {{134., 48.26}}, {{135., 52.53}}, {{
                136., 57.07}}, {{137., 57.35}}, {{138., 59.51}}, {{139., 
                59.660000000000004`}}, {{140., 58.97}}, {{141., 62.97}}, {{
                142., 58.92}}, {{143., 51.04}}, {{144., 55.59}}, {{145., 
                48.57}}, {{146., 48.57}}, {{147., 55.86}}, {{148., 55.67}}, {{
                149., 58.01}}, {{150., 60.84}}, {{151., 
                63.620000000000005`}}, {{152., 57.870000000000005`}}, {{153., 
                58.64}}, {{154., 55.78}}, {{155., 52.99}}, {{156., 53.75}}, {{
                157., 53.96}}, {{158., 58.1}}, {{159., 55.54}}, {{160., 
                56.77}}, {{161., 58.42}}, {{162., 61.22}}, {{163., 55.22}}, {{
                164., 58.160000000000004`}}, {{165., 55.63}}, {{166., 
                55.63}}, {{167., 60.31}}, {{168., 64.86}}, {{169., 64.86}}, {{
                170., 68.21000000000001}}, {{171., 60.38}}, {{172., 
                61.18}}, {{173., 63.18}}, {{174., 59.550000000000004`}}, {{
                175., 74.22}}, {{176., 79.53}}, {{177., 
                55.230000000000004`}}, {{178., 53.25}}, {{179., 51.92}}, {{
                180., 55.29}}, {{181., 53.28}}, {{182., 52.69}}, {{183., 
                63.31}}, {{184., 70.98}}, {{185., 67.67}}, {{186., 74.15}}, {{
                187., 75.}}, {{188., 72.86}}, {{189., 76.72}}, {{190., 
                78.69}}, {{191., 73.49}}, {{192., 75.51}}, {{193., 76.93}}, {{
                194., 77.97}}, {{195., 71.95}}, {{196., 67.76}}, {{197., 
                63.65}}, {{198., 63.86}}, {{199., 66.29}}, {{200., 70.83}}, {{
                201., 72.58}}, {{202., 73.79}}, {{203., 77.47}}, {{204., 
                78.35000000000001}}, {{205., 74.93}}, {{206., 71.42}}, {{207.,
                 65.14}}, {{208., 65.98}}, {{209., 70.73}}, {{210., 68.8}}, {{
                211., 69.75}}, {{212., 67.82000000000001}}, {{213., 
                72.22}}, {{214., 64.02}}, {{215., 61.39}}, {{216., 
                62.800000000000004`}}, {{217., 67.8}}, {{218., 65.14}}, {{
                219., 57.51}}, {{220., 58.83}}, {{221., 55.57}}, {{222., 
                52.03}}, {{223., 57.5}}, {{224., 57.27}}, {{225., 52.75}}, {{
                226., 42.56}}, {{227., 40.86}}, {{228., 45.64}}, {{229., 
                45.21}}, {{230., 51.95}}, {{231., 54.35}}, {{232., 53.5}}, {{
                233., 51.54}}, {{234., 47.19}}, {{235., 
                47.980000000000004`}}, {{236., 50.26}}, {{237., 51.63}}, {{
                238., 51.870000000000005`}}, {{239., 55.96}}, {{240., 
                65.01}}, {{241., 64.72}}, {{242., 68.5}}, {{243., 
                69.21000000000001}}, {{244., 61.32}}, {{245., 57.34}}, {{246.,
                 29.53}}, {{247., 34.68}}, {{248., 33.85}}, {{249., 
                35.08}}, {{250., 32.43}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "SubplotIndicatorValues"]] :> {{{""}, {""}, {""}, {""}, {""}, {
                ""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {
                ""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {
                ""}, {""}, {""}, {56.31}, {67.36}, {60.46}, {
                56.910000000000004`}, {57.76}, {57.59}, {59.56}, {
                62.910000000000004`}, {62.910000000000004`}, {62.24}, {
                59.32}, {64.68}, {59.29}, {51.85}, {45.95}, {42.9}, {42.76}, {
                37.65}, {34.67}, {37.93}, {41.82}, {44.81}, {42.32}, {
                41.31}, {34.980000000000004`}, {31.87}, {31.55}, {36.89}, {
                43.07}, {42.77}, {44.78}, {43.31}, {32.55}, {27.11}, {
                28.14}, {26.91}, {26.740000000000002`}, {34.03}, {
                40.230000000000004`}, {54.15}, {53.870000000000005`}, {
                55.370000000000005`}, {58.18}, {47.54}, {44.43}, {44.72}, {
                38.39}, {31.220000000000002`}, {29.55}, {28.43}, {27.51}, {
                31.11}, {30.95}, {35.03}, {46.07}, {42.89}, {39.83}, {
                43.74}, {39.67}, {36.800000000000004`}, {35.17}, {34.65}, {
                39.480000000000004`}, {40.43}, {37.58}, {44.87}, {49.96}, {
                48.94}, {47.24}, {43.5}, {47.81}, {53.7}, {50.43}, {
                54.870000000000005`}, {51.82}, {46.84}, {
                44.480000000000004`}, {45.94}, {41.25}, {43.72}, {55.07}, {
                50.63}, {45.17}, {44.65}, {43.160000000000004`}, {45.27}, {
                42.550000000000004`}, {47.64}, {48.46}, {52.71}, {50.33}, {
                53.14}, {53.14}, {51.53}, {57.730000000000004`}, {57.99}, {
                61.17}, {61.550000000000004`}, {62.84}, {59.4}, {51.93}, {
                58.68}, {50.83}, {51.56}, {49.21}, {48.26}, {52.53}, {
                57.07}, {57.35}, {59.51}, {59.660000000000004`}, {58.97}, {
                62.97}, {58.92}, {51.04}, {55.59}, {48.57}, {48.57}, {
                55.86}, {55.67}, {58.01}, {60.84}, {63.620000000000005`}, {
                57.870000000000005`}, {58.64}, {55.78}, {52.99}, {53.75}, {
                53.96}, {58.1}, {55.54}, {56.77}, {58.42}, {61.22}, {55.22}, {
                58.160000000000004`}, {55.63}, {55.63}, {60.31}, {64.86}, {
                64.86}, {68.21000000000001}, {60.38}, {61.18}, {63.18}, {
                59.550000000000004`}, {74.22}, {79.53}, {
                55.230000000000004`}, {53.25}, {51.92}, {55.29}, {53.28}, {
                52.69}, {63.31}, {70.98}, {67.67}, {74.15}, {75.}, {72.86}, {
                76.72}, {78.69}, {73.49}, {75.51}, {76.93}, {77.97}, {
                71.95}, {67.76}, {63.65}, {63.86}, {66.29}, {70.83}, {
                72.58}, {73.79}, {77.47}, {78.35000000000001}, {74.93}, {
                71.42}, {65.14}, {65.98}, {70.73}, {68.8}, {69.75}, {
                67.82000000000001}, {72.22}, {64.02}, {61.39}, {
                62.800000000000004`}, {67.8}, {65.14}, {57.51}, {58.83}, {
                55.57}, {52.03}, {57.5}, {57.27}, {52.75}, {42.56}, {40.86}, {
                45.64}, {45.21}, {51.95}, {54.35}, {53.5}, {51.54}, {47.19}, {
                47.980000000000004`}, {50.26}, {51.63}, {
                51.870000000000005`}, {55.96}, {65.01}, {64.72}, {68.5}, {
                69.21000000000001}, {61.32}, {57.34}, {29.53}, {34.68}, {
                33.85}, {35.08}, {32.43}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$545688["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$545688["YRange"]] :> 36.43,
              HoldPattern[
               System`TradingChartDump`$layoutData$545688[
               "SubplotPoints", {
                1}]] :> {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {56.31}, {
               67.36}, {60.46}, {56.910000000000004`}, {57.76}, {57.59}, {
               59.56}, {62.910000000000004`}, {62.910000000000004`}, {
               62.24}, {59.32}, {64.68}, {59.29}, {51.85}, {45.95}, {42.9}, {
               42.76}, {37.65}, {34.67}, {37.93}, {41.82}, {44.81}, {42.32}, {
               41.31}, {34.980000000000004`}, {31.87}, {31.55}, {36.89}, {
               43.07}, {42.77}, {44.78}, {43.31}, {32.55}, {27.11}, {28.14}, {
               26.91}, {26.740000000000002`}, {34.03}, {
               40.230000000000004`}, {54.15}, {53.870000000000005`}, {
               55.370000000000005`}, {58.18}, {47.54}, {44.43}, {44.72}, {
               38.39}, {31.220000000000002`}, {29.55}, {28.43}, {27.51}, {
               31.11}, {30.95}, {35.03}, {46.07}, {42.89}, {39.83}, {43.74}, {
               39.67}, {36.800000000000004`}, {35.17}, {34.65}, {
               39.480000000000004`}, {40.43}, {37.58}, {44.87}, {49.96}, {
               48.94}, {47.24}, {43.5}, {47.81}, {53.7}, {50.43}, {
               54.870000000000005`}, {51.82}, {46.84}, {
               44.480000000000004`}, {45.94}, {41.25}, {43.72}, {55.07}, {
               50.63}, {45.17}, {44.65}, {43.160000000000004`}, {45.27}, {
               42.550000000000004`}, {47.64}, {48.46}, {52.71}, {50.33}, {
               53.14}, {53.14}, {51.53}, {57.730000000000004`}, {57.99}, {
               61.17}, {61.550000000000004`}, {62.84}, {59.4}, {51.93}, {
               58.68}, {50.83}, {51.56}, {49.21}, {48.26}, {52.53}, {57.07}, {
               57.35}, {59.51}, {59.660000000000004`}, {58.97}, {62.97}, {
               58.92}, {51.04}, {55.59}, {48.57}, {48.57}, {55.86}, {55.67}, {
               58.01}, {60.84}, {63.620000000000005`}, {
               57.870000000000005`}, {58.64}, {55.78}, {52.99}, {53.75}, {
               53.96}, {58.1}, {55.54}, {56.77}, {58.42}, {61.22}, {55.22}, {
               58.160000000000004`}, {55.63}, {55.63}, {60.31}, {64.86}, {
               64.86}, {68.21000000000001}, {60.38}, {61.18}, {63.18}, {
               59.550000000000004`}, {74.22}, {79.53}, {
               55.230000000000004`}, {53.25}, {51.92}, {55.29}, {53.28}, {
               52.69}, {63.31}, {70.98}, {67.67}, {74.15}, {75.}, {72.86}, {
               76.72}, {78.69}, {73.49}, {75.51}, {76.93}, {77.97}, {71.95}, {
               67.76}, {63.65}, {63.86}, {66.29}, {70.83}, {72.58}, {73.79}, {
               77.47}, {78.35000000000001}, {74.93}, {71.42}, {65.14}, {
               65.98}, {70.73}, {68.8}, {69.75}, {67.82000000000001}, {
               72.22}, {64.02}, {61.39}, {62.800000000000004`}, {67.8}, {
               65.14}, {57.51}, {58.83}, {55.57}, {52.03}, {57.5}, {57.27}, {
               52.75}, {42.56}, {40.86}, {45.64}, {45.21}, {51.95}, {54.35}, {
               53.5}, {51.54}, {47.19}, {47.980000000000004`}, {50.26}, {
               51.63}, {51.870000000000005`}, {55.96}, {65.01}, {64.72}, {
               68.5}, {69.21000000000001}, {61.32}, {57.34}, {29.53}, {
               34.68}, {33.85}, {35.08}, {32.43}}, HoldPattern[
               System`TradingChartDump`$layoutData$545688[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$545688[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$545688[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$545688[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$545688[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$545688 = 
           System`TradingChartDump`$length$545688; 
          System`TradingChartDump`$layoutData$545688["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$545688; 
          System`TradingChartDump`$modelData$545688["Data"] = 
           System`TradingChartDump`$data$545688; 
          System`TradingChartDump`$modelData$545688["Indicators"] = 
           System`TradingChartDump`$indicators$545688; 
          System`TradingChartDump`$layoutData$545688[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545688["ScalingFunctions"] = {
            System`TradingChartDump`$sy$545688, 
             System`TradingChartDump`$isy$545688}; 
          System`TradingChartDump`$layoutData$545688["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545688["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545688[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545688["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$545688["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$545688, 
            System`TradingChartDump`$layoutData$545688, 
            System`TradingChartDump`$indicators$545688]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$545688, 
            System`TradingChartDump`$layoutData$545688, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$545688[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$545688["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$545688[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$545688[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$545688["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$545688[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$545688 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545688["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545688, 
                 System`TradingChartDump`$controlmax$545688}]]]; 
          System`TradingChartDump`$plotrangemax$545688 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545688["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545688, 
                 System`TradingChartDump`$controlmax$545688}]]]; {
            System`TradingChartDump`$plotrangemin$545688, 
             System`TradingChartDump`$plotrangemax$545688} = ReplaceAll[
             
             System`TradingChartDump`$sy$545688[{
              System`TradingChartDump`$plotrangemin$545688, 
               System`TradingChartDump`$plotrangemax$545688}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$545688[
                Min[System`TradingChartDump`$lows$545688]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$545688 == 
            System`TradingChartDump`$plotrangemax$545688, {
             System`TradingChartDump`$plotrangemin$545688, 
              System`TradingChartDump`$plotrangemax$545688} = {
             System`TradingChartDump`$plotrangemin$545688 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$545688], 
              System`TradingChartDump`$plotrangemax$545688 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$545688]}]; 
          System`TradingChartDump`$newgridlines$545688 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$545688, 
            Part[System`TradingChartDump`$newgridlines$545688, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$545688, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$545688], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$545688, 1]]; 
            Part[System`TradingChartDump`$newgridlines$545688, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$545688, 1] =!= None,
                 System`TradingChartDump`$length$545688 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$545688, 
                 Part[System`TradingChartDump`$newgridlines$545688, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$545688, 1]]; 
            System`TradingChartDump`$subpricegridlines$545688 = 
             Part[System`TradingChartDump`$gridlines$545688, 2]; 
            Part[System`TradingChartDump`$newgridlines$545688, 2] = 
             If[System`TradingChartDump`$sy$545688 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545688}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545688, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545688, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$545688, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$545688, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545688}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545688, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545688, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$545688 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$545688]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"MSFT\"", "\" with \"", 
           "\"RelativeStrengthIndex\"", "\"(\"", "14", "\",\"", "", "\",\"", 
           "", "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {720., -837.}, 
      ImageScaled[{0.5, 0.5}], {450, 310}]}, {InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$545702 = 
        "Full", System`TradingChartDump`$highlightposition$545702 = Automatic,
         System`TradingChartDump`$maxohlc$545702 = 36.43`4., 
        System`TradingChartDump`$timestampstyle$545702 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$545702 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$545702 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$545702, 
        System`TradingChartDump`$subplotpoint$545702, 
        System`TradingChartDump`$ndigits$545702 = 4, 
        System`TradingChartDump`$highlightstyle$545702 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$545702 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$545702 = True, 
        System`TradingChartDump`$timestampQ$545702 = True, 
        System`TradingChartDump`$data$545702 = {{{2012, 7, 26}, {
          28.367935528120714`, 28.62997256515775, 28.232064471879287`, 28.3, 
           45301400}}, {{2012, 7, 27}, {
          28.60827956989247, 28.967338709677417`, 28.317150537634404`, 28.88, 
           44242600}}, {{2012, 7, 30}, {
          28.866734143049936`, 28.934655870445347`, 28.58534412955466, 28.76, 
           28905000}}, {{2012, 7, 31}, {
          28.609704784526638`, 28.832914828639293`, 28.464133016627077`, 28.6,
            37620900}}, {{2012, 8, 1}, {
          28.714675280516833`, 28.77290037402244, 28.3459163549813, 28.54, 
           31721800}}, {{2012, 8, 2}, {
          28.349410757108597`, 28.65998287084618, 28.11648167180541, 28.33, 
           39520500}}, {{2012, 8, 3}, {
          28.65650756302521, 29.054379831932774`, 28.60798655462185, 28.87, 
           35859400}}, {{2012, 8, 6}, {
          29.108514190317194`, 29.215245409015022`, 28.924160267111848`, 
           29.06, 27471800}}, {{2012, 8, 7}, {
          29.185588235294116`, 29.457352941176467`, 28.99147058823529, 29.37, 
           28002900}}, {{2012, 8, 8}, {
          29.31356083086054, 29.56584569732938, 29.21652818991098, 29.43, 
           26257600}}, {{2012, 8, 9}, {
          29.493245901639348`, 29.745573770491806`, 29.40590163934427, 29.6, 
           24920800}}, {{2012, 8, 10}, {
          29.59763313609467, 29.714082840236685`, 29.355029585798814`, 29.52, 
           27810300}}, {{2012, 8, 13}, {
          29.451184600197433`, 29.55792694965449, 29.26681145113524, 29.49, 
           23049100}}, {{2012, 8, 14}, {
          29.596050448058413`, 29.68395950879522, 29.31278791901759, 29.43, 
           34551400}}, {{2012, 8, 15}, {
          29.412086092715235`, 29.578145695364242`, 29.324172185430466`, 29.5,
            24351000}}, {{2012, 8, 16}, {
          29.65968810916179, 30.22630929174789, 29.561994801819363`, 30.07, 
           35787200}}, {{2012, 8, 17}, {
          30.19953398058253, 30.19953398058253, 29.87722330097088, 30.18, 
           32589900}}, {{2012, 8, 20}, {
          30.108152244632407`, 30.13745933636956, 29.873695510735203`, 30.03, 
           23737700}}, {{2012, 8, 21}, {
          30.050922077922078`, 30.24631168831169, 29.90437987012987, 30.09, 
           28822700}}, {{2012, 8, 22}, {
          29.878837590045844`, 30.044885396201707`, 29.761627373935823`, 
           29.83, 33437400}}, {{2012, 8, 23}, {
          29.68699272967614, 29.696761401189683`, 29.384163912756108`, 29.56, 
           28355600}}, {{2012, 8, 24}, {
          29.547202225130892`, 29.91837369109948, 29.478828534031415`, 29.85, 
           22943300}}, {{2012, 8, 27}, {
          30.214447702834796`, 30.243753665689148`, 29.88231345715216, 29.98, 
           34691100}}, {{2012, 8, 28}, {
          29.988377407770162`, 30.08605941887039, 29.81254978778975, 29.92, 
           23947900}}, {{2012, 8, 29}, {
          29.940000000000005`, 30.037683523654167`, 29.734864600326272`, 
           29.94, 23346800}}, {{2012, 8, 30}, {
          29.82515171503958, 29.90330474934037, 29.52230870712401, 29.62, 
           23982100}}, {{2012, 8, 31}, {
          29.895068137573006`, 30.246774821544452`, 29.68013627514601, 30.11, 
           36590100}}, {{2012, 9, 4}, {
          29.748617966436328`, 29.953780848963476`, 29.45552813425469, 29.69, 
           48556700}}, {{2012, 9, 5}, {
          29.523915761763735`, 29.8267752550181, 29.51414610069102, 29.69, 
           33650000}}, {{2012, 9, 6}, {
          29.789792663476874`, 30.629767145135563`, 29.750724082934607`, 
           30.62, 48371700}}, {{2012, 9, 7}, {
          30.317906300484655`, 30.347208400646206`, 30.01511793214863, 30.23, 
           42649100}}, {{2012, 9, 10}, {
          30.11745768229167, 30.185839843750003`, 29.804853515625005`, 30.01, 
           40524000}}, {{2012, 9, 11}, {
          29.982305943488143`, 30.197232867814222`, 29.90415069827866, 30.08, 
           25191800}}, {{2012, 9, 12}, {
          30.22630929174789, 30.46077322936972, 30.021153346328784`, 30.07, 
           32775800}}, {{2012, 9, 13}, {
          30.171163542340008`, 30.454414996767934`, 29.692566257272134`, 
           30.22, 45047300}}, {{2012, 9, 14}, {
          30.29461390579942, 30.52907721884011, 30.09922781159884, 30.49, 
           51422800}}, {{2012, 9, 17}, {
          30.47046139057994, 30.53884652355014, 30.323921819929506`, 30.49, 
           36488500}}, {{2012, 9, 18}, {
          30.381847338037208`, 30.489307248236052`, 30.31346375881976, 30.46, 
           34542700}}, {{2012, 9, 19}, {
          30.369072463768113`, 30.466753623188403`, 30.320231884057968`, 
           30.33, 48871900}}, {{2012, 9, 20}, {
          30.231605723370425`, 30.74930365659777, 30.19253418124006, 30.72, 
           45543000}}, {{2012, 9, 21}, {
          30.704459762744467`, 30.88030458480282, 30.3723084321898, 30.47, 
           102348900}}, {{2012, 9, 24}, {
          30.284925276153345`, 30.353310591293045`, 29.933229369720596`, 
           30.07, 46825900}}, {{2012, 9, 25}, {
          30.23710102007239, 30.285949325435997`, 29.660691016781836`, 29.69, 
           54266400}}, {{2012, 9, 26}, {
          29.577447795823662`, 29.890023201856145`, 29.3430162412993, 29.47, 
           54672000}}, {{2012, 9, 27}, {
          29.46976790450929, 29.694429708222817`, 29.196266578249343`, 29.46, 
           47129900}}, {{2012, 9, 28}, {
          29.480262096774194`, 29.558407258064516`, 29.050463709677416`, 
           29.07, 54229300}}, {{2012, 10, 1}, {
          29.122621227534758`, 29.288701254662598`, 28.741614106476774`, 
           28.81, 54042700}}, {{2012, 10, 2}, {
          28.98953472690492, 29.194649359406608`, 28.813722184760618`, 28.97, 
           43338900}}, {{2012, 10, 3}, {
          29.062541862022776`, 29.296995981245818`, 28.98439048894843, 29.17, 
           46655900}}, {{2012, 10, 4}, {
          29.271398601398595`, 29.329999999999995`, 28.880722610722604`, 
           29.33, 43634900}}, {{2012, 10, 5}, {
          29.531216080402007`, 29.55075376884422, 29.052542713567835`, 29.16, 
           41133900}}, {{2012, 10, 8}, {
          28.953243787777033`, 29.226756212222973`, 28.865329079919412`, 
           29.09, 29752000}}, {{2012, 10, 9}, {
          28.990710382513658`, 29.049316939890705`, 28.502322404371583`, 28.6,
            45121100}}, {{2012, 10, 10}, {
          28.476069703243613`, 28.632370600414074`, 28.280693581780536`, 
           28.31, 47227100}}, {{2012, 10, 11}, {
          28.543751295336786`, 28.573056994818653`, 28.20185146804836, 28.28, 
           41488500}}, {{2012, 10, 12}, {
          28.29535616438356, 28.637205479452053`, 28.12931506849315, 28.52, 
           46464700}}, {{2012, 10, 15}, {
          28.693226025076243`, 29.03516096238563, 28.57599118942731, 28.83, 
           42440200}}, {{2012, 10, 16}, {
          28.770922346558155`, 29.054235334011526`, 28.643919972872162`, 
           28.81, 47739400}}, {{2012, 10, 17}, {
          28.626664413653266`, 28.958850963163233`, 28.421490368367696`, 
           28.91, 44206100}}, {{2012, 10, 18}, {
          28.966542372881356`, 29.044698305084747`, 28.585532203389832`, 
           28.82, 59238500}}, {{2012, 10, 19}, {
          28.380551675977653`, 28.409860335195525`, 27.843226256983236`, 
           27.98, 90470800}}, {{2012, 10, 22}, {
          28.063053571428572`, 28.16073214285714, 27.183946428571428`, 27.35, 
           83374000}}, {{2012, 10, 23}, {
          27.126488413547236`, 27.546524064171123`, 27.116720142602496`, 27.4,
            64414800}}, {{2012, 10, 24}, {
          27.503942652329755`, 27.543010752688176`, 27.220698924731188`, 
           27.25, 53320400}}, {{2012, 10, 25}, {
          27.532772596843618`, 27.542539454806313`, 27.210466284074606`, 
           27.23, 54084300}}, {{2012, 10, 26}, {
          27.21806451612903, 27.687004608294927`, 27.198525345622116`, 27.56, 
           57790000}}, {{2012, 10, 31}, {
          27.88976874562018, 28.21213735108619, 27.840925017519268`, 27.88, 
           69464100}}, {{2012, 11, 1}, {
          28.17566395663957, 28.879078590785912`, 28.15612466124662, 28.84, 
           72047900}}, {{2012, 11, 2}, {
          28.907925423728813`, 29.08377627118644, 28.653918644067797`, 28.82, 
           57131600}}, {{2012, 11, 5}, {
          28.930232872089103`, 29.047438407019914`, 28.646986162672967`, 
           28.94, 38070800}}, {{2012, 11, 6}, {
          29.13092431346283, 29.50214333556598, 28.92577695914267, 29.17, 
           43401500}}, {{2012, 11, 7}, {
          28.849632049518576`, 29.14272008253095, 28.380691196698766`, 28.41, 
           57871800}}, {{2012, 11, 8}, {
          28.442790697674425`, 28.68697674418605, 28.13023255813954, 28.14, 
           49841800}}, {{2012, 11, 9}, {
          28.2088380159556, 28.511633714880336`, 28.14046479361776, 28.16, 
           43291200}}, {{2012, 11, 12}, {
          28.273416017009215`, 28.341803685329555`, 27.560230333097095`, 
           27.57, 61112300}}, {{2012, 11, 13}, {
          26.611059431524552`, 26.88682170542636, 26.345145810262093`, 26.68, 
           131689200}}, {{2012, 11, 14}, {
          26.823889716840533`, 26.873125931445603`, 26.390611028315945`, 
           26.43, 76086100}}, {{2012, 11, 15}, {
          26.476699174793698`, 26.565348837209303`, 26.230450112528132`, 
           26.26, 50955600}}, {{2012, 11, 16}, {
          26.267737556561087`, 26.2972850678733, 25.942714932126695`, 26.12, 
           64083300}}, {{2012, 11, 19}, {
          26.398952487841374`, 26.398952487841374`, 26.07389075944631, 26.33, 
           57179300}}, {{2012, 11, 20}, {
          26.359251216772744`, 26.39865219019094, 26.06374391613628, 26.31, 
           47070400}}, {{2012, 11, 21}, {
          26.30365120593692, 26.75665306122449, 26.264259740259742`, 26.54, 
           66360300}}, {{2012, 11, 23}, {
          26.817126353790613`, 27.348938628158844`, 26.787581227436824`, 
           27.28, 57845700}}, {{2012, 11, 26}, {
          27.127754654983573`, 27.167155896312522`, 26.763293172690766`, 
           26.98, 85198700}}, {{2012, 11, 27}, {
          26.945760709010344`, 26.96545790251108, 26.630605612998526`, 26.67, 
           45018600}}, {{2012, 11, 28}, {
          26.605244883040935`, 26.97955043859649, 26.368841374269003`, 26.95, 
           53018400}}, {{2012, 11, 29}, {
          26.697565862708718`, 26.943762523191094`, 26.451369202226346`, 
           26.54, 69551400}}, {{2012, 11, 30}, {
          26.643538692712244`, 26.7223365890308, 26.09195341848234, 26.22, 
           83690200}}, {{2012, 12, 3}, {
          26.37470298902762, 26.414097616345064`, 26.000454029511918`, 26.03, 
           53173800}}, {{2012, 12, 4}, {
          26.098028062191883`, 26.226056124383767`, 25.9404550625711, 25.97, 
           49777500}}, {{2012, 12, 5}, {
          25.984349456317954`, 26.526100487439066`, 25.86614923134608, 26.27, 
           68283800}}, {{2012, 12, 6}, {
          26.408802843247283`, 26.57625888514777, 26.211795735129066`, 26.33, 
           39182300}}, {{2012, 12, 7}, {
          26.414557823129254`, 26.414557823129254`, 25.97136054421769, 26.06, 
           46162100}}, {{2012, 12, 10}, {
          26.155783221974758`, 26.559543429844098`, 26.116391982182627`, 
           26.53, 47031100}}, {{2012, 12, 11}, {
          26.64405197657394, 27.077448755490483`, 26.64405197657394, 26.91, 
           52282800}}, {{2012, 12, 12}, {
          27.11563509544787, 27.20428046989721, 26.67240822320117, 26.83, 
           43966300}}, {{2012, 12, 13}, {
          26.90682405016599, 27.10379933603836, 26.5424197713021, 26.7, 
           45080100}}, {{2012, 12, 14}, {
          26.695412159641922`, 26.71510630361805, 26.29168220813129, 26.4, 
           42077500}}, {{2012, 12, 17}, {
          26.38469003690037, 26.80818450184502, 26.27635424354244, 26.69, 
           42046100}}, {{2012, 12, 18}, {
          26.834724238026126`, 27.208933236574747`, 26.726400580551527`, 
           27.14, 50486900}}, {{2012, 12, 19}, {
          27.274295129989014`, 27.313694617356276`, 26.8409007689491, 26.9, 
           53519900}}, {{2012, 12, 20}, {
          26.94485549132948, 27.26, 26.738041907514454`, 27.26, 52607300}}, {{
          2012, 12, 21}, {
          27.04, 27.079402550091075`, 26.59672131147541, 27.04, 98776500}}, {{
          2012, 12, 24}, {
          26.78787878787879, 26.83712121212121, 26.59090909090909, 26.65, 
           20842400}}, {{2012, 12, 26}, {
          26.617405063291137`, 26.784810126582276`, 26.292442293373043`, 
           26.45, 31631100}}, {{2012, 12, 27}, {
          26.481064540059347`, 26.678022997032638`, 26.165931008902074`, 
           26.55, 39394000}}, {{2012, 12, 28}, {
          26.307589453860636`, 26.494726930320144`, 26.149999999999995`, 
           26.15, 28239900}}, {{2012, 12, 31}, {
          26.191797079745413`, 26.369101460127293`, 25.97509172594534, 26.31, 
           42749500}}, {{2013, 1, 2}, {
          26.8356263577118, 27.30832729905865, 26.737146994931205`, 27.2, 
           52899300}}, {{2013, 1, 3}, {
          27.214282568807338`, 27.233981651376148`, 26.75135412844037, 26.84, 
           48294400}}, {{2013, 1, 4}, {
          26.862071802543007`, 26.93102468212416, 26.330149588631265`, 26.34, 
           52521100}}, {{2013, 1, 7}, {
          26.36880104908205, 26.477152491569875`, 26.240749344323717`, 26.29, 
           37110400}}, {{2013, 1, 8}, {
          26.346986817325796`, 26.386384180790955`, 26.061355932203387`, 
           26.15, 44703100}}, {{2013, 1, 9}, {
          26.319700374531838`, 26.34925093632959, 26.162097378277153`, 26.3, 
           49047900}}, {{2013, 1, 10}, {
          26.247127739984883`, 26.572139077853365`, 25.89256991685563, 26.06, 
           71431300}}, {{2013, 1, 11}, {
          26.08519567648155, 26.51847185985837, 25.87840477077898, 26.42, 
           55512100}}, {{2013, 1, 14}, {
          26.489847526961693`, 26.667103012272218`, 26.351982149497953`, 
           26.48, 48324400}}, {{2013, 1, 15}, {
          26.42572583608967, 26.878794560823223`, 26.42572583608967, 26.8, 
           48244500}}, {{2013, 1, 16}, {
          26.738332100591716`, 26.817119082840236`, 26.600454881656805`, 
           26.63, 41077400}}, {{2013, 1, 17}, {
          26.78090275229358, 27.05668990825688, 26.65285871559633, 26.84, 
           51685900}}, {{2013, 1, 18}, {
          26.692256880733947`, 26.879398165137616`, 26.633159633027525`, 
           26.84, 52167700}}, {{2013, 1, 22}, {
          26.887734806629833`, 27.035469613259668`, 26.592265193370167`, 
           26.74, 58650600}}, {{2013, 1, 23}, {
          26.786236870699025`, 27.21954364360739, 26.786236870699025`, 27.19, 
           50387700}}, {{2013, 1, 24}, {
          27.27893593919653, 27.643311617806734`, 27.052432138979373`, 27.21, 
           101739300}}, {{2013, 1, 25}, {
          27.164519368723095`, 27.804727403156384`, 26.97738163558106, 27.46, 
           81847700}}, {{2013, 1, 28}, {
          27.58849516302401, 27.80518452167682, 27.342257255463995`, 27.49, 
           56056500}}, {{2013, 1, 29}, {
          27.402848982506246`, 27.708200642627627`, 27.186147804355585`, 
           27.59, 49242600}}, {{2013, 1, 30}, {
          27.58758707360862, 27.764872531418312`, 27.341357271095156`, 27.43, 
           43580500}}, {{2013, 1, 31}, {
          27.374921675774136`, 27.55223315118397, 26.990746812386156`, 27.04, 
           50530000}}, {{2013, 2, 1}, {
          27.253909774436092`, 27.628195488721804`, 27.135714285714286`, 
           27.51, 55565900}}, {{2013, 2, 4}, {
          27.453575072886295`, 27.60133381924198, 27.010298833819242`, 27.03, 
           50540000}}, {{2013, 2, 5}, {
          27.198167272727268`, 27.237556363636358`, 26.942138181818176`, 
           27.08, 35410400}}, {{2013, 2, 6}, {
          26.969400146305773`, 27.12700073152889, 26.841349670811994`, 26.93, 
           41889600}}, {{2013, 2, 7}, {
          26.938947947214075`, 26.978346774193547`, 26.692705278592374`, 
           26.87, 38028300}}, {{2013, 2, 8}, {
          26.933049001814883`, 27.287560798548096`, 26.893658802177857`, 
           27.13, 33318500}}, {{2013, 2, 11}, {
          27.23316582914573, 27.499095477386938`, 27.085427135678394`, 27.44, 
           32247700}}, {{2013, 2, 12}, {
          27.459999999999997`, 27.57819225251076, 27.33195839311334, 27.46, 
           35990900}}, {{2013, 2, 13}, {
          27.511498394577234`, 27.688801284338204`, 27.462247591865854`, 
           27.61, 41715600}}, {{2013, 2, 14}, {
          27.501797432239663`, 27.639700427960058`, 27.45254636233952, 27.62, 
           32663200}}, {{2013, 2, 15}, {
          27.619550160656903`, 27.737750803284538`, 27.46194930382006, 27.59, 
           49650900}}, {{2013, 2, 19}, {
          27.68121212121212, 27.889714795008913`, 27.6017825311943, 27.85, 
           38781400}}, {{2013, 2, 20}, {
          27.938227484750627`, 28.007750269106566`, 27.64027269465375, 27.68, 
           44110200}}, {{2013, 2, 21}, {
          27.548272098945073`, 27.548272098945073`, 27.041797017097128`, 27.3,
            49078500}}, {{2013, 2, 22}, {
          27.49054755043228, 27.570000000000004`, 27.29191642651297, 27.57, 
           31425900}}, {{2013, 2, 25}, {
          27.7758348556814, 27.85527950310559, 27.18, 27.18, 48011800}}, {{
          2013, 2, 26}, {
          27.18993058092802, 27.408403361344536`, 27.150208257215926`, 27.18, 
           49923300}}, {{2013, 2, 27}, {
          27.232664509169368`, 27.808701905789285`, 27.143279395900755`, 
           27.62, 36394700}}, {{2013, 2, 28}, {
          27.689453237410067`, 27.7788381294964, 27.55041007194244, 27.61, 
           35840200}}, {{2013, 3, 1}, {
          27.53156350626118, 27.789796064400715`, 27.332923076923077`, 27.76, 
           34849700}}, {{2013, 3, 4}, {
          27.652131438721142`, 27.950000000000003`, 27.503197158081708`, 
           27.95, 38157500}}, {{2013, 3, 5}, {
          28.090423280423277`, 28.33865961199294, 27.961340388007052`, 28.15, 
           41432200}}, {{2013, 3, 6}, {
          28.009145603417586`, 28.029003203987184`, 27.582207191171236`, 
           27.89, 51448500}}, {{2013, 3, 7}, {
          27.910213219616203`, 28.079004975124377`, 27.810923951670222`, 
           27.94, 29196700}}, {{2013, 3, 8}, {
          28.058303571428567`, 28.137760714285708`, 27.770271428571426`, 
           27.81, 37667800}}, {{2013, 3, 11}, {
          27.74952278435594, 27.779318263365624`, 27.48136347326875, 27.68, 
           36627500}}, {{2013, 3, 12}, {
          27.650476531709067`, 27.759727696166248`, 27.451838050877825`, 
           27.72, 39255200}}, {{2013, 3, 13}, {
          27.680340257879656`, 27.829319484240685`, 27.56115687679083, 27.73, 
           29093400}}, {{2013, 3, 14}, {
          27.800995024875622`, 27.959857853589195`, 27.731492537313432`, 
           27.94, 55914800}}, {{2013, 3, 15}, {
          27.83007132667618, 27.95914407988588, 27.780427960057064`, 27.84, 
           92710300}}, {{2013, 3, 18}, {
          27.681565836298926`, 28.07871886120996, 27.612064056939495`, 27.9, 
           44809400}}, {{2013, 3, 19}, {
          27.92042583392477, 28.01971611071682, 27.831064584811926`, 27.98, 
           51901600}}, {{2013, 3, 20}, {
          28.13985875706215, 28.28879943502825, 27.980988700564975`, 28.12, 
           35447800}}, {{2013, 3, 21}, {
          27.909999999999997`, 28.158221273568124`, 27.85042689434365, 27.91, 
           34233200}}, {{2013, 3, 22}, {
          27.990424778761064`, 28.13936283185841, 27.901061946902658`, 28.05, 
           28720900}}, {{2013, 3, 25}, {
          28.099005681818188`, 28.14865056818182, 27.76142045454546, 27.96, 
           44154000}}, {{2013, 3, 26}, {
          28.03943181818182, 28.138721590909096`, 27.910355113636367`, 27.96, 
           27824300}}, {{2013, 3, 27}, {
          27.941621431089178`, 28.24943602396898, 27.88204441311244, 28.17, 
           36047400}}, {{2013, 3, 28}, {
          28.12202726319469, 28.459650471862986`, 28.06244669695911, 28.41, 
           55453800}}, {{2013, 4, 1}, {
          28.439790283117794`, 28.459650471862986`, 28.16174764068508, 28.41, 
           29201100}}, {{2013, 4, 2}, {
          28.391458333333336`, 28.64965277777778, 28.321944444444448`, 28.6, 
           28456500}}, {{2013, 4, 3}, {
          28.548669467787114`, 28.747268907563026`, 28.34014005602241, 28.36, 
           35062800}}, {{2013, 4, 4}, {
          28.191468531468526`, 28.409930069930063`, 28.072307692307685`, 28.4,
            45263200}}, {{2013, 4, 5}, {
          28.02334494773519, 28.5794425087108, 27.91411149825784, 28.5, 
           50927300}}, {{2013, 4, 8}, {
          28.529020636586218`, 28.529020636586218`, 28.270839454354668`, 
           28.39, 34759500}}, {{2013, 4, 9}, {
          28.526241134751775`, 29.608510638297872`, 28.47659574468085, 29.4, 
           77733800}}, {{2013, 4, 10}, {
          29.364924042272122`, 30.109722589167763`, 29.315270805812414`, 
           30.07, 71116700}}, {{2013, 4, 11}, {
          28.89889426399447, 28.998203178991016`, 28.531451278507255`, 28.74, 
           130923200}}, {{2013, 4, 12}, {
          28.649583188607156`, 28.818402222994095`, 28.460903091351163`, 
           28.59, 62886300}}, {{2013, 4, 15}, {
          28.450278842802366`, 28.77797838968281, 28.311254792610665`, 28.49, 
           56332900}}, {{2013, 4, 16}, {
          28.700483258543322`, 28.93882637210908, 28.501863997238523`, 28.77, 
           52797300}}, {{2013, 4, 17}, {
          28.64986125563649, 28.83854318418314, 28.40159556018037, 28.63, 
           52840700}}, {{2013, 4, 18}, {
          28.74888850295241, 28.77868009725599, 28.302014588398748`, 28.59, 
           56906600}}, {{2013, 4, 19}, {
          29.411058112193484`, 30.02668458179375, 29.40112865300638, 29.56, 
           99790700}}, {{2013, 4, 22}, {
          30.093610120012976`, 30.967615958482, 30.063814466428806`, 30.62, 
           137904000}}, {{2013, 4, 23}, {
          30.489313725490195`, 30.687941176470588`, 30.17150980392157, 30.39, 
           59126900}}, {{2013, 4, 24}, {
          30.407896725440807`, 31.69889168765743, 30.388035264483626`, 31.54, 
           90946600}}, {{2013, 4, 25}, {
          31.491584220413277`, 32.61380087664371, 31.32275516593613, 31.72, 
           110700200}}, {{2013, 4, 26}, {
          31.679238754325258`, 31.758685121107266`, 31.23235294117647, 31.57, 
           47799300}}, {{2013, 4, 29}, {
          31.575712971481146`, 32.449506286415215`, 31.545924563017483`, 
           32.38, 59116400}}, {{2013, 4, 30}, {
          32.33375226586102, 32.87993051359516, 32.05569788519637, 32.87, 
           75165200}}, {{2013, 5, 1}, {
          32.69852383863081, 32.84746943765282, 32.3708435207824, 32.49, 
           54330900}}, {{2013, 5, 2}, {
          32.40367611580218, 32.939930639324494`, 32.16534077201448, 32.93, 
           46059500}}, {{2013, 5, 3}, {
          33.00178560764407, 33.28979396834876, 32.85281576590026, 33.26, 
           46784600}}, {{2013, 5, 6}, {
          33.18234666666667, 33.66886222222222, 33.013555555555556`, 33.51, 
           40978300}}, {{2013, 5, 7}, {
          33.41765235664965, 33.55668567997598, 33.01048333833683, 33.08, 
           43078300}}, {{2013, 5, 8}, {
          32.83944225522885, 33.00825704759018, 32.422370415277356`, 32.76, 
           51595700}}, {{2013, 5, 9}, {
          32.61866197183099, 32.76760563380282, 32.36049295774649, 32.43, 
           46417800}}, {{2013, 5, 10}, {
          32.44014071581524, 32.48978892627715, 32.09260324258183, 32.46, 
           36394900}}, {{2013, 5, 13}, {
          32.382924613987285`, 32.83972146533454, 32.323342415985465`, 32.8, 
           36027600}}, {{2013, 5, 14}, {
          32.86, 33.53, 32.8, 33.53, 56870100}}, {{2013, 5, 15}, {
          33.45, 33.9, 33.43, 33.85, 46303900}}, {{2013, 5, 16}, {
          33.64, 34.15, 33.55, 34.08, 59382900}}, {{2013, 5, 17}, {
          34.13, 34.87, 34.1, 34.87, 60666700}}, {{2013, 5, 20}, {
          34.73, 35.1, 34.68, 35.08, 54020800}}, {{2013, 5, 21}, {
          35.1, 35.27, 34.72, 34.85, 48702400}}, {{2013, 5, 22}, {
          34.79, 34.84, 34.36, 34.61, 66047500}}, {{2013, 5, 23}, {
          34.23, 34.55, 33.9, 34.15, 51102700}}, {{2013, 5, 24}, {
          33.92, 34.28, 33.9, 34.27, 33174400}}, {{2013, 5, 28}, {
          34.42, 35.18, 34.41, 35.02, 48212100}}, {{2013, 5, 29}, {
          34.74, 35.02, 34.57, 34.88, 38412200}}, {{2013, 5, 30}, {
          34.849999999999994`, 35.24999999999999, 34.809999999999995`, 35.03, 
           51131000}}, {{2013, 5, 31}, {
          34.82, 35.28, 34.79, 34.9, 56165700}}, {{2013, 6, 3}, {
          34.919999999999995`, 35.629999999999995`, 34.82999999999999, 35.59, 
           51252600}}, {{2013, 6, 4}, {
          35.62, 35.74, 34.77, 34.99, 65529500}}, {{2013, 6, 5}, {
          34.6, 34.89, 34.43, 34.78, 46025100}}, {{2013, 6, 6}, {
          34.84, 35.11, 34.49, 34.96, 37618500}}, {{2013, 6, 7}, {
          35.25, 35.78, 35.06, 35.67, 40757300}}, {{2013, 6, 10}, {
          35.51, 35.65, 35.14, 35.47, 35994500}}, {{2013, 6, 11}, {
          35.05, 35.18, 34.68, 34.84, 39435900}}, {{2013, 6, 12}, {
          35.14, 35.27, 34.85, 35., 37372700}}, {{2013, 6, 13}, {
          34.99, 35.02, 34.59, 34.72, 45654900}}, {{2013, 6, 14}, {
          34.55, 34.69, 34.25, 34.4, 53192600}}, {{2013, 6, 17}, {
          34.69, 35.16, 34.63, 35., 49670100}}, {{2013, 6, 18}, {
          34.97, 35.17, 34.9, 34.98, 28616500}}, {{2013, 6, 19}, {
          34.96, 35.09, 34.59, 34.59, 30816200}}, {{2013, 6, 20}, {
          34.26, 34.33, 33.37, 33.49, 54493700}}, {{2013, 6, 21}, {
          33.66, 33.73, 33.05, 33.27, 85338500}}, {{2013, 6, 24}, {
          32.94, 34.2, 32.57, 33.72, 56109000}}, {{2013, 6, 25}, {
          34.08, 34.38, 33.46, 33.67, 44073400}}, {{2013, 6, 26}, {
          34.12, 34.48, 33.89, 34.35, 48665900}}, {{2013, 6, 27}, {
          34.52, 34.78, 34.5, 34.62, 28993100}}, {{2013, 6, 28}, {
          34.38, 34.79, 34.34, 34.54, 65545500}}, {{2013, 7, 1}, {
          34.75, 34.99, 34.33, 34.36, 31055400}}, {{2013, 7, 2}, {
          34.41, 34.44, 33.63, 33.94, 37630000}}, {{2013, 7, 3}, {
          33.66, 34.37, 33.6, 34.01, 15994400}}, {{2013, 7, 5}, {
          34.09, 34.24, 33.58, 34.21, 26085900}}, {{2013, 7, 8}, {
          34.35, 34.59, 33.98, 34.33, 32396900}}, {{2013, 7, 9}, {
          34.58, 34.6, 34.14, 34.35, 25318500}}, {{2013, 7, 10}, {
          34.34, 34.81, 34.32, 34.7, 29658800}}, {{2013, 7, 11}, {
          35., 35.77, 34.9, 35.69, 53638300}}, {{2013, 7, 12}, {
          35.58, 35.73, 35.28, 35.67, 35501200}}, {{2013, 7, 15}, {
          35.66, 36.22, 35.58, 36.17, 34142600}}, {{2013, 7, 16}, {
          36.01, 36.43, 35.96, 36.27, 36378500}}, {{2013, 7, 17}, {
          36.34, 36.39, 35.49, 35.74, 37285100}}, {{2013, 7, 18}, {
          35.72, 35.89, 35.22, 35.44, 49547100}}, {{2013, 7, 19}, {
          32.4, 32.67, 31.02, 31.4, 248428500}}, {{2013, 7, 22}, {
          31.7, 32.01, 31.6, 32.01, 79040700}}, {{2013, 7, 23}, {
          31.91, 32.04, 31.71, 31.82, 65810400}}, {{2013, 7, 24}, {
          32.04, 32.19, 31.89, 31.96, 52803100}}, {{2013, 7, 25}, {
          31.62, 31.65, 31.25, 31.39, 63213000}}}, 
        System`TradingChartDump`$markerstyle$545702 = 1, 
        System`TradingChartDump`$controlmin$545702 = 0.5, 
        System`TradingChartDump`$controlmax$545702 = 250.5, 
        System`TradingChartDump`$datescope$545702 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$545702 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$545702, 
        System`TradingChartDump`$max$545702, 
        System`TradingChartDump`$ohlclabel$545702 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545702, 
              System`TradingChartDump`$opens$545702]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545702, 
              System`TradingChartDump`$highs$545702]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545702, 
              System`TradingChartDump`$lows$545702]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545702, 
              System`TradingChartDump`$closes$545702]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545702, 
              System`TradingChartDump`$visdates$545702]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$545702 = {}, 
        System`TradingChartDump`$subpricegridlines$545702 = Automatic, 
        System`TradingChartDump`$overlaypoint$545702, 
        System`TradingChartDump`$overlayvalue$545702, 
        System`TradingChartDump`$subplotvalue$545702, 
        System`TradingChartDump`$opts$545702 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "MSFT", " with ", "TRIX", "(", 15, 
            ",", Null, ",", Null, ",", Null, ")"}], ImageSize -> {450, 310}, 
         AlignmentPoint -> Center, AspectRatio -> GoldenRatio^(-1), Axes -> 
         Automatic, AxesLabel -> None, AxesOrigin -> Automatic, 
         AxesStyle -> {}, Background -> None, BaselinePosition -> Automatic, 
         BaseStyle -> {}, ColorOutput -> Automatic, ContentSelectable -> 
         Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$545702 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmgtcj+f7xyNbDokp/ORUIcmhckrnO2EhOipppcO3vt/6VsKIsIVpDtGo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             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyNmglYjmnUx5ssY5K1sku2bElp0d4tkvZdi9KmRW8LsnwYvJiECUOILGPN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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$545702 = 
        System`TradingChartDump`$staticindicatorpos$545702, 
        System`TradingChartDump`$length$545702 = 250, 
        System`TradingChartDump`$gridlinesflag$545702 = True, 
        System`TradingChartDump`$opens$545702 = 
        Dispatch[{
         1 -> 28.37`4., 2 -> 28.61`4., 3 -> 28.87`4., 4 -> 28.61`4., 5 -> 
          28.71`4., 6 -> 28.35`4., 7 -> 28.66`4., 8 -> 29.11`4., 9 -> 
          29.19`4., 10 -> 29.31`4., 11 -> 29.49`4., 12 -> 29.6`4., 13 -> 
          29.45`4., 14 -> 29.6`4., 15 -> 29.41`4., 16 -> 29.66`4., 17 -> 
          30.2`4., 18 -> 30.11`4., 19 -> 30.05`4., 20 -> 29.88`4., 21 -> 
          29.69`4., 22 -> 29.55`4., 23 -> 30.21`4., 24 -> 29.99`4., 25 -> 
          29.94`4., 26 -> 29.83`4., 27 -> 29.9`4., 28 -> 29.75`4., 29 -> 
          29.52`4., 30 -> 29.79`4., 31 -> 30.32`4., 32 -> 30.12`4., 33 -> 
          29.98`4., 34 -> 30.23`4., 35 -> 30.17`4., 36 -> 30.29`4., 37 -> 
          30.47`4., 38 -> 30.38`4., 39 -> 30.37`4., 40 -> 30.23`4., 41 -> 
          30.7`4., 42 -> 30.28`4., 43 -> 30.24`4., 44 -> 29.58`4., 45 -> 
          29.47`4., 46 -> 29.48`4., 47 -> 29.12`4., 48 -> 28.99`4., 49 -> 
          29.06`4., 50 -> 29.27`4., 51 -> 29.53`4., 52 -> 28.95`4., 53 -> 
          28.99`4., 54 -> 28.48`4., 55 -> 28.54`4., 56 -> 28.3`4., 57 -> 
          28.69`4., 58 -> 28.77`4., 59 -> 28.63`4., 60 -> 28.97`4., 61 -> 
          28.38`4., 62 -> 28.06`4., 63 -> 27.13`4., 64 -> 27.5`4., 65 -> 
          27.53`4., 66 -> 27.22`4., 67 -> 27.89`4., 68 -> 28.18`4., 69 -> 
          28.91`4., 70 -> 28.93`4., 71 -> 29.13`4., 72 -> 28.85`4., 73 -> 
          28.44`4., 74 -> 28.21`4., 75 -> 28.27`4., 76 -> 26.61`4., 77 -> 
          26.82`4., 78 -> 26.48`4., 79 -> 26.27`4., 80 -> 26.4`4., 81 -> 
          26.36`4., 82 -> 26.3`4., 83 -> 26.82`4., 84 -> 27.13`4., 85 -> 
          26.95`4., 86 -> 26.61`4., 87 -> 26.7`4., 88 -> 26.64`4., 89 -> 
          26.37`4., 90 -> 26.1`4., 91 -> 25.98`4., 92 -> 26.41`4., 93 -> 
          26.41`4., 94 -> 26.16`4., 95 -> 26.64`4., 96 -> 27.12`4., 97 -> 
          26.91`4., 98 -> 26.7`4., 99 -> 26.38`4., 100 -> 26.83`4., 101 -> 
          27.27`4., 102 -> 26.94`4., 103 -> 27.04`4., 104 -> 26.79`4., 105 -> 
          26.62`4., 106 -> 26.48`4., 107 -> 26.31`4., 108 -> 26.19`4., 109 -> 
          26.84`4., 110 -> 27.21`4., 111 -> 26.86`4., 112 -> 26.37`4., 113 -> 
          26.35`4., 114 -> 26.32`4., 115 -> 26.25`4., 116 -> 26.09`4., 117 -> 
          26.49`4., 118 -> 26.43`4., 119 -> 26.74`4., 120 -> 26.78`4., 121 -> 
          26.69`4., 122 -> 26.89`4., 123 -> 26.79`4., 124 -> 27.28`4., 125 -> 
          27.16`4., 126 -> 27.59`4., 127 -> 27.4`4., 128 -> 27.59`4., 129 -> 
          27.37`4., 130 -> 27.25`4., 131 -> 27.45`4., 132 -> 27.2`4., 133 -> 
          26.97`4., 134 -> 26.94`4., 135 -> 26.93`4., 136 -> 27.23`4., 137 -> 
          27.46`4., 138 -> 27.51`4., 139 -> 27.5`4., 140 -> 27.62`4., 141 -> 
          27.68`4., 142 -> 27.94`4., 143 -> 27.55`4., 144 -> 27.49`4., 145 -> 
          27.78`4., 146 -> 27.19`4., 147 -> 27.23`4., 148 -> 27.69`4., 149 -> 
          27.53`4., 150 -> 27.65`4., 151 -> 28.09`4., 152 -> 28.01`4., 153 -> 
          27.91`4., 154 -> 28.06`4., 155 -> 27.75`4., 156 -> 27.65`4., 157 -> 
          27.68`4., 158 -> 27.8`4., 159 -> 27.83`4., 160 -> 27.68`4., 161 -> 
          27.92`4., 162 -> 28.14`4., 163 -> 27.91`4., 164 -> 27.99`4., 165 -> 
          28.1`4., 166 -> 28.04`4., 167 -> 27.94`4., 168 -> 28.12`4., 169 -> 
          28.44`4., 170 -> 28.39`4., 171 -> 28.55`4., 172 -> 28.19`4., 173 -> 
          28.02`4., 174 -> 28.53`4., 175 -> 28.53`4., 176 -> 29.36`4., 177 -> 
          28.9`4., 178 -> 28.65`4., 179 -> 28.45`4., 180 -> 28.7`4., 181 -> 
          28.65`4., 182 -> 28.75`4., 183 -> 29.41`4., 184 -> 30.09`4., 185 -> 
          30.49`4., 186 -> 30.41`4., 187 -> 31.49`4., 188 -> 31.68`4., 189 -> 
          31.58`4., 190 -> 32.33`4., 191 -> 32.7`4., 192 -> 32.4`4., 193 -> 
          33.`4., 194 -> 33.18`4., 195 -> 33.42`4., 196 -> 32.84`4., 197 -> 
          32.62`4., 198 -> 32.44`4., 199 -> 32.38`4., 200 -> 32.86`4., 201 -> 
          33.45`4., 202 -> 33.64`4., 203 -> 34.13`4., 204 -> 34.73`4., 205 -> 
          35.1`4., 206 -> 34.79`4., 207 -> 34.23`4., 208 -> 33.92`4., 209 -> 
          34.42`4., 210 -> 34.74`4., 211 -> 34.85`4., 212 -> 34.82`4., 213 -> 
          34.92`4., 214 -> 35.62`4., 215 -> 34.6`4., 216 -> 34.84`4., 217 -> 
          35.25`4., 218 -> 35.51`4., 219 -> 35.05`4., 220 -> 35.14`4., 221 -> 
          34.99`4., 222 -> 34.55`4., 223 -> 34.69`4., 224 -> 34.97`4., 225 -> 
          34.96`4., 226 -> 34.26`4., 227 -> 33.66`4., 228 -> 32.94`4., 229 -> 
          34.08`4., 230 -> 34.12`4., 231 -> 34.52`4., 232 -> 34.38`4., 233 -> 
          34.75`4., 234 -> 34.41`4., 235 -> 33.66`4., 236 -> 34.09`4., 237 -> 
          34.35`4., 238 -> 34.58`4., 239 -> 34.34`4., 240 -> 35.`4., 241 -> 
          35.58`4., 242 -> 35.66`4., 243 -> 36.01`4., 244 -> 36.34`4., 245 -> 
          35.72`4., 246 -> 32.4`4., 247 -> 31.7`4., 248 -> 31.91`4., 249 -> 
          32.04`4., 250 -> 31.62`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$highs$545702 = 
        Dispatch[{
         1 -> 28.63`4., 2 -> 28.97`4., 3 -> 28.93`4., 4 -> 28.83`4., 5 -> 
          28.77`4., 6 -> 28.66`4., 7 -> 29.05`4., 8 -> 29.22`4., 9 -> 
          29.46`4., 10 -> 29.57`4., 11 -> 29.75`4., 12 -> 29.71`4., 13 -> 
          29.56`4., 14 -> 29.68`4., 15 -> 29.58`4., 16 -> 30.23`4., 17 -> 
          30.2`4., 18 -> 30.14`4., 19 -> 30.25`4., 20 -> 30.04`4., 21 -> 
          29.7`4., 22 -> 29.92`4., 23 -> 30.24`4., 24 -> 30.09`4., 25 -> 
          30.04`4., 26 -> 29.9`4., 27 -> 30.25`4., 28 -> 29.95`4., 29 -> 
          29.83`4., 30 -> 30.63`4., 31 -> 30.35`4., 32 -> 30.19`4., 33 -> 
          30.2`4., 34 -> 30.46`4., 35 -> 30.45`4., 36 -> 30.53`4., 37 -> 
          30.54`4., 38 -> 30.49`4., 39 -> 30.47`4., 40 -> 30.75`4., 41 -> 
          30.88`4., 42 -> 30.35`4., 43 -> 30.29`4., 44 -> 29.89`4., 45 -> 
          29.69`4., 46 -> 29.56`4., 47 -> 29.29`4., 48 -> 29.19`4., 49 -> 
          29.3`4., 50 -> 29.33`4., 51 -> 29.55`4., 52 -> 29.23`4., 53 -> 
          29.05`4., 54 -> 28.63`4., 55 -> 28.57`4., 56 -> 28.64`4., 57 -> 
          29.04`4., 58 -> 29.05`4., 59 -> 28.96`4., 60 -> 29.04`4., 61 -> 
          28.41`4., 62 -> 28.16`4., 63 -> 27.55`4., 64 -> 27.54`4., 65 -> 
          27.54`4., 66 -> 27.69`4., 67 -> 28.21`4., 68 -> 28.88`4., 69 -> 
          29.08`4., 70 -> 29.05`4., 71 -> 29.5`4., 72 -> 29.14`4., 73 -> 
          28.69`4., 74 -> 28.51`4., 75 -> 28.34`4., 76 -> 26.89`4., 77 -> 
          26.87`4., 78 -> 26.57`4., 79 -> 26.3`4., 80 -> 26.4`4., 81 -> 
          26.4`4., 82 -> 26.76`4., 83 -> 27.35`4., 84 -> 27.17`4., 85 -> 
          26.97`4., 86 -> 26.98`4., 87 -> 26.94`4., 88 -> 26.72`4., 89 -> 
          26.41`4., 90 -> 26.23`4., 91 -> 26.53`4., 92 -> 26.58`4., 93 -> 
          26.41`4., 94 -> 26.56`4., 95 -> 27.08`4., 96 -> 27.2`4., 97 -> 
          27.1`4., 98 -> 26.72`4., 99 -> 26.81`4., 100 -> 27.21`4., 101 -> 
          27.31`4., 102 -> 27.26`4., 103 -> 27.08`4., 104 -> 26.84`4., 105 -> 
          26.78`4., 106 -> 26.68`4., 107 -> 26.49`4., 108 -> 26.37`4., 109 -> 
          27.31`4., 110 -> 27.23`4., 111 -> 26.93`4., 112 -> 26.48`4., 113 -> 
          26.39`4., 114 -> 26.35`4., 115 -> 26.57`4., 116 -> 26.52`4., 117 -> 
          26.67`4., 118 -> 26.88`4., 119 -> 26.82`4., 120 -> 27.06`4., 121 -> 
          26.88`4., 122 -> 27.04`4., 123 -> 27.22`4., 124 -> 27.64`4., 125 -> 
          27.8`4., 126 -> 27.81`4., 127 -> 27.71`4., 128 -> 27.76`4., 129 -> 
          27.55`4., 130 -> 27.63`4., 131 -> 27.6`4., 132 -> 27.24`4., 133 -> 
          27.13`4., 134 -> 26.98`4., 135 -> 27.29`4., 136 -> 27.5`4., 137 -> 
          27.58`4., 138 -> 27.69`4., 139 -> 27.64`4., 140 -> 27.74`4., 141 -> 
          27.89`4., 142 -> 28.01`4., 143 -> 27.55`4., 144 -> 27.57`4., 145 -> 
          27.86`4., 146 -> 27.41`4., 147 -> 27.81`4., 148 -> 27.78`4., 149 -> 
          27.79`4., 150 -> 27.95`4., 151 -> 28.34`4., 152 -> 28.03`4., 153 -> 
          28.08`4., 154 -> 28.14`4., 155 -> 27.78`4., 156 -> 27.76`4., 157 -> 
          27.83`4., 158 -> 27.96`4., 159 -> 27.96`4., 160 -> 28.08`4., 161 -> 
          28.02`4., 162 -> 28.29`4., 163 -> 28.16`4., 164 -> 28.14`4., 165 -> 
          28.15`4., 166 -> 28.14`4., 167 -> 28.25`4., 168 -> 28.46`4., 169 -> 
          28.46`4., 170 -> 28.65`4., 171 -> 28.75`4., 172 -> 28.41`4., 173 -> 
          28.58`4., 174 -> 28.53`4., 175 -> 29.61`4., 176 -> 30.11`4., 177 -> 
          29.`4., 178 -> 28.82`4., 179 -> 28.78`4., 180 -> 28.94`4., 181 -> 
          28.84`4., 182 -> 28.78`4., 183 -> 30.03`4., 184 -> 30.97`4., 185 -> 
          30.69`4., 186 -> 31.7`4., 187 -> 32.61`4., 188 -> 31.76`4., 189 -> 
          32.45`4., 190 -> 32.88`4., 191 -> 32.85`4., 192 -> 32.94`4., 193 -> 
          33.29`4., 194 -> 33.67`4., 195 -> 33.56`4., 196 -> 33.01`4., 197 -> 
          32.77`4., 198 -> 32.49`4., 199 -> 32.84`4., 200 -> 33.53`4., 201 -> 
          33.9`4., 202 -> 34.15`4., 203 -> 34.87`4., 204 -> 35.1`4., 205 -> 
          35.27`4., 206 -> 34.84`4., 207 -> 34.55`4., 208 -> 34.28`4., 209 -> 
          35.18`4., 210 -> 35.02`4., 211 -> 35.25`4., 212 -> 35.28`4., 213 -> 
          35.63`4., 214 -> 35.74`4., 215 -> 34.89`4., 216 -> 35.11`4., 217 -> 
          35.78`4., 218 -> 35.65`4., 219 -> 35.18`4., 220 -> 35.27`4., 221 -> 
          35.02`4., 222 -> 34.69`4., 223 -> 35.16`4., 224 -> 35.17`4., 225 -> 
          35.09`4., 226 -> 34.33`4., 227 -> 33.73`4., 228 -> 34.2`4., 229 -> 
          34.38`4., 230 -> 34.48`4., 231 -> 34.78`4., 232 -> 34.79`4., 233 -> 
          34.99`4., 234 -> 34.44`4., 235 -> 34.37`4., 236 -> 34.24`4., 237 -> 
          34.59`4., 238 -> 34.6`4., 239 -> 34.81`4., 240 -> 35.77`4., 241 -> 
          35.73`4., 242 -> 36.22`4., 243 -> 36.43`4., 244 -> 36.39`4., 245 -> 
          35.89`4., 246 -> 32.67`4., 247 -> 32.01`4., 248 -> 32.04`4., 249 -> 
          32.19`4., 250 -> 31.65`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$545702 = 
        Dispatch[{
         1 -> 28.23`4., 2 -> 28.32`4., 3 -> 28.59`4., 4 -> 28.46`4., 5 -> 
          28.35`4., 6 -> 28.12`4., 7 -> 28.61`4., 8 -> 28.92`4., 9 -> 
          28.99`4., 10 -> 29.22`4., 11 -> 29.41`4., 12 -> 29.36`4., 13 -> 
          29.27`4., 14 -> 29.31`4., 15 -> 29.32`4., 16 -> 29.56`4., 17 -> 
          29.88`4., 18 -> 29.87`4., 19 -> 29.9`4., 20 -> 29.76`4., 21 -> 
          29.38`4., 22 -> 29.48`4., 23 -> 29.88`4., 24 -> 29.81`4., 25 -> 
          29.73`4., 26 -> 29.52`4., 27 -> 29.68`4., 28 -> 29.46`4., 29 -> 
          29.51`4., 30 -> 29.75`4., 31 -> 30.02`4., 32 -> 29.8`4., 33 -> 
          29.9`4., 34 -> 30.02`4., 35 -> 29.69`4., 36 -> 30.1`4., 37 -> 
          30.32`4., 38 -> 30.31`4., 39 -> 30.32`4., 40 -> 30.19`4., 41 -> 
          30.37`4., 42 -> 29.93`4., 43 -> 29.66`4., 44 -> 29.34`4., 45 -> 
          29.2`4., 46 -> 29.05`4., 47 -> 28.74`4., 48 -> 28.81`4., 49 -> 
          28.98`4., 50 -> 28.88`4., 51 -> 29.05`4., 52 -> 28.87`4., 53 -> 
          28.5`4., 54 -> 28.28`4., 55 -> 28.2`4., 56 -> 28.13`4., 57 -> 
          28.58`4., 58 -> 28.64`4., 59 -> 28.42`4., 60 -> 28.59`4., 61 -> 
          27.84`4., 62 -> 27.18`4., 63 -> 27.12`4., 64 -> 27.22`4., 65 -> 
          27.21`4., 66 -> 27.2`4., 67 -> 27.84`4., 68 -> 28.16`4., 69 -> 
          28.65`4., 70 -> 28.65`4., 71 -> 28.93`4., 72 -> 28.38`4., 73 -> 
          28.13`4., 74 -> 28.14`4., 75 -> 27.56`4., 76 -> 26.35`4., 77 -> 
          26.39`4., 78 -> 26.23`4., 79 -> 25.94`4., 80 -> 26.07`4., 81 -> 
          26.06`4., 82 -> 26.26`4., 83 -> 26.79`4., 84 -> 26.76`4., 85 -> 
          26.63`4., 86 -> 26.37`4., 87 -> 26.45`4., 88 -> 26.09`4., 89 -> 
          26.`4., 90 -> 25.94`4., 91 -> 25.87`4., 92 -> 26.21`4., 93 -> 
          25.97`4., 94 -> 26.12`4., 95 -> 26.64`4., 96 -> 26.67`4., 97 -> 
          26.54`4., 98 -> 26.29`4., 99 -> 26.28`4., 100 -> 26.73`4., 101 -> 
          26.84`4., 102 -> 26.74`4., 103 -> 26.6`4., 104 -> 26.59`4., 105 -> 
          26.29`4., 106 -> 26.17`4., 107 -> 26.15`4., 108 -> 25.98`4., 109 -> 
          26.74`4., 110 -> 26.75`4., 111 -> 26.33`4., 112 -> 26.24`4., 113 -> 
          26.06`4., 114 -> 26.16`4., 115 -> 25.89`4., 116 -> 25.88`4., 117 -> 
          26.35`4., 118 -> 26.43`4., 119 -> 26.6`4., 120 -> 26.65`4., 121 -> 
          26.63`4., 122 -> 26.59`4., 123 -> 26.79`4., 124 -> 27.05`4., 125 -> 
          26.98`4., 126 -> 27.34`4., 127 -> 27.19`4., 128 -> 27.34`4., 129 -> 
          26.99`4., 130 -> 27.14`4., 131 -> 27.01`4., 132 -> 26.94`4., 133 -> 
          26.84`4., 134 -> 26.69`4., 135 -> 26.89`4., 136 -> 27.09`4., 137 -> 
          27.33`4., 138 -> 27.46`4., 139 -> 27.45`4., 140 -> 27.46`4., 141 -> 
          27.6`4., 142 -> 27.64`4., 143 -> 27.04`4., 144 -> 27.29`4., 145 -> 
          27.18`4., 146 -> 27.15`4., 147 -> 27.14`4., 148 -> 27.55`4., 149 -> 
          27.33`4., 150 -> 27.5`4., 151 -> 27.96`4., 152 -> 27.58`4., 153 -> 
          27.81`4., 154 -> 27.77`4., 155 -> 27.48`4., 156 -> 27.45`4., 157 -> 
          27.56`4., 158 -> 27.73`4., 159 -> 27.78`4., 160 -> 27.61`4., 161 -> 
          27.83`4., 162 -> 27.98`4., 163 -> 27.85`4., 164 -> 27.9`4., 165 -> 
          27.76`4., 166 -> 27.91`4., 167 -> 27.88`4., 168 -> 28.06`4., 169 -> 
          28.16`4., 170 -> 28.32`4., 171 -> 28.34`4., 172 -> 28.07`4., 173 -> 
          27.91`4., 174 -> 28.27`4., 175 -> 28.48`4., 176 -> 29.32`4., 177 -> 
          28.53`4., 178 -> 28.46`4., 179 -> 28.31`4., 180 -> 28.5`4., 181 -> 
          28.4`4., 182 -> 28.3`4., 183 -> 29.4`4., 184 -> 30.06`4., 185 -> 
          30.17`4., 186 -> 30.39`4., 187 -> 31.32`4., 188 -> 31.23`4., 189 -> 
          31.55`4., 190 -> 32.06`4., 191 -> 32.37`4., 192 -> 32.17`4., 193 -> 
          32.85`4., 194 -> 33.01`4., 195 -> 33.01`4., 196 -> 32.42`4., 197 -> 
          32.36`4., 198 -> 32.09`4., 199 -> 32.32`4., 200 -> 32.8`4., 201 -> 
          33.43`4., 202 -> 33.55`4., 203 -> 34.1`4., 204 -> 34.68`4., 205 -> 
          34.72`4., 206 -> 34.36`4., 207 -> 33.9`4., 208 -> 33.9`4., 209 -> 
          34.41`4., 210 -> 34.57`4., 211 -> 34.81`4., 212 -> 34.79`4., 213 -> 
          34.83`4., 214 -> 34.77`4., 215 -> 34.43`4., 216 -> 34.49`4., 217 -> 
          35.06`4., 218 -> 35.14`4., 219 -> 34.68`4., 220 -> 34.85`4., 221 -> 
          34.59`4., 222 -> 34.25`4., 223 -> 34.63`4., 224 -> 34.9`4., 225 -> 
          34.59`4., 226 -> 33.37`4., 227 -> 33.05`4., 228 -> 32.57`4., 229 -> 
          33.46`4., 230 -> 33.89`4., 231 -> 34.5`4., 232 -> 34.34`4., 233 -> 
          34.33`4., 234 -> 33.63`4., 235 -> 33.6`4., 236 -> 33.58`4., 237 -> 
          33.98`4., 238 -> 34.14`4., 239 -> 34.32`4., 240 -> 34.9`4., 241 -> 
          35.28`4., 242 -> 35.58`4., 243 -> 35.96`4., 244 -> 35.49`4., 245 -> 
          35.22`4., 246 -> 31.02`4., 247 -> 31.6`4., 248 -> 31.71`4., 249 -> 
          31.89`4., 250 -> 31.25`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$545702 = 
        Dispatch[{
         1 -> 28.3`4., 2 -> 28.88`4., 3 -> 28.76`4., 4 -> 28.6`4., 5 -> 
          28.54`4., 6 -> 28.33`4., 7 -> 28.87`4., 8 -> 29.06`4., 9 -> 
          29.37`4., 10 -> 29.43`4., 11 -> 29.6`4., 12 -> 29.52`4., 13 -> 
          29.49`4., 14 -> 29.43`4., 15 -> 29.5`4., 16 -> 30.07`4., 17 -> 
          30.18`4., 18 -> 30.03`4., 19 -> 30.09`4., 20 -> 29.83`4., 21 -> 
          29.56`4., 22 -> 29.85`4., 23 -> 29.98`4., 24 -> 29.92`4., 25 -> 
          29.94`4., 26 -> 29.62`4., 27 -> 30.11`4., 28 -> 29.69`4., 29 -> 
          29.69`4., 30 -> 30.62`4., 31 -> 30.23`4., 32 -> 30.01`4., 33 -> 
          30.08`4., 34 -> 30.07`4., 35 -> 30.22`4., 36 -> 30.49`4., 37 -> 
          30.49`4., 38 -> 30.46`4., 39 -> 30.33`4., 40 -> 30.72`4., 41 -> 
          30.47`4., 42 -> 30.07`4., 43 -> 29.69`4., 44 -> 29.47`4., 45 -> 
          29.46`4., 46 -> 29.07`4., 47 -> 28.81`4., 48 -> 28.97`4., 49 -> 
          29.17`4., 50 -> 29.33`4., 51 -> 29.16`4., 52 -> 29.09`4., 53 -> 
          28.6`4., 54 -> 28.31`4., 55 -> 28.28`4., 56 -> 28.52`4., 57 -> 
          28.83`4., 58 -> 28.81`4., 59 -> 28.91`4., 60 -> 28.82`4., 61 -> 
          27.98`4., 62 -> 27.35`4., 63 -> 27.4`4., 64 -> 27.25`4., 65 -> 
          27.23`4., 66 -> 27.56`4., 67 -> 27.88`4., 68 -> 28.84`4., 69 -> 
          28.82`4., 70 -> 28.94`4., 71 -> 29.17`4., 72 -> 28.41`4., 73 -> 
          28.14`4., 74 -> 28.16`4., 75 -> 27.57`4., 76 -> 26.68`4., 77 -> 
          26.43`4., 78 -> 26.26`4., 79 -> 26.12`4., 80 -> 26.33`4., 81 -> 
          26.31`4., 82 -> 26.54`4., 83 -> 27.28`4., 84 -> 26.98`4., 85 -> 
          26.67`4., 86 -> 26.95`4., 87 -> 26.54`4., 88 -> 26.22`4., 89 -> 
          26.03`4., 90 -> 25.97`4., 91 -> 26.27`4., 92 -> 26.33`4., 93 -> 
          26.06`4., 94 -> 26.53`4., 95 -> 26.91`4., 96 -> 26.83`4., 97 -> 
          26.7`4., 98 -> 26.4`4., 99 -> 26.69`4., 100 -> 27.14`4., 101 -> 
          26.9`4., 102 -> 27.26`4., 103 -> 27.04`4., 104 -> 26.65`4., 105 -> 
          26.45`4., 106 -> 26.55`4., 107 -> 26.15`4., 108 -> 26.31`4., 109 -> 
          27.2`4., 110 -> 26.84`4., 111 -> 26.34`4., 112 -> 26.29`4., 113 -> 
          26.15`4., 114 -> 26.3`4., 115 -> 26.06`4., 116 -> 26.42`4., 117 -> 
          26.48`4., 118 -> 26.8`4., 119 -> 26.63`4., 120 -> 26.84`4., 121 -> 
          26.84`4., 122 -> 26.74`4., 123 -> 27.19`4., 124 -> 27.21`4., 125 -> 
          27.46`4., 126 -> 27.49`4., 127 -> 27.59`4., 128 -> 27.43`4., 129 -> 
          27.04`4., 130 -> 27.51`4., 131 -> 27.03`4., 132 -> 27.08`4., 133 -> 
          26.93`4., 134 -> 26.87`4., 135 -> 27.13`4., 136 -> 27.44`4., 137 -> 
          27.46`4., 138 -> 27.61`4., 139 -> 27.62`4., 140 -> 27.59`4., 141 -> 
          27.85`4., 142 -> 27.68`4., 143 -> 27.3`4., 144 -> 27.57`4., 145 -> 
          27.18`4., 146 -> 27.18`4., 147 -> 27.62`4., 148 -> 27.61`4., 149 -> 
          27.76`4., 150 -> 27.95`4., 151 -> 28.15`4., 152 -> 27.89`4., 153 -> 
          27.94`4., 154 -> 27.81`4., 155 -> 27.68`4., 156 -> 27.72`4., 157 -> 
          27.73`4., 158 -> 27.94`4., 159 -> 27.84`4., 160 -> 27.9`4., 161 -> 
          27.98`4., 162 -> 28.12`4., 163 -> 27.91`4., 164 -> 28.05`4., 165 -> 
          27.96`4., 166 -> 27.96`4., 167 -> 28.17`4., 168 -> 28.41`4., 169 -> 
          28.41`4., 170 -> 28.6`4., 171 -> 28.36`4., 172 -> 28.4`4., 173 -> 
          28.5`4., 174 -> 28.39`4., 175 -> 29.4`4., 176 -> 30.07`4., 177 -> 
          28.74`4., 178 -> 28.59`4., 179 -> 28.49`4., 180 -> 28.77`4., 181 -> 
          28.63`4., 182 -> 28.59`4., 183 -> 29.56`4., 184 -> 30.62`4., 185 -> 
          30.39`4., 186 -> 31.54`4., 187 -> 31.72`4., 188 -> 31.57`4., 189 -> 
          32.38`4., 190 -> 32.87`4., 191 -> 32.49`4., 192 -> 32.93`4., 193 -> 
          33.26`4., 194 -> 33.51`4., 195 -> 33.08`4., 196 -> 32.76`4., 197 -> 
          32.43`4., 198 -> 32.46`4., 199 -> 32.8`4., 200 -> 33.53`4., 201 -> 
          33.85`4., 202 -> 34.08`4., 203 -> 34.87`4., 204 -> 35.08`4., 205 -> 
          34.85`4., 206 -> 34.61`4., 207 -> 34.15`4., 208 -> 34.27`4., 209 -> 
          35.02`4., 210 -> 34.88`4., 211 -> 35.03`4., 212 -> 34.9`4., 213 -> 
          35.59`4., 214 -> 34.99`4., 215 -> 34.78`4., 216 -> 34.96`4., 217 -> 
          35.67`4., 218 -> 35.47`4., 219 -> 34.84`4., 220 -> 35.`4., 221 -> 
          34.72`4., 222 -> 34.4`4., 223 -> 35.`4., 224 -> 34.98`4., 225 -> 
          34.59`4., 226 -> 33.49`4., 227 -> 33.27`4., 228 -> 33.72`4., 229 -> 
          33.67`4., 230 -> 34.35`4., 231 -> 34.62`4., 232 -> 34.54`4., 233 -> 
          34.36`4., 234 -> 33.94`4., 235 -> 34.01`4., 236 -> 34.21`4., 237 -> 
          34.33`4., 238 -> 34.35`4., 239 -> 34.7`4., 240 -> 35.69`4., 241 -> 
          35.67`4., 242 -> 36.17`4., 243 -> 36.27`4., 244 -> 35.74`4., 245 -> 
          35.44`4., 246 -> 31.4`4., 247 -> 32.01`4., 248 -> 31.82`4., 249 -> 
          31.96`4., 250 -> 31.39`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$545702 = True, 
        System`TradingChartDump`$gridlines$545702 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$545702, 
        System`TradingChartDump`$plotrangemin$545702 = 25.337956692913384`, 
        System`TradingChartDump`$plotrangemax$545702 = 37.48638507686539, 
        System`TradingChartDump`$layoutData$545702, 
        System`TradingChartDump`$gridlinesscope$545702 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$545702 = {True, True}, 
        System`TradingChartDump`$indicators$545702 = {
         FinancialIndicator["TRIX", 15]}, 
        System`TradingChartDump`$mouseQ$545702 = False, 
        System`TradingChartDump`$modelData$545702 = 
        System`TradingChartDump`modelData$544622, 
        System`TradingChartDump`$sy$545702 = Identity, 
        System`TradingChartDump`$isy$545702 = Identity, 
        System`TradingChartDump`$appearance$545702 = Automatic, 
        System`TradingChartDump`$perfgoal$545702 = "Quality", 
        System`TradingChartDump`$axesorigin$545702 = Automatic, 
        System`TradingChartDump`$framestyle$545702 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$545702 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$545702 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$545702 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$545702 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$545702, 
        System`TradingChartDump`$newgridlines$545702 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{25.337956692913384`, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$545702 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$545702 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$545702 = "GraphicsFrame", 
        System`TradingChartDump`$frame$545702 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$545702 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$545702 = 
              Switch[System`TradingChartDump`$highlightposition$545702, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$545702], {
                 1, System`TradingChartDump`$length$545702}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$545702], {
                 1, System`TradingChartDump`$length$545702}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$545702, 
                   Charting`nearestDate[System`TradingChartDump`$dates$545702, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$545702]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$545702]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$545702, 
                    Floor[System`TradingChartDump`$controlmin$545702] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$545702, 
                    Floor[System`TradingChartDump`$controlmax$545702]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$545702 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$545702 = 
            If[System`TradingChartDump`$fastpos$545702 =!= True, 
              System`TradingChartDump`$fastpos$545702 = 
               Clip[System`TradingChartDump`$fastpos$545702, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$545702 = (
                  Floor[System`TradingChartDump`$controlmax$545702] - Floor[
                  System`TradingChartDump`$controlmin$545702]) (
                  System`TradingChartDump`$fastpos$545702/100) + 
                Floor[System`TradingChartDump`$controlmin$545702]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$545702], {
                Floor[System`TradingChartDump`$controlmin$545702] + 1, 
                 Floor[System`TradingChartDump`$controlmax$545702]}], 
              System`TradingChartDump`$staticindicatorpos$545702]; 
           System`TradingChartDump`$mouseQ$545702 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$545702]], 
              System`TradingChartDump`$highlightposition$545702 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$545702 = If[
              And[
              System`TradingChartDump`$bouncingballQ$545702, 
               System`TradingChartDump`$mouseQ$545702, 
               System`TradingChartDump`$appearance$545702 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$545702[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$545702]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$545702[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$545702, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$545702[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$545702]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$545702[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$545702[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545702, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545702[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545702, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545702, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545702[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545702[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$545702 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$545702, 
                 System`TradingChartDump`$defaultframeticksstyle$545702, 
                 System`TradingChartDump`$defaultlabelstyle$545702, 
                 System`TradingChartDump`$framestyle$545702, 
                 System`TradingChartDump`$frameticksstyle$545702, 
                 System`TradingChartDump`$labelstyle$545702}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545702 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$545702, 
                 System`TradingChartDump`$labelstyle$545702, 
                 System`TradingChartDump`$defaultframeticksstyle$545702, 
                 System`TradingChartDump`$defaultlabelstyle$545702}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545702 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545702, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$545702 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545702, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$545702 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545702, {}, Infinity]; 
           If[System`TradingChartDump`$tickstextstyle$545702 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$545702 = 
             Part[System`TradingChartDump`$tickstextstyle$545702, 1], 
             System`TradingChartDump`$tickstextstyle$545702 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545702[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545702, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545702[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545702[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545702[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$545702[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545702, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$545702]], 
                    Style[":", System`TradingChartDump`$textstyle$545702]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$545702[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545702]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545702[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$545702[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$545702, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$545702]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$545702[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545702, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545702[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545702, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545702, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$545702[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545702[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545702[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$545702[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$545702[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$545702], 1], 
                   Floor[System`TradingChartDump`$controlmax$545702]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$545702[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$545702[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$545702[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$545702[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$545702[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545702[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$545702[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$545702[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$545702[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545702[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$545702[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$545702[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$545702[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$545702[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$545702[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$545702, 
                  System`TradingChartDump`$mouseQ$545702], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$545702 - 0.5, 
                   System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$545702 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$545702 + 0.5, 
                    System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545702, 1]}, {
                    System`TradingChartDump`$indicatorpos$545702 + 0.5, 
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$545702[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$545702, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$545702[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545702]]], {}]; 
              System`TradingChartDump`$subplotgridlines$545702[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$545702[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$545702[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545702[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$545702 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$545702, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545702, 
                   System`TradingChartDump`$opens$545702]], 12, 
                 System`TradingChartDump`$textstyle$545702, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$545702, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545702, 
                   System`TradingChartDump`$highs$545702]], 12, 
                 System`TradingChartDump`$textstyle$545702, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$545702, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545702, 
                   System`TradingChartDump`$lows$545702]], 12, 
                 System`TradingChartDump`$textstyle$545702, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$545702, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545702, 
                   System`TradingChartDump`$closes$545702]], 12, 
                 System`TradingChartDump`$textstyle$545702, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545702, 
                   System`TradingChartDump`$visdates$545702]], 12, 
                 System`TradingChartDump`$textstyle$545702, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$545702, 
                  System`TradingChartDump`$mouseQ$545702], {{
                  System`TradingChartDump`$timestampstyle$545702, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$545702 - 0.5, 
                    System`TradingChartDump`$plotrangemin$545702}, 
                    If[
                    System`TradingChartDump`$timestampdepth$545702 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$545702[1]}, {
                    System`TradingChartDump`$indicatorpos$545702 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545702}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545702, 1]}, {
                    System`TradingChartDump`$indicatorpos$545702 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545702}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$545702, {
               System`TradingChartDump`$highlightstyle$545702, 
                Dynamic[System`TradingChartDump`$ohlcpoint$545702]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$545702[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545702, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$545702[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$545702[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$545702, Length[
                    System`TradingChartDump`$layoutData$545702[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$545702}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$545702] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$545702] + 0.5}, {
                System`TradingChartDump`$plotrangemin$545702, 
                 System`TradingChartDump`$plotrangemax$545702}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$545702, Left, {
                 False, System`TradingChartDump`$frame$545702}, 
                 Blank[], {System`TradingChartDump`$frame$545702, False}], {
                False, System`TradingChartDump`$frame$545702}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$545702, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$545702]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$545702 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           387.0228610767757}, {-286.92264150943396`, -65.76792452830186}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545702 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545702, 1]], 
               Part[System`TradingChartDump`$framestyle$545702, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$545702]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$545702} -> 
                   System`TradingChartDump`$isy$545702[
                    System`TradingChartDump`$plotrangemin$545702], {
                    0, System`TradingChartDump`$plotrangemax$545702} -> 
                   System`TradingChartDump`$isy$545702[
                    System`TradingChartDump`$plotrangemax$545702]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$545702[
                   System`TradingChartDump`$plotrangemin$545702], 
                   System`TradingChartDump`$isy$545702[
                   System`TradingChartDump`$plotrangemax$545702]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$545702, 
                   System`TradingChartDump`$isy$545702}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545702, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545702 > 
                    System`TradingChartDump`$plotrangemin$545702, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545702 > 
                    System`TradingChartDump`$plotrangemin$545702, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545702, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545702 > 
                    System`TradingChartDump`$plotrangemin$545702, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545702 > 
                    System`TradingChartDump`$plotrangemin$545702, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545702, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545702, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545702 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545702,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545702], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545702 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545702, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545702]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$545702, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$545702[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$545702[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545702, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$545702[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$545702, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545702[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545702, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545702[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545702[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545702[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545702[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545702], 
                    Style[":", System`TradingChartDump`$textstyle$545702]], 
                    Style[":", System`TradingChartDump`$textstyle$545702]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$545702[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545702]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545702[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$545702}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$545702, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$545702 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$545702[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$545702, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$545702, Left, {
                    False, System`TradingChartDump`$frame$545702}, 
                    Blank[], {
                    System`TradingChartDump`$frame$545702, False}], {
                   System`TradingChartDump`$frame$545702, 
                    System`TradingChartDump`$frame$545702}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$545702, 
                    System`TradingChartDump`$controlmax$545702}] + 0.5, {
                   System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$545702]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$545702) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$545702 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$545702 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$545702, 1]], 
                   Part[System`TradingChartDump`$framestyle$545702, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$545702]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545702[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545702[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$545702[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545702, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545702, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$545702, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$545702, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$545702 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
545702, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$545702], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$545702 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$545702, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$545702]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$545702, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$545702) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$545702 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$545702[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940382`, 
           475.9407855006933}, {-55.989622641509435`, -0.7009433962264069}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$545702, 
              Dynamic[System`TradingChartDump`$ohlclabel$545702], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$545702}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545702 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545702, 2]], 
               Part[System`TradingChartDump`$framestyle$545702, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$545702]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$545702, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$545702, 
                    System`TradingChartDump`$controlmax$545702}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$545702] + 
                    0.5, System`TradingChartDump`$plotrangemin$545702}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$545702], 
                    System`TradingChartDump`$plotrangemin$545702}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$545702, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545702, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545702, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545702 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545702, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545702], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545702 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545702,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545702]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$545702] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$545702[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$545702] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$545702[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$545702] = {HoldPattern[
               System`TradingChartDump`$min$545702[1]] :> -0.31}}, {
          DownValues[System`TradingChartDump`$max$545702] = {HoldPattern[
               System`TradingChartDump`$max$545702[1]] :> 
             0.7000000000000001}}, {
          DownValues[System`TradingChartDump`$subplotvalue$545702] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$545702[1, 1]] :> 
             Invisible[-0.05], HoldPattern[
               System`TradingChartDump`$subplotvalue$545702[1, 2]] :> 
             Invisible[-0.08]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$545702] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$545702[1]] :> {0, 
               Rational[1, 2]}}}, {
          DownValues[System`TradingChartDump`$layoutData$545702] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$545702["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "AllValues"]] :> CompressedData["
1:eJxVVgk8VVv7Fo1Cg6GuSlKZKhS5nb323uc5XE1mGZtHXEMpypdyQyFSEn2K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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545702["AppendedAdjust"]] :> 
             0.10115363851299045`, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "AppendedBox"]] :> {-0.3525644223190959, 0.9164462145690282}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "AppendedMin"]] :> -0.3571545777948395, HoldPattern[
               System`TradingChartDump`$layoutData$545702["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$545702["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$545702["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$545702["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545702["DataMax"]] :> 
             36.43, HoldPattern[
               System`TradingChartDump`$layoutData$545702["DataMin"]] :> 
             25.86614923134608, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "MainChartAllValues"]] :> CompressedData["
1:eJxdlglYzdv6x1OZ0mBocEISmtBAOvZv2t9dJ1NzGs1jdRqIoiuiolJSGtwo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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "MainChartPoints"]] :> CompressedData["
1:eJxdlltoXFUUhqdFUIKgYkSRUqdVSqylVGNtmzbJTmqaNEmTTO6XSXLmfp9U
pCiRyqFShCIEn0QRGS/4IhTBlyAqscUnKyIoVRCZIoiQIgWplD6Zk/V/D+cc
CMOftf/9r9tee+9Jr4zn7onFYne3/nbob2eM71b3D9e2vuETTv9wN1ZbL/ff
AN/nrt5uS65dAT/o3ns3+MCtruX6x2c7L4EfcwF7dRK8yz1xcTOx/gc47tau
bG34QKfwXrMvgZ9yAb21Dt4nPXCbC5bvvgje7zoDB86DD0T4B+3XBx9y41vs
zYe6hJ+19QfBz7mBIAH3gttdEF7Lo+DnLb6f2e+wxbMGfsH8/Q18xL0WEO6C
j7qbgfub4GPupSCAW+AOy8cH4OMuGQjsQv+Erf8ce2cEd4nP+m7T7wA7q+dO
Yd9ZPK3Ye8L58XtcABNHsfcq39gjOHbS/Re0yznsJ9UP2F+0/daxC7+KvS+i
3xeJ75TWC/unpIe9X3zs/VafH+m/AePfEfYHrB7PwD8tf+Gfdk9vFwD7oPoB
+2DkPAyZ3ij7D1k/9WMfVv9iH1Y/YT8T9tc/Y/p/Yx+x+H7CPqL+Oi77qPkz
J+yPuvz2h33Mfp2wG1N/sH5M/Sy8MaZ5AD9h8V+XvktE/Emon4U3EpH8jls8
Rfjj7pNguyfhy94Gf9z2fxv9CTuvlzvEF64L+xPW373CGxN2HnYLxyZVX/iT
qhf8Sc0z+JOqH/pTyjf8KYvvM/hTrj34/oU/Fd4vNq3zBH9a8wa+7HeOiT9t
/dIHfybi/4zmKfwZ2+9N9GfUP/Bn1W/wZ83fL+DPql/gz+r8wZ9TveifOVv/
F/w55Z/+mbP4W8jfvK3/FP15038Z/rzbvo/eQl/r96G/EK6XWzB+O/27oP6E
LzwDP2n+DMJPhvf3k6Y/DD8Zzm9s0epdgb9o/bAKf9H41+Av2vn5EP5S2D8X
wf6SzdOv4S9Z/g+Rv2Wbd4fJv/A54l/WPCb/y7b/O/A9nRfhuBeuj/OsfheE
PU/9yf6e7gvhhvb7B3893ffCTc/i34N+yuI5i34q7L9L2X33Pvop3Wfop8Lx
NFK6b4k3pfkg3Eypnuinw/Mkntb9j34Ee+mIfjrsXyOt9xH6aZ1/9NPqL+Z3
xs7Pn+hnNC/Rz2j+o58Jx+NndH+in7H++xL9yH7NjPqL+LM6r+hnw/eHy2pe
yl8vq/mBftbyeb/sjazV7zb6EdzMav4Tfy48/+MR7HLh+9TLWb6T3A85zSf0
c/o/90XO8psRbrKe+ycffl/E8zpv6OfVX+jLfh79vM3j79DP63yjH+E385H3
YSH8PosX5K+wK+i+6JZ+QfUW9gvqX+FGQfPBSb9geivCTel1CceK5t8rwvGi
/Bd2wt8Ke0X5I+zLnhJuaL8j6Bf1nkC/qPyjX7J4r6Jfsn66iX5J86hH+iXF
I+zLfkm4IX5VeKNk52VEuFmy8/iwcKxs53WvcFz4grAraz6hXzZ/30C/rPsK
/bL19/foly3fr6Mvfgb9iu4L9Ct2Xn5Bv2L9/hX6Fd036Ff0i77WJ9Gv6D5E
P7I+VlU/o1+1/YfQr5r/31D/quXnI+pfNb3fqX9V/lP/qtXjAPpV3dfo1/Se
Qb+meYt+Te8f9GvWbzuIv2b5e5z4a9YP+4m/FtGv6T2Mft32/xX9eiT/wo/0
Sr+ufhH267rf0Nd+6+jX1e86n826/Kf/V/Relj2+onkp7FbUL93ufxyzRGk=

              "], HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545702["NewSubplot"]] :> {
               FinancialIndicator["TRIX", 15]}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545702["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "PlotRangeMin"]] :> -0.3571545777948395, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$545702["Space"]] :> 
             3.6430000000000002`, HoldPattern[
               System`TradingChartDump`$layoutData$545702["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, 0}, {250., 0}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJw1lwlUjfkbx69iyJotMuEW/7ENqqmIkW+79n3f7r3d211aCUmWO5YQRkQi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                    "]]}, {
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Line[CompressedData["
1:eJw1lws41Pkax6daXTYppbI2ZXUj1ci9G99yKRLjfknMMDNuY2winG5DaWkt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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "SubplotIndicatorGridLines"]] :> {{0, 
                Rational[1, 2]}}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "TRIX"}]], 
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], " ", "SMA"}]]}},
              HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["TRIX", 15]}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "SubplotIndicatorParameters"]] :> {{{15}, {{9}}, {{9}}}}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "SubplotIndicatorPoints"]] :> {{{}, {{2., 0.26}, {2., 
                0.26}}, {{3., 0.16}, {3., 0.21}}, {{4., 0.11}, {4., 0.18}}, {{
                5., 0.08}, {5., 0.15}}, {{6., 0.05}, {6., 0.13}}, {{7., 
                0.04}, {7., 0.12}}, {{8., 0.04}, {8., 0.1}}, {{9., 0.04}, {9.,
                 0.1}}, {{10., 0.04}, {10., 0.09}}, {{11., 0.04}, {11., 
                0.06}}, {{12., 0.04}, {12., 0.05}}, {{13., 0.04}, {13., 
                0.04}}, {{14., 0.04}, {14., 0.04}}, {{15., 0.04}, {15., 
                0.04}}, {{16., 0.12}, {16., 0.05}}, {{17., 0.09}, {17., 
                0.05}}, {{18., 0.09}, {18., 0.06}}, {{19., 0.09}, {19., 
                0.06}}, {{20., 0.1}, {20., 0.07}}, {{21., 0.12}, {21., 
                0.08}}, {{22., 0.13}, {22., 0.09}}, {{23., 0.15}, {23., 
                0.1}}, {{24., 0.16}, {24., 0.12}}, {{25., 0.17}, {25., 
                0.12}}, {{26., 0.17}, {26., 0.13}}, {{27., 0.18}, {27., 
                0.14}}, {{28., 0.19}, {28., 0.15}}, {{29., 0.2}, {29., 
                0.16}}, {{30., 0.21}, {30., 0.17}}, {{31., 0.2}, {31., 
                0.18}}, {{32., 0.2}, {32., 0.19}}, {{33., 0.2}, {33., 
                0.19}}, {{34., 0.2}, {34., 0.2}}, {{35., 0.19}, {35., 
                0.2}}, {{36., 0.18}, {36., 0.2}}, {{37., 0.17}, {37., 
                0.2}}, {{38., 0.16}, {38., 0.19}}, {{39., 0.15}, {39., 
                0.19}}, {{40., 0.14}, {40., 0.18}}, {{41., 0.13}, {41., 
                0.17}}, {{42., 0.13}, {42., 0.16}}, {{43., 0.12}, {43., 
                0.15}}, {{44., 0.11}, {44., 0.14}}, {{45., 0.1}, {45., 
                0.14}}, {{46., 0.09}, {46., 0.13}}, {{47., 0.08}, {47., 
                0.12}}, {{48., 0.07}, {48., 0.11}}, {{49., 0.06}, {49., 
                0.1}}, {{50., 0.05}, {50., 0.09}}, {{51., 0.04}, {51., 
                0.08}}, {{52., 0.03}, {52., 0.07}}, {{53., 0.02}, {53., 
                0.06}}, {{54., 0.}, {54., 0.05}}, {{55., -0.02}, {55., 
                0.04}}, {{56., -0.05}, {56., 0.02}}, {{57., -0.07}, {57., 
                0.01}}, {{58., -0.1}, {58., -0.01}}, {{59., -0.12}, {
                59., -0.03}}, {{60., -0.14}, {60., -0.05}}, {{61., -0.17}, {
                61., -0.07}}, {{62., -0.19}, {62., -0.09}}, {{63., -0.21}, {
                63., -0.12}}, {{64., -0.23}, {64., -0.14}}, {{65., -0.25}, {
                65., -0.16}}, {{66., -0.26}, {66., -0.18}}, {{67., -0.28}, {
                67., -0.2}}, {{68., -0.29}, {68., -0.22}}, {{69., -0.3}, {
                69., -0.24}}, {{70., -0.3}, {70., -0.26}}, {{71., -0.3}, {
                71., -0.27}}, {{72., -0.29}, {72., -0.28}}, {{73., -0.28}, {
                73., -0.28}}, {{74., -0.27}, {74., -0.29}}, {{75., -0.27}, {
                75., -0.29}}, {{76., -0.26}, {76., -0.29}}, {{77., -0.25}, {
                77., -0.28}}, {{78., -0.24}, {78., -0.27}}, {{79., -0.23}, {
                79., -0.27}}, {{80., -0.22}, {80., -0.26}}, {{81., -0.21}, {
                81., -0.25}}, {{82., -0.19}, {82., -0.24}}, {{83., -0.18}, {
                83., -0.23}}, {{84., -0.18}, {84., -0.22}}, {{85., -0.18}, {
                85., -0.21}}, {{86., -0.19}, {86., -0.2}}, {{87., -0.2}, {
                87., -0.2}}, {{88., -0.21}, {88., -0.19}}, {{89., -0.22}, {
                89., -0.19}}, {{90., -0.23}, {90., -0.2}}, {{91., -0.25}, {
                91., -0.2}}, {{92., -0.26}, {92., -0.21}}, {{93., -0.27}, {
                93., -0.22}}, {{94., -0.28}, {94., -0.23}}, {{95., -0.29}, {
                95., -0.24}}, {{96., -0.3}, {96., -0.25}}, {{97., -0.3}, {
                97., -0.27}}, {{98., -0.31}, {98., -0.27}}, {{99., -0.31}, {
                99., -0.28}}, {{100., -0.3}, {100., -0.29}}, {{101., -0.29}, {
                101., -0.29}}, {{102., -0.27}, {102., -0.29}}, {{
                103., -0.25}, {103., -0.29}}, {{104., -0.23}, {
                104., -0.28}}, {{105., -0.2}, {105., -0.27}}, {{
                106., -0.17}, {106., -0.26}}, {{107., -0.14}, {
                107., -0.24}}, {{108., -0.11}, {108., -0.22}}, {{
                109., -0.09}, {109., -0.19}}, {{110., -0.06}, {
                110., -0.17}}, {{111., -0.04}, {111., -0.14}}, {{
                112., -0.03}, {112., -0.12}}, {{113., -0.01}, {
                113., -0.09}}, {{114., 0.01}, {114., -0.07}}, {{115., 0.02}, {
                115., -0.05}}, {{116., 0.03}, {116., -0.03}}, {{117., 0.03}, {
                117., -0.02}}, {{118., 0.03}, {118., 0.}}, {{119., 0.03}, {
                119., 0.01}}, {{120., 0.02}, {120., 0.02}}, {{121., 0.02}, {
                121., 0.02}}, {{122., 0.01}, {122., 0.02}}, {{123., 0.}, {
                123., 0.02}}, {{124., 0.}, {124., 0.02}}, {{125., -0.01}, {
                125., 0.02}}, {{126., -0.01}, {126., 0.01}}, {{127., -0.01}, {
                127., 0.01}}, {{128., -0.01}, {128., 0.}}, {{129., -0.01}, {
                129., 0.}}, {{130., 0.}, {130., 0.}}, {{131., 0.01}, {131., 
                0.}}, {{132., 0.02}, {132., 0.}}, {{133., 0.03}, {133., 
                0.}}, {{134., 0.05}, {134., 0.01}}, {{135., 0.06}, {135., 
                0.02}}, {{136., 0.08}, {136., 0.03}}, {{137., 0.09}, {137., 
                0.04}}, {{138., 0.1}, {138., 0.05}}, {{139., 0.12}, {139., 
                0.06}}, {{140., 0.13}, {140., 0.08}}, {{141., 0.14}, {141., 
                0.09}}, {{142., 0.15}, {142., 0.1}}, {{143., 0.15}, {143., 
                0.11}}, {{144., 0.15}, {144., 0.12}}, {{145., 0.15}, {145., 
                0.13}}, {{146., 0.14}, {146., 0.14}}, {{147., 0.14}, {147., 
                0.14}}, {{148., 0.13}, {148., 0.14}}, {{149., 0.13}, {149., 
                0.14}}, {{150., 0.12}, {150., 0.14}}, {{151., 0.12}, {151., 
                0.14}}, {{152., 0.11}, {152., 0.13}}, {{153., 0.11}, {153., 
                0.13}}, {{154., 0.1}, {154., 0.12}}, {{155., 0.09}, {155., 
                0.12}}, {{156., 0.09}, {156., 0.11}}, {{157., 0.09}, {157., 
                0.11}}, {{158., 0.09}, {158., 0.1}}, {{159., 0.08}, {159., 
                0.1}}, {{160., 0.09}, {160., 0.09}}, {{161., 0.09}, {161., 
                0.09}}, {{162., 0.09}, {162., 0.09}}, {{163., 0.09}, {163., 
                0.09}}, {{164., 0.09}, {164., 0.09}}, {{165., 0.09}, {165., 
                0.09}}, {{166., 0.09}, {166., 0.09}}, {{167., 0.09}, {167., 
                0.09}}, {{168., 0.09}, {168., 0.09}}, {{169., 0.09}, {169., 
                0.09}}, {{170., 0.09}, {170., 0.09}}, {{171., 0.09}, {171., 
                0.09}}, {{172., 0.09}, {172., 0.09}}, {{173., 0.09}, {173., 
                0.09}}, {{174., 0.09}, {174., 0.09}}, {{175., 0.1}, {175., 
                0.09}}, {{176., 0.1}, {176., 0.09}}, {{177., 0.1}, {177., 
                0.09}}, {{178., 0.1}, {178., 0.09}}, {{179., 0.11}, {179., 
                0.1}}, {{180., 0.11}, {180., 0.1}}, {{181., 0.12}, {181., 
                0.1}}, {{182., 0.13}, {182., 0.11}}, {{183., 0.14}, {183., 
                0.11}}, {{184., 0.15}, {184., 0.12}}, {{185., 0.16}, {185., 
                0.12}}, {{186., 0.17}, {186., 0.13}}, {{187., 0.18}, {187., 
                0.14}}, {{188., 0.2}, {188., 0.15}}, {{189., 0.22}, {189., 
                0.16}}, {{190., 0.24}, {190., 0.17}}, {{191., 0.26}, {191., 
                0.19}}, {{192., 0.28}, {192., 0.2}}, {{193., 0.3}, {193., 
                0.22}}, {{194., 0.34}, {194., 0.24}}, {{195., 0.37}, {195., 
                0.26}}, {{196., 0.4}, {196., 0.29}}, {{197., 0.44}, {197., 
                0.32}}, {{198., 0.48}, {198., 0.35000000000000003`}}, {{199., 
                0.52}, {199., 0.38}}, {{200., 0.55}, {200., 
                0.41000000000000003`}}, {{201., 0.59}, {201., 0.44}}, {{202., 
                0.62}, {202., 0.48}}, {{203., 0.64}, {203., 0.51}}, {{204., 
                0.66}, {204., 0.55}}, {{205., 0.68}, {205., 0.58}}, {{206., 
                0.6900000000000001}, {206., 0.6}}, {{207., 
                0.7000000000000001}, {207., 0.63}}, {{208., 
                0.7000000000000001}, {208., 0.65}}, {{209., 
                0.7000000000000001}, {209., 0.67}}, {{210., 
                0.6900000000000001}, {210., 0.68}}, {{211., 0.67}, {211., 
                0.68}}, {{212., 0.65}, {212., 0.68}}, {{213., 0.63}, {213., 
                0.68}}, {{214., 0.61}, {214., 0.67}}, {{215., 0.58}, {215., 
                0.66}}, {{216., 0.56}, {216., 0.64}}, {{217., 0.54}, {217., 
                0.62}}, {{218., 0.51}, {218., 0.6}}, {{219., 0.48}, {219., 
                0.58}}, {{220., 0.46}, {220., 0.56}}, {{221., 0.43}, {221., 
                0.53}}, {{222., 0.4}, {222., 0.51}}, {{223., 0.38}, {223., 
                0.48}}, {{224., 0.36}, {224., 0.46}}, {{225., 0.34}, {225., 
                0.43}}, {{226., 0.32}, {226., 0.41000000000000003`}}, {{227., 
                0.3}, {227., 0.39}}, {{228., 0.27}, {228., 0.36}}, {{229., 
                0.24}, {229., 0.34}}, {{230., 0.21}, {230., 0.31}}, {{231., 
                0.18}, {231., 0.29}}, {{232., 0.15}, {232., 0.26}}, {{233., 
                0.11}, {233., 0.23}}, {{234., 0.09}, {234., 0.21}}, {{235., 
                0.06}, {235., 0.18}}, {{236., 0.03}, {236., 0.15}}, {{237., 
                0.01}, {237., 0.12}}, {{238., -0.02}, {238., 0.09}}, {{
                239., -0.05}, {239., 0.06}}, {{240., -0.07}, {240., 0.03}}, {{
                241., -0.09}, {241., 0.01}}, {{242., -0.1}, {242., -0.02}}, {{
                243., -0.1}, {243., -0.04}}, {{244., -0.09}, {
                244., -0.05}}, {{245., -0.09}, {245., -0.07}}, {{
                246., -0.08}, {246., -0.08}}, {{247., -0.07}, {
                247., -0.08}}, {{248., -0.06}, {248., -0.08}}, {{
                249., -0.06}, {249., -0.08}}, {{250., -0.05}, {
                250., -0.08}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "SubplotIndicatorValues"]] :> {{{"", ""}, {0.26, 0.26}, {0.16, 
                0.21}, {0.11, 0.18}, {0.08, 0.15}, {0.05, 0.13}, {0.04, 
                0.12}, {0.04, 0.1}, {0.04, 0.1}, {0.04, 0.09}, {0.04, 0.06}, {
                0.04, 0.05}, {0.04, 0.04}, {0.04, 0.04}, {0.04, 0.04}, {0.12, 
                0.05}, {0.09, 0.05}, {0.09, 0.06}, {0.09, 0.06}, {0.1, 
                0.07}, {0.12, 0.08}, {0.13, 0.09}, {0.15, 0.1}, {0.16, 
                0.12}, {0.17, 0.12}, {0.17, 0.13}, {0.18, 0.14}, {0.19, 
                0.15}, {0.2, 0.16}, {0.21, 0.17}, {0.2, 0.18}, {0.2, 0.19}, {
                0.2, 0.19}, {0.2, 0.2}, {0.19, 0.2}, {0.18, 0.2}, {0.17, 
                0.2}, {0.16, 0.19}, {0.15, 0.19}, {0.14, 0.18}, {0.13, 
                0.17}, {0.13, 0.16}, {0.12, 0.15}, {0.11, 0.14}, {0.1, 
                0.14}, {0.09, 0.13}, {0.08, 0.12}, {0.07, 0.11}, {0.06, 
                0.1}, {0.05, 0.09}, {0.04, 0.08}, {0.03, 0.07}, {0.02, 
                0.06}, {0., 0.05}, {-0.02, 0.04}, {-0.05, 0.02}, {-0.07, 
                0.01}, {-0.1, -0.01}, {-0.12, -0.03}, {-0.14, -0.05}, {-0.17, \
-0.07}, {-0.19, -0.09}, {-0.21, -0.12}, {-0.23, -0.14}, {-0.25, -0.16}, \
{-0.26, -0.18}, {-0.28, -0.2}, {-0.29, -0.22}, {-0.3, -0.24}, {-0.3, -0.26}, \
{-0.3, -0.27}, {-0.29, -0.28}, {-0.28, -0.28}, {-0.27, -0.29}, {-0.27, \
-0.29}, {-0.26, -0.29}, {-0.25, -0.28}, {-0.24, -0.27}, {-0.23, -0.27}, \
{-0.22, -0.26}, {-0.21, -0.25}, {-0.19, -0.24}, {-0.18, -0.23}, {-0.18, \
-0.22}, {-0.18, -0.21}, {-0.19, -0.2}, {-0.2, -0.2}, {-0.21, -0.19}, {-0.22, \
-0.19}, {-0.23, -0.2}, {-0.25, -0.2}, {-0.26, -0.21}, {-0.27, -0.22}, {-0.28, \
-0.23}, {-0.29, -0.24}, {-0.3, -0.25}, {-0.3, -0.27}, {-0.31, -0.27}, {-0.31, \
-0.28}, {-0.3, -0.29}, {-0.29, -0.29}, {-0.27, -0.29}, {-0.25, -0.29}, \
{-0.23, -0.28}, {-0.2, -0.27}, {-0.17, -0.26}, {-0.14, -0.24}, {-0.11, \
-0.22}, {-0.09, -0.19}, {-0.06, -0.17}, {-0.04, -0.14}, {-0.03, -0.12}, \
{-0.01, -0.09}, {0.01, -0.07}, {0.02, -0.05}, {0.03, -0.03}, {0.03, -0.02}, {
                0.03, 0.}, {0.03, 0.01}, {0.02, 0.02}, {0.02, 0.02}, {0.01, 
                0.02}, {0., 0.02}, {0., 0.02}, {-0.01, 0.02}, {-0.01, 
                0.01}, {-0.01, 0.01}, {-0.01, 0.}, {-0.01, 0.}, {0., 0.}, {
                0.01, 0.}, {0.02, 0.}, {0.03, 0.}, {0.05, 0.01}, {0.06, 
                0.02}, {0.08, 0.03}, {0.09, 0.04}, {0.1, 0.05}, {0.12, 
                0.06}, {0.13, 0.08}, {0.14, 0.09}, {0.15, 0.1}, {0.15, 
                0.11}, {0.15, 0.12}, {0.15, 0.13}, {0.14, 0.14}, {0.14, 
                0.14}, {0.13, 0.14}, {0.13, 0.14}, {0.12, 0.14}, {0.12, 
                0.14}, {0.11, 0.13}, {0.11, 0.13}, {0.1, 0.12}, {0.09, 
                0.12}, {0.09, 0.11}, {0.09, 0.11}, {0.09, 0.1}, {0.08, 0.1}, {
                0.09, 0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 
                0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 
                0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 
                0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.1, 0.09}, {0.1, 0.09}, {
                0.1, 0.09}, {0.1, 0.09}, {0.11, 0.1}, {0.11, 0.1}, {0.12, 
                0.1}, {0.13, 0.11}, {0.14, 0.11}, {0.15, 0.12}, {0.16, 
                0.12}, {0.17, 0.13}, {0.18, 0.14}, {0.2, 0.15}, {0.22, 
                0.16}, {0.24, 0.17}, {0.26, 0.19}, {0.28, 0.2}, {0.3, 0.22}, {
                0.34, 0.24}, {0.37, 0.26}, {0.4, 0.29}, {0.44, 0.32}, {0.48, 
                0.35000000000000003`}, {0.52, 0.38}, {0.55, 
                0.41000000000000003`}, {0.59, 0.44}, {0.62, 0.48}, {0.64, 
                0.51}, {0.66, 0.55}, {0.68, 0.58}, {0.6900000000000001, 
                0.6}, {0.7000000000000001, 0.63}, {0.7000000000000001, 
                0.65}, {0.7000000000000001, 0.67}, {0.6900000000000001, 
                0.68}, {0.67, 0.68}, {0.65, 0.68}, {0.63, 0.68}, {0.61, 
                0.67}, {0.58, 0.66}, {0.56, 0.64}, {0.54, 0.62}, {0.51, 
                0.6}, {0.48, 0.58}, {0.46, 0.56}, {0.43, 0.53}, {0.4, 0.51}, {
                0.38, 0.48}, {0.36, 0.46}, {0.34, 0.43}, {0.32, 
                0.41000000000000003`}, {0.3, 0.39}, {0.27, 0.36}, {0.24, 
                0.34}, {0.21, 0.31}, {0.18, 0.29}, {0.15, 0.26}, {0.11, 
                0.23}, {0.09, 0.21}, {0.06, 0.18}, {0.03, 0.15}, {0.01, 
                0.12}, {-0.02, 0.09}, {-0.05, 0.06}, {-0.07, 0.03}, {-0.09, 
                0.01}, {-0.1, -0.02}, {-0.1, -0.04}, {-0.09, -0.05}, {-0.09, \
-0.07}, {-0.08, -0.08}, {-0.07, -0.08}, {-0.06, -0.08}, {-0.06, -0.08}, \
{-0.05, -0.08}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$545702["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$545702["YRange"]] :> 36.43,
              HoldPattern[
               System`TradingChartDump`$layoutData$545702[
               "SubplotPoints", {1}]] :> {{}, {0.26, 0.26}, {0.16, 0.21}, {
               0.11, 0.18}, {0.08, 0.15}, {0.05, 0.13}, {0.04, 0.12}, {0.04, 
               0.1}, {0.04, 0.1}, {0.04, 0.09}, {0.04, 0.06}, {0.04, 0.05}, {
               0.04, 0.04}, {0.04, 0.04}, {0.04, 0.04}, {0.12, 0.05}, {0.09, 
               0.05}, {0.09, 0.06}, {0.09, 0.06}, {0.1, 0.07}, {0.12, 0.08}, {
               0.13, 0.09}, {0.15, 0.1}, {0.16, 0.12}, {0.17, 0.12}, {0.17, 
               0.13}, {0.18, 0.14}, {0.19, 0.15}, {0.2, 0.16}, {0.21, 0.17}, {
               0.2, 0.18}, {0.2, 0.19}, {0.2, 0.19}, {0.2, 0.2}, {0.19, 
               0.2}, {0.18, 0.2}, {0.17, 0.2}, {0.16, 0.19}, {0.15, 0.19}, {
               0.14, 0.18}, {0.13, 0.17}, {0.13, 0.16}, {0.12, 0.15}, {0.11, 
               0.14}, {0.1, 0.14}, {0.09, 0.13}, {0.08, 0.12}, {0.07, 0.11}, {
               0.06, 0.1}, {0.05, 0.09}, {0.04, 0.08}, {0.03, 0.07}, {0.02, 
               0.06}, {0., 0.05}, {-0.02, 0.04}, {-0.05, 0.02}, {-0.07, 
               0.01}, {-0.1, -0.01}, {-0.12, -0.03}, {-0.14, -0.05}, {-0.17, \
-0.07}, {-0.19, -0.09}, {-0.21, -0.12}, {-0.23, -0.14}, {-0.25, -0.16}, \
{-0.26, -0.18}, {-0.28, -0.2}, {-0.29, -0.22}, {-0.3, -0.24}, {-0.3, -0.26}, \
{-0.3, -0.27}, {-0.29, -0.28}, {-0.28, -0.28}, {-0.27, -0.29}, {-0.27, \
-0.29}, {-0.26, -0.29}, {-0.25, -0.28}, {-0.24, -0.27}, {-0.23, -0.27}, \
{-0.22, -0.26}, {-0.21, -0.25}, {-0.19, -0.24}, {-0.18, -0.23}, {-0.18, \
-0.22}, {-0.18, -0.21}, {-0.19, -0.2}, {-0.2, -0.2}, {-0.21, -0.19}, {-0.22, \
-0.19}, {-0.23, -0.2}, {-0.25, -0.2}, {-0.26, -0.21}, {-0.27, -0.22}, {-0.28, \
-0.23}, {-0.29, -0.24}, {-0.3, -0.25}, {-0.3, -0.27}, {-0.31, -0.27}, {-0.31, \
-0.28}, {-0.3, -0.29}, {-0.29, -0.29}, {-0.27, -0.29}, {-0.25, -0.29}, \
{-0.23, -0.28}, {-0.2, -0.27}, {-0.17, -0.26}, {-0.14, -0.24}, {-0.11, \
-0.22}, {-0.09, -0.19}, {-0.06, -0.17}, {-0.04, -0.14}, {-0.03, -0.12}, \
{-0.01, -0.09}, {0.01, -0.07}, {0.02, -0.05}, {0.03, -0.03}, {0.03, -0.02}, {
               0.03, 0.}, {0.03, 0.01}, {0.02, 0.02}, {0.02, 0.02}, {0.01, 
               0.02}, {0., 0.02}, {0., 0.02}, {-0.01, 0.02}, {-0.01, 
               0.01}, {-0.01, 0.01}, {-0.01, 0.}, {-0.01, 0.}, {0., 0.}, {
               0.01, 0.}, {0.02, 0.}, {0.03, 0.}, {0.05, 0.01}, {0.06, 
               0.02}, {0.08, 0.03}, {0.09, 0.04}, {0.1, 0.05}, {0.12, 0.06}, {
               0.13, 0.08}, {0.14, 0.09}, {0.15, 0.1}, {0.15, 0.11}, {0.15, 
               0.12}, {0.15, 0.13}, {0.14, 0.14}, {0.14, 0.14}, {0.13, 
               0.14}, {0.13, 0.14}, {0.12, 0.14}, {0.12, 0.14}, {0.11, 
               0.13}, {0.11, 0.13}, {0.1, 0.12}, {0.09, 0.12}, {0.09, 0.11}, {
               0.09, 0.11}, {0.09, 0.1}, {0.08, 0.1}, {0.09, 0.09}, {0.09, 
               0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 
               0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 
               0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 0.09}, {0.09, 
               0.09}, {0.09, 0.09}, {0.1, 0.09}, {0.1, 0.09}, {0.1, 0.09}, {
               0.1, 0.09}, {0.11, 0.1}, {0.11, 0.1}, {0.12, 0.1}, {0.13, 
               0.11}, {0.14, 0.11}, {0.15, 0.12}, {0.16, 0.12}, {0.17, 
               0.13}, {0.18, 0.14}, {0.2, 0.15}, {0.22, 0.16}, {0.24, 0.17}, {
               0.26, 0.19}, {0.28, 0.2}, {0.3, 0.22}, {0.34, 0.24}, {0.37, 
               0.26}, {0.4, 0.29}, {0.44, 0.32}, {0.48, 
               0.35000000000000003`}, {0.52, 0.38}, {0.55, 
               0.41000000000000003`}, {0.59, 0.44}, {0.62, 0.48}, {0.64, 
               0.51}, {0.66, 0.55}, {0.68, 0.58}, {0.6900000000000001, 0.6}, {
               0.7000000000000001, 0.63}, {0.7000000000000001, 0.65}, {
               0.7000000000000001, 0.67}, {0.6900000000000001, 0.68}, {0.67, 
               0.68}, {0.65, 0.68}, {0.63, 0.68}, {0.61, 0.67}, {0.58, 
               0.66}, {0.56, 0.64}, {0.54, 0.62}, {0.51, 0.6}, {0.48, 0.58}, {
               0.46, 0.56}, {0.43, 0.53}, {0.4, 0.51}, {0.38, 0.48}, {0.36, 
               0.46}, {0.34, 0.43}, {0.32, 0.41000000000000003`}, {0.3, 
               0.39}, {0.27, 0.36}, {0.24, 0.34}, {0.21, 0.31}, {0.18, 
               0.29}, {0.15, 0.26}, {0.11, 0.23}, {0.09, 0.21}, {0.06, 
               0.18}, {0.03, 0.15}, {0.01, 0.12}, {-0.02, 0.09}, {-0.05, 
               0.06}, {-0.07, 0.03}, {-0.09, 
               
               0.01}, {-0.1, -0.02}, {-0.1, -0.04}, {-0.09, -0.05}, {-0.09, \
-0.07}, {-0.08, -0.08}, {-0.07, -0.08}, {-0.06, -0.08}, {-0.06, -0.08}, \
{-0.05, -0.08}}, HoldPattern[
               System`TradingChartDump`$layoutData$545702[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$545702[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$545702[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$545702[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$545702[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$545702 = 
           System`TradingChartDump`$length$545702; 
          System`TradingChartDump`$layoutData$545702["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$545702; 
          System`TradingChartDump`$modelData$545702["Data"] = 
           System`TradingChartDump`$data$545702; 
          System`TradingChartDump`$modelData$545702["Indicators"] = 
           System`TradingChartDump`$indicators$545702; 
          System`TradingChartDump`$layoutData$545702[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545702["ScalingFunctions"] = {
            System`TradingChartDump`$sy$545702, 
             System`TradingChartDump`$isy$545702}; 
          System`TradingChartDump`$layoutData$545702["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545702["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545702[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545702["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$545702["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$545702, 
            System`TradingChartDump`$layoutData$545702, 
            System`TradingChartDump`$indicators$545702]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$545702, 
            System`TradingChartDump`$layoutData$545702, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$545702[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$545702["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$545702[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$545702[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$545702["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$545702[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$545702 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545702["AllValues"], {1, 0} + 
              Map[
               IntegerPart, {
                System`TradingChartDump`$controlmin$545702, 
                 System`TradingChartDump`$controlmax$545702}]]]; 
          System`TradingChartDump`$plotrangemax$545702 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545702["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545702, 
                 System`TradingChartDump`$controlmax$545702}]]]; {
            System`TradingChartDump`$plotrangemin$545702, 
             System`TradingChartDump`$plotrangemax$545702} = ReplaceAll[
             
             System`TradingChartDump`$sy$545702[{
              System`TradingChartDump`$plotrangemin$545702, 
               System`TradingChartDump`$plotrangemax$545702}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$545702[
                Min[System`TradingChartDump`$lows$545702]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$545702 == 
            System`TradingChartDump`$plotrangemax$545702, {
             System`TradingChartDump`$plotrangemin$545702, 
              System`TradingChartDump`$plotrangemax$545702} = {
             System`TradingChartDump`$plotrangemin$545702 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$545702], 
              System`TradingChartDump`$plotrangemax$545702 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$545702]}]; 
          System`TradingChartDump`$newgridlines$545702 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$545702, 
            Part[System`TradingChartDump`$newgridlines$545702, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$545702, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$545702], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$545702, 1]]; 
            Part[System`TradingChartDump`$newgridlines$545702, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$545702, 1] =!= None,
                 System`TradingChartDump`$length$545702 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$545702, 
                 Part[System`TradingChartDump`$newgridlines$545702, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$545702, 1]]; 
            System`TradingChartDump`$subpricegridlines$545702 = 
             Part[System`TradingChartDump`$gridlines$545702, 2]; 
            Part[System`TradingChartDump`$newgridlines$545702, 2] = 
             If[System`TradingChartDump`$sy$545702 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545702}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545702, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545702, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$545702, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$545702, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545702}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545702, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545702, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$545702 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$545702]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"MSFT\"", "\" with \"", 
           "\"TRIX\"", "\"(\"", "15", "\",\"", "", "\",\"", "", "\",\"", "", 
           "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {240., -1171.8}, ImageScaled[{0.5, 0.5}], {450, 310}],
      InsetBox[
      GraphicsBox[
       DynamicModuleBox[{System`TradingChartDump`$timestampdepth$545716 = 
        "Full", System`TradingChartDump`$highlightposition$545716 = Automatic,
         System`TradingChartDump`$maxohlc$545716 = 36.43`4., 
        System`TradingChartDump`$timestampstyle$545716 = Directive[
         GrayLevel[0.75], 
         Opacity[0.25]], 
        System`TradingChartDump`$dates$545716 = CompressedData["
1:eJxd022OEkEURmGkblUxtwoY5huYwbgll+ACdMO6EX+JkU6emHSnz9/znttf
vv34+n29Wq1+X99yfX/21er6rE7wGb7An2+8uX4/wWu4wA3u8Aa+gxPewjt4
D9/DB/gJfoZf4Ff4DT7D7/AHfIGXTf56BFzhBnc44QFPeAvv4AP8AD/CT/Az
/AYf4RN8hpcdku5J96R7skOyQ9I96Z7skOyQ7JB0T7onOyQ7JDsk3ZPuyQ7J
DskOSd+B+8B94DhoPWg9cB+4DxwHrQetB+4D94HjoPWg9cB34DXoO+g7uPPB
nU/6TvpO3CfuE/dJ30nfifvEfeI+6TvpO3GfuE/cJ30n7hP3ifu8tf7V/3Ve
wwUOuMMb+A5OeMA7eA/fwwf4AX6BX+E3+Ai/wx/wBV7c17c7XzjgCje4wxt4
wBPewjt4Dz/CT/Az/AIf4RN8hpcdCo4Fx4JjwbHgWHAsOBYcC44Fx4JjoWnB
t+Bb8C34FnwLvgXfgm/gG9x2cNvBDsEOgW9w28FtBzsEOwS+wW0Htx3sEOwQ
+AZ3Htx5sEOwQ3DnwZ1XdqjsUNmh0r3SvbJDZYfKDpXule6VHSo7VHaodK90
r+xQ2aGyQ6V1xb3+57784w3fRvdG98YOjR0avo3uje6NHRo7NHwb3RvdGzs0
dmj4Nro3ujfuv7FJp3une2eHjnundad1x73j3nHvtO607rh33Dvundad1h33
fnP/A/729oo=
        "], System`TradingChartDump`$visdates$545716 = 
        Dispatch[{
         1 -> "Thu. Jul 26, 2012", 2 -> "Fri. Jul 27, 2012", 3 -> 
          "Mon. Jul 30, 2012", 4 -> "Tue. Jul 31, 2012", 5 -> 
          "Wed. Aug 01, 2012", 6 -> "Thu. Aug 02, 2012", 7 -> 
          "Fri. Aug 03, 2012", 8 -> "Mon. Aug 06, 2012", 9 -> 
          "Tue. Aug 07, 2012", 10 -> "Wed. Aug 08, 2012", 11 -> 
          "Thu. Aug 09, 2012", 12 -> "Fri. Aug 10, 2012", 13 -> 
          "Mon. Aug 13, 2012", 14 -> "Tue. Aug 14, 2012", 15 -> 
          "Wed. Aug 15, 2012", 16 -> "Thu. Aug 16, 2012", 17 -> 
          "Fri. Aug 17, 2012", 18 -> "Mon. Aug 20, 2012", 19 -> 
          "Tue. Aug 21, 2012", 20 -> "Wed. Aug 22, 2012", 21 -> 
          "Thu. Aug 23, 2012", 22 -> "Fri. Aug 24, 2012", 23 -> 
          "Mon. Aug 27, 2012", 24 -> "Tue. Aug 28, 2012", 25 -> 
          "Wed. Aug 29, 2012", 26 -> "Thu. Aug 30, 2012", 27 -> 
          "Fri. Aug 31, 2012", 28 -> "Tue. Sep 04, 2012", 29 -> 
          "Wed. Sep 05, 2012", 30 -> "Thu. Sep 06, 2012", 31 -> 
          "Fri. Sep 07, 2012", 32 -> "Mon. Sep 10, 2012", 33 -> 
          "Tue. Sep 11, 2012", 34 -> "Wed. Sep 12, 2012", 35 -> 
          "Thu. Sep 13, 2012", 36 -> "Fri. Sep 14, 2012", 37 -> 
          "Mon. Sep 17, 2012", 38 -> "Tue. Sep 18, 2012", 39 -> 
          "Wed. Sep 19, 2012", 40 -> "Thu. Sep 20, 2012", 41 -> 
          "Fri. Sep 21, 2012", 42 -> "Mon. Sep 24, 2012", 43 -> 
          "Tue. Sep 25, 2012", 44 -> "Wed. Sep 26, 2012", 45 -> 
          "Thu. Sep 27, 2012", 46 -> "Fri. Sep 28, 2012", 47 -> 
          "Mon. Oct 01, 2012", 48 -> "Tue. Oct 02, 2012", 49 -> 
          "Wed. Oct 03, 2012", 50 -> "Thu. Oct 04, 2012", 51 -> 
          "Fri. Oct 05, 2012", 52 -> "Mon. Oct 08, 2012", 53 -> 
          "Tue. Oct 09, 2012", 54 -> "Wed. Oct 10, 2012", 55 -> 
          "Thu. Oct 11, 2012", 56 -> "Fri. Oct 12, 2012", 57 -> 
          "Mon. Oct 15, 2012", 58 -> "Tue. Oct 16, 2012", 59 -> 
          "Wed. Oct 17, 2012", 60 -> "Thu. Oct 18, 2012", 61 -> 
          "Fri. Oct 19, 2012", 62 -> "Mon. Oct 22, 2012", 63 -> 
          "Tue. Oct 23, 2012", 64 -> "Wed. Oct 24, 2012", 65 -> 
          "Thu. Oct 25, 2012", 66 -> "Fri. Oct 26, 2012", 67 -> 
          "Wed. Oct 31, 2012", 68 -> "Thu. Nov 01, 2012", 69 -> 
          "Fri. Nov 02, 2012", 70 -> "Mon. Nov 05, 2012", 71 -> 
          "Tue. Nov 06, 2012", 72 -> "Wed. Nov 07, 2012", 73 -> 
          "Thu. Nov 08, 2012", 74 -> "Fri. Nov 09, 2012", 75 -> 
          "Mon. Nov 12, 2012", 76 -> "Tue. Nov 13, 2012", 77 -> 
          "Wed. Nov 14, 2012", 78 -> "Thu. Nov 15, 2012", 79 -> 
          "Fri. Nov 16, 2012", 80 -> "Mon. Nov 19, 2012", 81 -> 
          "Tue. Nov 20, 2012", 82 -> "Wed. Nov 21, 2012", 83 -> 
          "Fri. Nov 23, 2012", 84 -> "Mon. Nov 26, 2012", 85 -> 
          "Tue. Nov 27, 2012", 86 -> "Wed. Nov 28, 2012", 87 -> 
          "Thu. Nov 29, 2012", 88 -> "Fri. Nov 30, 2012", 89 -> 
          "Mon. Dec 03, 2012", 90 -> "Tue. Dec 04, 2012", 91 -> 
          "Wed. Dec 05, 2012", 92 -> "Thu. Dec 06, 2012", 93 -> 
          "Fri. Dec 07, 2012", 94 -> "Mon. Dec 10, 2012", 95 -> 
          "Tue. Dec 11, 2012", 96 -> "Wed. Dec 12, 2012", 97 -> 
          "Thu. Dec 13, 2012", 98 -> "Fri. Dec 14, 2012", 99 -> 
          "Mon. Dec 17, 2012", 100 -> "Tue. Dec 18, 2012", 101 -> 
          "Wed. Dec 19, 2012", 102 -> "Thu. Dec 20, 2012", 103 -> 
          "Fri. Dec 21, 2012", 104 -> "Mon. Dec 24, 2012", 105 -> 
          "Wed. Dec 26, 2012", 106 -> "Thu. Dec 27, 2012", 107 -> 
          "Fri. Dec 28, 2012", 108 -> "Mon. Dec 31, 2012", 109 -> 
          "Wed. Jan 02, 2013", 110 -> "Thu. Jan 03, 2013", 111 -> 
          "Fri. Jan 04, 2013", 112 -> "Mon. Jan 07, 2013", 113 -> 
          "Tue. Jan 08, 2013", 114 -> "Wed. Jan 09, 2013", 115 -> 
          "Thu. Jan 10, 2013", 116 -> "Fri. Jan 11, 2013", 117 -> 
          "Mon. Jan 14, 2013", 118 -> "Tue. Jan 15, 2013", 119 -> 
          "Wed. Jan 16, 2013", 120 -> "Thu. Jan 17, 2013", 121 -> 
          "Fri. Jan 18, 2013", 122 -> "Tue. Jan 22, 2013", 123 -> 
          "Wed. Jan 23, 2013", 124 -> "Thu. Jan 24, 2013", 125 -> 
          "Fri. Jan 25, 2013", 126 -> "Mon. Jan 28, 2013", 127 -> 
          "Tue. Jan 29, 2013", 128 -> "Wed. Jan 30, 2013", 129 -> 
          "Thu. Jan 31, 2013", 130 -> "Fri. Feb 01, 2013", 131 -> 
          "Mon. Feb 04, 2013", 132 -> "Tue. Feb 05, 2013", 133 -> 
          "Wed. Feb 06, 2013", 134 -> "Thu. Feb 07, 2013", 135 -> 
          "Fri. Feb 08, 2013", 136 -> "Mon. Feb 11, 2013", 137 -> 
          "Tue. Feb 12, 2013", 138 -> "Wed. Feb 13, 2013", 139 -> 
          "Thu. Feb 14, 2013", 140 -> "Fri. Feb 15, 2013", 141 -> 
          "Tue. Feb 19, 2013", 142 -> "Wed. Feb 20, 2013", 143 -> 
          "Thu. Feb 21, 2013", 144 -> "Fri. Feb 22, 2013", 145 -> 
          "Mon. Feb 25, 2013", 146 -> "Tue. Feb 26, 2013", 147 -> 
          "Wed. Feb 27, 2013", 148 -> "Thu. Feb 28, 2013", 149 -> 
          "Fri. Mar 01, 2013", 150 -> "Mon. Mar 04, 2013", 151 -> 
          "Tue. Mar 05, 2013", 152 -> "Wed. Mar 06, 2013", 153 -> 
          "Thu. Mar 07, 2013", 154 -> "Fri. Mar 08, 2013", 155 -> 
          "Mon. Mar 11, 2013", 156 -> "Tue. Mar 12, 2013", 157 -> 
          "Wed. Mar 13, 2013", 158 -> "Thu. Mar 14, 2013", 159 -> 
          "Fri. Mar 15, 2013", 160 -> "Mon. Mar 18, 2013", 161 -> 
          "Tue. Mar 19, 2013", 162 -> "Wed. Mar 20, 2013", 163 -> 
          "Thu. Mar 21, 2013", 164 -> "Fri. Mar 22, 2013", 165 -> 
          "Mon. Mar 25, 2013", 166 -> "Tue. Mar 26, 2013", 167 -> 
          "Wed. Mar 27, 2013", 168 -> "Thu. Mar 28, 2013", 169 -> 
          "Mon. Apr 01, 2013", 170 -> "Tue. Apr 02, 2013", 171 -> 
          "Wed. Apr 03, 2013", 172 -> "Thu. Apr 04, 2013", 173 -> 
          "Fri. Apr 05, 2013", 174 -> "Mon. Apr 08, 2013", 175 -> 
          "Tue. Apr 09, 2013", 176 -> "Wed. Apr 10, 2013", 177 -> 
          "Thu. Apr 11, 2013", 178 -> "Fri. Apr 12, 2013", 179 -> 
          "Mon. Apr 15, 2013", 180 -> "Tue. Apr 16, 2013", 181 -> 
          "Wed. Apr 17, 2013", 182 -> "Thu. Apr 18, 2013", 183 -> 
          "Fri. Apr 19, 2013", 184 -> "Mon. Apr 22, 2013", 185 -> 
          "Tue. Apr 23, 2013", 186 -> "Wed. Apr 24, 2013", 187 -> 
          "Thu. Apr 25, 2013", 188 -> "Fri. Apr 26, 2013", 189 -> 
          "Mon. Apr 29, 2013", 190 -> "Tue. Apr 30, 2013", 191 -> 
          "Wed. May 01, 2013", 192 -> "Thu. May 02, 2013", 193 -> 
          "Fri. May 03, 2013", 194 -> "Mon. May 06, 2013", 195 -> 
          "Tue. May 07, 2013", 196 -> "Wed. May 08, 2013", 197 -> 
          "Thu. May 09, 2013", 198 -> "Fri. May 10, 2013", 199 -> 
          "Mon. May 13, 2013", 200 -> "Tue. May 14, 2013", 201 -> 
          "Wed. May 15, 2013", 202 -> "Thu. May 16, 2013", 203 -> 
          "Fri. May 17, 2013", 204 -> "Mon. May 20, 2013", 205 -> 
          "Tue. May 21, 2013", 206 -> "Wed. May 22, 2013", 207 -> 
          "Thu. May 23, 2013", 208 -> "Fri. May 24, 2013", 209 -> 
          "Tue. May 28, 2013", 210 -> "Wed. May 29, 2013", 211 -> 
          "Thu. May 30, 2013", 212 -> "Fri. May 31, 2013", 213 -> 
          "Mon. Jun 03, 2013", 214 -> "Tue. Jun 04, 2013", 215 -> 
          "Wed. Jun 05, 2013", 216 -> "Thu. Jun 06, 2013", 217 -> 
          "Fri. Jun 07, 2013", 218 -> "Mon. Jun 10, 2013", 219 -> 
          "Tue. Jun 11, 2013", 220 -> "Wed. Jun 12, 2013", 221 -> 
          "Thu. Jun 13, 2013", 222 -> "Fri. Jun 14, 2013", 223 -> 
          "Mon. Jun 17, 2013", 224 -> "Tue. Jun 18, 2013", 225 -> 
          "Wed. Jun 19, 2013", 226 -> "Thu. Jun 20, 2013", 227 -> 
          "Fri. Jun 21, 2013", 228 -> "Mon. Jun 24, 2013", 229 -> 
          "Tue. Jun 25, 2013", 230 -> "Wed. Jun 26, 2013", 231 -> 
          "Thu. Jun 27, 2013", 232 -> "Fri. Jun 28, 2013", 233 -> 
          "Mon. Jul 01, 2013", 234 -> "Tue. Jul 02, 2013", 235 -> 
          "Wed. Jul 03, 2013", 236 -> "Fri. Jul 05, 2013", 237 -> 
          "Mon. Jul 08, 2013", 238 -> "Tue. Jul 09, 2013", 239 -> 
          "Wed. Jul 10, 2013", 240 -> "Thu. Jul 11, 2013", 241 -> 
          "Fri. Jul 12, 2013", 242 -> "Mon. Jul 15, 2013", 243 -> 
          "Tue. Jul 16, 2013", 244 -> "Wed. Jul 17, 2013", 245 -> 
          "Thu. Jul 18, 2013", 246 -> "Fri. Jul 19, 2013", 247 -> 
          "Mon. Jul 22, 2013", 248 -> "Tue. Jul 23, 2013", 249 -> 
          "Wed. Jul 24, 2013", 250 -> "Thu. Jul 25, 2013"}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$subplotrect$545716, 
        System`TradingChartDump`$subplotpoint$545716, 
        System`TradingChartDump`$ndigits$545716 = 4, 
        System`TradingChartDump`$highlightstyle$545716 = Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballstyle$545716 = 
        Directive[
         PointSize[0.01], 
         GrayLevel[0]], System`TradingChartDump`$bouncingballQ$545716 = True, 
        System`TradingChartDump`$timestampQ$545716 = True, 
        System`TradingChartDump`$data$545716 = {{{2012, 7, 26}, {
          28.367935528120714`, 28.62997256515775, 28.232064471879287`, 28.3, 
           45301400}}, {{2012, 7, 27}, {
          28.60827956989247, 28.967338709677417`, 28.317150537634404`, 28.88, 
           44242600}}, {{2012, 7, 30}, {
          28.866734143049936`, 28.934655870445347`, 28.58534412955466, 28.76, 
           28905000}}, {{2012, 7, 31}, {
          28.609704784526638`, 28.832914828639293`, 28.464133016627077`, 28.6,
            37620900}}, {{2012, 8, 1}, {
          28.714675280516833`, 28.77290037402244, 28.3459163549813, 28.54, 
           31721800}}, {{2012, 8, 2}, {
          28.349410757108597`, 28.65998287084618, 28.11648167180541, 28.33, 
           39520500}}, {{2012, 8, 3}, {
          28.65650756302521, 29.054379831932774`, 28.60798655462185, 28.87, 
           35859400}}, {{2012, 8, 6}, {
          29.108514190317194`, 29.215245409015022`, 28.924160267111848`, 
           29.06, 27471800}}, {{2012, 8, 7}, {
          29.185588235294116`, 29.457352941176467`, 28.99147058823529, 29.37, 
           28002900}}, {{2012, 8, 8}, {
          29.31356083086054, 29.56584569732938, 29.21652818991098, 29.43, 
           26257600}}, {{2012, 8, 9}, {
          29.493245901639348`, 29.745573770491806`, 29.40590163934427, 29.6, 
           24920800}}, {{2012, 8, 10}, {
          29.59763313609467, 29.714082840236685`, 29.355029585798814`, 29.52, 
           27810300}}, {{2012, 8, 13}, {
          29.451184600197433`, 29.55792694965449, 29.26681145113524, 29.49, 
           23049100}}, {{2012, 8, 14}, {
          29.596050448058413`, 29.68395950879522, 29.31278791901759, 29.43, 
           34551400}}, {{2012, 8, 15}, {
          29.412086092715235`, 29.578145695364242`, 29.324172185430466`, 29.5,
            24351000}}, {{2012, 8, 16}, {
          29.65968810916179, 30.22630929174789, 29.561994801819363`, 30.07, 
           35787200}}, {{2012, 8, 17}, {
          30.19953398058253, 30.19953398058253, 29.87722330097088, 30.18, 
           32589900}}, {{2012, 8, 20}, {
          30.108152244632407`, 30.13745933636956, 29.873695510735203`, 30.03, 
           23737700}}, {{2012, 8, 21}, {
          30.050922077922078`, 30.24631168831169, 29.90437987012987, 30.09, 
           28822700}}, {{2012, 8, 22}, {
          29.878837590045844`, 30.044885396201707`, 29.761627373935823`, 
           29.83, 33437400}}, {{2012, 8, 23}, {
          29.68699272967614, 29.696761401189683`, 29.384163912756108`, 29.56, 
           28355600}}, {{2012, 8, 24}, {
          29.547202225130892`, 29.91837369109948, 29.478828534031415`, 29.85, 
           22943300}}, {{2012, 8, 27}, {
          30.214447702834796`, 30.243753665689148`, 29.88231345715216, 29.98, 
           34691100}}, {{2012, 8, 28}, {
          29.988377407770162`, 30.08605941887039, 29.81254978778975, 29.92, 
           23947900}}, {{2012, 8, 29}, {
          29.940000000000005`, 30.037683523654167`, 29.734864600326272`, 
           29.94, 23346800}}, {{2012, 8, 30}, {
          29.82515171503958, 29.90330474934037, 29.52230870712401, 29.62, 
           23982100}}, {{2012, 8, 31}, {
          29.895068137573006`, 30.246774821544452`, 29.68013627514601, 30.11, 
           36590100}}, {{2012, 9, 4}, {
          29.748617966436328`, 29.953780848963476`, 29.45552813425469, 29.69, 
           48556700}}, {{2012, 9, 5}, {
          29.523915761763735`, 29.8267752550181, 29.51414610069102, 29.69, 
           33650000}}, {{2012, 9, 6}, {
          29.789792663476874`, 30.629767145135563`, 29.750724082934607`, 
           30.62, 48371700}}, {{2012, 9, 7}, {
          30.317906300484655`, 30.347208400646206`, 30.01511793214863, 30.23, 
           42649100}}, {{2012, 9, 10}, {
          30.11745768229167, 30.185839843750003`, 29.804853515625005`, 30.01, 
           40524000}}, {{2012, 9, 11}, {
          29.982305943488143`, 30.197232867814222`, 29.90415069827866, 30.08, 
           25191800}}, {{2012, 9, 12}, {
          30.22630929174789, 30.46077322936972, 30.021153346328784`, 30.07, 
           32775800}}, {{2012, 9, 13}, {
          30.171163542340008`, 30.454414996767934`, 29.692566257272134`, 
           30.22, 45047300}}, {{2012, 9, 14}, {
          30.29461390579942, 30.52907721884011, 30.09922781159884, 30.49, 
           51422800}}, {{2012, 9, 17}, {
          30.47046139057994, 30.53884652355014, 30.323921819929506`, 30.49, 
           36488500}}, {{2012, 9, 18}, {
          30.381847338037208`, 30.489307248236052`, 30.31346375881976, 30.46, 
           34542700}}, {{2012, 9, 19}, {
          30.369072463768113`, 30.466753623188403`, 30.320231884057968`, 
           30.33, 48871900}}, {{2012, 9, 20}, {
          30.231605723370425`, 30.74930365659777, 30.19253418124006, 30.72, 
           45543000}}, {{2012, 9, 21}, {
          30.704459762744467`, 30.88030458480282, 30.3723084321898, 30.47, 
           102348900}}, {{2012, 9, 24}, {
          30.284925276153345`, 30.353310591293045`, 29.933229369720596`, 
           30.07, 46825900}}, {{2012, 9, 25}, {
          30.23710102007239, 30.285949325435997`, 29.660691016781836`, 29.69, 
           54266400}}, {{2012, 9, 26}, {
          29.577447795823662`, 29.890023201856145`, 29.3430162412993, 29.47, 
           54672000}}, {{2012, 9, 27}, {
          29.46976790450929, 29.694429708222817`, 29.196266578249343`, 29.46, 
           47129900}}, {{2012, 9, 28}, {
          29.480262096774194`, 29.558407258064516`, 29.050463709677416`, 
           29.07, 54229300}}, {{2012, 10, 1}, {
          29.122621227534758`, 29.288701254662598`, 28.741614106476774`, 
           28.81, 54042700}}, {{2012, 10, 2}, {
          28.98953472690492, 29.194649359406608`, 28.813722184760618`, 28.97, 
           43338900}}, {{2012, 10, 3}, {
          29.062541862022776`, 29.296995981245818`, 28.98439048894843, 29.17, 
           46655900}}, {{2012, 10, 4}, {
          29.271398601398595`, 29.329999999999995`, 28.880722610722604`, 
           29.33, 43634900}}, {{2012, 10, 5}, {
          29.531216080402007`, 29.55075376884422, 29.052542713567835`, 29.16, 
           41133900}}, {{2012, 10, 8}, {
          28.953243787777033`, 29.226756212222973`, 28.865329079919412`, 
           29.09, 29752000}}, {{2012, 10, 9}, {
          28.990710382513658`, 29.049316939890705`, 28.502322404371583`, 28.6,
            45121100}}, {{2012, 10, 10}, {
          28.476069703243613`, 28.632370600414074`, 28.280693581780536`, 
           28.31, 47227100}}, {{2012, 10, 11}, {
          28.543751295336786`, 28.573056994818653`, 28.20185146804836, 28.28, 
           41488500}}, {{2012, 10, 12}, {
          28.29535616438356, 28.637205479452053`, 28.12931506849315, 28.52, 
           46464700}}, {{2012, 10, 15}, {
          28.693226025076243`, 29.03516096238563, 28.57599118942731, 28.83, 
           42440200}}, {{2012, 10, 16}, {
          28.770922346558155`, 29.054235334011526`, 28.643919972872162`, 
           28.81, 47739400}}, {{2012, 10, 17}, {
          28.626664413653266`, 28.958850963163233`, 28.421490368367696`, 
           28.91, 44206100}}, {{2012, 10, 18}, {
          28.966542372881356`, 29.044698305084747`, 28.585532203389832`, 
           28.82, 59238500}}, {{2012, 10, 19}, {
          28.380551675977653`, 28.409860335195525`, 27.843226256983236`, 
           27.98, 90470800}}, {{2012, 10, 22}, {
          28.063053571428572`, 28.16073214285714, 27.183946428571428`, 27.35, 
           83374000}}, {{2012, 10, 23}, {
          27.126488413547236`, 27.546524064171123`, 27.116720142602496`, 27.4,
            64414800}}, {{2012, 10, 24}, {
          27.503942652329755`, 27.543010752688176`, 27.220698924731188`, 
           27.25, 53320400}}, {{2012, 10, 25}, {
          27.532772596843618`, 27.542539454806313`, 27.210466284074606`, 
           27.23, 54084300}}, {{2012, 10, 26}, {
          27.21806451612903, 27.687004608294927`, 27.198525345622116`, 27.56, 
           57790000}}, {{2012, 10, 31}, {
          27.88976874562018, 28.21213735108619, 27.840925017519268`, 27.88, 
           69464100}}, {{2012, 11, 1}, {
          28.17566395663957, 28.879078590785912`, 28.15612466124662, 28.84, 
           72047900}}, {{2012, 11, 2}, {
          28.907925423728813`, 29.08377627118644, 28.653918644067797`, 28.82, 
           57131600}}, {{2012, 11, 5}, {
          28.930232872089103`, 29.047438407019914`, 28.646986162672967`, 
           28.94, 38070800}}, {{2012, 11, 6}, {
          29.13092431346283, 29.50214333556598, 28.92577695914267, 29.17, 
           43401500}}, {{2012, 11, 7}, {
          28.849632049518576`, 29.14272008253095, 28.380691196698766`, 28.41, 
           57871800}}, {{2012, 11, 8}, {
          28.442790697674425`, 28.68697674418605, 28.13023255813954, 28.14, 
           49841800}}, {{2012, 11, 9}, {
          28.2088380159556, 28.511633714880336`, 28.14046479361776, 28.16, 
           43291200}}, {{2012, 11, 12}, {
          28.273416017009215`, 28.341803685329555`, 27.560230333097095`, 
           27.57, 61112300}}, {{2012, 11, 13}, {
          26.611059431524552`, 26.88682170542636, 26.345145810262093`, 26.68, 
           131689200}}, {{2012, 11, 14}, {
          26.823889716840533`, 26.873125931445603`, 26.390611028315945`, 
           26.43, 76086100}}, {{2012, 11, 15}, {
          26.476699174793698`, 26.565348837209303`, 26.230450112528132`, 
           26.26, 50955600}}, {{2012, 11, 16}, {
          26.267737556561087`, 26.2972850678733, 25.942714932126695`, 26.12, 
           64083300}}, {{2012, 11, 19}, {
          26.398952487841374`, 26.398952487841374`, 26.07389075944631, 26.33, 
           57179300}}, {{2012, 11, 20}, {
          26.359251216772744`, 26.39865219019094, 26.06374391613628, 26.31, 
           47070400}}, {{2012, 11, 21}, {
          26.30365120593692, 26.75665306122449, 26.264259740259742`, 26.54, 
           66360300}}, {{2012, 11, 23}, {
          26.817126353790613`, 27.348938628158844`, 26.787581227436824`, 
           27.28, 57845700}}, {{2012, 11, 26}, {
          27.127754654983573`, 27.167155896312522`, 26.763293172690766`, 
           26.98, 85198700}}, {{2012, 11, 27}, {
          26.945760709010344`, 26.96545790251108, 26.630605612998526`, 26.67, 
           45018600}}, {{2012, 11, 28}, {
          26.605244883040935`, 26.97955043859649, 26.368841374269003`, 26.95, 
           53018400}}, {{2012, 11, 29}, {
          26.697565862708718`, 26.943762523191094`, 26.451369202226346`, 
           26.54, 69551400}}, {{2012, 11, 30}, {
          26.643538692712244`, 26.7223365890308, 26.09195341848234, 26.22, 
           83690200}}, {{2012, 12, 3}, {
          26.37470298902762, 26.414097616345064`, 26.000454029511918`, 26.03, 
           53173800}}, {{2012, 12, 4}, {
          26.098028062191883`, 26.226056124383767`, 25.9404550625711, 25.97, 
           49777500}}, {{2012, 12, 5}, {
          25.984349456317954`, 26.526100487439066`, 25.86614923134608, 26.27, 
           68283800}}, {{2012, 12, 6}, {
          26.408802843247283`, 26.57625888514777, 26.211795735129066`, 26.33, 
           39182300}}, {{2012, 12, 7}, {
          26.414557823129254`, 26.414557823129254`, 25.97136054421769, 26.06, 
           46162100}}, {{2012, 12, 10}, {
          26.155783221974758`, 26.559543429844098`, 26.116391982182627`, 
           26.53, 47031100}}, {{2012, 12, 11}, {
          26.64405197657394, 27.077448755490483`, 26.64405197657394, 26.91, 
           52282800}}, {{2012, 12, 12}, {
          27.11563509544787, 27.20428046989721, 26.67240822320117, 26.83, 
           43966300}}, {{2012, 12, 13}, {
          26.90682405016599, 27.10379933603836, 26.5424197713021, 26.7, 
           45080100}}, {{2012, 12, 14}, {
          26.695412159641922`, 26.71510630361805, 26.29168220813129, 26.4, 
           42077500}}, {{2012, 12, 17}, {
          26.38469003690037, 26.80818450184502, 26.27635424354244, 26.69, 
           42046100}}, {{2012, 12, 18}, {
          26.834724238026126`, 27.208933236574747`, 26.726400580551527`, 
           27.14, 50486900}}, {{2012, 12, 19}, {
          27.274295129989014`, 27.313694617356276`, 26.8409007689491, 26.9, 
           53519900}}, {{2012, 12, 20}, {
          26.94485549132948, 27.26, 26.738041907514454`, 27.26, 52607300}}, {{
          2012, 12, 21}, {
          27.04, 27.079402550091075`, 26.59672131147541, 27.04, 98776500}}, {{
          2012, 12, 24}, {
          26.78787878787879, 26.83712121212121, 26.59090909090909, 26.65, 
           20842400}}, {{2012, 12, 26}, {
          26.617405063291137`, 26.784810126582276`, 26.292442293373043`, 
           26.45, 31631100}}, {{2012, 12, 27}, {
          26.481064540059347`, 26.678022997032638`, 26.165931008902074`, 
           26.55, 39394000}}, {{2012, 12, 28}, {
          26.307589453860636`, 26.494726930320144`, 26.149999999999995`, 
           26.15, 28239900}}, {{2012, 12, 31}, {
          26.191797079745413`, 26.369101460127293`, 25.97509172594534, 26.31, 
           42749500}}, {{2013, 1, 2}, {
          26.8356263577118, 27.30832729905865, 26.737146994931205`, 27.2, 
           52899300}}, {{2013, 1, 3}, {
          27.214282568807338`, 27.233981651376148`, 26.75135412844037, 26.84, 
           48294400}}, {{2013, 1, 4}, {
          26.862071802543007`, 26.93102468212416, 26.330149588631265`, 26.34, 
           52521100}}, {{2013, 1, 7}, {
          26.36880104908205, 26.477152491569875`, 26.240749344323717`, 26.29, 
           37110400}}, {{2013, 1, 8}, {
          26.346986817325796`, 26.386384180790955`, 26.061355932203387`, 
           26.15, 44703100}}, {{2013, 1, 9}, {
          26.319700374531838`, 26.34925093632959, 26.162097378277153`, 26.3, 
           49047900}}, {{2013, 1, 10}, {
          26.247127739984883`, 26.572139077853365`, 25.89256991685563, 26.06, 
           71431300}}, {{2013, 1, 11}, {
          26.08519567648155, 26.51847185985837, 25.87840477077898, 26.42, 
           55512100}}, {{2013, 1, 14}, {
          26.489847526961693`, 26.667103012272218`, 26.351982149497953`, 
           26.48, 48324400}}, {{2013, 1, 15}, {
          26.42572583608967, 26.878794560823223`, 26.42572583608967, 26.8, 
           48244500}}, {{2013, 1, 16}, {
          26.738332100591716`, 26.817119082840236`, 26.600454881656805`, 
           26.63, 41077400}}, {{2013, 1, 17}, {
          26.78090275229358, 27.05668990825688, 26.65285871559633, 26.84, 
           51685900}}, {{2013, 1, 18}, {
          26.692256880733947`, 26.879398165137616`, 26.633159633027525`, 
           26.84, 52167700}}, {{2013, 1, 22}, {
          26.887734806629833`, 27.035469613259668`, 26.592265193370167`, 
           26.74, 58650600}}, {{2013, 1, 23}, {
          26.786236870699025`, 27.21954364360739, 26.786236870699025`, 27.19, 
           50387700}}, {{2013, 1, 24}, {
          27.27893593919653, 27.643311617806734`, 27.052432138979373`, 27.21, 
           101739300}}, {{2013, 1, 25}, {
          27.164519368723095`, 27.804727403156384`, 26.97738163558106, 27.46, 
           81847700}}, {{2013, 1, 28}, {
          27.58849516302401, 27.80518452167682, 27.342257255463995`, 27.49, 
           56056500}}, {{2013, 1, 29}, {
          27.402848982506246`, 27.708200642627627`, 27.186147804355585`, 
           27.59, 49242600}}, {{2013, 1, 30}, {
          27.58758707360862, 27.764872531418312`, 27.341357271095156`, 27.43, 
           43580500}}, {{2013, 1, 31}, {
          27.374921675774136`, 27.55223315118397, 26.990746812386156`, 27.04, 
           50530000}}, {{2013, 2, 1}, {
          27.253909774436092`, 27.628195488721804`, 27.135714285714286`, 
           27.51, 55565900}}, {{2013, 2, 4}, {
          27.453575072886295`, 27.60133381924198, 27.010298833819242`, 27.03, 
           50540000}}, {{2013, 2, 5}, {
          27.198167272727268`, 27.237556363636358`, 26.942138181818176`, 
           27.08, 35410400}}, {{2013, 2, 6}, {
          26.969400146305773`, 27.12700073152889, 26.841349670811994`, 26.93, 
           41889600}}, {{2013, 2, 7}, {
          26.938947947214075`, 26.978346774193547`, 26.692705278592374`, 
           26.87, 38028300}}, {{2013, 2, 8}, {
          26.933049001814883`, 27.287560798548096`, 26.893658802177857`, 
           27.13, 33318500}}, {{2013, 2, 11}, {
          27.23316582914573, 27.499095477386938`, 27.085427135678394`, 27.44, 
           32247700}}, {{2013, 2, 12}, {
          27.459999999999997`, 27.57819225251076, 27.33195839311334, 27.46, 
           35990900}}, {{2013, 2, 13}, {
          27.511498394577234`, 27.688801284338204`, 27.462247591865854`, 
           27.61, 41715600}}, {{2013, 2, 14}, {
          27.501797432239663`, 27.639700427960058`, 27.45254636233952, 27.62, 
           32663200}}, {{2013, 2, 15}, {
          27.619550160656903`, 27.737750803284538`, 27.46194930382006, 27.59, 
           49650900}}, {{2013, 2, 19}, {
          27.68121212121212, 27.889714795008913`, 27.6017825311943, 27.85, 
           38781400}}, {{2013, 2, 20}, {
          27.938227484750627`, 28.007750269106566`, 27.64027269465375, 27.68, 
           44110200}}, {{2013, 2, 21}, {
          27.548272098945073`, 27.548272098945073`, 27.041797017097128`, 27.3,
            49078500}}, {{2013, 2, 22}, {
          27.49054755043228, 27.570000000000004`, 27.29191642651297, 27.57, 
           31425900}}, {{2013, 2, 25}, {
          27.7758348556814, 27.85527950310559, 27.18, 27.18, 48011800}}, {{
          2013, 2, 26}, {
          27.18993058092802, 27.408403361344536`, 27.150208257215926`, 27.18, 
           49923300}}, {{2013, 2, 27}, {
          27.232664509169368`, 27.808701905789285`, 27.143279395900755`, 
           27.62, 36394700}}, {{2013, 2, 28}, {
          27.689453237410067`, 27.7788381294964, 27.55041007194244, 27.61, 
           35840200}}, {{2013, 3, 1}, {
          27.53156350626118, 27.789796064400715`, 27.332923076923077`, 27.76, 
           34849700}}, {{2013, 3, 4}, {
          27.652131438721142`, 27.950000000000003`, 27.503197158081708`, 
           27.95, 38157500}}, {{2013, 3, 5}, {
          28.090423280423277`, 28.33865961199294, 27.961340388007052`, 28.15, 
           41432200}}, {{2013, 3, 6}, {
          28.009145603417586`, 28.029003203987184`, 27.582207191171236`, 
           27.89, 51448500}}, {{2013, 3, 7}, {
          27.910213219616203`, 28.079004975124377`, 27.810923951670222`, 
           27.94, 29196700}}, {{2013, 3, 8}, {
          28.058303571428567`, 28.137760714285708`, 27.770271428571426`, 
           27.81, 37667800}}, {{2013, 3, 11}, {
          27.74952278435594, 27.779318263365624`, 27.48136347326875, 27.68, 
           36627500}}, {{2013, 3, 12}, {
          27.650476531709067`, 27.759727696166248`, 27.451838050877825`, 
           27.72, 39255200}}, {{2013, 3, 13}, {
          27.680340257879656`, 27.829319484240685`, 27.56115687679083, 27.73, 
           29093400}}, {{2013, 3, 14}, {
          27.800995024875622`, 27.959857853589195`, 27.731492537313432`, 
           27.94, 55914800}}, {{2013, 3, 15}, {
          27.83007132667618, 27.95914407988588, 27.780427960057064`, 27.84, 
           92710300}}, {{2013, 3, 18}, {
          27.681565836298926`, 28.07871886120996, 27.612064056939495`, 27.9, 
           44809400}}, {{2013, 3, 19}, {
          27.92042583392477, 28.01971611071682, 27.831064584811926`, 27.98, 
           51901600}}, {{2013, 3, 20}, {
          28.13985875706215, 28.28879943502825, 27.980988700564975`, 28.12, 
           35447800}}, {{2013, 3, 21}, {
          27.909999999999997`, 28.158221273568124`, 27.85042689434365, 27.91, 
           34233200}}, {{2013, 3, 22}, {
          27.990424778761064`, 28.13936283185841, 27.901061946902658`, 28.05, 
           28720900}}, {{2013, 3, 25}, {
          28.099005681818188`, 28.14865056818182, 27.76142045454546, 27.96, 
           44154000}}, {{2013, 3, 26}, {
          28.03943181818182, 28.138721590909096`, 27.910355113636367`, 27.96, 
           27824300}}, {{2013, 3, 27}, {
          27.941621431089178`, 28.24943602396898, 27.88204441311244, 28.17, 
           36047400}}, {{2013, 3, 28}, {
          28.12202726319469, 28.459650471862986`, 28.06244669695911, 28.41, 
           55453800}}, {{2013, 4, 1}, {
          28.439790283117794`, 28.459650471862986`, 28.16174764068508, 28.41, 
           29201100}}, {{2013, 4, 2}, {
          28.391458333333336`, 28.64965277777778, 28.321944444444448`, 28.6, 
           28456500}}, {{2013, 4, 3}, {
          28.548669467787114`, 28.747268907563026`, 28.34014005602241, 28.36, 
           35062800}}, {{2013, 4, 4}, {
          28.191468531468526`, 28.409930069930063`, 28.072307692307685`, 28.4,
            45263200}}, {{2013, 4, 5}, {
          28.02334494773519, 28.5794425087108, 27.91411149825784, 28.5, 
           50927300}}, {{2013, 4, 8}, {
          28.529020636586218`, 28.529020636586218`, 28.270839454354668`, 
           28.39, 34759500}}, {{2013, 4, 9}, {
          28.526241134751775`, 29.608510638297872`, 28.47659574468085, 29.4, 
           77733800}}, {{2013, 4, 10}, {
          29.364924042272122`, 30.109722589167763`, 29.315270805812414`, 
           30.07, 71116700}}, {{2013, 4, 11}, {
          28.89889426399447, 28.998203178991016`, 28.531451278507255`, 28.74, 
           130923200}}, {{2013, 4, 12}, {
          28.649583188607156`, 28.818402222994095`, 28.460903091351163`, 
           28.59, 62886300}}, {{2013, 4, 15}, {
          28.450278842802366`, 28.77797838968281, 28.311254792610665`, 28.49, 
           56332900}}, {{2013, 4, 16}, {
          28.700483258543322`, 28.93882637210908, 28.501863997238523`, 28.77, 
           52797300}}, {{2013, 4, 17}, {
          28.64986125563649, 28.83854318418314, 28.40159556018037, 28.63, 
           52840700}}, {{2013, 4, 18}, {
          28.74888850295241, 28.77868009725599, 28.302014588398748`, 28.59, 
           56906600}}, {{2013, 4, 19}, {
          29.411058112193484`, 30.02668458179375, 29.40112865300638, 29.56, 
           99790700}}, {{2013, 4, 22}, {
          30.093610120012976`, 30.967615958482, 30.063814466428806`, 30.62, 
           137904000}}, {{2013, 4, 23}, {
          30.489313725490195`, 30.687941176470588`, 30.17150980392157, 30.39, 
           59126900}}, {{2013, 4, 24}, {
          30.407896725440807`, 31.69889168765743, 30.388035264483626`, 31.54, 
           90946600}}, {{2013, 4, 25}, {
          31.491584220413277`, 32.61380087664371, 31.32275516593613, 31.72, 
           110700200}}, {{2013, 4, 26}, {
          31.679238754325258`, 31.758685121107266`, 31.23235294117647, 31.57, 
           47799300}}, {{2013, 4, 29}, {
          31.575712971481146`, 32.449506286415215`, 31.545924563017483`, 
           32.38, 59116400}}, {{2013, 4, 30}, {
          32.33375226586102, 32.87993051359516, 32.05569788519637, 32.87, 
           75165200}}, {{2013, 5, 1}, {
          32.69852383863081, 32.84746943765282, 32.3708435207824, 32.49, 
           54330900}}, {{2013, 5, 2}, {
          32.40367611580218, 32.939930639324494`, 32.16534077201448, 32.93, 
           46059500}}, {{2013, 5, 3}, {
          33.00178560764407, 33.28979396834876, 32.85281576590026, 33.26, 
           46784600}}, {{2013, 5, 6}, {
          33.18234666666667, 33.66886222222222, 33.013555555555556`, 33.51, 
           40978300}}, {{2013, 5, 7}, {
          33.41765235664965, 33.55668567997598, 33.01048333833683, 33.08, 
           43078300}}, {{2013, 5, 8}, {
          32.83944225522885, 33.00825704759018, 32.422370415277356`, 32.76, 
           51595700}}, {{2013, 5, 9}, {
          32.61866197183099, 32.76760563380282, 32.36049295774649, 32.43, 
           46417800}}, {{2013, 5, 10}, {
          32.44014071581524, 32.48978892627715, 32.09260324258183, 32.46, 
           36394900}}, {{2013, 5, 13}, {
          32.382924613987285`, 32.83972146533454, 32.323342415985465`, 32.8, 
           36027600}}, {{2013, 5, 14}, {
          32.86, 33.53, 32.8, 33.53, 56870100}}, {{2013, 5, 15}, {
          33.45, 33.9, 33.43, 33.85, 46303900}}, {{2013, 5, 16}, {
          33.64, 34.15, 33.55, 34.08, 59382900}}, {{2013, 5, 17}, {
          34.13, 34.87, 34.1, 34.87, 60666700}}, {{2013, 5, 20}, {
          34.73, 35.1, 34.68, 35.08, 54020800}}, {{2013, 5, 21}, {
          35.1, 35.27, 34.72, 34.85, 48702400}}, {{2013, 5, 22}, {
          34.79, 34.84, 34.36, 34.61, 66047500}}, {{2013, 5, 23}, {
          34.23, 34.55, 33.9, 34.15, 51102700}}, {{2013, 5, 24}, {
          33.92, 34.28, 33.9, 34.27, 33174400}}, {{2013, 5, 28}, {
          34.42, 35.18, 34.41, 35.02, 48212100}}, {{2013, 5, 29}, {
          34.74, 35.02, 34.57, 34.88, 38412200}}, {{2013, 5, 30}, {
          34.849999999999994`, 35.24999999999999, 34.809999999999995`, 35.03, 
           51131000}}, {{2013, 5, 31}, {
          34.82, 35.28, 34.79, 34.9, 56165700}}, {{2013, 6, 3}, {
          34.919999999999995`, 35.629999999999995`, 34.82999999999999, 35.59, 
           51252600}}, {{2013, 6, 4}, {
          35.62, 35.74, 34.77, 34.99, 65529500}}, {{2013, 6, 5}, {
          34.6, 34.89, 34.43, 34.78, 46025100}}, {{2013, 6, 6}, {
          34.84, 35.11, 34.49, 34.96, 37618500}}, {{2013, 6, 7}, {
          35.25, 35.78, 35.06, 35.67, 40757300}}, {{2013, 6, 10}, {
          35.51, 35.65, 35.14, 35.47, 35994500}}, {{2013, 6, 11}, {
          35.05, 35.18, 34.68, 34.84, 39435900}}, {{2013, 6, 12}, {
          35.14, 35.27, 34.85, 35., 37372700}}, {{2013, 6, 13}, {
          34.99, 35.02, 34.59, 34.72, 45654900}}, {{2013, 6, 14}, {
          34.55, 34.69, 34.25, 34.4, 53192600}}, {{2013, 6, 17}, {
          34.69, 35.16, 34.63, 35., 49670100}}, {{2013, 6, 18}, {
          34.97, 35.17, 34.9, 34.98, 28616500}}, {{2013, 6, 19}, {
          34.96, 35.09, 34.59, 34.59, 30816200}}, {{2013, 6, 20}, {
          34.26, 34.33, 33.37, 33.49, 54493700}}, {{2013, 6, 21}, {
          33.66, 33.73, 33.05, 33.27, 85338500}}, {{2013, 6, 24}, {
          32.94, 34.2, 32.57, 33.72, 56109000}}, {{2013, 6, 25}, {
          34.08, 34.38, 33.46, 33.67, 44073400}}, {{2013, 6, 26}, {
          34.12, 34.48, 33.89, 34.35, 48665900}}, {{2013, 6, 27}, {
          34.52, 34.78, 34.5, 34.62, 28993100}}, {{2013, 6, 28}, {
          34.38, 34.79, 34.34, 34.54, 65545500}}, {{2013, 7, 1}, {
          34.75, 34.99, 34.33, 34.36, 31055400}}, {{2013, 7, 2}, {
          34.41, 34.44, 33.63, 33.94, 37630000}}, {{2013, 7, 3}, {
          33.66, 34.37, 33.6, 34.01, 15994400}}, {{2013, 7, 5}, {
          34.09, 34.24, 33.58, 34.21, 26085900}}, {{2013, 7, 8}, {
          34.35, 34.59, 33.98, 34.33, 32396900}}, {{2013, 7, 9}, {
          34.58, 34.6, 34.14, 34.35, 25318500}}, {{2013, 7, 10}, {
          34.34, 34.81, 34.32, 34.7, 29658800}}, {{2013, 7, 11}, {
          35., 35.77, 34.9, 35.69, 53638300}}, {{2013, 7, 12}, {
          35.58, 35.73, 35.28, 35.67, 35501200}}, {{2013, 7, 15}, {
          35.66, 36.22, 35.58, 36.17, 34142600}}, {{2013, 7, 16}, {
          36.01, 36.43, 35.96, 36.27, 36378500}}, {{2013, 7, 17}, {
          36.34, 36.39, 35.49, 35.74, 37285100}}, {{2013, 7, 18}, {
          35.72, 35.89, 35.22, 35.44, 49547100}}, {{2013, 7, 19}, {
          32.4, 32.67, 31.02, 31.4, 248428500}}, {{2013, 7, 22}, {
          31.7, 32.01, 31.6, 32.01, 79040700}}, {{2013, 7, 23}, {
          31.91, 32.04, 31.71, 31.82, 65810400}}, {{2013, 7, 24}, {
          32.04, 32.19, 31.89, 31.96, 52803100}}, {{2013, 7, 25}, {
          31.62, 31.65, 31.25, 31.39, 63213000}}}, 
        System`TradingChartDump`$markerstyle$545716 = 1, 
        System`TradingChartDump`$controlmin$545716 = 0.5, 
        System`TradingChartDump`$controlmax$545716 = 250.5, 
        System`TradingChartDump`$datescope$545716 = {{"`", "YearShort"}}, 
        System`TradingChartDump`$aspectratio$545716 = GoldenRatio^(-1), 
        System`TradingChartDump`$min$545716, 
        System`TradingChartDump`$max$545716, 
        System`TradingChartDump`$ohlclabel$545716 = Grid[{{
           Style["O: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545716, 
              System`TradingChartDump`$opens$545716]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["H: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545716, 
              System`TradingChartDump`$highs$545716]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["L: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545716, 
              System`TradingChartDump`$lows$545716]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style["C: ", 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> False], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545716, 
              System`TradingChartDump`$closes$545716]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times"], 
           Style[
            Dynamic[
             ReplaceAll[
             System`TradingChartDump`$indicatorpos$545716, 
              System`TradingChartDump`$visdates$545716]], 12, 
            Directive["GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}, {
              Directive[], 
              Directive[]}], FontFamily -> "Times", LineBreakWithin -> 
            False]}}, ItemSize -> Automatic, 
         Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> False], 
        System`TradingChartDump`$ohlcpoint$545716 = {}, 
        System`TradingChartDump`$subpricegridlines$545716 = Automatic, 
        System`TradingChartDump`$overlaypoint$545716, 
        System`TradingChartDump`$overlayvalue$545716, 
        System`TradingChartDump`$subplotvalue$545716, 
        System`TradingChartDump`$opts$545716 = {
        AxesOrigin -> Automatic, GridLinesStyle -> Directive[
           Dashing[{0, Small}], 
           AbsoluteThickness[0.1], 
           GrayLevel[0.5]], FrameLabel -> {None, None}, PlotLabel -> 
         Row[{"Last ", 365, " days of ", "MSFT", " with ", "WilliamsPercentR",
             "(", 10, ",", Null, ",", Null, ",", Null, ")"}], 
         ImageSize -> {450, 310}, AlignmentPoint -> Center, AspectRatio -> 
         GoldenRatio^(-1), Axes -> Automatic, AxesLabel -> None, AxesOrigin -> 
         Automatic, AxesStyle -> {}, Background -> None, BaselinePosition -> 
         Automatic, BaseStyle -> {}, ColorOutput -> Automatic, 
         ContentSelectable -> Automatic, CoordinatesToolOptions -> Automatic, 
         DisplayFunction :> $DisplayFunction, Epilog -> {}, FormatType :> 
         TraditionalForm, Frame -> True, FrameLabel -> None, FrameStyle -> {},
          FrameTicks -> Automatic, FrameTicksStyle -> {}, GridLines -> 
         Automatic, GridLinesStyle -> {}, ImageMargins -> 0., ImagePadding -> 
         All, ImageSize -> Automatic, ImageSizeRaw -> Automatic, 
         LabelStyle -> {}, Method -> Automatic, PlotLabel -> None, PlotRange -> 
         All, PlotRangeClipping -> False, PlotRangePadding -> Automatic, 
         PlotRegion -> Automatic, PreserveImageOptions -> Automatic, 
         Prolog -> {}, RotateLabel -> True, Ticks -> Automatic, 
         TicksStyle -> {}}, 
        System`TradingChartDump`$candlestickchart$545716 = {{{}, {
          Antialiasing -> True, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.5, 0.7, 0]], 
            Line[CompressedData["
1:eJxlmgtcj+f7xyNbDokp/ORUIcmhckrnO2EhOipppcO3vt/6VsKIsIVpDtGo
/f3ntCxiTCvWlmM1szY2lnIYk+SnSYWkEeFXz3Vf9zV339drr73ePs99Pdd9
Xdd93c9zP5mGL/CJ1NXR0dF00NHpqAP/7fii7dfsErT25ISCnY5MB34MeZzy
02V3koxy3r9DuswJ+oYl1t7Ewyclrcl65siilJ8x63/O+k7Pg6gPEAz3H8gG
r6v1LqggXWabNUUd9u8k3v691dXa7k7cP1PmOaAmf42VE9fNBP/+W9vPDOyF
kC7z7hjbTqWvHAUb9W79LUH7Q9iUG7+um+qF1w8VDPaHstZgJBnFky5zjN9E
Vbwt8Te7Vrrd/AztD2M+cZ2Dp36EurlgsG/O40S6zMGhSSNr1MQbOtnU3TqD
9kewTbM/upK8GHVLwWDfkjl1vZaVsIp0mVsuzy2eNYU43+eJR/kWtD+ajQmM
WP5RNOpjBIP9MfDvyaTLHHT05yctPsSZNROCOmSgfSv2VFPtfecg6taCob6s
mU/BoHW17zkLXeYe/mP+W5FG47dcrVA/snPmcRzLrnkfs+/SHa8fJxjst3JW
glPXvv/SJQ4IiUtY97cT6bWR7gYuaH8C83asX9g7FfWJgsH+RLjuT9JlTjI4
szojiXhhyS8bjGuduH175rc1yWrIPdQdBIN9B/ZB2o9NFgOchS7zzPSx0QNz
aPzyjiu/GiX8d2SBX1UHDE5B3Ukw2HdiC9sKJpd0mROvWBl9uZa4YmGXTQfK
nKiOXQfcsDqPurNgsO8M63WPs9BlNkz5z4dWRTT+z8Wx2kl7naH+PBjLffIq
atlLricTK+V1jDEjZcE6C13m0WfTtEv/pvFzm2JvrBqL9l3ZyD0F80tH4vXE
YN+VtZWj9yTSZe7kkfeOR56T4CEPN2/0+5Db/82VPZtnVqqdifOdLBjWx2S+
XkmXOe9w3OuofsR9X5TsWPgp+j+ZeW4LsUhYhv4Qg/+SveT2fNMgYGOdD7HB
xE+uN2xA/yczu0dTCovC8P5ugsF/N/aPRWtFLiFd5mO7rEe4eBHvqVA5ua1C
+27MdaHL2hkOqE8RDPanQLwLSJe55NdNtdNtiH3/mhl8uRDj484udvI707En
5ocY4uPO6rxbLY4kXea/U/7S7dDiKHjdRyfq9TywP7qzaqum0KSpWL/TBYP/
06Ee/UiX+XT18i6JYj+ezgy5Dvansz576n/Re4r6DMFgfwbvZ05Cl9l4fdX4
lFs0fsfXjXn69mh/Jut2zHLprpmoewgG+x6sLdqD1pEuc4XB1fPGpsQDjZ7d
G5zlyOPvwaYk/Dg5MQ/jRwzx94B4lJMu8835X1h8mE58YWMPT50u6L8H6253
wjLoHN5/lmDwfxZra5cfXCJdZvMTyx5f20f86lZNcFV3bt9jFhs7wd4oLhPv
Twz+z2Ij2hryfdJlvv1D4/lqLbFNSoFrYhPGx5OZrFmwKczEgevEYN9T7AOo
yzzIrdv8OwOJU/tO06nZ5MCv82K2NqsMy2xRJ4b+7QXxSCNd5p9u79hyeSzx
87Lv1t/+ltuv9mKBN4Z6PR+F8fMWrNjv5w31eI10mV2GW/76bDhx965RM7vd
wedPb7ZgetnpIQ8xfsTgvzfsV49Jl9l4/xdVmfuJtx6Pqhuqz/enbG/WvG2l
6yemfL0UEcM+7v12Pyhqz8vvdyx4U+co+J0R4xNTk7n9ah+W4NlLFb/Lns/P
VzDExxeeN3NIlzkg7tLyoLnEcdazC9+9a8/j48f+vFvR+9QsricTQ3z8WFu7
d9pIuswHep5JyXYj/ir0uu53xdx+th9rsfe3sSrlehExxMePuSsvFA5Cl7nq
l5C6Pb/S+JvsVFe/QKzPOWzBSTO/hh14f2Lwfw6sg0bSZc6+p46IDSGu2zyj
9OwL9N+fpRcs8n390o7fnxj894d+NtVe6DJP7nPm6clbNL6yae26nBSMfwA7
uP+s5s5wvD8x+B8A8fiUdJmPvoq9dWEgMbv90tE5Df0PYJaeJtsr96E/xOB/
AO83pMssj9/65OOcMkMe/+y5bMPn17qtCEedGOzP5c+DpMs83OSqeeE04qdb
no6+d5H7Xz2XWSdfW5l7Bes3UDDUfyDb19YOhjgIvR27LYxoOk7jL5l1zV45
AesnkJ377pB+VQPGjxjiH8jOtrWzyQ5Cl3nwjY+9Hp+yb6eD/XnsWenRbsNX
oE4M9udBH08lXeYFmaEfJlkS11pPe7DtCMZnHvusufPufjY4vyDBEJ8g6Mee
pMvca8PqXV822wnuMbwuflUIt28exBz0q3fWYvwZsWI/MIjvkw5Cl/nNtqBD
+adofHFt3oaHs7H/f8DyXaaEX+qN/gQLBv+DoV9qSZdZPSzd7HalneD6lrBt
Jz7B9RXM2HueIS2xGD9iiH8wfw4gXWZ5fEKWZc7zSox/MDNcYu5cU4L+hAgG
/0P4fkW6zL0icwtNDxC/ab5iv9aAx8c8hNWOsS20zcP4EUP8JXusPZvr1Bf2
+Yo4N+6Zo8kd7A8h7ELaxdJpor8Sw/oNgfVq7SB0meXxWf6muuMnof/zWbRd
y+OBllgPxOD/fP68T7rMxuv/yJnwwl5wfNHS3R0vYv+ZzwL7Rg4wVaM/xOD/
fIjHdtJlflxfG3bAinht3+FZHvn8+WlcKEv0N3XQcUV/iOH5KxTW+xrSZR51
pmrkGTPi7lvU2tJMbr8slLl+sM/jr4d8fpXEiv26UDhvM3UQusz1ZsWXf/4v
jbcK3fv57uncfmOrP8eTinMdsB+GCVbs64dBPhNIl/l1/erNFb2J5zVlFvz0
MbdvGMaa/p0vE2LF/qiwt/Np0p6fdj9k99KPOGOOp6ZTBsY/jMUd0k9rEPEk
hviHwXnGLtJl/ueHvJtzlhJXf1P//pxcbt83jGV/e//CkmSuhxIr9mPD+HkD
6TJ3HtXL6MZi4hBfV83ZLG4/PYzlOFc/iMjheiaxYv+bMF6npMu885c1WoMd
xPv8Zgb+dBfzG8Z8nSamZKzC/IQLhvyGw3nYVtJlLu/S0PnkjH+N5zrEJ5x9
cvl4dRrWTygxxCdcikd73vH5/KYjQ4kfpm/uo3cJ4xPOUoec3WS0HudHDPEJ
h/X0I+ky302cv8h+DrHngJGG1ufx/SecWet07PMkG9c3MfT5cB5H0mU+EhX9
aWky8Xiuw/oNZ91s778Y1pc/v1cSw/oN532QdJkX/eGvNv7HQXBgy5LIo/78
/dAwgi3KOn9StwbXBzGsrwj+vkK6zMufzfz+/y8Ra8LWH7Yz4vYXR7CU1dP2
rsP4JBPDc0gEPy8hXeY/dqYfPLyY2K364NpVP2J+I9jFM0tKLEX9E0N+I9iK
thf2E6TL/PK06YsDacTlhYPcZ5djflvn1y+1o8HvmB9iyK8Uj6L2vEpv1n/c
ThIvaN7gfLwJ8xvBarQNmz8ux/wQQ34j+H5LuswufktMzpcQd3VTJ25E+40R
bFMz67cC46OjEgzrV8WfM0iX+cSuu/a5u4izlvvXmmN+DVUsv5+e3t5azD8x
1I8K4v2CdJlT9+pnF5UTHzq5aKD+O9y+r4pZKO8LuL6JoT+o+PsE6TJPu340
Pf9P4pzVK6xXW2B9qphb/cKk1FdYX8RQnyoeJ0ehy/x0d83rw9U0fuCAOe5H
hnD7ZSq29/QQY4MGzA8x5FfF39cdhS5zy6Osr3+/Q+P7q7p3venC7TeqmPO+
otFOg/F8IlIw+BkJ8dCQLnPhmOOrW3oQGzmzA4eX4PlUJCuN1t09UcV1Rgz7
Y6Q4x0dd5i2dVjbG+BBne77Y55mN8Y9k1yruG3WywXgSQ/wj+XM26TI35p8r
XtOL2OyN7+gGDbefHskO6Ts8an6H65nE0B8i+TjSZXZ80H2i7gMHwXZlJnP9
MzC/kWz3VqvTP6Rgvoghv+ivk9BltigtGt0xicbfL46ZV7KTn882RrJJvVd8
rQ3G89IowZDfKOl7VHvuEaj5v3wvGr+/f0ZJnwH8/No3ih1/oF4+dTG/fygx
rK8ofh5PuswLWqpUOZ7Ex3JWbh9RgvmNYhevPqzwOYb5IYb8RsF5xjnSZa4e
/a1FUjJxXnl5nf9jjH8Ui8g8ZeyA3wcriSH+Ufy8kHSZ95kbhORGEW8d8Pq3
8nd5fBqj2M9646/8I77HqQVD/NXS96L2fMGnzzD/nsQZPz0+kv8Mvx+oWV1N
Yq1Ww3VGDOtLzc/DXIQuc1X2ovf9I2i8/6PfP3tw1IXnV82++Hv/0uur+PWh
xJBfNd9vSZc51dOsd6YPcXxBw7tbZzO+vtTstaqyLiyd65nEsL7U/H2OCV1m
V2ev74s30fjnhXqxG+y4/WNqptLWqwos+fVFxLD/qiGfC0iXufnb4/1N9Ygj
fYZ9tjeB229s1c/lHTw8jus6GsGQXw3st4mky5znUlc1ojdx//E5+z2XcfuG
GpZte3aNfTLXTYhhf9TA+9Ze0mXupGfx3og4Yo23zvO++7n9cRrW79F3ZgHb
uc6IoX64vWLSZTa/52R9ajXx9y0t03ZfwfhrmGvnh5/6T8L4EUP8NbCf25Mu
s/PYWbE3uhGXmc9W5zlz+2Ua5vc06RtdG65XEsP61fB+SbrMOzqXuEeMILbN
Gfd6hRbzq+F/L4H5iRYM+Y2G87yzpMv81v3+pUN+o2G/O475IYb8RvN5kC6z
Uk8/EIPfmN9o6OelmB9iyG809IOurkKXWXH/ZxoPfrvy/hAN67Envz6UGPpD
NF9PpMsMcWyvQ/+Phv0imOvJxND/ub8bSZdZmU4AMYzj9huj4X2/CfMTIxj8
ioH3OTNXocuM8UaG811u35Dbm8CvNyGG/HJ7a0iXWfleOJ4Yzoe4/XEx/O+F
MF/EkN8Yfl5CuszK85w7Md4f8hvDlGUai/khhvzy+a4lXWblc4+a+E3b70vM
L7+/BvNDDHni8V1MuszKfh9JrNw/i9tPj+HnPVzPJIb9JQaely+QLnOXtoDH
ECvm/+D2y2LE31koeiUxrFPuTwTpMiv5tCVW1udCrE/ujxbrTSsY6lML/TKJ
dJmVenAmVvrXFqxPLZ8X1hcx1KcW6vUK6TLD9x5iZX53MT5aeB6Yi/Mjhvjw
+yWTLrNSr17EyvQyMD5aOE9bifOLFQzxieXPm6TL/FY9tbIyv8+xPmPB32V8
fScTQ33y+/1Fusywvojh3J3bPxYL/a4Hv38RMeyPsTwPpMus1EsDE6zMzwnj
H8u/92D8iCH+/H6epMus/J8RY/1C/GP58xjGL04wxD+Of28kXWZ4X5X0SOw/
cfzvJfj8Qomh/8TB80gHV6HLDHGk8cr8rDC//P7dsH8QQ37jYD0Zky6zEu7z
TLCy3gZh/KX5VRJD/OP4dwbSZVbqx4LYnfdTiH8cvy/GL14wxD8e6vU66TK/
Xf/xUB9V2B/i+fxwfRNDHcZL/aA9Yz9GVurzFu5f8TyfuP8QQx/l9npPFrrM
b/nXyvD3g5N5/cTzeuDXhxJD/fD5mpEuM5w3uQqGfs3tl/H4HePvH5XEkF+8
HxO6zHDe4dJO/x/FX9dz
             "]]}, {
            Directive[
             AbsoluteThickness[1], 
             EdgeForm[], 
             RGBColor[0.7, 0.1, 0]], 
            Line[CompressedData["
1:eJyNmglYjmnUx5ssY5K1sku2bElp0d4tkvZdi9KmRW8LsnwYvJiECUOILGPN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             "]]}}, {}, {}}, {}, {}}, 
        System`TradingChartDump`$indicatorpos$545716 = 
        System`TradingChartDump`$staticindicatorpos$545716, 
        System`TradingChartDump`$length$545716 = 250, 
        System`TradingChartDump`$gridlinesflag$545716 = True, 
        System`TradingChartDump`$opens$545716 = 
        Dispatch[{
         1 -> 28.37`4., 2 -> 28.61`4., 3 -> 28.87`4., 4 -> 28.61`4., 5 -> 
          28.71`4., 6 -> 28.35`4., 7 -> 28.66`4., 8 -> 29.11`4., 9 -> 
          29.19`4., 10 -> 29.31`4., 11 -> 29.49`4., 12 -> 29.6`4., 13 -> 
          29.45`4., 14 -> 29.6`4., 15 -> 29.41`4., 16 -> 29.66`4., 17 -> 
          30.2`4., 18 -> 30.11`4., 19 -> 30.05`4., 20 -> 29.88`4., 21 -> 
          29.69`4., 22 -> 29.55`4., 23 -> 30.21`4., 24 -> 29.99`4., 25 -> 
          29.94`4., 26 -> 29.83`4., 27 -> 29.9`4., 28 -> 29.75`4., 29 -> 
          29.52`4., 30 -> 29.79`4., 31 -> 30.32`4., 32 -> 30.12`4., 33 -> 
          29.98`4., 34 -> 30.23`4., 35 -> 30.17`4., 36 -> 30.29`4., 37 -> 
          30.47`4., 38 -> 30.38`4., 39 -> 30.37`4., 40 -> 30.23`4., 41 -> 
          30.7`4., 42 -> 30.28`4., 43 -> 30.24`4., 44 -> 29.58`4., 45 -> 
          29.47`4., 46 -> 29.48`4., 47 -> 29.12`4., 48 -> 28.99`4., 49 -> 
          29.06`4., 50 -> 29.27`4., 51 -> 29.53`4., 52 -> 28.95`4., 53 -> 
          28.99`4., 54 -> 28.48`4., 55 -> 28.54`4., 56 -> 28.3`4., 57 -> 
          28.69`4., 58 -> 28.77`4., 59 -> 28.63`4., 60 -> 28.97`4., 61 -> 
          28.38`4., 62 -> 28.06`4., 63 -> 27.13`4., 64 -> 27.5`4., 65 -> 
          27.53`4., 66 -> 27.22`4., 67 -> 27.89`4., 68 -> 28.18`4., 69 -> 
          28.91`4., 70 -> 28.93`4., 71 -> 29.13`4., 72 -> 28.85`4., 73 -> 
          28.44`4., 74 -> 28.21`4., 75 -> 28.27`4., 76 -> 26.61`4., 77 -> 
          26.82`4., 78 -> 26.48`4., 79 -> 26.27`4., 80 -> 26.4`4., 81 -> 
          26.36`4., 82 -> 26.3`4., 83 -> 26.82`4., 84 -> 27.13`4., 85 -> 
          26.95`4., 86 -> 26.61`4., 87 -> 26.7`4., 88 -> 26.64`4., 89 -> 
          26.37`4., 90 -> 26.1`4., 91 -> 25.98`4., 92 -> 26.41`4., 93 -> 
          26.41`4., 94 -> 26.16`4., 95 -> 26.64`4., 96 -> 27.12`4., 97 -> 
          26.91`4., 98 -> 26.7`4., 99 -> 26.38`4., 100 -> 26.83`4., 101 -> 
          27.27`4., 102 -> 26.94`4., 103 -> 27.04`4., 104 -> 26.79`4., 105 -> 
          26.62`4., 106 -> 26.48`4., 107 -> 26.31`4., 108 -> 26.19`4., 109 -> 
          26.84`4., 110 -> 27.21`4., 111 -> 26.86`4., 112 -> 26.37`4., 113 -> 
          26.35`4., 114 -> 26.32`4., 115 -> 26.25`4., 116 -> 26.09`4., 117 -> 
          26.49`4., 118 -> 26.43`4., 119 -> 26.74`4., 120 -> 26.78`4., 121 -> 
          26.69`4., 122 -> 26.89`4., 123 -> 26.79`4., 124 -> 27.28`4., 125 -> 
          27.16`4., 126 -> 27.59`4., 127 -> 27.4`4., 128 -> 27.59`4., 129 -> 
          27.37`4., 130 -> 27.25`4., 131 -> 27.45`4., 132 -> 27.2`4., 133 -> 
          26.97`4., 134 -> 26.94`4., 135 -> 26.93`4., 136 -> 27.23`4., 137 -> 
          27.46`4., 138 -> 27.51`4., 139 -> 27.5`4., 140 -> 27.62`4., 141 -> 
          27.68`4., 142 -> 27.94`4., 143 -> 27.55`4., 144 -> 27.49`4., 145 -> 
          27.78`4., 146 -> 27.19`4., 147 -> 27.23`4., 148 -> 27.69`4., 149 -> 
          27.53`4., 150 -> 27.65`4., 151 -> 28.09`4., 152 -> 28.01`4., 153 -> 
          27.91`4., 154 -> 28.06`4., 155 -> 27.75`4., 156 -> 27.65`4., 157 -> 
          27.68`4., 158 -> 27.8`4., 159 -> 27.83`4., 160 -> 27.68`4., 161 -> 
          27.92`4., 162 -> 28.14`4., 163 -> 27.91`4., 164 -> 27.99`4., 165 -> 
          28.1`4., 166 -> 28.04`4., 167 -> 27.94`4., 168 -> 28.12`4., 169 -> 
          28.44`4., 170 -> 28.39`4., 171 -> 28.55`4., 172 -> 28.19`4., 173 -> 
          28.02`4., 174 -> 28.53`4., 175 -> 28.53`4., 176 -> 29.36`4., 177 -> 
          28.9`4., 178 -> 28.65`4., 179 -> 28.45`4., 180 -> 28.7`4., 181 -> 
          28.65`4., 182 -> 28.75`4., 183 -> 29.41`4., 184 -> 30.09`4., 185 -> 
          30.49`4., 186 -> 30.41`4., 187 -> 31.49`4., 188 -> 31.68`4., 189 -> 
          31.58`4., 190 -> 32.33`4., 191 -> 32.7`4., 192 -> 32.4`4., 193 -> 
          33.`4., 194 -> 33.18`4., 195 -> 33.42`4., 196 -> 32.84`4., 197 -> 
          32.62`4., 198 -> 32.44`4., 199 -> 32.38`4., 200 -> 32.86`4., 201 -> 
          33.45`4., 202 -> 33.64`4., 203 -> 34.13`4., 204 -> 34.73`4., 205 -> 
          35.1`4., 206 -> 34.79`4., 207 -> 34.23`4., 208 -> 33.92`4., 209 -> 
          34.42`4., 210 -> 34.74`4., 211 -> 34.85`4., 212 -> 34.82`4., 213 -> 
          34.92`4., 214 -> 35.62`4., 215 -> 34.6`4., 216 -> 34.84`4., 217 -> 
          35.25`4., 218 -> 35.51`4., 219 -> 35.05`4., 220 -> 35.14`4., 221 -> 
          34.99`4., 222 -> 34.55`4., 223 -> 34.69`4., 224 -> 34.97`4., 225 -> 
          34.96`4., 226 -> 34.26`4., 227 -> 33.66`4., 228 -> 32.94`4., 229 -> 
          34.08`4., 230 -> 34.12`4., 231 -> 34.52`4., 232 -> 34.38`4., 233 -> 
          34.75`4., 234 -> 34.41`4., 235 -> 33.66`4., 236 -> 34.09`4., 237 -> 
          34.35`4., 238 -> 34.58`4., 239 -> 34.34`4., 240 -> 35.`4., 241 -> 
          35.58`4., 242 -> 35.66`4., 243 -> 36.01`4., 244 -> 36.34`4., 245 -> 
          35.72`4., 246 -> 32.4`4., 247 -> 31.7`4., 248 -> 31.91`4., 249 -> 
          32.04`4., 250 -> 31.62`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {183}, {},
             {155}, {140}, {}, {190}, {}, {}, {}, {}, {}, {}, {}, {}, {
            64}, {}, {114}, {99, 151}, {}, {}}]}], 
        System`TradingChartDump`$highs$545716 = 
        Dispatch[{
         1 -> 28.63`4., 2 -> 28.97`4., 3 -> 28.93`4., 4 -> 28.83`4., 5 -> 
          28.77`4., 6 -> 28.66`4., 7 -> 29.05`4., 8 -> 29.22`4., 9 -> 
          29.46`4., 10 -> 29.57`4., 11 -> 29.75`4., 12 -> 29.71`4., 13 -> 
          29.56`4., 14 -> 29.68`4., 15 -> 29.58`4., 16 -> 30.23`4., 17 -> 
          30.2`4., 18 -> 30.14`4., 19 -> 30.25`4., 20 -> 30.04`4., 21 -> 
          29.7`4., 22 -> 29.92`4., 23 -> 30.24`4., 24 -> 30.09`4., 25 -> 
          30.04`4., 26 -> 29.9`4., 27 -> 30.25`4., 28 -> 29.95`4., 29 -> 
          29.83`4., 30 -> 30.63`4., 31 -> 30.35`4., 32 -> 30.19`4., 33 -> 
          30.2`4., 34 -> 30.46`4., 35 -> 30.45`4., 36 -> 30.53`4., 37 -> 
          30.54`4., 38 -> 30.49`4., 39 -> 30.47`4., 40 -> 30.75`4., 41 -> 
          30.88`4., 42 -> 30.35`4., 43 -> 30.29`4., 44 -> 29.89`4., 45 -> 
          29.69`4., 46 -> 29.56`4., 47 -> 29.29`4., 48 -> 29.19`4., 49 -> 
          29.3`4., 50 -> 29.33`4., 51 -> 29.55`4., 52 -> 29.23`4., 53 -> 
          29.05`4., 54 -> 28.63`4., 55 -> 28.57`4., 56 -> 28.64`4., 57 -> 
          29.04`4., 58 -> 29.05`4., 59 -> 28.96`4., 60 -> 29.04`4., 61 -> 
          28.41`4., 62 -> 28.16`4., 63 -> 27.55`4., 64 -> 27.54`4., 65 -> 
          27.54`4., 66 -> 27.69`4., 67 -> 28.21`4., 68 -> 28.88`4., 69 -> 
          29.08`4., 70 -> 29.05`4., 71 -> 29.5`4., 72 -> 29.14`4., 73 -> 
          28.69`4., 74 -> 28.51`4., 75 -> 28.34`4., 76 -> 26.89`4., 77 -> 
          26.87`4., 78 -> 26.57`4., 79 -> 26.3`4., 80 -> 26.4`4., 81 -> 
          26.4`4., 82 -> 26.76`4., 83 -> 27.35`4., 84 -> 27.17`4., 85 -> 
          26.97`4., 86 -> 26.98`4., 87 -> 26.94`4., 88 -> 26.72`4., 89 -> 
          26.41`4., 90 -> 26.23`4., 91 -> 26.53`4., 92 -> 26.58`4., 93 -> 
          26.41`4., 94 -> 26.56`4., 95 -> 27.08`4., 96 -> 27.2`4., 97 -> 
          27.1`4., 98 -> 26.72`4., 99 -> 26.81`4., 100 -> 27.21`4., 101 -> 
          27.31`4., 102 -> 27.26`4., 103 -> 27.08`4., 104 -> 26.84`4., 105 -> 
          26.78`4., 106 -> 26.68`4., 107 -> 26.49`4., 108 -> 26.37`4., 109 -> 
          27.31`4., 110 -> 27.23`4., 111 -> 26.93`4., 112 -> 26.48`4., 113 -> 
          26.39`4., 114 -> 26.35`4., 115 -> 26.57`4., 116 -> 26.52`4., 117 -> 
          26.67`4., 118 -> 26.88`4., 119 -> 26.82`4., 120 -> 27.06`4., 121 -> 
          26.88`4., 122 -> 27.04`4., 123 -> 27.22`4., 124 -> 27.64`4., 125 -> 
          27.8`4., 126 -> 27.81`4., 127 -> 27.71`4., 128 -> 27.76`4., 129 -> 
          27.55`4., 130 -> 27.63`4., 131 -> 27.6`4., 132 -> 27.24`4., 133 -> 
          27.13`4., 134 -> 26.98`4., 135 -> 27.29`4., 136 -> 27.5`4., 137 -> 
          27.58`4., 138 -> 27.69`4., 139 -> 27.64`4., 140 -> 27.74`4., 141 -> 
          27.89`4., 142 -> 28.01`4., 143 -> 27.55`4., 144 -> 27.57`4., 145 -> 
          27.86`4., 146 -> 27.41`4., 147 -> 27.81`4., 148 -> 27.78`4., 149 -> 
          27.79`4., 150 -> 27.95`4., 151 -> 28.34`4., 152 -> 28.03`4., 153 -> 
          28.08`4., 154 -> 28.14`4., 155 -> 27.78`4., 156 -> 27.76`4., 157 -> 
          27.83`4., 158 -> 27.96`4., 159 -> 27.96`4., 160 -> 28.08`4., 161 -> 
          28.02`4., 162 -> 28.29`4., 163 -> 28.16`4., 164 -> 28.14`4., 165 -> 
          28.15`4., 166 -> 28.14`4., 167 -> 28.25`4., 168 -> 28.46`4., 169 -> 
          28.46`4., 170 -> 28.65`4., 171 -> 28.75`4., 172 -> 28.41`4., 173 -> 
          28.58`4., 174 -> 28.53`4., 175 -> 29.61`4., 176 -> 30.11`4., 177 -> 
          29.`4., 178 -> 28.82`4., 179 -> 28.78`4., 180 -> 28.94`4., 181 -> 
          28.84`4., 182 -> 28.78`4., 183 -> 30.03`4., 184 -> 30.97`4., 185 -> 
          30.69`4., 186 -> 31.7`4., 187 -> 32.61`4., 188 -> 31.76`4., 189 -> 
          32.45`4., 190 -> 32.88`4., 191 -> 32.85`4., 192 -> 32.94`4., 193 -> 
          33.29`4., 194 -> 33.67`4., 195 -> 33.56`4., 196 -> 33.01`4., 197 -> 
          32.77`4., 198 -> 32.49`4., 199 -> 32.84`4., 200 -> 33.53`4., 201 -> 
          33.9`4., 202 -> 34.15`4., 203 -> 34.87`4., 204 -> 35.1`4., 205 -> 
          35.27`4., 206 -> 34.84`4., 207 -> 34.55`4., 208 -> 34.28`4., 209 -> 
          35.18`4., 210 -> 35.02`4., 211 -> 35.25`4., 212 -> 35.28`4., 213 -> 
          35.63`4., 214 -> 35.74`4., 215 -> 34.89`4., 216 -> 35.11`4., 217 -> 
          35.78`4., 218 -> 35.65`4., 219 -> 35.18`4., 220 -> 35.27`4., 221 -> 
          35.02`4., 222 -> 34.69`4., 223 -> 35.16`4., 224 -> 35.17`4., 225 -> 
          35.09`4., 226 -> 34.33`4., 227 -> 33.73`4., 228 -> 34.2`4., 229 -> 
          34.38`4., 230 -> 34.48`4., 231 -> 34.78`4., 232 -> 34.79`4., 233 -> 
          34.99`4., 234 -> 34.44`4., 235 -> 34.37`4., 236 -> 34.24`4., 237 -> 
          34.59`4., 238 -> 34.6`4., 239 -> 34.81`4., 240 -> 35.77`4., 241 -> 
          35.73`4., 242 -> 36.22`4., 243 -> 36.43`4., 244 -> 36.39`4., 245 -> 
          35.89`4., 246 -> 32.67`4., 247 -> 32.01`4., 248 -> 32.04`4., 249 -> 
          32.19`4., 250 -> 31.65`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$lows$545716 = 
        Dispatch[{
         1 -> 28.23`4., 2 -> 28.32`4., 3 -> 28.59`4., 4 -> 28.46`4., 5 -> 
          28.35`4., 6 -> 28.12`4., 7 -> 28.61`4., 8 -> 28.92`4., 9 -> 
          28.99`4., 10 -> 29.22`4., 11 -> 29.41`4., 12 -> 29.36`4., 13 -> 
          29.27`4., 14 -> 29.31`4., 15 -> 29.32`4., 16 -> 29.56`4., 17 -> 
          29.88`4., 18 -> 29.87`4., 19 -> 29.9`4., 20 -> 29.76`4., 21 -> 
          29.38`4., 22 -> 29.48`4., 23 -> 29.88`4., 24 -> 29.81`4., 25 -> 
          29.73`4., 26 -> 29.52`4., 27 -> 29.68`4., 28 -> 29.46`4., 29 -> 
          29.51`4., 30 -> 29.75`4., 31 -> 30.02`4., 32 -> 29.8`4., 33 -> 
          29.9`4., 34 -> 30.02`4., 35 -> 29.69`4., 36 -> 30.1`4., 37 -> 
          30.32`4., 38 -> 30.31`4., 39 -> 30.32`4., 40 -> 30.19`4., 41 -> 
          30.37`4., 42 -> 29.93`4., 43 -> 29.66`4., 44 -> 29.34`4., 45 -> 
          29.2`4., 46 -> 29.05`4., 47 -> 28.74`4., 48 -> 28.81`4., 49 -> 
          28.98`4., 50 -> 28.88`4., 51 -> 29.05`4., 52 -> 28.87`4., 53 -> 
          28.5`4., 54 -> 28.28`4., 55 -> 28.2`4., 56 -> 28.13`4., 57 -> 
          28.58`4., 58 -> 28.64`4., 59 -> 28.42`4., 60 -> 28.59`4., 61 -> 
          27.84`4., 62 -> 27.18`4., 63 -> 27.12`4., 64 -> 27.22`4., 65 -> 
          27.21`4., 66 -> 27.2`4., 67 -> 27.84`4., 68 -> 28.16`4., 69 -> 
          28.65`4., 70 -> 28.65`4., 71 -> 28.93`4., 72 -> 28.38`4., 73 -> 
          28.13`4., 74 -> 28.14`4., 75 -> 27.56`4., 76 -> 26.35`4., 77 -> 
          26.39`4., 78 -> 26.23`4., 79 -> 25.94`4., 80 -> 26.07`4., 81 -> 
          26.06`4., 82 -> 26.26`4., 83 -> 26.79`4., 84 -> 26.76`4., 85 -> 
          26.63`4., 86 -> 26.37`4., 87 -> 26.45`4., 88 -> 26.09`4., 89 -> 
          26.`4., 90 -> 25.94`4., 91 -> 25.87`4., 92 -> 26.21`4., 93 -> 
          25.97`4., 94 -> 26.12`4., 95 -> 26.64`4., 96 -> 26.67`4., 97 -> 
          26.54`4., 98 -> 26.29`4., 99 -> 26.28`4., 100 -> 26.73`4., 101 -> 
          26.84`4., 102 -> 26.74`4., 103 -> 26.6`4., 104 -> 26.59`4., 105 -> 
          26.29`4., 106 -> 26.17`4., 107 -> 26.15`4., 108 -> 25.98`4., 109 -> 
          26.74`4., 110 -> 26.75`4., 111 -> 26.33`4., 112 -> 26.24`4., 113 -> 
          26.06`4., 114 -> 26.16`4., 115 -> 25.89`4., 116 -> 25.88`4., 117 -> 
          26.35`4., 118 -> 26.43`4., 119 -> 26.6`4., 120 -> 26.65`4., 121 -> 
          26.63`4., 122 -> 26.59`4., 123 -> 26.79`4., 124 -> 27.05`4., 125 -> 
          26.98`4., 126 -> 27.34`4., 127 -> 27.19`4., 128 -> 27.34`4., 129 -> 
          26.99`4., 130 -> 27.14`4., 131 -> 27.01`4., 132 -> 26.94`4., 133 -> 
          26.84`4., 134 -> 26.69`4., 135 -> 26.89`4., 136 -> 27.09`4., 137 -> 
          27.33`4., 138 -> 27.46`4., 139 -> 27.45`4., 140 -> 27.46`4., 141 -> 
          27.6`4., 142 -> 27.64`4., 143 -> 27.04`4., 144 -> 27.29`4., 145 -> 
          27.18`4., 146 -> 27.15`4., 147 -> 27.14`4., 148 -> 27.55`4., 149 -> 
          27.33`4., 150 -> 27.5`4., 151 -> 27.96`4., 152 -> 27.58`4., 153 -> 
          27.81`4., 154 -> 27.77`4., 155 -> 27.48`4., 156 -> 27.45`4., 157 -> 
          27.56`4., 158 -> 27.73`4., 159 -> 27.78`4., 160 -> 27.61`4., 161 -> 
          27.83`4., 162 -> 27.98`4., 163 -> 27.85`4., 164 -> 27.9`4., 165 -> 
          27.76`4., 166 -> 27.91`4., 167 -> 27.88`4., 168 -> 28.06`4., 169 -> 
          28.16`4., 170 -> 28.32`4., 171 -> 28.34`4., 172 -> 28.07`4., 173 -> 
          27.91`4., 174 -> 28.27`4., 175 -> 28.48`4., 176 -> 29.32`4., 177 -> 
          28.53`4., 178 -> 28.46`4., 179 -> 28.31`4., 180 -> 28.5`4., 181 -> 
          28.4`4., 182 -> 28.3`4., 183 -> 29.4`4., 184 -> 30.06`4., 185 -> 
          30.17`4., 186 -> 30.39`4., 187 -> 31.32`4., 188 -> 31.23`4., 189 -> 
          31.55`4., 190 -> 32.06`4., 191 -> 32.37`4., 192 -> 32.17`4., 193 -> 
          32.85`4., 194 -> 33.01`4., 195 -> 33.01`4., 196 -> 32.42`4., 197 -> 
          32.36`4., 198 -> 32.09`4., 199 -> 32.32`4., 200 -> 32.8`4., 201 -> 
          33.43`4., 202 -> 33.55`4., 203 -> 34.1`4., 204 -> 34.68`4., 205 -> 
          34.72`4., 206 -> 34.36`4., 207 -> 33.9`4., 208 -> 33.9`4., 209 -> 
          34.41`4., 210 -> 34.57`4., 211 -> 34.81`4., 212 -> 34.79`4., 213 -> 
          34.83`4., 214 -> 34.77`4., 215 -> 34.43`4., 216 -> 34.49`4., 217 -> 
          35.06`4., 218 -> 35.14`4., 219 -> 34.68`4., 220 -> 34.85`4., 221 -> 
          34.59`4., 222 -> 34.25`4., 223 -> 34.63`4., 224 -> 34.9`4., 225 -> 
          34.59`4., 226 -> 33.37`4., 227 -> 33.05`4., 228 -> 32.57`4., 229 -> 
          33.46`4., 230 -> 33.89`4., 231 -> 34.5`4., 232 -> 34.34`4., 233 -> 
          34.33`4., 234 -> 33.63`4., 235 -> 33.6`4., 236 -> 33.58`4., 237 -> 
          33.98`4., 238 -> 34.14`4., 239 -> 34.32`4., 240 -> 34.9`4., 241 -> 
          35.28`4., 242 -> 35.58`4., 243 -> 35.96`4., 244 -> 35.49`4., 245 -> 
          35.22`4., 246 -> 31.02`4., 247 -> 31.6`4., 248 -> 31.71`4., 249 -> 
          31.89`4., 250 -> 31.25`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$closes$545716 = 
        Dispatch[{
         1 -> 28.3`4., 2 -> 28.88`4., 3 -> 28.76`4., 4 -> 28.6`4., 5 -> 
          28.54`4., 6 -> 28.33`4., 7 -> 28.87`4., 8 -> 29.06`4., 9 -> 
          29.37`4., 10 -> 29.43`4., 11 -> 29.6`4., 12 -> 29.52`4., 13 -> 
          29.49`4., 14 -> 29.43`4., 15 -> 29.5`4., 16 -> 30.07`4., 17 -> 
          30.18`4., 18 -> 30.03`4., 19 -> 30.09`4., 20 -> 29.83`4., 21 -> 
          29.56`4., 22 -> 29.85`4., 23 -> 29.98`4., 24 -> 29.92`4., 25 -> 
          29.94`4., 26 -> 29.62`4., 27 -> 30.11`4., 28 -> 29.69`4., 29 -> 
          29.69`4., 30 -> 30.62`4., 31 -> 30.23`4., 32 -> 30.01`4., 33 -> 
          30.08`4., 34 -> 30.07`4., 35 -> 30.22`4., 36 -> 30.49`4., 37 -> 
          30.49`4., 38 -> 30.46`4., 39 -> 30.33`4., 40 -> 30.72`4., 41 -> 
          30.47`4., 42 -> 30.07`4., 43 -> 29.69`4., 44 -> 29.47`4., 45 -> 
          29.46`4., 46 -> 29.07`4., 47 -> 28.81`4., 48 -> 28.97`4., 49 -> 
          29.17`4., 50 -> 29.33`4., 51 -> 29.16`4., 52 -> 29.09`4., 53 -> 
          28.6`4., 54 -> 28.31`4., 55 -> 28.28`4., 56 -> 28.52`4., 57 -> 
          28.83`4., 58 -> 28.81`4., 59 -> 28.91`4., 60 -> 28.82`4., 61 -> 
          27.98`4., 62 -> 27.35`4., 63 -> 27.4`4., 64 -> 27.25`4., 65 -> 
          27.23`4., 66 -> 27.56`4., 67 -> 27.88`4., 68 -> 28.84`4., 69 -> 
          28.82`4., 70 -> 28.94`4., 71 -> 29.17`4., 72 -> 28.41`4., 73 -> 
          28.14`4., 74 -> 28.16`4., 75 -> 27.57`4., 76 -> 26.68`4., 77 -> 
          26.43`4., 78 -> 26.26`4., 79 -> 26.12`4., 80 -> 26.33`4., 81 -> 
          26.31`4., 82 -> 26.54`4., 83 -> 27.28`4., 84 -> 26.98`4., 85 -> 
          26.67`4., 86 -> 26.95`4., 87 -> 26.54`4., 88 -> 26.22`4., 89 -> 
          26.03`4., 90 -> 25.97`4., 91 -> 26.27`4., 92 -> 26.33`4., 93 -> 
          26.06`4., 94 -> 26.53`4., 95 -> 26.91`4., 96 -> 26.83`4., 97 -> 
          26.7`4., 98 -> 26.4`4., 99 -> 26.69`4., 100 -> 27.14`4., 101 -> 
          26.9`4., 102 -> 27.26`4., 103 -> 27.04`4., 104 -> 26.65`4., 105 -> 
          26.45`4., 106 -> 26.55`4., 107 -> 26.15`4., 108 -> 26.31`4., 109 -> 
          27.2`4., 110 -> 26.84`4., 111 -> 26.34`4., 112 -> 26.29`4., 113 -> 
          26.15`4., 114 -> 26.3`4., 115 -> 26.06`4., 116 -> 26.42`4., 117 -> 
          26.48`4., 118 -> 26.8`4., 119 -> 26.63`4., 120 -> 26.84`4., 121 -> 
          26.84`4., 122 -> 26.74`4., 123 -> 27.19`4., 124 -> 27.21`4., 125 -> 
          27.46`4., 126 -> 27.49`4., 127 -> 27.59`4., 128 -> 27.43`4., 129 -> 
          27.04`4., 130 -> 27.51`4., 131 -> 27.03`4., 132 -> 27.08`4., 133 -> 
          26.93`4., 134 -> 26.87`4., 135 -> 27.13`4., 136 -> 27.44`4., 137 -> 
          27.46`4., 138 -> 27.61`4., 139 -> 27.62`4., 140 -> 27.59`4., 141 -> 
          27.85`4., 142 -> 27.68`4., 143 -> 27.3`4., 144 -> 27.57`4., 145 -> 
          27.18`4., 146 -> 27.18`4., 147 -> 27.62`4., 148 -> 27.61`4., 149 -> 
          27.76`4., 150 -> 27.95`4., 151 -> 28.15`4., 152 -> 27.89`4., 153 -> 
          27.94`4., 154 -> 27.81`4., 155 -> 27.68`4., 156 -> 27.72`4., 157 -> 
          27.73`4., 158 -> 27.94`4., 159 -> 27.84`4., 160 -> 27.9`4., 161 -> 
          27.98`4., 162 -> 28.12`4., 163 -> 27.91`4., 164 -> 28.05`4., 165 -> 
          27.96`4., 166 -> 27.96`4., 167 -> 28.17`4., 168 -> 28.41`4., 169 -> 
          28.41`4., 170 -> 28.6`4., 171 -> 28.36`4., 172 -> 28.4`4., 173 -> 
          28.5`4., 174 -> 28.39`4., 175 -> 29.4`4., 176 -> 30.07`4., 177 -> 
          28.74`4., 178 -> 28.59`4., 179 -> 28.49`4., 180 -> 28.77`4., 181 -> 
          28.63`4., 182 -> 28.59`4., 183 -> 29.56`4., 184 -> 30.62`4., 185 -> 
          30.39`4., 186 -> 31.54`4., 187 -> 31.72`4., 188 -> 31.57`4., 189 -> 
          32.38`4., 190 -> 32.87`4., 191 -> 32.49`4., 192 -> 32.93`4., 193 -> 
          33.26`4., 194 -> 33.51`4., 195 -> 33.08`4., 196 -> 32.76`4., 197 -> 
          32.43`4., 198 -> 32.46`4., 199 -> 32.8`4., 200 -> 33.53`4., 201 -> 
          33.85`4., 202 -> 34.08`4., 203 -> 34.87`4., 204 -> 35.08`4., 205 -> 
          34.85`4., 206 -> 34.61`4., 207 -> 34.15`4., 208 -> 34.27`4., 209 -> 
          35.02`4., 210 -> 34.88`4., 211 -> 35.03`4., 212 -> 34.9`4., 213 -> 
          35.59`4., 214 -> 34.99`4., 215 -> 34.78`4., 216 -> 34.96`4., 217 -> 
          35.67`4., 218 -> 35.47`4., 219 -> 34.84`4., 220 -> 35.`4., 221 -> 
          34.72`4., 222 -> 34.4`4., 223 -> 35.`4., 224 -> 34.98`4., 225 -> 
          34.59`4., 226 -> 33.49`4., 227 -> 33.27`4., 228 -> 33.72`4., 229 -> 
          33.67`4., 230 -> 34.35`4., 231 -> 34.62`4., 232 -> 34.54`4., 233 -> 
          34.36`4., 234 -> 33.94`4., 235 -> 34.01`4., 236 -> 34.21`4., 237 -> 
          34.33`4., 238 -> 34.35`4., 239 -> 34.7`4., 240 -> 35.69`4., 241 -> 
          35.67`4., 242 -> 36.17`4., 243 -> 36.27`4., 244 -> 35.74`4., 245 -> 
          35.44`4., 246 -> 31.4`4., 247 -> 32.01`4., 248 -> 31.82`4., 249 -> 
          31.96`4., 250 -> 31.39`4.}, {
          HashTable[
          1, 250, 1, {{41, 44, 98}, {}, {29, 229}, {}, {74, 181}, {}, {208}, {
            202, 232}, {}, {209, 245}, {71, 132, 219}, {}, {227}, {137}, {}, {
            163}, {}, {5}, {}, {}, {}, {121}, {131}, {196}, {112, 119, 215}, {
            231, 239}, {}, {129, 136}, {188}, {199}, {}, {146}, {}, {150}, {
            102}, {70}, {}, {147}, {162}, {93, 141}, {216, 223, 246}, {126, 
            157}, {34}, {32}, {1}, {}, {53}, {}, {179}, {17}, {}, {24}, {100, 
            134, 195, 240}, {65, 185}, {}, {200}, {37}, {79}, {}, {228}, {}, {
            169, 206}, {}, {160, 170, 250}, {18}, {90, 96, 130}, {}, {11}, {
            20}, {72}, {82}, {12, 60}, {78}, {}, {135}, {}, {}, {}, {83, 
            204}, {6, 55, 105, 203}, {106}, {139, 143, 165}, {110}, {16}, {61,
             233, 244}, {19, 192}, {}, {49, 76}, {153}, {}, {}, {211}, {36}, {
            109}, {}, {}, {13, 187}, {77, 138, 175}, {221}, {}, {81, 159, 168,
             186}, {42}, {}, {166}, {}, {}, {}, {226}, {57}, {214}, {}, {207, 
            224}, {56}, {80}, {247}, {174}, {198}, {30, 63}, {}, {40}, {
            197}, {28}, {}, {}, {23}, {88}, {}, {212}, {68, 86, 111, 
            173}, {}, {33}, {95, 116, 177}, {67, 241}, {}, {}, {145}, {218}, {
            43}, {}, {}, {101}, {178, 205}, {}, {62, 235}, {10, 21, 193}, {
            238}, {144}, {89, 115, 127}, {148}, {51, 149, 248}, {50, 171}, {
            87}, {}, {}, {103}, {}, {176}, {194, 242}, {172}, {182}, {234}, {
            243}, {}, {124, 158, 164}, {236}, {4, 84, 94}, {}, {2, 48, 
            85}, {}, {26}, {}, {191}, {217}, {54}, {}, {69, 189}, {14, 59, 
            120, 154}, {3, 230}, {}, {237}, {75}, {}, {201}, {}, {}, {222}, {
            220}, {97, 128}, {8, 38, 47}, {113, 161}, {92}, {107}, {}, {
            184}, {152}, {104}, {}, {108}, {}, {39}, {66}, {118, 125}, {}, {7,
             15, 31}, {142}, {58}, {123}, {133}, {}, {}, {}, {249}, {}, {
            91}, {}, {117}, {27}, {}, {35, 122, 167}, {9, 45}, {}, {22, 52}, {
            46}, {}, {73, 180}, {}, {25, 225}, {}, {156, 210, 213}, {
            183}, {}, {155}, {140}, {}, {
            190}, {}, {}, {}, {}, {}, {}, {}, {}, {64}, {}, {114}, {99, 
            151}, {}, {}}]}], System`TradingChartDump`$fastpos$545716 = True, 
        System`TradingChartDump`$gridlines$545716 = {Automatic, Automatic}, 
        System`TradingChartDump`$subplotgridlines$545716, 
        System`TradingChartDump`$plotrangemin$545716 = 25.337956692913384`, 
        System`TradingChartDump`$plotrangemax$545716 = 37.48638507686539, 
        System`TradingChartDump`$layoutData$545716, 
        System`TradingChartDump`$gridlinesscope$545716 = {"MonthNameShort"}, 
        System`TradingChartDump`$axes$545716 = {True, True}, 
        System`TradingChartDump`$indicators$545716 = {
         FinancialIndicator["WilliamsPercentR", 10]}, 
        System`TradingChartDump`$mouseQ$545716 = False, 
        System`TradingChartDump`$modelData$545716 = 
        System`TradingChartDump`modelData$544930, 
        System`TradingChartDump`$sy$545716 = Identity, 
        System`TradingChartDump`$isy$545716 = Identity, 
        System`TradingChartDump`$appearance$545716 = Automatic, 
        System`TradingChartDump`$perfgoal$545716 = "Quality", 
        System`TradingChartDump`$axesorigin$545716 = Automatic, 
        System`TradingChartDump`$framestyle$545716 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$frameticksstyle$545716 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$labelstyle$545716 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$tickstextstyle$545716 = {
         Directive[], 
         Directive[]}, System`TradingChartDump`$textstyle$545716 = Directive[
        "GraphicsFrame", "GraphicsFrameTicks", "GraphicsLabel", {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}, {
          Directive[], 
          Directive[]}], System`TradingChartDump`$staticindicatorpos$545716, 
        System`TradingChartDump`$newgridlines$545716 = {{{4.5, {}}, {
          27.5, {}}, {46.5, {}}, {67.5, {}}, {88.5, {}}, {108.5, {}}, {
          129.5, {}}, {148.5, {}}, {168.5, {}}, {190.5, {}}, {212.5, {}}, {
          232.5, {}}, {108.5, 
           Directive[
            Opacity[0.4], 
            Dashing[{}]]}}, FindDivisions[{25.337956692913384`, #2}, 6]& }, 
        System`TradingChartDump`$defaultframeticksstyle$545716 = 
        "GraphicsFrameTicks", 
        System`TradingChartDump`$defaultlabelstyle$545716 = "GraphicsLabel", 
        System`TradingChartDump`$defaultframestyle$545716 = "GraphicsFrame", 
        System`TradingChartDump`$frame$545716 = True}, {
         DynamicBox[Typeset`ToBoxes[
          If[System`TradingChartDump`$highlightposition$545716 =!= Automatic, 
             System`TradingChartDump`$staticindicatorpos$545716 = 
              Switch[System`TradingChartDump`$highlightposition$545716, 
                Alternatives["Left", Left], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmin$545716], {
                 1, System`TradingChartDump`$length$545716}], 
                Alternatives["Right", Right], 
                Clip[
                 Ceiling[System`TradingChartDump`$controlmax$545716], {
                 1, System`TradingChartDump`$length$545716}], 
                Blank[], 
                Last[
                 Flatten[
                  Position[System`TradingChartDump`$dates$545716, 
                   Charting`nearestDate[System`TradingChartDump`$dates$545716, 
                    Take[
                    Quiet[
                    Check[
                    DateList[
                    AbsoluteTime[
                    System`TradingChartDump`$highlightposition$545716]], 
                    DateList[
                    Last[System`TradingChartDump`$dates$545716]]]], 
                    Span[1, 3]], 
                    DateString[
                    Part[
                    System`TradingChartDump`$dates$545716, 
                    Floor[System`TradingChartDump`$controlmin$545716] + 1], {
                    "Month", "/", "Day", "/", "Year"}], 
                    DateString[
                    Part[System`TradingChartDump`$dates$545716, 
                    Floor[System`TradingChartDump`$controlmax$545716]], {
                    "Month", "/", "Day", "/", "Year"}], Automatic]]]]]; Null]; 
           System`TradingChartDump`$fastpos$545716 = First[
              MousePosition[{"Graphics", Graphics}, {True, 0}]]; 
           System`TradingChartDump`$indicatorpos$545716 = 
            If[System`TradingChartDump`$fastpos$545716 =!= True, 
              System`TradingChartDump`$fastpos$545716 = 
               Clip[System`TradingChartDump`$fastpos$545716, {0, 100}] - 0.5; 
              System`TradingChartDump`$fastpos$545716 = (
                  Floor[System`TradingChartDump`$controlmax$545716] - Floor[
                  System`TradingChartDump`$controlmin$545716]) (
                  System`TradingChartDump`$fastpos$545716/100) + 
                Floor[System`TradingChartDump`$controlmin$545716]; Clip[
                Ceiling[System`TradingChartDump`$fastpos$545716], {
                Floor[System`TradingChartDump`$controlmin$545716] + 1, 
                 Floor[System`TradingChartDump`$controlmax$545716]}], 
              System`TradingChartDump`$staticindicatorpos$545716]; 
           System`TradingChartDump`$mouseQ$545716 = Or[
              Not[
               TrueQ[System`TradingChartDump`$fastpos$545716]], 
              System`TradingChartDump`$highlightposition$545716 =!= 
              Automatic]; System`TradingChartDump`$ohlcpoint$545716 = If[
              And[
              System`TradingChartDump`$bouncingballQ$545716, 
               System`TradingChartDump`$mouseQ$545716, 
               System`TradingChartDump`$appearance$545716 =!= None], 
              Dynamic[
               Point[
                FEPrivate`Part[
                 System`TradingChartDump`$layoutData$545716[
                 "MainChartPoints"], 
                 System`TradingChartDump`$indicatorpos$545716]]], {}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`l}, 
              System`TradingChartDump`$overlaypoint$545716[
               System`TradingChartDump`i$] = 
              If[System`TradingChartDump`$mouseQ$545716, 
                Dynamic[
                 Point[
                  FEPrivate`Part[
                   System`TradingChartDump`$layoutData$545716[
                   "OverlayIndicatorPoints", {System`TradingChartDump`i$}], 
                   System`TradingChartDump`$indicatorpos$545716]]], {}]], {
             System`TradingChartDump`l, 
              Length[
               System`TradingChartDump`$layoutData$545716[
               "OverlayIndicatorNames"]]}]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$overlayvalue$545716[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545716, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545716[
                    "OverlayIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545716, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545716, 2}, 
                   NumberPadding -> {" ", "0"}], {}]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545716[
                 "OverlayIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545716[
               "OverlayIndicatorNames"]]}]; 
           System`TradingChartDump`$textstyle$545716 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$defaultframestyle$545716, 
                 System`TradingChartDump`$defaultframeticksstyle$545716, 
                 System`TradingChartDump`$defaultlabelstyle$545716, 
                 System`TradingChartDump`$framestyle$545716, 
                 System`TradingChartDump`$frameticksstyle$545716, 
                 System`TradingChartDump`$labelstyle$545716}, {}, Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545716 = Directive[
              Apply[Sequence, 
               
               DeleteCases[{
                System`TradingChartDump`$frameticksstyle$545716, 
                 System`TradingChartDump`$labelstyle$545716, 
                 System`TradingChartDump`$defaultframeticksstyle$545716, 
                 System`TradingChartDump`$defaultlabelstyle$545716}, 
                Directive[], Infinity]]]; 
           System`TradingChartDump`$tickstextstyle$545716 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545716, 
              "GraphicsFrameTicks", Infinity]; 
           System`TradingChartDump`$tickstextstyle$545716 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545716, "GraphicsLabel", 
              Infinity]; 
           System`TradingChartDump`$tickstextstyle$545716 = 
            DeleteCases[
             System`TradingChartDump`$tickstextstyle$545716, {}, Infinity]; 
           If[
            System`TradingChartDump`$tickstextstyle$545716 =!= Directive[], 
             System`TradingChartDump`$tickstextstyle$545716 = 
             Part[System`TradingChartDump`$tickstextstyle$545716, 1], 
             System`TradingChartDump`$tickstextstyle$545716 = {
               Directive[], 
               Directive[]}]; System`TradingChartDump`$overlaylegends = Inset[
              Style[
               Row[
                Table[
                 
                 With[{System`TradingChartDump`i$ = 
                   System`TradingChartDump`i}, 
                  Row[
                   Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545716[
                    "OverlayIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545716, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545716[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545716[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545716[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Part[
                    System`TradingChartDump`$layoutData$545716[
                    "OverlayIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545716, FontFamily -> 
                    "Times"], 
                    Style[":", System`TradingChartDump`$textstyle$545716]], 
                    Style[":", System`TradingChartDump`$textstyle$545716]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$overlayvalue$545716[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545716]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545716[
                    "OverlayIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]]], {
                 System`TradingChartDump`i, 
                  Length[
                   System`TradingChartDump`$layoutData$545716[
                   "OverlayIndicatorNames"]]}], ImageSize -> {300, Automatic},
                 ImageMargins -> {{0, 0}, {5, 5}}, 
                Alignment -> {Left, Center}], LineIndent -> 0], 
              Scaled[{0, 1}], {Left, Top}, {
              System`TradingChartDump`$length$545716, Automatic}, Alignment -> 
              Left, Background -> 
              System`TradingChartDump`$timestampstyle$545716]; Table[
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              Table[
               
               With[{System`TradingChartDump`k$ = System`TradingChartDump`k}, 
                System`TradingChartDump`$subplotvalue$545716[
                 System`TradingChartDump`i$, System`TradingChartDump`k$] = 
                If[System`TradingChartDump`$mouseQ$545716, 
                  NumberForm[
                   Part[
                    System`TradingChartDump`$layoutData$545716[
                    "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545716, 
                    System`TradingChartDump`k$], {
                   System`TradingChartDump`$ndigits$545716, 2}, 
                   NumberPadding -> {" ", "0"}, 
                   ExponentFunction -> (
                    If[-3 < # < 3, Null, 3 Quotient[#, 3]]& )], 
                  Invisible[
                   Part[
                    System`TradingChartDump`$layoutData$545716[
                    "SubplotIndicatorValues", {
                    System`TradingChartDump`i$}], -1, 
                    System`TradingChartDump`k$]]]], {
               System`TradingChartDump`k, 
                Length[
                 System`TradingChartDump`$layoutData$545716[
                 "SubplotIndicatorLegends", {
                  System`TradingChartDump`i$}]]}]], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545716[
               "SubplotIndicatorNames"]]}]; Table[
             
             With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, 
              System`TradingChartDump`$layoutData$545716[
                "SubplotPoints", {System`TradingChartDump`i$}] = DeleteCases[
                 Part[
                  System`TradingChartDump`$layoutData$545716[
                  "SubplotIndicatorValues", {System`TradingChartDump`i$}], 
                  Span[
                   Max[
                    Floor[System`TradingChartDump`$controlmin$545716], 1], 
                   Floor[System`TradingChartDump`$controlmax$545716]]], "", 
                 Infinity]; 
              System`TradingChartDump`$min$545716[System`TradingChartDump`i$] = 
               Min[
                 System`TradingChartDump`$layoutData$545716[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              System`TradingChartDump`$max$545716[System`TradingChartDump`i$] = 
               Max[
                 System`TradingChartDump`$layoutData$545716[
                 "SubplotPoints", {System`TradingChartDump`i$}]]; 
              If[System`TradingChartDump`$min$545716[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545716[
                 System`TradingChartDump`i$] == 0., 
                System`TradingChartDump`$min$545716[
                  System`TradingChartDump`i$] = 0; 
                System`TradingChartDump`$max$545716[
                  System`TradingChartDump`i$] = 1]; 
              If[System`TradingChartDump`$min$545716[
                 System`TradingChartDump`i$] == 
                System`TradingChartDump`$max$545716[
                 System`TradingChartDump`i$], 
                System`TradingChartDump`$min$545716[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$min$545716[
                   System`TradingChartDump`i$] - 0.1 Abs[
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]]; 
                System`TradingChartDump`$max$545716[
                  System`TradingChartDump`i$] = 
                 System`TradingChartDump`$max$545716[
                   System`TradingChartDump`i$] + 0.1 Abs[
                    System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$]]]; 
              System`TradingChartDump`$subplotrect$545716[
                System`TradingChartDump`i$] = If[
                 And[
                 System`TradingChartDump`$timestampQ$545716, 
                  System`TradingChartDump`$mouseQ$545716], 
                 
                 Rectangle[{
                  System`TradingChartDump`$indicatorpos$545716 - 0.5, 
                   System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$] - 0.15 
                   Abs[System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]]}, 
                  If[
                  System`TradingChartDump`$timestampdepth$545716 === "Full", 
                   
                   Scaled[{0, 0}, {
                    System`TradingChartDump`$indicatorpos$545716 + 0.5, 
                    System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]]}], 
                   Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545716, 1]}, {
                    System`TradingChartDump`$indicatorpos$545716 + 0.5, 
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]]}]]], {}]; 
              System`TradingChartDump`$subplotpoint$545716[
                System`TradingChartDump`i$] = 
               If[System`TradingChartDump`$mouseQ$545716, 
                 Dynamic[
                  Point[
                   FEPrivate`Part[
                    System`TradingChartDump`$layoutData$545716[
                    "SubplotIndicatorPoints", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`$indicatorpos$545716]]], {}]; 
              System`TradingChartDump`$subplotgridlines$545716[
                System`TradingChartDump`i$] = Select[
                 
                 FindDivisions[{
                  System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]], 
                   System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$]]}, 3], 
                 System`TradingChartDump`$min$545716[
                   System`TradingChartDump`i$] - 0.15 Abs[
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]] < # < 
                 System`TradingChartDump`$max$545716[
                   System`TradingChartDump`i$] + 0.25 Abs[
                    System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$]]& ]; Null], {
             System`TradingChartDump`i, 
              Length[
               System`TradingChartDump`$layoutData$545716[
               "SubplotIndicatorNames"]]}]; 
           System`TradingChartDump`$ohlclabel$545716 = Grid[{{
                Style[
                "O: ", 12, System`TradingChartDump`$textstyle$545716, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545716, 
                   System`TradingChartDump`$opens$545716]], 12, 
                 System`TradingChartDump`$textstyle$545716, FontFamily -> 
                 "Times"], 
                Style[
                "H: ", 12, System`TradingChartDump`$textstyle$545716, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545716, 
                   System`TradingChartDump`$highs$545716]], 12, 
                 System`TradingChartDump`$textstyle$545716, FontFamily -> 
                 "Times"], 
                Style[
                "L: ", 12, System`TradingChartDump`$textstyle$545716, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545716, 
                   System`TradingChartDump`$lows$545716]], 12, 
                 System`TradingChartDump`$textstyle$545716, FontFamily -> 
                 "Times"], 
                Style[
                "C: ", 12, System`TradingChartDump`$textstyle$545716, 
                 FontFamily -> "Times", LineBreakWithin -> False], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545716, 
                   System`TradingChartDump`$closes$545716]], 12, 
                 System`TradingChartDump`$textstyle$545716, FontFamily -> 
                 "Times"], 
                Style[
                 Dynamic[
                  ReplaceAll[
                  System`TradingChartDump`$indicatorpos$545716, 
                   System`TradingChartDump`$visdates$545716]], 12, 
                 System`TradingChartDump`$textstyle$545716, FontFamily -> 
                 "Times", LineBreakWithin -> False]}}, ItemSize -> Automatic, 
              Spacings -> {{0, 0, 1, 0, 1, 0, 1, 0, 1, 0}, 0}, Frame -> 
              False]; {}, StandardForm, Graphics],
          
          ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}},
          TrackedSymbols:>{}], 
         DynamicBox[Typeset`ToBoxes[
           Inset[
            Deploy[
             Graphics[{
               Dynamic[
                If[
                 And[
                 System`TradingChartDump`$timestampQ$545716, 
                  System`TradingChartDump`$mouseQ$545716], {{
                  System`TradingChartDump`$timestampstyle$545716, 
                   
                   Rectangle[{
                    System`TradingChartDump`$indicatorpos$545716 - 0.5, 
                    System`TradingChartDump`$plotrangemin$545716}, 
                    If[
                    System`TradingChartDump`$timestampdepth$545716 === "Full", 
                    Scaled[{0, 
                    System`TradingChartDump`$isy$545716[1]}, {
                    System`TradingChartDump`$indicatorpos$545716 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545716}], 
                    Offset[{0, 
                    Part[
                    System`TradingChartDump`$timestampdepth$545716, 1]}, {
                    System`TradingChartDump`$indicatorpos$545716 + 0.5, 
                    System`TradingChartDump`$plotrangemin$545716}]]]}}, {}]], 
               System`TradingChartDump`$candlestickchart$545716, {
               System`TradingChartDump`$highlightstyle$545716, 
                Dynamic[System`TradingChartDump`$ohlcpoint$545716]}, 
               Table[
                
                With[{System`TradingChartDump`i$ = 
                  System`TradingChartDump`l}, {
                  System`TradingChartDump`$layoutData$545716[
                  "OverlayIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545716, 
                   Dynamic[
                    System`TradingChartDump`$overlaypoint$545716[
                    System`TradingChartDump`i$]]}}], {
                System`TradingChartDump`l, 
                 Length[
                  System`TradingChartDump`$layoutData$545716[
                  "OverlayIndicatorNames"]]}], 
               Dynamic[
                If[
                 And[System`TradingChartDump`$mouseQ$545716, Length[
                    System`TradingChartDump`$layoutData$545716[
                    "OverlayIndicatorNames"]] =!= 0], 
                 System`TradingChartDump`$overlaylegends, {}], 
                TrackedSymbols :> {System`TradingChartDump`$mouseQ$545716}]}, 
              PlotLabel -> None, 
              PlotRange -> {{
                Floor[System`TradingChartDump`$controlmin$545716] + 0.5, 
                 Floor[System`TradingChartDump`$controlmax$545716] + 0.5}, {
                System`TradingChartDump`$plotrangemin$545716, 
                 System`TradingChartDump`$plotrangemax$545716}}, AspectRatio -> 
              Full, Frame -> {
                Switch[
                System`TradingChartDump`$axesorigin$545716, Left, {
                 False, System`TradingChartDump`$frame$545716}, 
                 Blank[], {System`TradingChartDump`$frame$545716, False}], {
                False, System`TradingChartDump`$frame$545716}}, Axes -> False,
               FrameTicks -> None, GridLines -> 
              System`TradingChartDump`$newgridlines$545716, 
              ImagePadding -> {{1, 1}, {5, 5}}, PlotRangeClipping -> True, 
              PlotRangePadding -> None, 
              System`TradingChartDump`$opts$545716]], {0.5, 0}, {
            Left, Bottom}, {
            100, System`TradingChartDump`$aspectratio$545716 100}], 
           StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           387.02286107677577`}, {-286.92264150943396`, -65.76792452830186}}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             Graphics[{
               GrayLevel[0.4], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545716 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545716, 1]], 
               Part[System`TradingChartDump`$framestyle$545716, 1], 
               If[
                Not[
                 TrueQ[
                  Last[System`TradingChartDump`$axes$545716]]], {}, 
                
                Charting`ScaleAxis[{
                 "Line", {{0, System`TradingChartDump`$plotrangemin$545716} -> 
                   System`TradingChartDump`$isy$545716[
                    System`TradingChartDump`$plotrangemin$545716], {
                    0, System`TradingChartDump`$plotrangemax$545716} -> 
                   System`TradingChartDump`$isy$545716[
                    System`TradingChartDump`$plotrangemax$545716]}}, 
                 FindDivisions[{
                   System`TradingChartDump`$isy$545716[
                   System`TradingChartDump`$plotrangemin$545716], 
                   System`TradingChartDump`$isy$545716[
                   System`TradingChartDump`$plotrangemax$545716]}, {6}], 
                 ScalingFunctions -> {
                  System`TradingChartDump`$sy$545716, 
                   System`TradingChartDump`$isy$545716}, Charting`LabelSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545716, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545716 > 
                    System`TradingChartDump`$plotrangemin$545716, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545716 > 
                    System`TradingChartDump`$plotrangemin$545716, Right, 
                    Left]], Charting`TickSide -> 
                 Switch[System`TradingChartDump`$axesorigin$545716, Left, 
                   If[
                   System`TradingChartDump`$plotrangemax$545716 > 
                    System`TradingChartDump`$plotrangemin$545716, Left, 
                    Right], 
                   Blank[], 
                   If[
                   System`TradingChartDump`$plotrangemax$545716 > 
                    System`TradingChartDump`$plotrangemin$545716, Right, 
                    Left]], LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545716, 2], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545716, 2], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545716 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545716,
                     2], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545716], 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545716 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545716, 2], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545716]]]}, 
              AspectRatio -> Full, ImagePadding -> {{1, 1}, {5, 5}}, 
              PlotRangePadding -> None, PlotRangeClipping -> False, Frame -> 
              False, Axes -> False, PlotLabel -> None], TraditionalForm],
            ImageSizeCache->{180., {0., 221.}}], 
           Offset[{-1, 0}, {100.5, 0}], {Center, Bottom}, 
           NCache[{Automatic, 100/GoldenRatio}, {
            Automatic, 61.803398874989476`}]],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         DynamicBox[Typeset`ToBoxes[
           Table[
            With[{System`TradingChartDump`i$ = System`TradingChartDump`i}, {
              Inset[
               Deploy[
                Graphics[{{System`TradingChartDump`$timestampstyle$545716, 
                   Dynamic[
                    System`TradingChartDump`$subplotrect$545716[
                    System`TradingChartDump`i$]]}, 
                  System`TradingChartDump`$layoutData$545716[
                  "SubplotIndicator", {System`TradingChartDump`i$}], {
                  System`TradingChartDump`$highlightstyle$545716, 
                   Dynamic[
                    System`TradingChartDump`$subplotpoint$545716[
                    System`TradingChartDump`i$]]}, 
                  Inset[
                   Dynamic[
                    If[System`TradingChartDump`$mouseQ$545716, 
                    Row[
                    Prepend[
                    Riffle[
                    Table[
                    Row[{
                    Style[
                    Part[
                    System`TradingChartDump`$layoutData$545716[
                    "SubplotIndicatorLegends", {System`TradingChartDump`i$}], 
                    System`TradingChartDump`k], 
                    System`TradingChartDump`$textstyle$545716, FontFamily -> 
                    "Times"], 
                    If[Length[
                    System`TradingChartDump`$layoutData$545716[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}]] >= 
                    System`TradingChartDump`k, 
                    If[Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545716[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]] =!= 0, 
                    Style[
                    Row[{"(", 
                    Apply[Sequence, 
                    Riffle[
                    Table[
                    Part[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545716[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], System`TradingChartDump`k]],
                     System`TradingChartDump`m], {System`TradingChartDump`m, 
                    Length[
                    Flatten[
                    Part[
                    System`TradingChartDump`$layoutData$545716[
                    "SubplotIndicatorParameters", {
                    System`TradingChartDump`i$}], 
                    System`TradingChartDump`k]]]}], ", "]], ")", ":"}], 
                    System`TradingChartDump`$textstyle$545716], 
                    Style[":", System`TradingChartDump`$textstyle$545716]], 
                    Style[":", System`TradingChartDump`$textstyle$545716]], 
                    
                    With[{System`TradingChartDump`k$ = 
                    System`TradingChartDump`k}, 
                    Dynamic[
                    Style[
                    System`TradingChartDump`$subplotvalue$545716[
                    System`TradingChartDump`i$, System`TradingChartDump`k$], 
                    System`TradingChartDump`$textstyle$545716]]]}], {
                    System`TradingChartDump`k, 
                    Length[
                    System`TradingChartDump`$layoutData$545716[
                    "SubplotIndicatorLegends", {
                    System`TradingChartDump`i$}]]}], " "], "  "]], ""], 
                    TrackedSymbols :> {
                    System`TradingChartDump`$mouseQ$545716}], 
                   Scaled[{0, 0.95}], {-1, 1}]}, AspectRatio -> Full, 
                 PlotRangeClipping -> True, GridLines -> {
                   Part[System`TradingChartDump`$newgridlines$545716, 1], 
                   If[
                   System`TradingChartDump`$subpricegridlines$545716 === 
                    Automatic, 
                    System`TradingChartDump`$subplotgridlines$545716[
                    System`TradingChartDump`i$], 
                    Part[System`TradingChartDump`$newgridlines$545716, 2]]}, 
                 Frame -> {
                   Switch[
                   System`TradingChartDump`$axesorigin$545716, Left, {
                    False, System`TradingChartDump`$frame$545716}, 
                    Blank[], {
                    System`TradingChartDump`$frame$545716, False}], {
                   System`TradingChartDump`$frame$545716, 
                    System`TradingChartDump`$frame$545716}}, 
                 ImagePadding -> {{1, 1}, {5, 2}}, FrameTicks -> None, Axes -> 
                 False, PlotLabel -> None, PlotRangePadding -> None, 
                 PlotRange -> {
                  Map[Floor, {
                    System`TradingChartDump`$controlmin$545716, 
                    System`TradingChartDump`$controlmax$545716}] + 0.5, {
                   System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]], 
                    System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]]}}, 
                 System`TradingChartDump`$opts$545716]], 
               
               Offset[{0, -10}, {
                0.5, (((-System`TradingChartDump`$aspectratio$545716) 100)/
                  4) (System`TradingChartDump`i$ - 1)}], {Left, Top}, {
               100, System`TradingChartDump`$aspectratio$545716 (100/4)}], 
              Deploy[
               Inset[
                Graphics[
                 Dynamic[{
                   GrayLevel[0.4], 
                   AbsoluteThickness[0.1], 
                   If[
                   System`TradingChartDump`$defaultframestyle$545716 =!= 
                    "GraphicsFrame", 
                    Part[
                    System`TradingChartDump`$defaultframestyle$545716, 1]], 
                   Part[System`TradingChartDump`$framestyle$545716, 1], 
                   If[
                    Not[
                    TrueQ[
                    Last[System`TradingChartDump`$axes$545716]]], {}, 
                    
                    Charting`ScaleAxis[{
                    "Line", {{0, 0} -> 
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$] - 0.15 
                    Abs[System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]], {0, 1} -> 
                    System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] + 
                    0.5 Abs[
                    System`TradingChartDump`$max$545716[
                    System`TradingChartDump`i$] - 
                    System`TradingChartDump`$min$545716[
                    System`TradingChartDump`i$]]}}, {
                    System`TradingChartDump`$subplotgridlines$545716[
                    System`TradingChartDump`i$]}, Charting`LabelSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545716, Left, 
                    Left, 
                    Blank[], Right], Charting`TickSide -> 
                    Switch[System`TradingChartDump`$axesorigin$545716, Left, 
                    Left, 
                    Blank[], Right], LabelStyle -> 
                    Part[System`TradingChartDump`$tickstextstyle$545716, 2], 
                    TicksStyle -> 
                    Part[System`TradingChartDump`$frameticksstyle$545716, 2], 
                    Antialiasing -> False, 
                    If[
                    System`TradingChartDump`$defaultframeticksstyle$545716 =!= 
                    "GraphicsFrameTicks", DefaultTicksStyle -> 
                    Part[System`TradingChartDump`$defaultframeticksstyle$\
545716, 2], DefaultTicksStyle -> 
                    System`TradingChartDump`$defaultframeticksstyle$545716], 
                    If[
                    System`TradingChartDump`$defaultlabelstyle$545716 =!= 
                    "GraphicsLabel", DefaultLabelStyle -> 
                    Part[System`TradingChartDump`$defaultlabelstyle$545716, 
                    2], DefaultLabelStyle -> 
                    System`TradingChartDump`$defaultlabelstyle$545716]]]}, 
                  TrackedSymbols :> {}], AspectRatio -> Full, 
                 ImagePadding -> {{1, 1}, {5, 2}}, PlotRangePadding -> None, 
                 PlotRangeClipping -> False, Frame -> False, Axes -> False, 
                 PlotLabel -> None], 
                Offset[{-1, -10}, {
                  Switch[
                  System`TradingChartDump`$axesorigin$545716, Left, 0.5, 
                   Alternatives[Right, Automatic, 
                    Blank[]], 
                   100.5], (((-System`TradingChartDump`$aspectratio$545716) 
                    100)/4) (System`TradingChartDump`i$ - 1)}], {
                Center, Top}, {
                Automatic, 
                 System`TradingChartDump`$aspectratio$545716 (100/4)}]]}], {
            System`TradingChartDump`i, 
             Length[
              System`TradingChartDump`$layoutData$545716[
              "SubplotIndicatorNames"]]}], StandardForm, Graphics],
          
          ImageSizeCache->{{29.187012228940432`, 
           475.9407855006933}, {-55.989622641509435`, -0.7009433962264069}},
          TrackedSymbols:>{}], 
         TagBox[InsetBox[
           DynamicBox[ToBoxes[
             If[System`TradingChartDump`$mouseQ$545716, 
              Dynamic[System`TradingChartDump`$ohlclabel$545716], 
              Text[
               Spacer[{1, 11}]]], TraditionalForm],
            ImageSizeCache->{1., {2., 11.}},
            TrackedSymbols:>{System`TradingChartDump`$mouseQ$545716}], NCache[
           Offset[{0, 2}, {0.5, 100/GoldenRatio}], 
            Offset[{0, 2}, {0.5, 61.803398874989476`}]], {Left, Bottom}],
          Deploy,
          DefaultBaseStyle->"Deploy"], 
         TagBox[InsetBox[
           GraphicsBox[
            DynamicBox[Typeset`ToBoxes[{
               GrayLevel[0.1], 
               AbsoluteThickness[0.5], 
               If[
               System`TradingChartDump`$defaultframestyle$545716 =!= 
                "GraphicsFrame", 
                Part[System`TradingChartDump`$defaultframestyle$545716, 2]], 
               Part[System`TradingChartDump`$framestyle$545716, 2], 
               If[
                Not[
                 TrueQ[
                  First[System`TradingChartDump`$axes$545716]]], {}, 
                Charting`DateAxis[
                 Take[
                 System`TradingChartDump`$dates$545716, {1, 0} + 
                  Map[IntegerPart, {
                    System`TradingChartDump`$controlmin$545716, 
                    System`TradingChartDump`$controlmax$545716}]], {{{
                   IntegerPart[System`TradingChartDump`$controlmin$545716] + 
                    0.5, System`TradingChartDump`$plotrangemin$545716}, {
                   1.5 + IntegerPart[
                    System`TradingChartDump`$controlmin$545716], 
                    System`TradingChartDump`$plotrangemin$545716}}, {0, 1}}, 
                 Charting`DateScope -> 
                 System`TradingChartDump`$datescope$545716, 
                 Charting`LabelSide -> Right, LabelStyle -> 
                 Part[System`TradingChartDump`$tickstextstyle$545716, 1], 
                 TicksStyle -> 
                 Part[System`TradingChartDump`$frameticksstyle$545716, 1], 
                 Antialiasing -> False, 
                 If[
                 System`TradingChartDump`$defaultlabelstyle$545716 =!= 
                  "GraphicsLabel", DefaultLabelStyle -> 
                  Part[System`TradingChartDump`$defaultlabelstyle$545716, 1], 
                  DefaultLabelStyle -> 
                  System`TradingChartDump`$defaultlabelstyle$545716], 
                 If[
                 System`TradingChartDump`$defaultframeticksstyle$545716 =!= 
                  "GraphicsFrameTicks", DefaultTicksStyle -> 
                  Part[System`TradingChartDump`$defaultframeticksstyle$545716,
                     1], DefaultTicksStyle -> 
                  System`TradingChartDump`$defaultframeticksstyle$545716]]]}, 
              StandardForm, Graphics],
             
             ImageSizeCache->{{-0.41421356237310647`, 
              358.4142135623731}, {-37.414213562373114`, -20.80220155284337}},
             TrackedSymbols:>{}],
            AspectRatio->Full,
            Axes->False,
            Frame->False,
            ImagePadding->{{1, 1}, {0, 0}},
            PlotLabel->None,
            PlotRangeClipping->False,
            PlotRangePadding->None], Offset[{0, 5}, {0.5, 0}], {
           Left, Center}, {100, 20}],
          Deploy,
          DefaultBaseStyle->"Deploy"]},
        DynamicModuleValues:>{{
          DownValues[System`TradingChartDump`$subplotrect$545716] = {
            HoldPattern[
               System`TradingChartDump`$subplotrect$545716[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$subplotpoint$545716] = {
            HoldPattern[
               System`TradingChartDump`$subplotpoint$545716[1]] :> {}}}, {
          DownValues[System`TradingChartDump`$min$545716] = {HoldPattern[
               System`TradingChartDump`$min$545716[1]] :> -100.}}, {
          DownValues[System`TradingChartDump`$max$545716] = {HoldPattern[
               System`TradingChartDump`$max$545716[1]] :> 0.}}, {
          DownValues[System`TradingChartDump`$subplotvalue$545716] = {
            HoldPattern[
               System`TradingChartDump`$subplotvalue$545716[1, 1]] :> 
             Invisible[-93.16]}}, {
          DownValues[System`TradingChartDump`$subplotgridlines$545716] = {
            HoldPattern[
               System`TradingChartDump`$subplotgridlines$545716[
               1]] :> {-100, -50}}}, {
          DownValues[System`TradingChartDump`$layoutData$545716] = {
            HoldPattern[
               System`TradingChartDump`$layoutData$545716["Adjust"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "AllValues"]] :> CompressedData["
1:eJxVVgk8VVv7Fo1Cg6GuSlKZKhS5nb323uc5XE1mGZtHXEMpypdyQyFSEn2K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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545716["AppendedAdjust"]] :> 
             9.99999999999997, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "AppendedBox"]] :> {-114.99999999999964`, 0.}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "AppendedMin"]] :> -104.99999999999967`, HoldPattern[
               System`TradingChartDump`$layoutData$545716["AppendedRatio"]] :> 
             1., HoldPattern[
               System`TradingChartDump`$layoutData$545716["AppendedShift"]] :> 
             0, HoldPattern[
               System`TradingChartDump`$layoutData$545716["ChartStyle"]] :> 1,
              HoldPattern[
               System`TradingChartDump`$layoutData$545716["Counter"]] :> 0, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545716["DataMax"]] :> 
             36.43, HoldPattern[
               System`TradingChartDump`$layoutData$545716["DataMin"]] :> 
             25.86614923134608, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "GridLinesPosition"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "MainChartAllValues"]] :> CompressedData["
1:eJxdlglYzdv6x1OZ0mBocEISmtBAOvZv2t9dJ1NzGs1jdRqIoiuiolJSGtwo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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "MainChartPoints"]] :> CompressedData["
1:eJxdlltoXFUUhqdFUIKgYkSRUqdVSqylVGNtmzbJTmqaNEmTTO6XSXLmfp9U
pCiRyqFShCIEn0QRGS/4IhTBlyAqscUnKyIoVRCZIoiQIgWplD6Zk/V/D+cc
CMOftf/9r9tee+9Jr4zn7onFYne3/nbob2eM71b3D9e2vuETTv9wN1ZbL/ff
AN/nrt5uS65dAT/o3ns3+MCtruX6x2c7L4EfcwF7dRK8yz1xcTOx/gc47tau
bG34QKfwXrMvgZ9yAb21Dt4nPXCbC5bvvgje7zoDB86DD0T4B+3XBx9y41vs
zYe6hJ+19QfBz7mBIAH3gttdEF7Lo+DnLb6f2e+wxbMGfsH8/Q18xL0WEO6C
j7qbgfub4GPupSCAW+AOy8cH4OMuGQjsQv+Erf8ce2cEd4nP+m7T7wA7q+dO
Yd9ZPK3Ye8L58XtcABNHsfcq39gjOHbS/Re0yznsJ9UP2F+0/daxC7+KvS+i
3xeJ75TWC/unpIe9X3zs/VafH+m/AePfEfYHrB7PwD8tf+Gfdk9vFwD7oPoB
+2DkPAyZ3ij7D1k/9WMfVv9iH1Y/YT8T9tc/Y/p/Yx+x+H7CPqL+Oi77qPkz
J+yPuvz2h33Mfp2wG1N/sH5M/Sy8MaZ5AD9h8V+XvktE/Emon4U3EpH8jls8
Rfjj7pNguyfhy94Gf9z2fxv9CTuvlzvEF64L+xPW373CGxN2HnYLxyZVX/iT
qhf8Sc0z+JOqH/pTyjf8KYvvM/hTrj34/oU/Fd4vNq3zBH9a8wa+7HeOiT9t
/dIHfybi/4zmKfwZ2+9N9GfUP/Bn1W/wZ83fL+DPql/gz+r8wZ9TveifOVv/
F/w55Z/+mbP4W8jfvK3/FP15038Z/rzbvo/eQl/r96G/EK6XWzB+O/27oP6E
LzwDP2n+DMJPhvf3k6Y/DD8Zzm9s0epdgb9o/bAKf9H41+Av2vn5EP5S2D8X
wf6SzdOv4S9Z/g+Rv2Wbd4fJv/A54l/WPCb/y7b/O/A9nRfhuBeuj/OsfheE
PU/9yf6e7gvhhvb7B3893ffCTc/i34N+yuI5i34q7L9L2X33Pvop3Wfop8Lx
NFK6b4k3pfkg3Eypnuinw/Mkntb9j34Ee+mIfjrsXyOt9xH6aZ1/9NPqL+Z3
xs7Pn+hnNC/Rz2j+o58Jx+NndH+in7H++xL9yH7NjPqL+LM6r+hnw/eHy2pe
yl8vq/mBftbyeb/sjazV7zb6EdzMav4Tfy48/+MR7HLh+9TLWb6T3A85zSf0
c/o/90XO8psRbrKe+ycffl/E8zpv6OfVX+jLfh79vM3j79DP63yjH+E385H3
YSH8PosX5K+wK+i+6JZ+QfUW9gvqX+FGQfPBSb9geivCTel1CceK5t8rwvGi
/Bd2wt8Ke0X5I+zLnhJuaL8j6Bf1nkC/qPyjX7J4r6Jfsn66iX5J86hH+iXF
I+zLfkm4IX5VeKNk52VEuFmy8/iwcKxs53WvcFz4grAraz6hXzZ/30C/rPsK
/bL19/foly3fr6Mvfgb9iu4L9Ct2Xn5Bv2L9/hX6Fd036Ff0i77WJ9Gv6D5E
P7I+VlU/o1+1/YfQr5r/31D/quXnI+pfNb3fqX9V/lP/qtXjAPpV3dfo1/Se
Qb+meYt+Te8f9GvWbzuIv2b5e5z4a9YP+4m/FtGv6T2Mft32/xX9eiT/wo/0
Sr+ufhH267rf0Nd+6+jX1e86n826/Kf/V/Relj2+onkp7FbUL93ufxyzRGk=

              "], HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "NewOverlay"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545716["NewSubplot"]] :> {
               FinancialIndicator["WilliamsPercentR", 10]}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "OverlayIndicator"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "OverlayIndicatorCount"]] :> 0, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "OverlayIndicatorLegends"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "OverlayIndicatorNames"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "OverlayIndicatorParameters"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "OverlayIndicatorPoints"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "OverlayIndicatorValues"]] :> {}, HoldPattern[
               System`TradingChartDump`$layoutData$545716["OverPara"]] :> {}, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "PlotRangeMin"]] :> -104.99999999999967`, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "ScalingFunctions"]] :> {Identity, Identity}, HoldPattern[
               System`TradingChartDump`$layoutData$545716["Space"]] :> 
             3.6430000000000002`, HoldPattern[
               System`TradingChartDump`$layoutData$545716["Style"]] :> 1, 
             HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "SubplotIndicator"]] :> {{{{{}, {Antialiasing -> False, 
                   GrayLevel[0.5], {
                    Line[{{0, -80}, {250., -80}}], 
                    Line[{{0, -50}, {250., -50}}], 
                    Line[{{0, -20}, {250., -20}}]}}, {{
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Line[CompressedData["
1:eJxdV3dU1EcXXU0wGkGUrC1BXBArIKBopF8XYZFelw4Lu8ACyyIEe9DfZzmK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                    "]]}}}}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "SubplotIndicatorGridLines"]] :> {{-100, -50, 0}}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "SubplotIndicatorLegends"]] :> {{
                Deploy[
                 Row[{
                   Style["\[FilledSquare]", 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], " ", 
                   "WilliamsR"}]]}}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "SubplotIndicatorNames"]] :> {
               FinancialIndicator["WilliamsPercentR", 10]}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "SubplotIndicatorParameters"]] :> {{{10}}}, HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "SubplotIndicatorPoints"]] :> CompressedData["
1:eJxdl1lsVGUUxwe3mIqKpiguwGW1LCL7XvhYulDa0n1f7kxn63SmlfCiEJMb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              "], HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "SubplotIndicatorValues"]] :> CompressedData["
1:eJw9VVtIU3EYn0k9mN1kahe8LFOnM8103jedzs2tOd3ZdnYKCSoyH4QUX0rp
JRLJAu2pCxSV3aCQoh7MKP8pFYRBPoQ+9JBFIdnloUyRknb2++0cGN/+5/9d
f7/v+47h4FHpcKxOp4sJ/5Ypv/lGUnufBMTEgrFlYDxbFEWeKtGjH3bOLjeI
wfHwxYZGETc91GEZlUROWGvhThH0a/PwPm6rsKp/nm4Xs92qoQF+HppwPlAg
0nrnfSP7i8SNsPZ0Rr6QwmHnfRmI0x0v3kyqT4FQ3Rtb8oVOfWrqRaJ6fcoH
vQq7aFAd9lXB/oEN/iZs4tLF8JMjiceq25ECxM9o1uQftbyFuTH1NnU17Q65
UU+bE/fvnNDvsjGfbE12WtQC81Hnv2rYGdeII63hx2ETapr69T6cWxURKeOn
DL+JQQGcFeKroK6ADLsVP/TTJOB6UiIOfsSzhGDfQ78DIeSTLgGXfS7Gd4OP
fgf8P3KJCD19MnB7JYsI7EoQZ2cIuJ0O8eyHH6+XcTOB81QuzynwN20Cfp8c
yGOwETwbGuFnMQB8FBl6fgW4vFSg9zwaT6adzLr8yG/Jyb7xsF8a2D9V5NuD
vDYFcO5SUMdxBfnsklBHPvlwBPneDv0hE+NUQs7Ugud4L+orrRORPunVs34r
+lG3Eby8L2EfNMHvW87P9Wbq7UW+z8jPcrrWr5F4RglyM+sdCULOUT9O5tw1
IZ9FD/GzETcH+3e3JjF3FcDhYgzqOVsGuy+FyPO+mf1XAHx+WNFXZxgnVIa+
+d2EPF77OMfkMZZ5Kl7491g5F+RlKI1yG/PMQx0DcYgzX4a+mHMD35t1wLM9
qEnwakc+5+3I/1Y57ZNR35adjM85vVcDPlIcrHsPePjg4p7yksc66nlQ32gD
+SqFf1MxcLzm0PYM6qlD3Rei/olnR7ImMa9Jmn4kzmUb8NSXox9Sa7k3jNx7
f8fQl02cOx/id0b3gBf6M83aPebOQr+5yPuumX2UwLqKsXfMZbAbTmTcyTHs
awPxnEL8ju9juE8A378KiTvnot0F/8c87Bs36rli0PYg+mot8dTp4Pcz/eeC
7xfFuL/KOVgib5YdtDezX03cY5XEaRX3gZ371A0+C+u5b5PJWwn8tkVx8vC9
n7zJiHfChXwy6afTr+2lCO4fZe7PqD2/f/3ViJdl5veI85VVzT3g4HfLzj6r
QZz6Sth/tSPeuWLWu45zkkAcVohXksYf9p4N0hoiHwHoN3KP3w7Avzsk/gNE
XMhI
              "], HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "SubplotState"]] :> {True}, HoldPattern[
               System`TradingChartDump`$layoutData$545716["XPosition"]] :> {1,
               2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
               20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35,
               36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
               52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
               68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
               84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99,
               100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
              112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
               125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 
              137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
               150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 
              162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174,
               175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
              187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
               200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 
              212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
               225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 
              237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249,
               250}, HoldPattern[
               System`TradingChartDump`$layoutData$545716["YRange"]] :> 36.43,
              HoldPattern[
               System`TradingChartDump`$layoutData$545716[
               "SubplotPoints", {1}]] :> CompressedData["
1:eJw9VVtIU3EYn0Y9mN3ESxe8LFOnM8103jedzs2tubmz7ewUElRkPggpvpTS
SySSBdpTGRSV3aCQoh7MKP8pFYRBPoQ+9JBFIdnloSyRknb2++0cGN/+5/9d
f7/v+47+4FHpcKxOp1sO/2LCv6++0bTexwExuWhoGZjIEcWRp1r0JI445pYb
xeBE+GJDk4ibGe4wj0kiN6y1eLsY+nX5eB+3VVjUP0+2i7lu1VAPPw+MOB8o
FOm9C77R/cXielh7JrNASOGwC75MxOmOF6+n1KdQqO4NLQVCpz61DSJJvT7l
g16lTTSqDvuqYX/fCn+TVnFxKPzkSuKR6na0EPEzmzX5Wy1vcX5cvU1bTbtD
LtTT5sD9Wwf0u6zMJ0eTnWa1wALU+a8GdoY14khr+LFbhZpm4nofzq2KiJTx
Q4bfpKAAzgrxVVBXQIbdih/66RJwPSkRBz/imUOw76HfgRDyyZCAyz4n47vA
R78d/h86RYSePhm4vZRFBHYliLMjBNxOh3j2w4/Hw7hZwHk6j+dU+JsxAr+P
duQx2ASe9U3w8ycAfBQZen4FuLxQoPcsGk+mncy6/MhvycG+cbNfGtk/1eTb
jbw2BXDuUlDHcQX57JJQRwH5sAf53gb9YSPjVEHO1oHneA/qK6sXkT7pTWT9
FvSjbiN4eVfKPvDC7xvOz7Vm6u1Fvk/Jz3KG1q+ReAYJcjPrHQ1CzlM/Tubc
eZHPHzfxsxI3O/t3tyYxd5XAYSgG9Zwth93nIuR5z8T+KwQ+3y3oqzOMEypH
3/zyIo9XPs4xeVzFPBUP/LstnAvyMpxOuY155qOOgTjEWShHX8y7gO+NeuDZ
HtQkeLUhn/M25H+zgvYpqG/LTsbnnN6tBR+pdta9Bzy8d3JPechjPfXcqG+s
kXyVwb+xBDhetWt7BvXUo+4LUf/EsyNFk5jXZE0/EueSFXgmVqAf0uq4Nwzc
e3/H0Zdezp0P8Tuje8AD/dlm7R5zZ6bfPOR9x8Q+SmBdJdg7pnLYjSQx7tQ4
9rWeeE4jfse3cdwngO+fRcSdc9HuhP9jbvaNC/Vc1mt7EH21lnjqdPD7if7z
wPfzEtxf4RwskTfzDtqb2K9G7rEq4hTLfWDjPnWBz6IG7tsU8lYKv21RnNx8
7ydvMuKdcCKfLPrp9Gt7KYL7B5n7M2rP719/DeJlm/g94nxl13AP2PndsrHP
ahGnoQr2X2yId66E9a7jnCQQhxXilazxh71nhbSEyEcA+k3c47cC8O8Kif8t
8MhG
              "], HoldPattern[
               System`TradingChartDump`$layoutData$545716[
                Pattern[Charting`s$, 
                 Blank[]], {
                 Pattern[System`InteractiveTradingChartDump`p$, 
                  Blank[]]}]] :> Part[
               System`TradingChartDump`$layoutData$545716[Charting`s$], 
               System`InteractiveTradingChartDump`p$], HoldPattern[
               System`TradingChartDump`$layoutData$545716[
                Pattern[Charting`s$, 
                 Blank[]], {
                  Pattern[System`InteractiveTradingChartDump`p$, 
                   Blank[]]} -> 
                Pattern[System`InteractiveTradingChartDump`val$, 
                  Blank[]]]] :> (
              System`TradingChartDump`$layoutData$545716[Charting`s$] = 
              ReplacePart[
                System`TradingChartDump`$layoutData$545716[Charting`s$], 
                System`InteractiveTradingChartDump`p$ -> 
                System`InteractiveTradingChartDump`val$])}}},
        Initialization:>{
         System`TradingChartDump`$indicatorpos$545716 = 
           System`TradingChartDump`$length$545716; 
          System`TradingChartDump`$layoutData$545716["ChartStyle"] = 
           System`TradingChartDump`$markerstyle$545716; 
          System`TradingChartDump`$modelData$545716["Data"] = 
           System`TradingChartDump`$data$545716; 
          System`TradingChartDump`$modelData$545716["Indicators"] = 
           System`TradingChartDump`$indicators$545716; 
          System`TradingChartDump`$layoutData$545716[
            "SubplotIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "OverlayIndicatorNames"] = {}; 
          System`TradingChartDump`$layoutData$545716["ScalingFunctions"] = {
            System`TradingChartDump`$sy$545716, 
             System`TradingChartDump`$isy$545716}; 
          System`TradingChartDump`$layoutData$545716["SubplotIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "SubplotIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "SubplotIndicatorGridLines"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "SubplotIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "SubplotIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "SubplotIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545716["OverlayIndicator"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "OverlayIndicatorPoints"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "OverlayIndicatorLegends"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "OverlayIndicatorValues"] = {}; 
          System`TradingChartDump`$layoutData$545716[
            "OverlayIndicatorParameters"] = {}; 
          System`TradingChartDump`$layoutData$545716["OverPara"] = {}; 
          System`TradingChartDump`$layoutData$545716["OverlayIndicatorCount"] = 
           0; Charting`FinancialIndicatorList[
           System`TradingChartDump`$modelData$545716, 
            System`TradingChartDump`$layoutData$545716, 
            System`TradingChartDump`$indicators$545716]; 
          Charting`TradingChartIndicator[
           System`TradingChartDump`$modelData$545716, 
            System`TradingChartDump`$layoutData$545716, "Candlestick"]; 
          ReplaceAll[
            If[
            System`TradingChartDump`$layoutData$545716[
              "OverlayIndicatorNames"] =!= {}, 
             System`TradingChartDump`$layoutData$545716["AllValues"] = 
             ReplaceAll[
               Transpose[
                Join[
                 System`TradingChartDump`$layoutData$545716[
                 "MainChartAllValues"], 
                 System`TradingChartDump`$layoutData$545716[
                 "OverlayIndicatorValues"]]], "" -> {}], 
             System`TradingChartDump`$layoutData$545716["AllValues"] = 
             Transpose[
               System`TradingChartDump`$layoutData$545716[
               "MainChartAllValues"]]], "" -> {}]; 
          System`TradingChartDump`$plotrangemin$545716 = (Min[#] - 
            0.05 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545716["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545716, 
                 System`TradingChartDump`$controlmax$545716}]]]; 
          System`TradingChartDump`$plotrangemax$545716 = (Max[#] + 
            0.1 (Max[#] - Min[#])& )[
             Take[
              System`TradingChartDump`$layoutData$545716["AllValues"], {1, 0} + 
              Map[IntegerPart, {
                System`TradingChartDump`$controlmin$545716, 
                 System`TradingChartDump`$controlmax$545716}]]]; {
            System`TradingChartDump`$plotrangemin$545716, 
             System`TradingChartDump`$plotrangemax$545716} = ReplaceAll[
             
             System`TradingChartDump`$sy$545716[{
              System`TradingChartDump`$plotrangemin$545716, 
               System`TradingChartDump`$plotrangemax$545716}], Alternatives[
               Blank[Complex], Infinity, -Infinity] -> 
             System`TradingChartDump`$sy$545716[
                Min[System`TradingChartDump`$lows$545716]] - 0.1]; 
          If[System`TradingChartDump`$plotrangemin$545716 == 
            System`TradingChartDump`$plotrangemax$545716, {
             System`TradingChartDump`$plotrangemin$545716, 
              System`TradingChartDump`$plotrangemax$545716} = {
             System`TradingChartDump`$plotrangemin$545716 - 0.5 
              Abs[System`TradingChartDump`$plotrangemin$545716], 
              System`TradingChartDump`$plotrangemax$545716 + 
              0.5 Abs[System`TradingChartDump`$plotrangemax$545716]}]; 
          System`TradingChartDump`$newgridlines$545716 = {{}, {}}; 
          If[System`TradingChartDump`$gridlinesflag$545716, 
            Part[System`TradingChartDump`$newgridlines$545716, 1] = Switch[
               Part[System`TradingChartDump`$gridlines$545716, 1], Automatic, {
                First[System`TradingChartDump`$gridlinesscope$545716], {
                "Year", 
                 Directive[
                  Opacity[0.4], 
                  Dashing[{}]]}}, 
               Blank[], 
               Part[System`TradingChartDump`$gridlines$545716, 1]]; 
            Part[System`TradingChartDump`$newgridlines$545716, 1] = If[
               And[
               Part[System`TradingChartDump`$newgridlines$545716, 1] =!= None,
                 System`TradingChartDump`$length$545716 > 0], 
               DeleteCases[
                Charting`gridlinesFinder[
                System`TradingChartDump`$dates$545716, 
                 Part[System`TradingChartDump`$newgridlines$545716, 1]], {}], 
               Part[System`TradingChartDump`$newgridlines$545716, 1]]; 
            System`TradingChartDump`$subpricegridlines$545716 = 
             Part[System`TradingChartDump`$gridlines$545716, 2]; 
            Part[System`TradingChartDump`$newgridlines$545716, 2] = 
             If[System`TradingChartDump`$sy$545716 === Identity, 
               
               With[{System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545716}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545716, 2], 
                 Automatic, 
                 FindDivisions[{System`TradingChartDump`minbox$, #2}, 6]& , 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545716, 2]]], 
               
               With[{System`TradingChartDump`scy$ = 
                 System`TradingChartDump`$sy$545716, 
                 System`TradingChartDump`iscy$ = 
                 System`TradingChartDump`$isy$545716, 
                 System`TradingChartDump`minbox$ = 
                 System`TradingChartDump`$plotrangemin$545716}, 
                Switch[
                 Part[System`TradingChartDump`$gridlines$545716, 2], 
                 Automatic, 
                 Map[System`TradingChartDump`scy$, DeleteCases[
                   FindDivisions[{
                    System`TradingChartDump`iscy$[
                    System`TradingChartDump`minbox$], 
                    Max[
                    System`TradingChartDump`iscy$[#], 
                    System`TradingChartDump`iscy$[#2]]}, 6], 0]& ], 
                 Blank[], 
                 Part[System`TradingChartDump`$gridlines$545716, 2]]]]; Null]; 
          System`TradingChartDump`$ndigits$545716 = Last[
              RealDigits[System`TradingChartDump`$maxohlc$545716]] + 2; Null}],
       AlignmentPoint->Center,
       AspectRatio->Automatic,
       Axes->False,
       AxesLabel->None,
       AxesOrigin->Automatic,
       AxesStyle->{},
       Background->None,
       BaseStyle->{},
       BaselinePosition->Automatic,
       ColorOutput->Automatic,
       ContentSelectable->Automatic,
       CoordinatesToolOptions:>Automatic,
       DisplayFunction:>$DisplayFunction,
       Epilog->{},
       FormatType:>TraditionalForm,
       Frame->False,
       FrameLabel->{None, None},
       FrameStyle->{},
       FrameTicks->Automatic,
       FrameTicksStyle->{},
       GridLines->None,
       GridLinesStyle->Directive[
         Dashing[{0, Small}], 
         AbsoluteThickness[0.1], 
         GrayLevel[0.5]],
       ImageMargins->0.,
       ImagePadding->{{2, 50}, {All, All}},
       ImageSize->{450, 310},
       ImageSizeRaw->Automatic,
       LabelStyle->{},
       Method->Automatic,
       PlotLabel->FormBox[
         TemplateBox[{
          "\"Last \"", "365", "\" days of \"", "\"MSFT\"", "\" with \"", 
           "\"WilliamsPercentR\"", "\"(\"", "10", "\",\"", "", "\",\"", "", 
           "\",\"", "", "\")\""}, "RowDefault"], TraditionalForm],
       PlotRange->{{0.5, 100}, {All, All}},
       PlotRangeClipping->False,
       PlotRangePadding->Automatic,
       PlotRegion->Automatic,
       PreserveImageOptions->Automatic,
       Prolog->{},
       RotateLabel->True,
       Ticks->Automatic,
       TicksStyle->{}], {720., -1171.8}, 
      ImageScaled[{0.5, 0.5}], {450, 310}]}}, {}},
  ContentSelectable->True,
  ImageSize->{972., 1351.2},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.583814151133752*^9}]
}, {2}]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example 7: Backtesting for a list of securities\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}, {3.583805545995566*^9, 
  3.583805546363587*^9}, {3.5838068151691585`*^9, 3.583806822049552*^9}, {
  3.5838069601934533`*^9, 3.583806960626478*^9}, {3.58380760213317*^9, 
  3.583807631092827*^9}, {3.5838116233511705`*^9, 3.583811629062497*^9}, {
  3.5838116638304863`*^9, 3.58381166424651*^9}, {3.583812316825835*^9, 
  3.583812321610109*^9}, {3.583814247426259*^9, 3.583814247922288*^9}, {
  3.583814653316475*^9, 3.583814656595662*^9}}],

Cell["\<\
1)  Added Value: Backtesting methods associated with two financial indicators \
for trading assets, which allow one to investigate the profitability of \
trading based upon recognizing price patterns as revealed by indicators.

2)  Caption: Once a trader has identified a particular financial indicator as \
the one most likely to determine optimal buy/sell points then it is necessary \
to use backtesting of that strategy with prior historical data to see whether \
the strategy will be successful. Here we indicate two backtesting methods \
based upon the financial indicators Linear Regression Slope and Moving \
Average Convergence Divergence.

3)  Why we are better: We are not in fact better at this than many other \
trading programs but it is considered so essential by traders that we need to \
show that this is something we can do, otherwise no trader will buy the \
program. \
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}, {
   3.5841523050128965`*^9, 3.584152336611704*^9}, {3.5841524176203375`*^9, 
   3.584152584884905*^9}, {3.5841526407420993`*^9, 3.584152706260847*^9}, {
   3.5841527365015764`*^9, 3.584153095111088*^9}, {3.584153167688239*^9, 
   3.5841531828071036`*^9}, {3.5841532221193523`*^9, 
   3.5841535705692825`*^9}, {3.584153700921738*^9, 3.584153727577263*^9}, {
   3.5841537587780476`*^9, 3.5841541514035044`*^9}, {3.5841541882036095`*^9, 
   3.5841542615158024`*^9}, {3.5841547896620107`*^9, 3.5841547902060413`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Backtesting for a range of securities\
\>", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9, 
   3.5838068609627776`*^9, {3.583811423989768*^9, 3.5838114473181024`*^9}, {
   3.5838116356548743`*^9, 3.5838116388550577`*^9}, {3.5838123767312613`*^9, 
   3.5838123817065463`*^9}, 3.583814671445512*^9}],

Cell[CellGroupData[{

Cell["\<\
Linear Regression Slope and Moving Average Convergence Divergence Backtesting \
for General Electric\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}, {
   3.583812331977702*^9, 3.5838123364259567`*^9}, 3.583814675412739*^9, {
   3.5838147288857975`*^9, 3.583814742085552*^9}, {3.5838148195889854`*^9, 
   3.5838148260533547`*^9}, {3.583815801913171*^9, 3.5838158031612425`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{"Charting`BackTesting", "[", 
         RowBox[{
          RowBox[{"FinancialData", "[", 
           RowBox[{"\"\<GE\>\"", ",", "\"\<OHLCV\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"2012", ",", "1"}], "}"}], ",", 
              RowBox[{"Date", "[", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "\"\<LRS\>\"", ",", 
          RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", "21"}], ",", " ", 
          RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
          RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
          RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "10000"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{
       "\"\<Linear Regression Slope Backtesting for \>\"", "<>", 
        "\"\<GE\>\""}], ",", "Top"}], "]"}], ",", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{"Charting`BackTesting", "[", 
         RowBox[{
          RowBox[{"FinancialData", "[", 
           RowBox[{"\"\<GE\>\"", ",", "\"\<OHLCV\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"2011", ",", "1"}], "}"}], ",", 
              RowBox[{"Date", "[", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "\"\<MACD\>\"", ",", 
          RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"13", ",", "33", ",", "10"}], "}"}]}], ",", " ", 
          RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
          RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
          RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "10000"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{
       "\"\<Moving Average Convergence Divergence Backtesting for \>\"", 
        "<>", "\"\<GE\>\""}], ",", "Top"}], "]"}]}], "}"}], ",", " ", 
   "\"\<   \>\"", ",", 
   RowBox[{"Alignment", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Center", ",", "Top"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4996270095708523`*^9, 3.4996270290401287`*^9}, {
   3.49962782853901*^9, 3.4996278352799664`*^9}, {3.499627894766952*^9, 
   3.499627907869459*^9}, {3.49962875540844*^9, 3.499628769476714*^9}, {
   3.5354677790942416`*^9, 3.535467806502982*^9}, {3.5354818876640234`*^9, 
   3.535481888512108*^9}, {3.5354819243206887`*^9, 3.5354819848817444`*^9}, {
   3.535482056405896*^9, 3.5354820666619215`*^9}, {3.53548209765602*^9, 
   3.5354821010953646`*^9}, {3.5354822512783813`*^9, 3.535482271950448*^9}, {
   3.535483594918644*^9, 3.535483658123644*^9}, {3.5355539399426875`*^9, 
   3.5355539454452376`*^9}, {3.5355568164010196`*^9, 
   3.5355568222570195`*^9}, {3.5355568528310194`*^9, 3.5355568583990197`*^9}, 
   3.53555717972602*^9, {3.5838148674477224`*^9, 3.583814931511387*^9}, {
   3.583814964695285*^9, 3.5838150212075167`*^9}, {3.583815060519766*^9, 
   3.5838150832160635`*^9}, {3.5838151133687887`*^9, 3.583815144503569*^9}, {
   3.583815344937033*^9, 3.5838153920747294`*^9}, {3.583815588266951*^9, 
   3.5838155945233088`*^9}, {3.5838156973551903`*^9, 
   3.5838157145941763`*^9}, {3.583815774204586*^9, 3.5838157756296673`*^9}, {
   3.5838159183488307`*^9, 3.5838159361088467`*^9}}],

Cell[BoxData[
 TemplateBox[{TemplateBox[{
     TagBox[
      GridBox[{{
         TagBox[
          
          GridBox[{{
            "\"BuyDate\"", "\"BuyPrice\"", "\"SellDate\"", "\"SellPrice\""}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "1", ",", "5"}], "}"}], 
             "17.554415094339625`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "1", ",", "25"}], "}"}], 
             "17.914584422373235`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "1", ",", "26"}], "}"}], 
             "18.32073413738857`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "1", ",", "27"}], "}"}], 
             "18.071466106148186`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "9"}], "}"}], 
             "18.371249346576057`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "10"}], "}"}], 
             "18.064639830508476`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "14"}], "}"}], 
             "18.00049102428722`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "15"}], "}"}], 
             "18.077739872068232`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "17"}], "}"}], 
             "18.2448755186722`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "3", ",", "1"}], "}"}], 
             "18.378791841004183`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "3", ",", "9"}], "}"}], 
             "18.25080882352941`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "3", ",", "30"}], "}"}], "19.26`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "18"}], "}"}], 
             "18.45475916230366`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "24"}], "}"}], 
             "18.414150460593657`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "25"}], "}"}], 
             "18.96700257069409`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "5", ",", "9"}], "}"}], 
             "18.236382866208352`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "5", ",", "24"}], "}"}], 
             "18.374051948051946`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "6", ",", "5"}], "}"}], 
             "17.346491228070175`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "6", ",", "7"}], "}"}], 
             "18.316352631578948`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "5"}], "}"}], 
             "19.67967535661584`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "27"}], "}"}], 
             "19.96928776290631`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "13"}], "}"}], 
             "20.358380181038587`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "7"}], "}"}], 
             "20.628754052802222`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "27"}], "}"}], 
             "21.682287725472943`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "28"}], "}"}], 
             "22.20852047556142`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "10", ",", "2"}], "}"}], 
             "22.3564984642387`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "11", ",", "6"}], "}"}], 
             "20.972000926354795`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "11", ",", "13"}], "}"}], 
             "20.091972920696332`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "11", ",", "19"}], "}"}], 
             "19.90617134559535`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "12", ",", "17"}], "}"}], 
             "21.146019151846783`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "3"}], "}"}], 
             "21.133876777251185`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "4"}], "}"}], 
             "20.86983962264151`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "11"}], "}"}], 
             "20.87855182205395`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "31"}], "}"}], 
             "21.85113105924596`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "1"}], "}"}], 
             "22.073023872679045`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "7"}], "}"}], 
             "22.139679715302492`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "14"}], "}"}], 
             "22.882528833831696`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "19"}], "}"}], "23.04528`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "20"}], "}"}], 
             "23.33525843656557`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "26"}], "}"}], 
             "22.790624728850325`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "28"}], "}"}], 
             "23.188837209302328`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "4"}], "}"}], 
             "22.970928233777396`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "6"}], "}"}], 
             "23.648635403464297`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "7"}], "}"}], 
             "23.509839527027022`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "21"}], "}"}], 
             "23.238995276942894`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "22"}], "}"}], 
             "23.130406504065036`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "9"}], "}"}], 
             "23.068516912402426`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "18"}], "}"}], 
             "22.579285399206`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "5", ",", "1"}], "}"}], 
             "21.920406320541762`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "5", ",", "22"}], "}"}], 
             "23.590637049455157`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "10"}], "}"}], 
             "23.689201009251473`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "11"}], "}"}], 
             "23.300725190839696`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "19"}], "}"}], 
             "24.008256880733942`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "21"}], "}"}], 
             "23.579999999999995`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "24"}], "}"}], "23.12`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "25"}], "}"}], 
             "23.169999999999998`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "7", ",", "10"}], "}"}], 
             "23.719999999999995`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "7", ",", "17"}], "}"}], 
             "23.539999999999996`"}}, AutoDelete -> False, 
           GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{"."}}}, 
           GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"number of trades:\"", "58"}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"cost per trade:\"", "3.5`"}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"total transaction costs:\"", "203.`"}}, AutoDelete -> 
           False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"largest winning trade:\"", "826.7642108121308`"}}, 
           AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"largest losing trade:\"", 
             RowBox[{"-", "563.1032745500107`"}]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"gross profits:\"", "4418.319344318166`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"gross loss:\"", 
             RowBox[{"-", "3214.8924979250946`"}]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"net profits:\"", "1199.926846393073`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"equity plot:\""}, {
             GraphicsBox[{{}, 
               GraphicsComplexBox[CompressedData["
1:eJxF0Vsow2EUAPC1CK2JPHhwb0qS24uE1c6Lhz2wlstcilwic40kNW3Karmt
XVw2zRoibBahva25JEQkD6xsXuQkt2hI8d9Zcurr69f5zjnf15dU1yFuZLNY
rARm+Xcm1LkVCJZG/pUPdwSMn0cY94R9v6RZyOrrKoSDYbXJJyTLbdUIQcWm
VEs1WZRSg2Cff/PKZGTnYz0C56eoQD6663cntxmht9bR2jZAFihbEEAn5t/b
A/Wf7QhX7txgt9ZF87Eb4SFHU5j8SnmBpB9B0lUaGi6mertLgfB0eTjFkez5
bdYPIkwaVrdv+shyhQqhLm6h/2SMzntixhHKDK2V5nPKC6I0CEKzalmqIouU
Ewj5ttmPbOU+9bNOIqxneBeidWTP4jSCNp53u+YgZ50amPes6J2aDLLo2Ijg
2z5oOHqnfh7hDMLPl8NQcka275gQOobY97sbZGfOHFMfr7wz5pETz5YQeNxM
h+wiMC92FUEta5Lkd5GdLitC+ma5pzaELJfaED4VyVZuROC+nHWE0sg7y5aX
+tF/sv6D8n/4BbRf0A4=
                "], {{{}, {
                   Hue[0.67, 0.6, 0.6], 
                   Opacity[0.2], 
                   EdgeForm[None], 
                   GraphicsGroupBox[
                    
                    PolygonBox[{{1, 30, 31, 29, 28, 27, 26, 25, 24, 23, 22, 
                    21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 
                    6, 5, 4, 3, 2}}]]}, {}, {}}, {{}, {}, {
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   
                   LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
                     16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
                    29}]}}}], {}}, AspectRatio -> 
              NCache[GoldenRatio^(-1), 0.6180339887498948], 
              AxesOrigin -> {3.54*^9, 9400.}, Frame -> True, 
              FrameLabel -> {None, None}, 
              FrameTicks -> {{Automatic, Automatic}, {{{3534364800, 
                   FormBox["\"Jan\"", TraditionalForm]}, {3550089600, 
                   FormBox["\"Jul\"", TraditionalForm]}, {3565987200, 
                   FormBox["\"Jan\"", TraditionalForm]}, {3581625600, 
                   FormBox["\"Jul\"", TraditionalForm]}, {3539548800, 
                   FormBox["\"\"", TraditionalForm]}, {3544819200, 
                   FormBox["\"\"", TraditionalForm]}, {3555446400, 
                   FormBox["\"\"", TraditionalForm]}, {3560716800, 
                   FormBox["\"\"", TraditionalForm]}, {3571084800, 
                   FormBox["\"\"", TraditionalForm]}, {3576355200, 
                   FormBox["\"\"", TraditionalForm]}}, {{3534364800, 
                   FormBox["\"\"", TraditionalForm]}, {3550089600, 
                   FormBox["\"\"", TraditionalForm]}, {3565987200, 
                   FormBox["\"\"", TraditionalForm]}, {3581625600, 
                   FormBox["\"\"", TraditionalForm]}, {3539548800, 
                   FormBox["\"\"", TraditionalForm]}, {3544819200, 
                   FormBox["\"\"", TraditionalForm]}, {3555446400, 
                   FormBox["\"\"", TraditionalForm]}, {3560716800, 
                   FormBox["\"\"", TraditionalForm]}, {3571084800, 
                   FormBox["\"\"", TraditionalForm]}, {3576355200, 
                   FormBox["\"\"", TraditionalForm]}}}}, 
              GridLines -> {{{3534364800, 
                  GrayLevel[0.8]}, {3550089600, 
                  GrayLevel[0.8]}, {3565987200, 
                  GrayLevel[0.8]}, {3581625600, 
                  GrayLevel[0.8]}}, None}, ImageSize -> Medium, Method -> {}, 
              PlotRange -> {{3.5364384*^9, 3.583008*^9}, {9400., 
               11688.982213860907`}}, PlotRangeClipping -> True, 
              PlotRangePadding -> {
                Scaled[0.02], 
                Scaled[0.02]}, Ticks -> None]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"current position:\"", 
             TagBox[
              GridBox[{{"\"BuyDate\"", "\"BuyPrice:\""}, {
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "18"}], "}"}], "23.6`"}}, 
               AutoDelete -> False, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{"."}}},
                GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "Grid"]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}}, 
       DefaultBaseStyle -> "Column", 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, 
       GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
     "\"Linear Regression Slope Backtesting for GE\""}, "Labeled", 
    DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {2, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],TemplateBox[{
     TagBox[
      GridBox[{{
         TagBox[
          
          GridBox[{{
            "\"BuyDate\"", "\"BuyPrice\"", "\"SellDate\"", "\"SellPrice\""}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "1", ",", "4"}], "}"}], 
             "16.851907576571737`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "1", ",", "21"}], "}"}], 
             "17.744853090172242`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "1", ",", "24"}], "}"}], 
             "18.318892215568862`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "2", ",", "23"}], "}"}], 
             "18.85784977908689`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "3", ",", "31"}], "}"}], 
             "18.58777057356608`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "4", ",", "15"}], "}"}], 
             "18.55925648702595`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "4", ",", "20"}], "}"}], 
             "18.99105882352941`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "4", ",", "26"}], "}"}], 
             "18.544477611940298`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "4", ",", "28"}], "}"}], 
             "19.143271844660195`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "5", ",", "6"}], "}"}], 
             "18.686596701649176`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "6", ",", "21"}], "}"}], 
             "17.354066985645936`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "7", ",", "19"}], "}"}], 
             "17.17201291711518`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "7", ",", "21"}], "}"}], 
             "17.712025052192068`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "7", ",", "28"}], "}"}], 
             "16.927995582551077`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "8", ",", "29"}], "}"}], 
             "14.736677057356609`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "10", ",", "4"}], "}"}], 
             "13.651413189771198`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "10", ",", "7"}], "}"}], 
             "14.788387096774192`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "11", ",", "3"}], "}"}], 
             "15.558728254349127`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "12", ",", "5"}], "}"}], 
             "15.39883649724434`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "1", ",", "24"}], "}"}], "17.92`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "3", ",", "15"}], "}"}], 
             "19.061795634920635`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "2"}], "}"}], 
             "19.219595404595406`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "27"}], "}"}], 
             "18.893640040444897`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "5", ",", "9"}], "}"}], 
             "18.236382866208352`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "5", ",", "24"}], "}"}], 
             "18.374051948051946`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "6", ",", "4"}], "}"}], 
             "17.698336088154274`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "6", ",", "11"}], "}"}], 
             "18.570329670329674`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "11"}], "}"}], "19.05`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "27"}], "}"}], 
             "19.96928776290631`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "17"}], "}"}], 
             "20.33935238095238`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "10"}], "}"}], "20.79`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "10", ",", "10"}], "}"}], 
             "22.04550601872492`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "11", ",", "26"}], "}"}], 
             "20.364444444444445`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "12", ",", "26"}], "}"}], 
             "20.479364467982666`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "7"}], "}"}], 
             "20.819517274017986`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "10"}], "}"}], 
             "20.702087860179493`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "11"}], "}"}], 
             "20.87855182205395`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "1"}], "}"}], 
             "22.841319534282018`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "7"}], "}"}], 
             "23.509839527027022`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "12"}], "}"}], 
             "23.39853908586074`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "15"}], "}"}], 
             "23.096291100394566`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "16"}], "}"}], 
             "22.890233766233766`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "5", ",", "6"}], "}"}], 
             "22.38015943312666`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "6"}], "}"}], 
             "23.06105645851155`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "10"}], "}"}], 
             "23.689201009251473`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "12"}], "}"}], 
             "23.508382978723404`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "19"}], "}"}], 
             "24.008256880733942`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "21"}], "}"}], 
             "23.579999999999995`"}}, AutoDelete -> False, 
           GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{"."}}}, 
           GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"number of trades:\"", "48"}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"cost per trade:\"", "3.5`"}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"total transaction costs:\"", "168.`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"largest winning trade:\"", "1545.473227189221`"}}, 
           AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"largest losing trade:\"", 
             RowBox[{"-", "714.1036248712004`"}]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"gross profits:\"", "5474.386670589946`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"gross loss:\"", 
             RowBox[{"-", "3212.3887561917027`"}]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"net profits:\"", "2258.49791439824`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"equity plot:\""}, {
             GraphicsBox[{{}, 
               GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQQJmTKvHFUtHik59R5xAPIn3FR85dixQi23QOUo
iK/gqPXKseLhBtslEmC+gaDOK0fmblWGgGlg9QLbdV85bpjNI2QlCuZ/eGH5
yrH0xZm9124fBvEXpFi/cvT86PNo2/dDIH7CTLdXjrdbdszT7D8I4jN0e79y
fHn6DXdZKUSeL/KVY6/eonmbysD2BeSmvHLsb+p7uGQBmO/QlvXKMavwQNnT
O2D7FM7nvXKMr195WRJiv8CLkleOUQ47z1tB3MfAWP3K8Vbqq8e2XyDqnze/
cjRwuHGDw+QY2L/TJ7xy5AsRejojAMxPEJj8ytHlKN/b1zpg/gHf2a8c5aMF
lQLsToD4F2TnvnJ89knRoUYWzE94tOiVI6fBpYvfHx0H+99z9SvHMIVrkVEz
wfIC7mteOXY1XWq6kQrmHzi09pVj8JYVu/9/AqsHhz8DAoDlYRwAOyqjQg==

                "], {{{}, {
                   Hue[0.67, 0.6, 0.6], 
                   Opacity[0.2], 
                   EdgeForm[None], 
                   GraphicsGroupBox[
                    
                    PolygonBox[{{1, 25, 26, 24, 23, 22, 21, 20, 19, 18, 17, 
                    16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 
                    2}}]]}, {}, {}}, {{}, {}, {
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   
                   LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
                     16, 17, 18, 19, 20, 21, 22, 23, 24}]}}}], {}}, 
              AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
              AxesOrigin -> {3.51*^9, 8800.}, Frame -> True, 
              FrameLabel -> {None, None}, 
              FrameTicks -> {{Automatic, Automatic}, {{{3534364800, 
                   FormBox["\"2012\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3565987200, 
                   FormBox["\"2013\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3510604800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3518467200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3526416000, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3542227200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3550089600, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3558038400, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3573763200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3581625600, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}}, {{3534364800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3565987200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3510604800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3518467200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3526416000, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3542227200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3550089600, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3558038400, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3573763200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3581625600, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}}}}, GridLines -> {{{3534364800, 
                  GrayLevel[0.8]}, {3565987200, 
                  GrayLevel[0.8]}}, None}, ImageSize -> Medium, Method -> {}, 
              PlotRange -> {{3.5045568*^9, 3.5807616*^9}, {8800., 
               12594.705866590299`}}, PlotRangeClipping -> True, 
              PlotRangePadding -> {
                Scaled[0.02], 
                Scaled[0.02]}, Ticks -> None]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"current position:\"", 
             TagBox[
              GridBox[{{"\"BuyDate\"", "\"BuyPrice:\""}, {
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "11"}], "}"}], "23.91`"}}, 
               AutoDelete -> False, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{"."}}},
                GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "Grid"]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}}, 
       DefaultBaseStyle -> "Column", 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, 
       GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
     "\"Moving Average Convergence Divergence Backtesting for GE\""}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {2, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
  "Row",
  DisplayFunction->(PaneBox[
    RowBox[{
      TemplateSlotSequence[1, "   "]}], Alignment -> {Center, Top}]& ),
  InterpretationFunction->(RowBox[{"Row", "[", 
     RowBox[{
       RowBox[{"{", 
         TemplateSlotSequence[1, ","], "}"}], ",", "\"   \"", ",", 
       RowBox[{"Alignment", "\[Rule]", 
         RowBox[{"{", 
           RowBox[{"Center", ",", "Top"}], "}"}]}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.583815099071971*^9, 3.5838151194011335`*^9}, {
   3.58381536516019*^9, 3.5838153953689175`*^9}, 3.583815719676467*^9, 
   3.58381577847283*^9, {3.5838159216000166`*^9, 3.5838159381199617`*^9}}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Linear Regression Slope and Moving Average Convergence Divergence Backtesting \
for Microsoft\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}, {
   3.583812331977702*^9, 3.5838123364259567`*^9}, 3.583814675412739*^9, {
   3.5838147288857975`*^9, 3.583814742085552*^9}, {3.5838148195889854`*^9, 
   3.5838148260533547`*^9}, {3.583815801913171*^9, 3.5838158031612425`*^9}, {
   3.583815868489979*^9, 3.583815872201191*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{"Charting`BackTesting", "[", 
         RowBox[{
          RowBox[{"FinancialData", "[", 
           RowBox[{"\"\<MSFT\>\"", ",", "\"\<OHLCV\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"2012", ",", "1"}], "}"}], ",", 
              RowBox[{"Date", "[", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "\"\<LRS\>\"", ",", 
          RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", "21"}], ",", " ", 
          RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
          RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
          RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "10000"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{
       "\"\<Linear Regression Slope Backtesting for \>\"", "<>", 
        "\"\<MSFT\>\""}], ",", "Top"}], "]"}], ",", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{"Charting`BackTesting", "[", 
         RowBox[{
          RowBox[{"FinancialData", "[", 
           RowBox[{"\"\<MSFT\>\"", ",", "\"\<OHLCV\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"2010", ",", "1"}], "}"}], ",", 
              RowBox[{"Date", "[", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "\"\<MACD\>\"", ",", 
          RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"13", ",", "33", ",", "10"}], "}"}]}], ",", " ", 
          RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
          RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
          RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "10000"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{
       "\"\<Moving Average Convergence Divergence Backtesting for \>\"", 
        "<>", "\"\<MSFT\>\""}], ",", "Top"}], "]"}]}], "}"}], ",", " ", 
   "\"\<   \>\"", ",", 
   RowBox[{"Alignment", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Center", ",", "Top"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4996270095708523`*^9, 3.4996270290401287`*^9}, {
   3.49962782853901*^9, 3.4996278352799664`*^9}, {3.499627894766952*^9, 
   3.499627907869459*^9}, {3.49962875540844*^9, 3.499628769476714*^9}, {
   3.5354677790942416`*^9, 3.535467806502982*^9}, {3.5354818876640234`*^9, 
   3.535481888512108*^9}, {3.5354819243206887`*^9, 3.5354819848817444`*^9}, {
   3.535482056405896*^9, 3.5354820666619215`*^9}, {3.53548209765602*^9, 
   3.5354821010953646`*^9}, {3.5354822512783813`*^9, 3.535482271950448*^9}, {
   3.535483594918644*^9, 3.535483658123644*^9}, {3.5355539399426875`*^9, 
   3.5355539454452376`*^9}, {3.5355568164010196`*^9, 
   3.5355568222570195`*^9}, {3.5355568528310194`*^9, 3.5355568583990197`*^9}, 
   3.53555717972602*^9, {3.5838148674477224`*^9, 3.583814931511387*^9}, {
   3.583814964695285*^9, 3.5838150212075167`*^9}, {3.583815060519766*^9, 
   3.5838150832160635`*^9}, {3.5838151133687887`*^9, 3.583815144503569*^9}, {
   3.583815344937033*^9, 3.5838153920747294`*^9}, {3.583815588266951*^9, 
   3.5838155945233088`*^9}, {3.5838156973551903`*^9, 
   3.5838157145941763`*^9}, {3.583815774204586*^9, 3.5838157756296673`*^9}, {
   3.5838158453886576`*^9, 3.583815861116557*^9}, {3.583815891885317*^9, 
   3.58381590137286*^9}}],

Cell[BoxData[
 TemplateBox[{TemplateBox[{
     TagBox[
      GridBox[{{
         TagBox[
          
          GridBox[{{
            "\"BuyDate\"", "\"BuyPrice\"", "\"SellDate\"", "\"SellPrice\""}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "1", ",", "5"}], "}"}], 
             "26.222680635838156`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "1", ",", "30"}], "}"}], 
             "27.747017899358326`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "6"}], "}"}], 
             "28.77672847682119`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "13"}], "}"}], 
             "29.33789077828646`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "22"}], "}"}], 
             "30.323552926127277`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "28"}], "}"}], 
             "30.286454345779728`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "3", ",", "2"}], "}"}], 
             "31.151754987531177`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "3", ",", "6"}], "}"}], 
             "30.410716096324464`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "3", ",", "14"}], "}"}], 
             "31.358642050656087`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "3", ",", "15"}], "}"}], 
             "31.61215525114155`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "2"}], "}"}], 
             "31.062514710436663`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "3"}], "}"}], 
             "31.00207889793362`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "17"}], "}"}], 
             "30.146110050890584`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "20"}], "}"}], 
             "30.999660703269587`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "23"}], "}"}], 
             "31.15319738480698`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "5", ",", "7"}], "}"}], 
             "29.598205546492665`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "5", ",", "22"}], "}"}], 
             "28.81206989247312`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "5", ",", "23"}], "}"}], 
             "28.482909653040196`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "5", ",", "29"}], "}"}], 
             "28.515297699594047`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "6", ",", "6"}], "}"}], 
             "28.023931856899488`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "6", ",", "7"}], "}"}], 
             "28.767937050975025`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "6", ",", "26"}], "}"}], 
             "29.110592938041307`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "6", ",", "27"}], "}"}], 
             "29.299410009943653`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "3"}], "}"}], 
             "29.33567945383615`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "19"}], "}"}], 
             "29.604747310074995`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "24"}], "}"}], 
             "28.377344768439105`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "30"}], "}"}], 
             "28.866734143049936`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "31"}], "}"}], 
             "28.609704784526638`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "1"}], "}"}], 
             "28.714675280516833`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "13"}], "}"}], 
             "29.451184600197433`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "14"}], "}"}], 
             "29.596050448058413`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "23"}], "}"}], 
             "29.68699272967614`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "28"}], "}"}], 
             "29.988377407770162`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "29"}], "}"}], 
             "29.940000000000005`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "7"}], "}"}], 
             "30.317906300484655`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "10"}], "}"}], 
             "30.11745768229167`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "17"}], "}"}], 
             "30.47046139057994`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "25"}], "}"}], 
             "30.23710102007239`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "10", ",", "8"}], "}"}], 
             "28.953243787777033`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "10", ",", "9"}], "}"}], 
             "28.990710382513658`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "10", ",", "16"}], "}"}], 
             "28.770922346558155`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "10", ",", "23"}], "}"}], 
             "27.126488413547236`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "10", ",", "31"}], "}"}], 
             "27.88976874562018`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "11", ",", "13"}], "}"}], 
             "26.611059431524552`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "12", ",", "4"}], "}"}], 
             "26.098028062191883`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "12", ",", "17"}], "}"}], 
             "26.38469003690037`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "12", ",", "19"}], "}"}], 
             "27.274295129989014`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "12", ",", "31"}], "}"}], 
             "26.191797079745413`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "3"}], "}"}], 
             "27.214282568807338`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "4"}], "}"}], 
             "26.862071802543007`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "14"}], "}"}], 
             "26.489847526961693`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "17"}], "}"}], 
             "26.78090275229358`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "18"}], "}"}], 
             "26.692256880733947`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "1"}], "}"}], 
             "27.253909774436092`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "4"}], "}"}], 
             "27.453575072886295`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "6"}], "}"}], 
             "26.969400146305773`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "15"}], "}"}], 
             "27.619550160656903`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "19"}], "}"}], 
             "27.68121212121212`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "20"}], "}"}], 
             "27.938227484750627`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "21"}], "}"}], 
             "27.548272098945073`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "25"}], "}"}], 
             "27.7758348556814`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "26"}], "}"}], 
             "27.18993058092802`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "28"}], "}"}], 
             "27.689453237410067`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "7"}], "}"}], 
             "27.910213219616203`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "15"}], "}"}], 
             "27.83007132667618`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "25"}], "}"}], 
             "28.099005681818188`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "1"}], "}"}], 
             "28.439790283117794`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "12"}], "}"}], 
             "28.649583188607156`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "22"}], "}"}], 
             "30.093610120012976`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "5", ",", "13"}], "}"}], 
             "32.382924613987285`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "5", ",", "31"}], "}"}], "34.82`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "3"}], "}"}], 
             "34.919999999999995`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "4"}], "}"}], "35.62`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "6"}], "}"}], "34.84`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "19"}], "}"}], "34.96`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "20"}], "}"}], "34.26`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "6", ",", "28"}], "}"}], "34.38`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "7", ",", "2"}], "}"}], "34.41`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "7", ",", "3"}], "}"}], "33.66`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "7", ",", "5"}], "}"}], "34.09`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "7", ",", "8"}], "}"}], "34.35`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "7", ",", "22"}], "}"}], "31.7`"}}, 
           AutoDelete -> False, 
           GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{"."}}}, 
           GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"number of trades:\"", "82"}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"cost per trade:\"", "3.5`"}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"total transaction costs:\"", "287.`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"largest winning trade:\"", "629.5614858429351`"}}, 
           AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"largest losing trade:\"", 
             RowBox[{"-", "665.1500000000005`"}]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"gross profits:\"", "2804.71077117523`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"gross loss:\"", 
             RowBox[{"-", "4826.91108362767`"}]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"net profits:\"", 
             RowBox[{"-", "2022.20031245245`"}]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"equity plot:\""}, {
             GraphicsBox[{{}, 
               GraphicsComplexBox[CompressedData["
1:eJxF0l9IU3EUB/DLHkqdPfgnCYS1sNiGPjgkplFxjwyjPYRYglzH0qU0hmxz
ZhNdsjWsrIfdRm0ujUaJgitaZmyBpJUDaVYiET5IzT9BnF7WQDIz7e7coh/8
uHw433P4/X7cA0ZrXauEYZhSYWe+wnJJOYTSZfXyysgMK1jO6RH6fFU5+px4
xqkFA8JeX+JEDUNmN88iDN2IM2kn5VOdzQhHueyK2QdkV6AF4dtYa5bET460
nEfoCm8sdiioP6k2I7SZes+oiqie/NCGIEkyyvzF19RfYhXygxsDxZfIrNWO
sNugObg6Qeb9HQiNDKcMRcV8rgOh5l1D0LH6KuP5ii4E46S9UPqMzDZ0I7yQ
B/eUlVFevt2DMHPIte+5Rpz/y4nw8cjO4Vqx7lrvRfDptpdsWeRaixuB037V
xT7TvNSkB6GyfE7buULmpVcQrr3N/+5JvKR+dz+C3H13/faPabpfsRdBNdGY
DpeIdfNNBEf/Ka3FTnW2wIewFTSFPJXkiOYWwrkAf5E3kl0RP8Kw2ms+HiXb
PAGEXYru5gsmcf5oEOHNF0P8tEWctyX4qTrdU19OLn9/B2HnYdyVF56ivG4I
4bpsYfrqGpmtvie8x+zgb1UR5UNV9xGUTm5kU+y31Y8itMv291Wb6PxNiTEE
m+DL7eTUyfBf55L5gUcI2bGYbOkJ9c/7HiMojg3bCsfJTXkRhAKv3vtzjcx/
GkeYitbF5lR0Hvofmf+L6v/wB4BKEoM=
                "], {{{}, {
                   Hue[0.67, 0.6, 0.6], 
                   Opacity[0.2], 
                   EdgeForm[None], 
                   GraphicsGroupBox[
                    
                    PolygonBox[{{1, 42, 43, 41, 40, 39, 38, 37, 36, 35, 34, 
                    33, 32, 31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 
                    19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 
                    3, 2}}]]}, {}, {}}, {{}, {}, {
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   
                   LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
                     16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
                    30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41}]}}}], {}},
               AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
              AxesOrigin -> {3.54*^9, 7800.}, Frame -> True, 
              FrameLabel -> {None, None}, 
              FrameTicks -> {{Automatic, Automatic}, {{{3534364800, 
                   FormBox["\"Jan\"", TraditionalForm]}, {3550089600, 
                   FormBox["\"Jul\"", TraditionalForm]}, {3565987200, 
                   FormBox["\"Jan\"", TraditionalForm]}, {3581625600, 
                   FormBox["\"Jul\"", TraditionalForm]}, {3597523200, 
                   FormBox["\"Jan\"", TraditionalForm]}, {3539548800, 
                   FormBox["\"\"", TraditionalForm]}, {3544819200, 
                   FormBox["\"\"", TraditionalForm]}, {3555446400, 
                   FormBox["\"\"", TraditionalForm]}, {3560716800, 
                   FormBox["\"\"", TraditionalForm]}, {3571084800, 
                   FormBox["\"\"", TraditionalForm]}, {3576355200, 
                   FormBox["\"\"", TraditionalForm]}}, {{3534364800, 
                   FormBox["\"\"", TraditionalForm]}, {3550089600, 
                   FormBox["\"\"", TraditionalForm]}, {3565987200, 
                   FormBox["\"\"", TraditionalForm]}, {3581625600, 
                   FormBox["\"\"", TraditionalForm]}, {3597523200, 
                   FormBox["\"\"", TraditionalForm]}, {3539548800, 
                   FormBox["\"\"", TraditionalForm]}, {3544819200, 
                   FormBox["\"\"", TraditionalForm]}, {3555446400, 
                   FormBox["\"\"", TraditionalForm]}, {3560716800, 
                   FormBox["\"\"", TraditionalForm]}, {3571084800, 
                   FormBox["\"\"", TraditionalForm]}, {3576355200, 
                   FormBox["\"\"", TraditionalForm]}}}}, 
              GridLines -> {{{3534364800, 
                  GrayLevel[0.8]}, {3550089600, 
                  GrayLevel[0.8]}, {3565987200, 
                  GrayLevel[0.8]}, {3581625600, 
                  GrayLevel[0.8]}, {3597523200, 
                  GrayLevel[0.8]}}, None}, ImageSize -> Medium, Method -> {}, 
              PlotRange -> {{3.5368704*^9, 3.58344*^9}, {7800., 
               10830.905058940625`}}, PlotRangeClipping -> True, 
              PlotRangePadding -> {
                Scaled[0.02], 
                Scaled[0.02]}, Ticks -> None]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"current position:\"", 
             TagBox[
              GridBox[{{"\"SellDate\"", "\"SellPrice:\""}, {
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "22"}], "}"}], "31.7`"}}, 
               AutoDelete -> False, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{"."}}},
                GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "Grid"]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}}, 
       DefaultBaseStyle -> "Column", 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, 
       GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
     "\"Linear Regression Slope Backtesting for MSFT\""}, "Labeled", 
    DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {2, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],TemplateBox[{
     TagBox[
      GridBox[{{
         TagBox[
          
          GridBox[{{
            "\"BuyDate\"", "\"BuyPrice\"", "\"SellDate\"", "\"SellPrice\""}, {
             RowBox[{"{", 
               RowBox[{"2010", ",", "1", ",", "5"}], "}"}], 
             "28.199450904392766`", 
             RowBox[{"{", 
               RowBox[{"2010", ",", "1", ",", "7"}], "}"}], 
             "27.994512315270935`"}, {
             RowBox[{"{", 
               RowBox[{"2010", ",", "1", ",", "20"}], "}"}], 
             "28.161085322000655`", 
             RowBox[{"{", 
               RowBox[{"2010", ",", "1", ",", "22"}], "}"}], 
             "27.420580110497237`"}, {
             RowBox[{"{", 
               RowBox[{"2010", ",", "2", ",", "18"}], "}"}], 
             "26.251087331722477`", 
             RowBox[{"{", 
               RowBox[{"2010", ",", "4", ",", "5"}], "}"}], 
             "26.751431499829174`"}, {
             RowBox[{"{", 
               RowBox[{"2010", ",", "4", ",", "12"}], "}"}], 
             "27.775725593667545`", 
             RowBox[{"{", 
               RowBox[{"2010", ",", "4", ",", "30"}], "}"}], 
             "28.526614276358874`"}, {
             RowBox[{"{", 
               RowBox[{"2010", ",", "6", ",", "16"}], "}"}], 
             "24.41837386018237`", 
             RowBox[{"{", 
               RowBox[{"2010", ",", "6", ",", "29"}], "}"}], 
             "22.256327756327753`"}, {
             RowBox[{"{", 
               RowBox[{"2010", ",", "7", ",", "9"}], "}"}], 
             "22.445352286773794`", 
             RowBox[{"{", 
               RowBox[{"2010", ",", "8", ",", "11"}], "}"}], 
             "22.76397425583266`"}, {
             RowBox[{"{", 
               RowBox[{"2010", ",", "9", ",", "8"}], "}"}], 
             "22.319820309235272`", 
             RowBox[{"{", 
               RowBox[{"2010", ",", "10", ",", "1"}], "}"}], 
             "22.971685808039375`"}, {
             RowBox[{"{", 
               RowBox[{"2010", ",", "10", ",", "13"}], "}"}], 
             "23.20323599052881`", 
             RowBox[{"{", 
               RowBox[{"2010", ",", "11", ",", "15"}], "}"}], 
             "24.42057251908397`"}, {
             RowBox[{"{", 
               RowBox[{"2010", ",", "12", ",", "6"}], "}"}], 
             "25.12396423248882`", 
             RowBox[{"{", 
               RowBox[{"2010", ",", "12", ",", "31"}], "}"}], 
             "25.937370118237194`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "1", ",", "10"}], "}"}], 
             "26.367321048901488`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "1", ",", "11"}], "}"}], 
             "26.313980789754535`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "3", ",", "24"}], "}"}], 
             "24.02293684618365`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "4", ",", "19"}], "}"}], 
             "23.459244532803183`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "4", ",", "21"}], "}"}], 
             "24.203389498432603`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "5", ",", "12"}], "}"}], 
             "23.788151658767774`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "6", ",", "1"}], "}"}], 
             "23.609054441260742`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "6", ",", "3"}], "}"}], 
             "22.72227101631117`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "6", ",", "15"}], "}"}], 
             "22.675652906486942`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "6", ",", "16"}], "}"}], 
             "22.433854166666666`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "6", ",", "17"}], "}"}], 
             "22.882209398186315`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "8", ",", "2"}], "}"}], 
             "25.490059701492537`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "8", ",", "30"}], "}"}], 
             "24.464590163934428`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "9", ",", "23"}], "}"}], 
             "23.667916999201914`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "10", ",", "10"}], "}"}], 
             "25.26777282850779`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "10", ",", "27"}], "}"}], 
             "25.78594495412844`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "10", ",", "28"}], "}"}], 
             "25.80211267605634`", 
             RowBox[{"{", 
               RowBox[{"2011", ",", "10", ",", "31"}], "}"}], 
             "25.443604956815623`"}, {
             RowBox[{"{", 
               RowBox[{"2011", ",", "12", ",", "6"}], "}"}], 
             "24.72368667186282`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "15"}], "}"}], 
             "29.239936772046587`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "21"}], "}"}], 
             "30.059344783715012`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "28"}], "}"}], 
             "30.286454345779728`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "2", ",", "29"}], "}"}], 
             "30.744612476370516`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "3", ",", "6"}], "}"}], 
             "30.410716096324464`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "4", ",", "24"}], "}"}], 
             "31.04955200501253`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "5", ",", "7"}], "}"}], 
             "29.598205546492665`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "6", ",", "11"}], "}"}], 
             "28.85558823529412`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "11"}], "}"}], 
             "28.827825938566555`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "20"}], "}"}], 
             "30.0839973439575`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "7", ",", "24"}], "}"}], 
             "28.377344768439105`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "7"}], "}"}], 
             "29.185588235294116`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "8", ",", "31"}], "}"}], 
             "29.895068137573006`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "4"}], "}"}], 
             "29.748617966436328`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "5"}], "}"}], 
             "29.523915761763735`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "7"}], "}"}], 
             "30.317906300484655`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "13"}], "}"}], 
             "30.171163542340008`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "17"}], "}"}], 
             "30.47046139057994`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "9", ",", "25"}], "}"}], 
             "30.23710102007239`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "11", ",", "2"}], "}"}], 
             "28.907925423728813`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "11", ",", "14"}], "}"}], 
             "26.823889716840533`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "11", ",", "29"}], "}"}], 
             "26.697565862708718`", 
             RowBox[{"{", 
               RowBox[{"2012", ",", "12", ",", "3"}], "}"}], 
             "26.37470298902762`"}, {
             RowBox[{"{", 
               RowBox[{"2012", ",", "12", ",", "7"}], "}"}], 
             "26.414557823129254`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "9"}], "}"}], 
             "26.319700374531838`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "1", ",", "15"}], "}"}], 
             "26.42572583608967`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "8"}], "}"}], 
             "26.933049001814883`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "12"}], "}"}], 
             "27.459999999999997`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "2", ",", "26"}], "}"}], 
             "27.18993058092802`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "4"}], "}"}], 
             "27.652131438721142`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "13"}], "}"}], 
             "27.680340257879656`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "21"}], "}"}], 
             "27.909999999999997`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "22"}], "}"}], 
             "27.990424778761064`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "25"}], "}"}], 
             "28.099005681818188`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "3", ",", "26"}], "}"}], 
             "28.03943181818182`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "1"}], "}"}], 
             "28.439790283117794`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "18"}], "}"}], 
             "28.74888850295241`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "4", ",", "22"}], "}"}], 
             "30.093610120012976`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "5", ",", "28"}], "}"}], "34.42`"}, {
             RowBox[{"{", 
               RowBox[{"2013", ",", "7", ",", "12"}], "}"}], "35.58`", 
             RowBox[{"{", 
               RowBox[{"2013", ",", "7", ",", "22"}], "}"}], "31.7`"}}, 
           AutoDelete -> False, 
           GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{"."}}}, 
           GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"number of trades:\"", "78"}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"cost per trade:\"", "3.5`"}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"total transaction costs:\"", "273.`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"largest winning trade:\"", "1860.6950412757126`"}}, 
           AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"largest losing trade:\"", 
             RowBox[{"-", "1245.4799999999998`"}]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"gross profits:\"", "6832.836965023016`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"gross loss:\"", 
             RowBox[{"-", "6649.078272320131`"}]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          
          GridBox[{{"\"net profits:\"", "183.75869270288422`"}}, AutoDelete -> 
           False, GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"equity plot:\""}, {
             GraphicsBox[{{}, 
               GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQQBX+6+dHyhPfOSZcJhByBfIffBS0f1m2vnpd46
BOJfKHnz0lEsbsbJrUZg+YbJH1461vWJfNy7Gcw/UPbrpWNHvIv7nU8Hwep7
GF859jJNPdZiANaf8IXzlePVRYv2v9sCMS9O8JWjzmk9U5M1YP0FnyVeOZ7/
fm5akvcRsPmHpV45LjoTFpNuC+Y/eKn1yjF+sefU3ANg9QZb9F453nZRvRmZ
BuYHhBi9cnSp441fsAJs/oEKE6D9NQpBVkVg/gRzm1eO28PEXn1sB5sXcNLl
lWN1Y+L/vptg/RuSvV45zmv7x29mB5Yv4PF+5ZioyDnlyieIf9fFvHJc8V61
e+3E4yD+h0txrxzvbG2bv203mO/wK/6Voxxj1SWXMjD/gWHWK0d2SZdNK6KO
gfgCL0peOW7KUateGQjmN/CUv3LU7H0feYDrKIi/wL/2leP/hz2Nal1g/gSl
uleOnV2Cc0RiwXyBkvpXjgWT+LZo2YP5AXmNrxxtd8p/UBAC8zes7nzl2HR0
x54vnWD3OpztAbrnq89SES9IeD2b9MrxyZmeo49NwPwL16e/ctw7a39HfT9E
/vwsoPqKraU3osB8Bo+5rxzT0k5KpsZAwufwvFeOTP88ZmmnQ+IrZ/4rx8JC
04vqkZD4N1v8ytF5z3nPgm6I/edWvnKMaKnulQsD+3fCvU2vHH3XXpd5+BgS
X6D0xoAAYHkYBwAs4Q2/
                "], {{{}, {
                   Hue[0.67, 0.6, 0.6], 
                   Opacity[0.2], 
                   EdgeForm[None], 
                   GraphicsGroupBox[
                    
                    PolygonBox[{{1, 40, 41, 39, 38, 37, 36, 35, 34, 33, 32, 
                    31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 
                    17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 
                    2}}]]}, {}, {}}, {{}, {}, {
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   
                   LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
                     16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
                    30, 31, 32, 33, 34, 35, 36, 37, 38, 39}]}}}], {}}, 
              AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
              AxesOrigin -> {3.48*^9, 9000.}, Frame -> True, 
              FrameLabel -> {None, None}, 
              FrameTicks -> {{Automatic, Automatic}, {{{3471292800, 
                   FormBox["\"2010\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3502828800, 
                   FormBox["\"2011\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3534364800, 
                   FormBox["\"2012\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3565987200, 
                   FormBox["\"2013\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3479068800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3486931200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3494880000, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3510604800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3518467200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3526416000, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3542227200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3550089600, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3558038400, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3573763200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3581625600, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}}, {{3471292800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3502828800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3534364800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3565987200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.020601132958329826`, 0}}, {3479068800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3486931200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3494880000, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3510604800, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3518467200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3526416000, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3542227200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3550089600, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3558038400, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3573763200, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}, {3581625600, 
                   FormBox["\"\"", TraditionalForm], {
                   0.012360679774997897`, 0}}}}}, GridLines -> {{{3471292800, 
                  GrayLevel[0.8]}, {3502828800, 
                  GrayLevel[0.8]}, {3534364800, 
                  GrayLevel[0.8]}, {3565987200, 
                  GrayLevel[0.8]}}, None}, ImageSize -> Medium, Method -> {}, 
              PlotRange -> {{3.4718112*^9, 3.58344*^9}, {9000., 
               12151.426743353652`}}, PlotRangeClipping -> True, 
              PlotRangePadding -> {
                Scaled[0.02], 
                Scaled[0.02]}, Ticks -> None]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}, {
         TagBox[
          GridBox[{{"\"current position:\"", 
             TagBox[
              GridBox[{{"\"SellDate\"", "\"SellPrice:\""}, {
                 RowBox[{"{", 
                   RowBox[{"2013", ",", "7", ",", "22"}], "}"}], "31.7`"}}, 
               AutoDelete -> False, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{"."}}},
                GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "Grid"]}}, AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]}}, 
       DefaultBaseStyle -> "Column", 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, 
       GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
     "\"Moving Average Convergence Divergence Backtesting for MSFT\""}, 
    "Labeled", DisplayFunction -> (GridBox[{{
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      BaselinePosition -> {2, 1}]& ), 
    InterpretationFunction -> (RowBox[{"Labeled", "[", 
       RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
  "Row",
  DisplayFunction->(PaneBox[
    RowBox[{
      TemplateSlotSequence[1, "   "]}], Alignment -> {Center, Top}]& ),
  InterpretationFunction->(RowBox[{"Row", "[", 
     RowBox[{
       RowBox[{"{", 
         TemplateSlotSequence[1, ","], "}"}], ",", "\"   \"", ",", 
       RowBox[{"Alignment", "\[Rule]", 
         RowBox[{"{", 
           RowBox[{"Center", ",", "Top"}], "}"}]}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.583815250271619*^9, {3.583815878265538*^9, 3.583815903494981*^9}}]
}, {2}]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1375, 916},
WindowMargins->{{148, Automatic}, {Automatic, 4}},
Magnification:>1.25 Inherited,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (May 20, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 111, 1, 113, "Title"],
Cell[CellGroupData[{
Cell[715, 27, 32, 0, 98, "Section"],
Cell[750, 29, 119, 3, 36, "Input",
 InitializationCell->True],
Cell[872, 34, 101, 2, 36, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1010, 41, 88, 1, 60, "Section"],
Cell[1101, 44, 230, 7, 36, "Input",
 InitializationCell->True],
Cell[1334, 53, 831, 16, 106, "Input",
 InitializationCell->True],
Cell[2168, 71, 416, 9, 60, "Input",
 InitializationCell->True],
Cell[2587, 82, 244, 7, 36, "Input",
 InitializationCell->True],
Cell[2834, 91, 306, 8, 36, "Input",
 InitializationCell->True],
Cell[3143, 101, 468, 11, 60, "Input",
 InitializationCell->True],
Cell[3614, 114, 311, 8, 36, "Input",
 InitializationCell->True],
Cell[3928, 124, 110, 2, 36, "Input",
 InitializationCell->True],
Cell[4041, 128, 531, 12, 60, "Input",
 InitializationCell->True],
Cell[4575, 142, 5660, 126, 418, "Input",
 InitializationCell->True],
Cell[10238, 270, 707, 21, 60, "Input",
 InitializationCell->True],
Cell[10948, 293, 4651, 121, 244, "Input",
 InitializationCell->True],
Cell[15602, 416, 3173, 85, 244, "Input",
 InitializationCell->True],
Cell[18778, 503, 6955, 188, 451, "Input",
 InitializationCell->True],
Cell[25736, 693, 13309, 311, 888, "Input",
 InitializationCell->True],
Cell[39048, 1006, 1509, 33, 83, "Input",
 InitializationCell->True],
Cell[40560, 1041, 1337, 28, 83, "Input",
 InitializationCell->True],
Cell[41900, 1071, 1373, 28, 83, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[43310, 1104, 136, 2, 60, "Section"],
Cell[43449, 1108, 857, 17, 60, "Input",
 InitializationCell->True],
Cell[44309, 1127, 885, 16, 83, "Input",
 InitializationCell->True],
Cell[45197, 1145, 920, 17, 83, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[46154, 1167, 144, 2, 60, "Section"],
Cell[46301, 1171, 475, 8, 38, "Text"],
Cell[46779, 1181, 301, 11, 187, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47117, 1197, 124, 3, 98, "Section"],
Cell[CellGroupData[{
Cell[47266, 1204, 157, 2, 38, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[47426, 1208, 1161, 19, 106, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[48602, 1230, 838, 15, 182, "Text"],
Cell[CellGroupData[{
Cell[49465, 1249, 167, 2, 53, "Subsection"],
Cell[CellGroupData[{
Cell[49657, 1255, 101, 1, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[49783, 1260, 894, 20, 112, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[50680, 1282, 11341, 236, 1083, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62070, 1524, 101, 1, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[62196, 1529, 2788, 65, 300, "Input"],
Cell[64987, 1596, 24995, 440, 710, "Output"]
}, Closed]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[90043, 2043, 162, 2, 42, "Subsection"],
Cell[CellGroupData[{
Cell[90230, 2049, 101, 1, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[90356, 2054, 975, 21, 112, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[91334, 2077, 11244, 235, 1083, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[102624, 2318, 101, 1, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[102750, 2323, 2857, 66, 300, "Input"],
Cell[105610, 2391, 25372, 448, 710, "Output"]
}, {2}]]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[131052, 2847, 215, 3, 98, "Section"],
Cell[131270, 2852, 1246, 21, 212, "Text"],
Cell[CellGroupData[{
Cell[132541, 2877, 169, 3, 53, "Subsection"],
Cell[CellGroupData[{
Cell[132735, 2884, 114, 1, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[132874, 2889, 678, 16, 81, "Input"],
Cell[133555, 2907, 896, 24, 66, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[134500, 2937, 248, 5, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[134773, 2946, 496, 10, 47, "Input"],
Cell[135272, 2958, 70139, 1675, 1153, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[205484, 4641, 344, 6, 98, "Section"],
Cell[205831, 4649, 1532, 25, 283, "Text"],
Cell[CellGroupData[{
Cell[207388, 4678, 190, 2, 66, "Subsection"],
Cell[207581, 4682, 291, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[207897, 4691, 103, 1, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[208025, 4696, 169, 3, 47, "Input"],
Cell[208197, 4701, 27083, 626, 516, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[235329, 5333, 106, 1, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[235460, 5338, 523, 11, 47, "Input"],
Cell[235986, 5351, 4445, 92, 485, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[240492, 5450, 213, 3, 66, "Subsection"],
Cell[CellGroupData[{
Cell[240730, 5457, 103, 1, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[240858, 5462, 222, 4, 47, "Input"],
Cell[241083, 5468, 27101, 626, 516, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[268230, 6100, 106, 1, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[268361, 6105, 574, 12, 47, "Input"],
Cell[268938, 6119, 4483, 91, 512, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[273491, 6218, 441, 7, 60, "Section"],
Cell[273935, 6227, 1462, 24, 187, "Text"],
Cell[CellGroupData[{
Cell[275422, 6255, 222, 3, 53, "Subsection"],
Cell[CellGroupData[{
Cell[275669, 6262, 142, 2, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[275836, 6268, 3375, 74, 456, "Input"],
Cell[279214, 6344, 351373, 8841, 889, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[630633, 15191, 158, 2, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[630816, 15197, 3445, 75, 456, "Input"],
Cell[634264, 15274, 363935, 9140, 893, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[998269, 24422, 600, 9, 98, "Section"],
Cell[998872, 24433, 1888, 29, 261, "Text"],
Cell[CellGroupData[{
Cell[1000785, 24466, 382, 6, 53, "Subsection"],
Cell[CellGroupData[{
Cell[1001192, 24476, 230, 4, 42, "Subsubsection"],
Cell[CellGroupData[{
Cell[1001447, 24484, 4945, 95, 198, "Input"],
Cell[1006395, 24581, 106414, 2264, 4765, "Output"]
}, {2}]]
}, Closed]],
Cell[CellGroupData[{
Cell[1112855, 26851, 275, 5, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[1113155, 26860, 4951, 95, 268, "Input"],
Cell[1118109, 26957, 86414, 1853, 3925, "Output"]
}, {2}]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1204593, 28818, 693, 11, 98, "Section"],
Cell[1205289, 28831, 1902, 29, 283, "Text"],
Cell[CellGroupData[{
Cell[1207216, 28864, 404, 7, 66, "Subsection"],
Cell[CellGroupData[{
Cell[1207645, 28875, 275, 5, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[1207945, 28884, 3928, 89, 331, "Input"],
Cell[1211876, 28975, 1424197, 24360, 2133, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2636119, 53341, 323, 6, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[2636467, 53351, 3986, 90, 331, "Input"],
Cell[2640456, 53443, 1412910, 24121, 2133, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4053436, 77572, 779, 12, 60, "Section"],
Cell[4054218, 77586, 2176, 33, 283, "Text"],
Cell[CellGroupData[{
Cell[4056419, 77623, 417, 7, 66, "Subsection"],
Cell[CellGroupData[{
Cell[4056861, 77634, 502, 8, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[4057388, 77646, 3383, 69, 237, "Input"],
Cell[4060774, 77717, 29990, 643, 1495, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4090810, 78366, 545, 9, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[4091380, 78379, 3438, 70, 237, "Input"],
Cell[4094821, 78451, 38713, 832, 1795, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
