(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    118239,       2865]
NotebookOptionsPosition[    111920,       2653]
NotebookOutlinePosition[    112291,       2669]
CellTagsIndexPosition[    112248,       2666]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Report Generation Examples", "Title",
 CellChangeTimes->{{3.583783014205821*^9, 3.5837830283526306`*^9}}],

Cell[CellGroupData[{

Cell["Load packages", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<CUDALink`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Calendar`\>\"", "]"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Code", "Section",
 CellChangeTimes->{{3.520786469854125*^9, 3.52078648436975*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dividends", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<DividendYield\>\"", ",", "\"\<DividendPerShare\>\"", ",", 
     "\"\<Dividend\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"LongTermTrends", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Average200Day\>\"", ",", "\"\<Average50Day\>\"", ",", 
     "\"\<AverageVolume3Month\>\"", ",", "\"\<Change200Day\>\"", ",", 
     "\"\<Change50Day\>\"", ",", "\"\<ChangeHigh52Week\>\"", ",", 
     "\"\<ChangeLow52Week\>\"", ",", "\"\<CumulativeFractionalChange\>\"", 
     ",", "\"\<CumulativeReturn\>\"", ",", "\"\<FractionalChange\>\"", ",", 
     "\"\<FractionalChange200Day\>\"", ",", "\"\<FractionalChange50Day\>\"", 
     ",", "\"\<FractionalChangeHigh52Week\>\"", ",", 
     "\"\<FractionalChangeLow52Week\>\"", ",", "\"\<Volatility20Day\>\"", 
     ",", "\"\<Volatility50Day\>\"", ",", "\"\<High52Week\>\"", ",", 
     "\"\<Low52Week\>\"", ",", "\"\<Range52Week\>\""}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"DailyPriceProperties", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Change\>\"", ",", "\"\<Close\>\"", ",", "\"\<FractionalChange\>\"", 
     ",", "\"\<High\>\"", ",", "\"\<Low\>\"", ",", "\"\<Open\>\"", ",", 
     "\"\<OHLC\>\"", ",", "\"\<OHLCV\>\"", ",", "\"\<Range\>\"", ",", 
     "\"\<Return\>\"", ",", "\"\<Volume\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RecentPriceProperties", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Bid\>\"", ",", "\"\<Ask\>\"", ",", "\"\<LatestTrade\>\"", ",", 
     "\"\<Price\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RawDailyPriceProperties", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<RawClose\>\"", ",", "\"\<RawHigh\>\"", ",", "\"\<RawLow\>\"", ",", 
     "\"\<RawOHLC\>\"", ",", "\"\<RawOpen\>\"", ",", "\"\<RawRange\>\""}], 
    "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Fundamentals", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<BookValuePerShare\>\"", ",", "\"\<FloatShares\>\"", ",", 
     "\"\<ForwardPERatio\>\"", ",", "\"\<MarketCap\>\"", ",", 
     "\"\<PEGRatio\>\"", ",", "\"\<PriceTarget\>\"", ",", 
     "\"\<PriceToBookRatio\>\"", ",", "\"\<PriceToSalesRatio\>\"", ",", 
     "\"\<ShortRatio\>\"", ",", "\"\<YearPERatioEstimate\>\""}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Earnings", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<EarningsPerShare\>\"", ",", "\"\<EBITDA\>\"", ",", 
     "\"\<ForwardEarnings\>\"", ",", "\"\<QuarterForwardEarnings\>\"", ",", 
     "\"\<YearEarningsEstimate\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "financialDataProperties", "]"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "financialDataProperties", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Properties\>\"", "\[Rule]", "All"}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "\"\<Dividends\>\"", ",", "\"\<LongTermTrends\>\"", ",", 
      "\"\<DailyPriceProperties\>\"", ",", "\"\<RecentPriceProperties\>\"", 
      ",", "\"\<RawDailyPriceProperties\>\"", ",", "\"\<Fundamentals\>\"", 
      ",", "\"\<Earnings\>\""}], " ", "*)"}], "}"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"financialDataProperties", "[", 
   RowBox[{"name_String", ",", 
    RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"optVal", "=", 
       RowBox[{"OptionValue", "[", "\"\<Properties\>\"", "]"}]}], ",", 
      "props", ",", "heading", ",", "cases"}], "}"}], ",", 
    RowBox[{
     RowBox[{"props", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{"optVal", ",", "All", ",", 
        RowBox[{"FinancialData", "[", 
         RowBox[{"name", ",", "\"\<Properties\>\""}], "]"}], ",", 
        "\"\<Dividends\>\"", ",", "Dividends", ",", "\"\<LongTermTrends\>\"", 
        ",", "LongTermTrends", ",", "\"\<DailyPriceProperties\>\"", ",", 
        "DailyPriceProperties", ",", "\"\<RecentPriceProperties\>\"", ",", 
        "RecentPriceProperties", ",", "\"\<RawDailyPriceProperties\>\"", ",", 
        "RawDailyPriceProperties", ",", "\"\<Fundamentals\>\"", ",", 
        "Fundamentals", ",", "\"\<Earnings\>\"", ",", "Earnings", ",", "_", 
        ",", 
        RowBox[{"FinancialData", "[", 
         RowBox[{"name", ",", "\"\<Properties\>\""}], "]"}]}], "]"}]}], ";", 
     RowBox[{"heading", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{
       "optVal", ",", "All", ",", "\"\<All Properties\>\"", ",", 
        "\"\<Dividends\>\"", ",", "\"\<Dividend Properties\>\"", ",", 
        "\"\<LongTermTrends\>\"", ",", "\"\<Long Term Trend Properties\>\"", 
        ",", "\"\<DailyPriceProperties\>\"", ",", 
        "\"\<Daily Price Properties\>\"", ",", 
        "\"\<RecentPriceProperties\>\"", ",", 
        "\"\<Recent Price Properties\>\"", ",", 
        "\"\<RawDailyPriceProperties\>\"", ",", 
        "\"\<Raw Daily Price Properties\>\"", ",", "\"\<Fundamentals\>\"", 
        ",", "\"\<Fundamental Properties\>\"", ",", "\"\<Earnings\>\"", ",", 
        "\"\<Earning Properties\>\"", ",", "_", ",", 
        "\"\<All Properties\>\""}], "]"}]}], ";", 
     RowBox[{"cases", "=", 
      RowBox[{"Cases", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"props", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"FinancialData", "[", 
              RowBox[{"name", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
            "props"}]}], "}"}], "]"}], ",", 
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"_", ",", 
            RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "}"}], 
          "|", 
          RowBox[{"{", 
           RowBox[{"_", ",", "_FinancialData"}], "}"}], "|", 
          RowBox[{"{", 
           RowBox[{"_", ",", 
            RowBox[{"{", 
             RowBox[{"_List", ",", "_"}], "}"}]}], "}"}]}], "]"}]}], "]"}]}], 
     ";", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Grid", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Transpose", " ", "/@", " ", 
            RowBox[{"Switch", "[", 
             RowBox[{"optVal", ",", "\"\<LongTermTrends\>\"", ",", 
              RowBox[{"Partition", "[", 
               RowBox[{"cases", ",", "3", ",", "3", ",", "1", ",", 
                RowBox[{"{", "}"}]}], "]"}], ",", "_", ",", 
              RowBox[{"Partition", "[", 
               RowBox[{"cases", ",", "4", ",", "4", ",", "1", ",", 
                RowBox[{"{", "}"}]}], "]"}]}], "]"}]}], ",", "1"}], "]"}], 
         ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Alignment", "\[Rule]", 
          RowBox[{"{", "Left", "}"}]}], ",", 
         RowBox[{"Background", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"None", ",", 
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Lighter", "[", 
                RowBox[{
                 RowBox[{"Blend", "[", 
                  RowBox[{"{", 
                   RowBox[{"Blue", ",", "Green"}], "}"}], "]"}], ",", ".8"}], 
                "]"}], ",", 
               RowBox[{"Lighter", "[", 
                RowBox[{"Yellow", ",", ".9"}], "]"}]}], "}"}], "}"}]}], 
           "}"}]}]}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"heading", "<>", "\"\< of \>\"", "<>", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"MatchQ", "[", 
             RowBox[{
              RowBox[{"FinancialData", "[", 
               RowBox[{"name", ",", "\"\<Name\>\""}], "]"}], ",", 
              RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "]"}], 
            ",", "name", ",", 
            RowBox[{"FinancialData", "[", 
             RowBox[{"name", ",", "\"\<Name\>\""}], "]"}]}], "]"}]}], ",", 
         RowBox[{"FontColor", "\[Rule]", "Blue"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",",
        "Top"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5838509689830904`*^9, 3.583850993063468*^9}, 
   3.5838512554654765`*^9, {3.5838520716441593`*^9, 3.583852072916232*^9}, {
   3.5838521624123507`*^9, 3.5838521967323136`*^9}, {3.583852299133171*^9, 
   3.5838523065885973`*^9}, {3.5838523373253555`*^9, 
   3.5838523495980573`*^9}, {3.583852383981024*^9, 3.583852401149006*^9}, {
   3.5838524827976756`*^9, 3.583852494798362*^9}, {3.5838526947848005`*^9, 
   3.5838526963358893`*^9}, {3.5838528147526627`*^9, 
   3.5838528517447786`*^9}, {3.5838550212408667`*^9, 3.583855026153147*^9}, {
   3.5838550602170954`*^9, 3.583855109002886*^9}, {3.583868635378916*^9, 
   3.5838686644189568`*^9}, {3.5838687659490986`*^9, 3.5838687747491107`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SimpleMovingAverage", "[", 
     RowBox[{"list_", ",", "n_Integer"}], "]"}], "/;", 
    RowBox[{"(", 
     RowBox[{"n", "<=", " ", 
      RowBox[{"Length", "[", "list", "]"}]}], ")"}]}], ":=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Mean", " ", "/@", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Take", "[", 
         RowBox[{"list", ",", "k"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"MovingAverage", "[", 
      RowBox[{"list", ",", "n"}], "]"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TrendLinesDateListPlot", "[", 
   RowBox[{
   "tickSymbol_String", ",", "proportions_List", ",", "dateRange_List"}], 
   "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"data", "=", 
       RowBox[{"FinancialData", "[", 
        RowBox[{"tickSymbol", ",", "\"\<Close\>\"", ",", "dateRange"}], 
        "]"}]}], ",", 
      RowBox[{"props", "=", "proportions"}], ",", "trdata", ",", "datarange", 
      ",", "x", ",", "lmfns", ",", "lmdata", ",", "titles"}], "}"}], ",", 
    RowBox[{
     RowBox[{"trdata", "=", 
      RowBox[{"Transpose", "[", "data", "]"}]}], ";", 
     RowBox[{"datarange", "=", 
      RowBox[{"Outer", "[", 
       RowBox[{"Times", ",", 
        RowBox[{"Sort", "[", "props", "]"}], ",", 
        RowBox[{"trdata", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";", 
     RowBox[{"lmfns", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"LinearModelFit", "[", 
         RowBox[{"#", ",", "x", ",", "x"}], "]"}], "&"}], " ", "/@", " ", 
       "datarange"}]}], ";", 
     RowBox[{"lmdata", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"Length", "[", "data", "]"}], ",", "1"}], "]"}], 
              "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"lmfns", "[", 
               RowBox[{"[", "k", "]"}], "]"}], "[", 
              RowBox[{"Length", "[", "data", "]"}], "]"}]}], "}"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "[", "lmfns", "]"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"titles", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ToString", "[", "#", "]"}], "<>", "\"\< %\>\""}], "&"}], 
       " ", "/@", " ", 
       RowBox[{"Round", "[", 
        RowBox[{
         RowBox[{"Sort", "[", 
          RowBox[{"props", "-", "1"}], "]"}], " ", "100"}], "]"}]}]}], ";", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Framed", "[", 
        RowBox[{"DateListPlot", "[", 
         RowBox[{
          RowBox[{"Prepend", "[", 
           RowBox[{"lmdata", ",", "data"}], "]"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"Frame", "\[Rule]", "False"}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<dates\>\"", ",", "\"\<Prices\>\""}], "}"}]}], ",", 
          RowBox[{"Epilog", "\[RuleDelayed]", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{
               RowBox[{"titles", "[", 
                RowBox[{"[", "k", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"data", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"-", "2"}], ",", "1"}], "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"lmfns", "[", 
                   RowBox[{"[", "k", "]"}], "]"}], "[", 
                  RowBox[{"Length", "[", "data", "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1", ",", 
               RowBox[{"Length", "[", "lmfns", "]"}]}], "}"}]}], "]"}]}]}], 
         "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MatchQ", "[", 
           RowBox[{
            RowBox[{"FinancialData", "[", 
             RowBox[{"tickSymbol", ",", "\"\<Name\>\""}], "]"}], ",", 
            RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], "]"}], 
          ",", "tickSymbol", ",", 
          RowBox[{"FinancialData", "[", 
           RowBox[{"tickSymbol", ",", "\"\<Name\>\""}], "]"}]}], "]"}], "<>", 
        "\"\< with \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"Length", "[", "props", "]"}], "]"}], "<>", 
        "\"\< Trend Lines\>\""}], ",", "Top"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5402394418035975`*^9, 3.5402394524032035`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DailyRangeData", "[", 
   RowBox[{"dataName_String", ",", "numbDaysOfData_Integer"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "data", ",", "rangeData", ",", "dailyGroups", ",", "rangeLists", ",", 
      "days", ",", "name"}], "}"}], ",", 
    RowBox[{
     RowBox[{"data", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"dataName", ",", " ", "\"\<Range\>\"", ",", 
        RowBox[{"DatePlus", "[", 
         RowBox[{"-", "numbDaysOfData"}], "]"}]}], "]"}]}], ";", "\n", 
     RowBox[{"rangeData", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"Subtract", " ", "@@", " ", 
           RowBox[{"Reverse", "[", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "}"}], "&"}], " ", "/@",
        " ", "data"}]}], ";", "\n", 
     RowBox[{"dailyGroups", "=", 
      RowBox[{"GatherBy", "[", 
       RowBox[{"rangeData", ",", 
        RowBox[{
         RowBox[{"DayOfWeek", "[", 
          RowBox[{"First", "[", "#", "]"}], "]"}], "&"}]}], "]"}]}], ";", 
     "\n", 
     RowBox[{"rangeLists", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "&"}], ",", " ", "dailyGroups", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"days", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"DayOfWeek", "[", 
         RowBox[{"First", "[", "#", "]"}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"dailyGroups", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], ";", 
     RowBox[{"name", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"dataName", ",", "\"\<Name\>\""}], "]"}]}], ";", "\n", 
     RowBox[{"Row", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"BoxWhiskerChart", "[", 
         RowBox[{"rangeLists", ",", 
          RowBox[{"ChartLabels", "\[Rule]", "days"}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{
           "\"\<Box-Whisker plots for \>\"", "<>", "name", "<>", 
            "\"\< daily Ranges\>\""}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"350", ",", "200"}], "}"}]}]}], "]"}], ",", " ", 
        RowBox[{"TableForm", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Through", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
               "Length", ",", "Mean", ",", " ", "Median", ",", 
                "StandardDeviation"}], "}"}], "[", "#", "]"}], "]"}], "&"}], 
           " ", "/@", " ", "rangeLists"}], ",", " ", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"days", ",", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Number\>\"", ",", "Mean", ",", " ", "Median", ",", 
               "StandardDeviation"}], "}"}]}], "}"}]}]}], "]"}]}], "}"}], 
      "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"financialDataComparisons", "[", 
   RowBox[{
    RowBox[{"dataNames", ":", 
     RowBox[{"{", "__String", "}"}]}], ",", "numbDays_Integer"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dataArray1", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"#", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "numbDays"}], "]"}], ",", "\"\<Value\>\""}], "]"}], 
         "&"}], " ", "/@", " ", "dataNames"}]}], ",", 
      RowBox[{"returnArray1", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"#", ",", "\"\<Return\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "numbDays"}], "]"}], ",", "\"\<Value\>\""}], "]"}], 
         "&"}], " ", "/@", " ", "dataNames"}]}], ",", "dataPosns", ",", 
      "returnPosns", ",", "dataArray", ",", "returnArray", ",", "datanames", 
      ",", "stats", ",", "returnStats", ",", "trRetStats", ",", " ", 
      "histograms", ",", "rankedMeans", ",", "rankedSDs", ",", "tableStats", 
      ",", "ranktable", ",", "partNumb"}], "}"}], ",", 
    RowBox[{
     RowBox[{"dataPosns", "=", 
      RowBox[{"Position", "[", 
       RowBox[{"dataArray1", ",", 
        StyleBox[
         RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True]}], 
       StyleBox["]",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}], 
     StyleBox[";",
      ShowSpecialCharacters->False,
      ShowStringCharacters->True,
      NumberMarks->True], 
     RowBox[{"returnPosns", "=", 
      RowBox[{"Position", "[", 
       RowBox[{"returnArray1", ",", 
        StyleBox[
         RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True]}], 
       StyleBox["]",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}], 
     StyleBox[";",
      ShowSpecialCharacters->False,
      ShowStringCharacters->True,
      NumberMarks->True], 
     RowBox[{"dataArray", "=", 
      RowBox[{"Delete", "[", 
       RowBox[{"dataArray1", ",", "dataPosns"}], "]"}]}], ";", 
     RowBox[{"returnArray", "=", 
      RowBox[{"Delete", "[", 
       RowBox[{"returnArray1", ",", "returnPosns"}], "]"}]}], ";", 
     RowBox[{"datanames", "=", 
      RowBox[{"Delete", "[", 
       RowBox[{"dataNames", ",", "returnPosns"}], "]"}]}], ";", 
     RowBox[{"returnStats", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Mean", ",", " ", "StandardDeviation"}], "}"}], "[", "#", 
          "]"}], "]"}], "&"}], " ", "/@", " ", "returnArray"}]}], ";", 
     RowBox[{"stats", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Mean", ",", " ", "Median", ",", "StandardDeviation"}], 
           "}"}], "[", "#", "]"}], "]"}], "&"}], " ", "/@", " ", 
       "dataArray"}]}], ";", 
     RowBox[{"trRetStats", "=", 
      RowBox[{"Transpose", "[", "returnStats", "]"}]}], ";", 
     RowBox[{"partNumb", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "datanames", "]"}], "\[GreaterEqual]", "3"}], 
        ",", "3", ",", "2"}], "]"}]}], ";", 
     RowBox[{"tableStats", "=", 
      RowBox[{"TableForm", "[", 
       RowBox[{"stats", ",", 
        RowBox[{"TableHeadings", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"datanames", ",", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Mean\>\"", ",", " ", "\"\<Median\>\"", ",", 
             "\"\<StandardDeviation\>\""}], "}"}]}], "}"}]}]}], "]"}]}], ";", 
     RowBox[{"rankedMeans", "=", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Sort", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"trRetStats", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "datanames"}], "}"}], 
           "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#1", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ">", 
            RowBox[{"#2", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", 
     RowBox[{"rankedSDs", "=", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Sort", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"trRetStats", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "datanames"}], "}"}], 
           "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#1", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "<", 
            RowBox[{"#2", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", 
     RowBox[{"ranktable", "=", 
      RowBox[{"TableForm", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"rankedMeans", ",", "rankedSDs"}], "}"}], "]"}], ",", 
        RowBox[{"TableHeadings", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"None", ",", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Decr. Ranked \\nReturn Means\>\"", ",", " ", 
             "\"\<Incr. Ranked \\nReturn SDs\>\""}], "}"}]}], "}"}]}]}], 
       "]"}]}], ";", 
     RowBox[{"histograms", "=", 
      RowBox[{"GraphicsGrid", "[", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"MapThread", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Histogram", "[", 
              RowBox[{
              "#1", ",", "Automatic", ",", "\"\<ProbabilityDensity\>\"", ",", 
               RowBox[{"PlotLabel", "\[Rule]", 
                RowBox[{"\"\<Prob Density of \>\"", "<>", "#2"}]}]}], "]"}], 
             "&"}], ",", 
            RowBox[{"{", 
             RowBox[{"dataArray", ",", "datanames"}], "}"}]}], "]"}], ",", 
          "partNumb", ",", "partNumb", ",", "1", ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"800", ",", "570"}], "}"}]}]}], "]"}]}], ";", 
     RowBox[{"Column", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Row", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"tableStats", ",", "ranktable"}], "}"}], ",", 
           "\"\<        \>\""}], "]"}], ",", "histograms"}], "}"}], ",", 
       "\"\<      \>\""}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Signer", "[", "x_", "]"}], ":=", 
   RowBox[{"Which", "[", 
    RowBox[{
     RowBox[{"x", ">", "0"}], ",", "\"\<+\>\"", ",", 
     RowBox[{"x", "\[Equal]", "0"}], ",", "\"\< \>\"", ",", "True", ",", 
     "\"\<\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "FromFractionalChangeToPercentString", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<Sign\>\"", "\[Rule]", "True"}], ",", 
      RowBox[{"\"\<DecimalDigits\>\"", "\[Rule]", "2"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FromFractionalChangeToPercentString", "[", 
     RowBox[{"xx_", ",", 
      RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", "=", 
        RowBox[{"Chop", "@", "xx"}]}], "}"}], ",", 
      RowBox[{"StringJoin", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"OptionValue", "[", "\"\<Sign\>\"", "]"}], ",", 
          RowBox[{"Signer", "@", "x"}], ",", "\"\<\>\""}], "]"}], ",", 
        RowBox[{"ToString", "@", 
         RowBox[{"NumberForm", "[", 
          RowBox[{
           RowBox[{"100", " ", "x"}], ",", 
           RowBox[{"{", 
            RowBox[{"10", ",", 
             RowBox[{"OptionValue", "@", "\"\<DecimalDigits\>\""}]}], "}"}]}],
           "]"}]}], ",", "\"\<%\>\""}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DeltaGammaHedge", "[", 
    RowBox[{"type_", ",", "a_", ",", " ", "b_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tab", ",", "lower", ",", "upper", ",", 
       RowBox[{"price", "=", 
        RowBox[{"FinancialDerivative", "[", 
         RowBox[{"type", ",", " ", "a", ",", " ", "b", ",", "\"\<Value\>\""}],
          "]"}]}], ",", 
       RowBox[{"delta", "=", 
        RowBox[{"FinancialDerivative", "[", 
         RowBox[{"type", ",", " ", "a", ",", " ", "b", ",", "\"\<Delta\>\""}],
          "]"}]}], ",", 
       RowBox[{"gamma", "=", 
        RowBox[{"FinancialDerivative", "[", 
         RowBox[{"type", ",", " ", "a", ",", " ", "b", ",", "\"\<Gamma\>\""}],
          "]"}]}], ",", "myLinearApproximation", ",", 
       "myParabolicApproximation", ",", 
       RowBox[{"underlyingprice", "=", 
        RowBox[{"\"\<CurrentPrice\>\"", "/.", "b"}]}], ",", 
       RowBox[{"strikeprice", "=", 
        RowBox[{"\"\<StrikePrice\>\"", "/.", "a"}]}], ",", 
       RowBox[{"volatility", "=", 
        RowBox[{"\"\<Volatility\>\"", "/.", "b"}]}], ",", 
       RowBox[{"timetoexpiry", "=", 
        RowBox[{"\"\<Expiration\>\"", "/.", "a"}]}], ",", "underlyingrange"}],
       "}"}], ",", " ", "\n", 
     RowBox[{
      RowBox[{
       RowBox[{"myLinearApproximation", "[", "x_", "]"}], ":=", 
       RowBox[{"price", "+", 
        RowBox[{"delta", "*", 
         RowBox[{"(", 
          RowBox[{"x", "-", "underlyingprice"}], ")"}]}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"myParabolicApproximation", "[", "x_", "]"}], ":=", 
       RowBox[{"price", "+", 
        RowBox[{"delta", "*", 
         RowBox[{"(", 
          RowBox[{"x", "-", "underlyingprice"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"gamma", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "underlyingprice"}], ")"}], "^", "2"}]}], 
          ")"}], "/", "2"}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"underlyingrange", "[", "number_", "]"}], ":=", 
       RowBox[{"underlyingprice", "+", 
        RowBox[{"number", "*", "underlyingprice", "*", "volatility", "*", 
         RowBox[{"Sqrt", "[", "timetoexpiry", "]"}]}]}]}], ";", "\n", 
      RowBox[{"lower", "=", 
       RowBox[{"underlyingprice", "-", 
        RowBox[{"1.5", "*", "strikeprice", "*", "volatility", "*", 
         RowBox[{"Sqrt", "[", "timetoexpiry", "]"}]}]}]}], ";", "\n", 
      RowBox[{"upper", "=", 
       RowBox[{"underlyingprice", "+", 
        RowBox[{"1.5", "*", "strikeprice", "*", "volatility", "*", 
         RowBox[{"Sqrt", "[", "timetoexpiry", "]"}]}]}]}], ";", "\n", 
      RowBox[{"tab", "=", 
       RowBox[{"Transpose", "@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"val", ",", 
              RowBox[{"FinancialDerivative", "[", 
               RowBox[{"type", ",", " ", "a", ",", " ", 
                RowBox[{"b", "/.", 
                 RowBox[{
                  RowBox[{"_", "[", 
                   RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "_"}], "]"}], ":>", 
                  RowBox[{"Rule", "[", 
                   RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "val"}], 
                   "]"}]}]}], ",", "\"\<Value\>\""}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"val", ",", 
              RowBox[{"myLinearApproximation", "[", "val", "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"val", ",", 
              RowBox[{"myParabolicApproximation", "[", "val", "]"}]}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"val", ",", "lower", ",", "upper", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"upper", "-", "lower"}], ")"}], "/", "81"}]}], "}"}]}], 
         "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Column", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{"tab", ",", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<underlying price\>\"", ",", "\"\<value\>\"", ",", "None", 
              ",", "None"}], "}"}]}], ",", 
           RowBox[{"AxesOrigin", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"lower", ",", "0"}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"530", ",", "370"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"FontFamily", "\[Rule]", "\"\<Verdana\>\""}], ",", 
              RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"StringJoin", " ", "@", " ", "type"}], ")"}], "<>", 
             "\"\< \[Delta]-\[Gamma] Hedge\>\""}]}], " ", ",", " ", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Value\>\"", ",", " ", "\"\<Delta\>\"", ",", 
              "\"\<Delta-Gamma\>\""}], "}"}]}]}], "]"}], ",", " ", 
         RowBox[{"Spacer", "[", "20", "]"}], ",", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"t", "=", 
             RowBox[{"Module", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"pricemovements", "=", 
                  RowBox[{"(*", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "0.5"}], ",", "0.5", ",", "1"}], "}"}], 
                   "*)"}], 
                  RowBox[{"Select", "[", 
                   RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{
                    RowBox[{"-", "1.2"}], ",", "1.2", ",", ".2"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Chop", "[", "#", "]"}], "=!=", "1000"}], "&"}]}],
                    "]"}]}], ",", "ranges", ",", "truevalues"}], "}"}], ",", 
               RowBox[{
                RowBox[{"ranges", "=", 
                 RowBox[{"N", "[", 
                  RowBox[{"underlyingrange", "/@", "pricemovements"}], 
                  "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"truevalues", "=", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"FinancialDerivative", "[", 
                    RowBox[{"type", ",", " ", "a", ",", " ", 
                    RowBox[{"b", "/.", 
                    RowBox[{
                    RowBox[{"_", "[", 
                    RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "_"}], "]"}], ":>", 
                    RowBox[{"Rule", "[", 
                    RowBox[{"\"\<CurrentPrice\>\"", ",", " ", "#"}], 
                    "]"}]}]}], ",", "\"\<Value\>\""}], "]"}], "&"}], "/@", 
                  "ranges"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"Grid", "[", 
                 RowBox[{
                  RowBox[{"Join", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Thread", "[", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "\"\<price\>\"", ",", 
                    "\"\<shares short for \[Delta]-neutral\>\"", ",", 
                    "\"\<\[Delta]-neutral tracking error\>\"", ",", 
                    "\"\<\[Delta]-\[Gamma] shares short\>\"", ",", 
                    "\"\<\[Delta]-\[Gamma] tracking error\>\""}], "}"}], ",", 
                    " ", "Bold"}], "]"}], "]"}], "}"}], ",", 
                    RowBox[{"Transpose", "@", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"NumberForm", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"10", ",", "2"}], "}"}]}], "]"}], "&"}], ",", 
                    "ranges"}], "]"}], ",", 
                    RowBox[{"Array", "[", 
                    RowBox[{
                    RowBox[{"delta", "&"}], ",", 
                    RowBox[{"Length", "@", "ranges"}]}], "]"}], ",", 
                    RowBox[{"Map", "[", 
                    RowBox[{"FromFractionalChangeToPercentString", ",", 
                    RowBox[{
                    RowBox[{"1", "/", "price"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"delta", " ", 
                    RowBox[{"(", 
                    RowBox[{"ranges", "-", "underlyingprice"}], ")"}]}], "-", 
                    RowBox[{"(", 
                    RowBox[{"truevalues", "-", "price"}], ")"}]}], ")"}]}]}], 
                    "]"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"delta", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}], " ", "gamma", " ", 
                    RowBox[{"(", 
                    RowBox[{"#", "-", "underlyingprice"}], ")"}]}]}], ")"}], 
                    "&"}], ",", "ranges"}], "]"}], ",", 
                    RowBox[{"Map", "[", 
                    RowBox[{"FromFractionalChangeToPercentString", ",", 
                    RowBox[{
                    RowBox[{"1", "/", "price"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"delta", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "/", "2"}], ")"}], " ", "gamma", " ", 
                    RowBox[{"(", 
                    RowBox[{"#", "-", "underlyingprice"}], ")"}]}]}], ")"}], 
                    "&"}], ",", "ranges"}], "]"}], 
                    RowBox[{"(*", 
                    RowBox[{
                    RowBox[{
                    "the", " ", "preceding", " ", "is", " ", "the", " ", 
                    "quantity", " ", "of", " ", "shares", " ", "per", " ", 
                    "option", " ", "contract", " ", "to", " ", "obtain", " ", 
                    "a", " ", "delta"}], "-", 
                    RowBox[{"gamma", " ", "hedged", " ", "portfolio"}]}], 
                    "*)"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"ranges", "-", "underlyingprice"}], ")"}]}], "-", 
                    RowBox[{"(", 
                    RowBox[{"truevalues", "-", "price"}], ")"}]}], ")"}]}]}], 
                    "]"}]}], "}"}]}]}], "]"}], ",", " ", 
                  RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]}]}], "]"}]}], 
            "}"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"FreeQ", "[", 
              RowBox[{"t", ",", "Indeterminate", ",", "Infinity"}], "]"}], 
             ",", "t", ",", "$Failed"}], "]"}]}], "]"}]}], "}"}], "]"}]}]}], 
    "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.5837831496415677`*^9, {3.591408245606044*^9, 3.591408246417245*^9}, {
   3.591408405663325*^9, 3.5914084130421376`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PFEBackTest", "[", 
    RowBox[{"OHLCVData_List", ",", "a_", ",", "b_"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "OHLCVData", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ")"}]}], ":=", 
  RowBox[{
   RowBox[{"Charting`BackTesting", "[", 
    RowBox[{"OHLCVData", ",", " ", "\"\<PFE\>\"", ",", 
     RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b"}], "}"}]}], ",", " ", 
     RowBox[{"\"\<Threshold\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"15", ",", "0.8", ",", "25", ",", 
        RowBox[{"-", "15"}]}], "}"}]}], ",", 
     RowBox[{"\"\<StopLoss\>\"", "\[Rule]", "0.1"}], ",", 
     RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", " ", 
     RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
     RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "50000"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "9", ",", "1", ",", "1", ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.499626226271566*^9, 3.499626299845377*^9}, {
   3.49962705281682*^9, 3.499627067597726*^9}, 3.5354823483060827`*^9, {
   3.5355552977200193`*^9, 3.5355553027910194`*^9}, {3.5355722056660194`*^9, 
   3.5355722059700193`*^9}, {3.5379954165271034`*^9, 3.537995421345585*^9}, {
   3.5379955401244617`*^9, 3.53799555510896*^9}, {3.5379956793482137`*^9, 
   3.5379957071882133`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MACDBackTest", "[", 
    RowBox[{"OHLCVData_List", ",", "s_", ",", "l_"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "OHLCVData", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ")"}]}], ":=", " ", 
  RowBox[{
   RowBox[{"Charting`BackTesting", "[", 
    RowBox[{"OHLCVData", ",", " ", "\"\<MACD\>\"", ",", 
     RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"s", ",", "l"}], "}"}]}], ",", " ", 
     RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", " ", 
     RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
     RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "50000"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "9", ",", "1", ",", "1", ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.499627088795846*^9, 3.499627120689699*^9}, 
   3.499627165482944*^9, {3.4996286297210293`*^9, 3.499628632824604*^9}, {
   3.49962874635847*^9, 3.499628776738965*^9}, 3.53548233387464*^9, {
   3.5355554366390195`*^9, 3.5355554405430193`*^9}, {3.5355723275310197`*^9, 
   3.5355723279300194`*^9}, {3.5379954278062305`*^9, 3.537995433015752*^9}, {
   3.5379955605305023`*^9, 3.537995563757825*^9}, 3.5379957356952133`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"LRSBackTest", "[", 
    RowBox[{"OHLCVData_List", ",", "a_", ",", "b_"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Dimensions", "[", "OHLCVData", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ")"}]}], ":=", " ", 
  RowBox[{
   RowBox[{"Charting`BackTesting", "[", 
    RowBox[{"OHLCVData", ",", " ", "\"\<LRS\>\"", ",", 
     RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", "a"}], ",", " ", 
     RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
     RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
     RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "b"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "9", ",", "1", ",", "1", ",", "2"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.499627088795846*^9, 3.499627120689699*^9}, 
   3.499627165482944*^9, {3.4996286297210293`*^9, 3.499628632824604*^9}, {
   3.49962874635847*^9, 3.499628776738965*^9}, 3.53548233387464*^9, {
   3.5355554366390195`*^9, 3.5355554405430193`*^9}, {3.53555571990302*^9, 
   3.5355557207350197`*^9}, {3.53555579562702*^9, 3.5355558062980194`*^9}, {
   3.5355559032370195`*^9, 3.5355559228520193`*^9}, {3.5379954416226125`*^9, 
   3.537995445036954*^9}, {3.5379955673241816`*^9, 3.537995570242473*^9}, 
   3.5379957422292137`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Data", "Section",
 CellChangeTimes->{{3.520786469854125*^9, 3.52078648436975*^9}, {
  3.52121936621875*^9, 3.521219370578125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"stocksUS", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<AAPL\>\"", ",", "\"\<GOOG\>\"", ",", "\"\<CTSH\>\"", ",", 
     "\"\<GRMN\>\"", ",", "\"\<AMZN\>\"", ",", "\"\<DLB\>\"", ",", 
     "\"\<COH\>\"", ",", "\"\<INFY\>\"", ",", "\"\<DECK\>\"", ",", 
     "\"\<BIDU\>\"", ",", "\"\<SYK\>\"", ",", "\"\<NVDA\>\"", ",", 
     "\"\<EBIX\>\"", ",", "\"\<DV\>\"", ",", "\"\<FCX\>\"", ",", 
     "\"\<AFAM\>\"", ",", "\"\<GILD\>\"", ",", "\"\<FSLR\>\"", ",", 
     "\"\<MIDD\>\"", ",", "\"\<ORCL\>\"", ",", "\"\<QSII\>\"", ",", 
     "\"\<MSFT\>\"", ",", "\"\<NFLX\>\"", ",", "\"\<WDC\>\"", ",", 
     "\"\<LULU\>\"", ",", "\"\<PG\>\"", ",", "\"\<ARO\>\"", ",", 
     "\"\<GE\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.539714494578482*^9, {3.5796246127315426`*^9, 3.57962462265316*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"stocksForeign", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<F:UTDI\>\"", ",", "\"\<F:S92\>\"", ",", "\"\<TSX:RIM\>\"", ",", 
     "\"\<F:SWV\>\"", ",", "\"\<F:NDA\>\"", ",", "\"\<F:SZG\>\"", ",", 
     "\"\<F:SDF\>\"", ",", "\"\<F:MAN\>\"", ",", "\"\<F:DBK\>\"", ",", 
     "\"\<F:DAI\>\"", ",", "\"\<ASX:WOW\>\"", ",", "\"\<F:VIA\>\"", ",", 
     "\"\<F:APC\>\"", ",", "\"\<F:BMW\>\"", ",", "\"\<F:ALV\>\"", ",", 
     "\"\<F:SAP\>\"", ",", "\"\<F:SIE\>\"", ",", "\"\<F:WDI\>\"", ",", 
     "\"\<F:CBK\>\"", ",", "\"\<F:IFX\>\"", ",", "\"\<ASX:BHP\>\"", ",", 
     "\"\<F:DB1\>\"", ",", "\"\<F:BAS\>\"", ",", "\"\<F:LHA\>\"", ",", 
     "\"\<F:ADS\>\"", ",", "\"\<F:EOAN\>\"", ",", "\"\<F:MUV2\>\"", ",", 
     "\"\<TSX:POT\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.539618721102978*^9, 3.579624647036003*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"indices", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<^AORD\>\"", ",", "\"\<^ATX\>\"", ",", "\"\<^SSEC\>\"", ",", 
     "\"\<^HSI\>\"", ",", "\"\<^N225\>\"", ",", "\"\<^BFX\>\"", ",", 
     "\"\<^BSESN\>\"", ",", "\"\<^FCHI\>\"", ",", "\"\<^BXD\>\"", ",", 
     "\"\<^BXM\>\"", ",", "\"\<^VIX\>\"", ",", "\"\<^VXN\>\"", ",", 
     "\"\<FTSE100\>\"", ",", "\"\<FTSE250\>\"", ",", "\"\<FTSE350\>\"", ",", 
     "\"\<^DJI\>\"", ",", "\"\<SP100\>\"", ",", "\"\<SP400\>\"", ",", 
     "\"\<SP500\>\"", ",", "\"\<SP600\>\"", ",", "\"\<^SSMI\>\"", ",", 
     "\"\<^OSEAX\>\"", ",", "\"\<^GDAXI\>\"", ",", "\"\<^OMXSPI\>\"", ",", 
     "\"\<^KLSE\>\"", ",", "\"\<^NZ50\>\"", ",", "\"\<^KS11\>\"", ",", 
     "\"\<^JKSE\>\"", ",", "\"\<^MXX\>\"", ",", "\"\<^MERV\>\"", ",", 
     "\"\<^BVSP\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.546793950903283*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Feedback", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583840256114871*^9, 3.5838402579229746`*^9}}],

Cell["\<\
Required: Interactivity - Manipulate. What\[CloseCurlyQuote]s special? Pitch \
at top of Examples, Captions explaining material. \
\>", "Text",
 CellChangeTimes->{{3.583840303635589*^9, 3.583840325907863*^9}, {
  3.5838405268843584`*^9, 3.583840534900817*^9}, {3.5838419558180885`*^9, 
  3.583841961034387*^9}, {3.583874610463281*^9, 3.5838746111832824`*^9}, {
  3.5841544143965464`*^9, 3.5841544374208636`*^9}, {3.5841545720455637`*^9, 
  3.5841545822211456`*^9}}],

Cell["\<\
Focal points:

1)      What is the _added_ value we offer that others don\[CloseCurlyQuote]t \
in the market

2)      Brief captions and not descriptions

3)      Why we are better\
\>", "Text",
 CellChangeTimes->{
  3.5838442803425217`*^9, {3.5841544436292186`*^9, 3.5841544510686445`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 1: Properties of Stocks\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}}],

Cell[CellGroupData[{

Cell["Template Structure", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5841543458306246`*^9, 3.5841543843868303`*^9}}],

Cell["\<\
Template Groups -> { \[OpenCurlyDoubleQuote]Stocks\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]Properties\[CloseCurlyDoubleQuote] }, Template \
Variables -> { \[OpenCurlyDoubleQuote]Stock\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]Property\[CloseCurlyDoubleQuote],\
\[OpenCurlyDoubleQuote]Dividends\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]LongTermTrends\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]DailyPriceProperties\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]RecentPriceProperties\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]RawDailyPriceProperties\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]Fundamentals\[CloseCurlyDoubleQuote],\
\[CloseCurlyDoubleQuote]Earnings\[CloseCurlyDoubleQuote] }, 
EvaluateExpression -> financialDataProperties[\"Stock\", \"Properties\" -> \
\"Property\"]\
\>", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5837838408451023`*^9, 3.5837838762531276`*^9}, {
   3.583784035710248*^9, 3.583784057405489*^9}, 3.5837842152965193`*^9, {
   3.5837843077438073`*^9, 3.5837843109439907`*^9}, 3.5838044148538685`*^9, 
   3.5841543843868303`*^9}]
}, Closed]],

Cell["\<\
1)  Added Value: the WFP makes it possible to collect all the relevant data \
about companies in one place with one simple command.

2)  Caption: Every company has a wide range of financial data associated with \
it, which makes it difficult to collate and present meaningfully. Merely by \
specifying the list of companies that one is interested in, it is possible \
with the Wolfram Finance Platform to automatically generate tables and graphs \
which parse and display the data.

3)  Why we are better: Ease of use and comprehensiveness of financial data \
especially if one uses BloombergLink.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, 3.5841545102050266`*^9}],

Cell[CellGroupData[{

Cell["Company : General Electric", "Subsection",
 CellChangeTimes->{{3.5838031777391095`*^9, 3.583803197017212*^9}, {
  3.583804300438324*^9, 3.5838043052696004`*^9}}],

Cell[CellGroupData[{

Cell["Properties", "Subsubsection",
 CellChangeTimes->{{3.583803357362383*^9, 3.583803359682516*^9}}],

Cell[BoxData[
 RowBox[{"Column", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"financialDataProperties", "[", 
      RowBox[{"\"\<GE\>\"", ",", 
       RowBox[{"\"\<Properties\>\"", "\[Rule]", "#"}]}], "]"}], "&"}], " ", "/@",
     " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<DailyPriceProperties\>\"", ",", "\"\<LongTermTrends\>\"", ",", 
      "\"\<Fundamentals\>\"", ",", "\"\<Earnings\>\"", ",", 
      "\"\<RawDailyPriceProperties\>\"", ",", "\"\<Dividends\>\""}], "}"}]}], 
   ",", 
   RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5838504909127464`*^9, 3.5838505205664425`*^9}, {
  3.5838505599536953`*^9, 3.5838506095705333`*^9}, {3.583851086164793*^9, 
  3.5838511857134867`*^9}, {3.5838683602985306`*^9, 3.5838683646885366`*^9}, {
  3.5838686887189903`*^9, 3.583868691768995*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphs", "Subsubsection",
 CellChangeTimes->{{3.5838034744190784`*^9, 3.5838034756341476`*^9}}],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<GE\>\"", ",", "\"\<High\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", "\"\< \>\"", ",", "\"\<High\>\""}], 
            "}"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<GE\>\"", ",", "\"\<Low\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", "\"\< \>\"", ",", "\"\<Low\>\""}], 
            "}"}], "]"}]}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<GE\>\"", ",", "\"\<Close\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", "\"\< \>\"", ",", "\"\<Close\>\""}], 
            "}"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<GE\>\"", ",", "\"\<Return\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", "\"\< \>\"", ",", "\"\<Return\>\""}], 
            "}"}], "]"}]}]}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"700", ",", "440"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5838034901159763`*^9, 3.5838035144683695`*^9}, {
  3.583803716564928*^9, 3.583803790279145*^9}, {3.58380385821603*^9, 
  3.5838038670645366`*^9}, {3.5838039376875763`*^9, 3.5838039403277273`*^9}, {
  3.583803993608774*^9, 3.5838039959119062`*^9}, {3.5838041096094093`*^9, 
  3.583804138680072*^9}, {3.5838041699128585`*^9, 3.5838042027607374`*^9}, {
  3.583817205234436*^9, 3.583817212066827*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Company : Microsoft", "Subsection",
 CellChangeTimes->{{3.5838031777391095`*^9, 3.583803197017212*^9}, {
  3.5838042920858464`*^9, 3.5838043122299986`*^9}}],

Cell[CellGroupData[{

Cell["Properties", "Subsubsection",
 CellChangeTimes->{{3.583803357362383*^9, 3.583803359682516*^9}}],

Cell[BoxData[
 RowBox[{"Column", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"financialDataProperties", "[", 
      RowBox[{"\"\<MSFT\>\"", ",", 
       RowBox[{"\"\<Properties\>\"", "\[Rule]", "#"}]}], "]"}], "&"}], " ", "/@",
     " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<DailyPriceProperties\>\"", ",", "\"\<LongTermTrends\>\"", ",", 
      "\"\<Fundamentals\>\"", ",", "\"\<Earnings\>\"", ",", 
      "\"\<RawDailyPriceProperties\>\"", ",", "\"\<Dividends\>\""}], "}"}]}], 
   ",", 
   RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5838504909127464`*^9, 3.5838505205664425`*^9}, {
   3.5838505599536953`*^9, 3.5838506095705333`*^9}, {3.583851086164793*^9, 
   3.5838511857134867`*^9}, {3.5838683602985306`*^9, 
   3.5838683646885366`*^9}, {3.5838686887189903`*^9, 3.583868691768995*^9}, {
   3.583868849869216*^9, 3.5838688521392193`*^9}, 3.5838690544795027`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphs", "Subsubsection",
 CellChangeTimes->{{3.5838034744190784`*^9, 3.5838034756341476`*^9}}],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<MSFT\>\"", ",", "\"\<High\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", "\"\< \>\"", ",", "\"\<High\>\""}], 
            "}"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<MSFT\>\"", ",", "\"\<Low\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", "\"\< \>\"", ",", "\"\<Low\>\""}], 
            "}"}], "]"}]}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<MSFT\>\"", ",", "\"\<Close\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", "\"\< \>\"", ",", "\"\<Close\>\""}], 
            "}"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"DateListPlot", "[", 
        RowBox[{
         RowBox[{"FinancialData", "[", 
          RowBox[{"\"\<MSFT\>\"", ",", "\"\<Return\>\"", ",", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "360"}], "]"}]}], "]"}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", "\"\< \>\"", ",", "\"\<Return\>\""}],
             "}"}], "]"}]}]}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"700", ",", "440"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5838034901159763`*^9, 3.5838035144683695`*^9}, {
  3.583803716564928*^9, 3.583803790279145*^9}, {3.58380385821603*^9, 
  3.5838038670645366`*^9}, {3.5838039376875763`*^9, 3.5838039403277273`*^9}, {
  3.583803993608774*^9, 3.5838039959119062`*^9}, {3.5838041096094093`*^9, 
  3.583804138680072*^9}, {3.5838041699128585`*^9, 3.5838042027607374`*^9}, {
  3.583804355752488*^9, 3.5838043600807357`*^9}, {3.583817232017968*^9, 
  3.5838172362902126`*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: Ranking of Stocks", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}}],

Cell["\<\
1)  Added Value: Unlike other finance programs, the WFP has advanced \
statistical tools like distribution estimation that makes it possible to \
determine the probability density of any stock\[CloseCurlyQuote]s historical \
data.

2)  Caption: One of the most important criteria in the selection of stocks \
for a portfolio is a ranking system that allows one to see at a glance which \
stocks are better than others in terms of higher returns and lower \
volatilities. In addition one can use the WFP\[CloseCurlyQuote]s \
sophisticated statistical techniques to calculate the probability density of \
any stock from its historical data which reveals its structure.

3)  Why we are better: Rapid parallel calculation of PDFs and ranking \
criteria from easily accessible data.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Ranking of Stocks by Returns and Volatilities with corresponding PDFs\
\>", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}}],

Cell[CellGroupData[{

Cell["Stocks to be Analyzed", "Subsubsection",
 CellChangeTimes->{{3.583804972793781*^9, 3.5838049820253086`*^9}}],

Cell[BoxData[
 RowBox[{"Framed", "[", 
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"FinancialData", "[", 
       RowBox[{"#", ",", "\"\<Name\>\""}], "]"}], "&"}], " ", "/@", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<SP100\>\"", ",", "\"\<SP500\>\"", ",", "\"\<^DJI\>\"", ",", 
       "\"\<SPY\>\"", ",", "\"\<^N225\>\"", ",", "\"\<FTSE100\>\"", ",", 
       "\"\<GE\>\""}], "}"}]}], ",", 
    RowBox[{"TableDirections", "\[Rule]", "Row"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.583804707444604*^9, 3.5838047239615483`*^9}, {
  3.583805005530653*^9, 3.583805010682948*^9}, {3.583805084603176*^9, 
  3.583805094794759*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Statistics, Ranks and Probability Densities\
\>", "Subsubsection",
 CellChangeTimes->{{3.583804972793781*^9, 3.5838049820253086`*^9}, {
  3.5838051408423924`*^9, 3.5838051549862013`*^9}, {3.5838145849315634`*^9, 
  3.583814585603602*^9}}],

Cell[BoxData[
 RowBox[{"financialDataComparisons", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<SP100\>\"", ",", "\"\<SP500\>\"", ",", "\"\<^DJI\>\"", ",", 
     "\"\<SPY\>\"", ",", "\"\<^N225\>\"", ",", "\"\<FTSE100\>\"", ",", 
     "\"\<GE\>\""}], "}"}], ",", "365"}], "]"}]], "Input",
 CellChangeTimes->{{3.520025262367125*^9, 3.520025268304625*^9}, {
  3.5200280382265*^9, 3.52002803844525*^9}, {3.520030385664*^9, 
  3.5200303861015*^9}, {3.5200313647265*^9, 3.5200313663515*^9}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example 3: Daily Ranges and Trend Lines for Stocks\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}}],

Cell["\<\
1)  Added Value: Quick graphical representation of daily price ranges and \
future trend lines.

2)  Caption: For the purposes of trading it is often necessary to identify \
the pattern of daily price behavior which will help organize the trading \
along more profitable strategies. For instance the daily price ranges below \
suggest that it is best to sell around the high levels on Friday and buy at \
the lower levels on  Monday. Long term trading strategies however need to \
track the price changes that indicate percentage variability away from the \
mean behavior.  

3)  Why we are better: Tooltip Box-Whisker plots and superimposed labeled \
regression lines are easy to calculate as well as informative about the \
behavior of a stock at a glance.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}}],

Cell[CellGroupData[{

Cell["Comany: General Electric", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9}],

Cell["\<\
Point: Intra-day behaviour, Required: Easier with M than other programs\
\>", "Text",
 CellChangeTimes->{{3.5838406126282625`*^9, 3.583840661253044*^9}, 
   3.5838409967742343`*^9, {3.5838410424388466`*^9, 3.583841061622944*^9}, {
   3.5838413737517967`*^9, 3.583841397784171*^9}}],

Cell[CellGroupData[{

Cell["Daily Range", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}}],

Cell[BoxData[
 RowBox[{"DailyRangeData", "[", 
  RowBox[{"\"\<GE\>\"", ",", "365"}], "]"}]], "Input",
 CellChangeTimes->{{3.5838053652432275`*^9, 3.583805372795659*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trend Lines", "Subsubsection",
 CellChangeTimes->{{3.5838054368433228`*^9, 3.5838054399314995`*^9}}],

Cell[BoxData[
 RowBox[{"TrendLinesDateListPlot", "[", 
  RowBox[{"\"\<GE\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
    "0.87", ",", "0.9", ",", "0.95", ",", "0.98", ",", "1.0", ",", "1.02", 
     ",", "1.05"}], "}"}], ",", 
   RowBox[{"DatePlus", "[", 
    RowBox[{"-", "60"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.519749287906933*^9, 3.519749346344533*^9}, {
  3.5218488029698763`*^9, 3.521848853752781*^9}, {3.5402189332456064`*^9, 
  3.5402189598571286`*^9}, {3.5838053552276545`*^9, 3.5838053555956755`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comany: Microsoft", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
  3.5838053417868857`*^9, 3.583805349706339*^9}, {3.5838054808598404`*^9, 
  3.5838054829869623`*^9}}],

Cell[CellGroupData[{

Cell["Daily Range", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}}],

Cell[BoxData[
 RowBox[{"DailyRangeData", "[", 
  RowBox[{"\"\<MSFT\>\"", ",", "365"}], "]"}]], "Input",
 CellChangeTimes->{{3.5838053652432275`*^9, 3.583805372795659*^9}, {
  3.583805491149429*^9, 3.5838054935165644`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trend Lines", "Subsubsection",
 CellChangeTimes->{{3.5838054368433228`*^9, 3.5838054399314995`*^9}}],

Cell[BoxData[
 RowBox[{"TrendLinesDateListPlot", "[", 
  RowBox[{"\"\<MSFT\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
    "0.87", ",", "0.9", ",", "0.95", ",", "0.98", ",", "1.0", ",", "1.02", 
     ",", "1.05"}], "}"}], ",", 
   RowBox[{"DatePlus", "[", 
    RowBox[{"-", "60"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.519749287906933*^9, 3.519749346344533*^9}, {
  3.5218488029698763`*^9, 3.521848853752781*^9}, {3.5402189332456064`*^9, 
  3.5402189598571286`*^9}, {3.5838053552276545`*^9, 3.5838053555956755`*^9}, {
  3.583805499228891*^9, 3.583805500396958*^9}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example 4: Candlestick and Trend Charts for Stocks\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}, {3.583805545995566*^9, 
  3.583805546363587*^9}, {3.5838068151691585`*^9, 3.583806822049552*^9}}],

Cell["\<\
1)  Added Value: A grid of popular price change plots that provide a number \
of different ways of viewing the persistence of trends in data by the use of \
reversal thresholds.

2)  Caption: A table of popular financial charts that are designed to show \
trends in the data and to indicate when thershold reversals occur. These \
structures are important because the pivot points suggest buy/sell \
possibilities for trading. 

3)  Why we are better: Not only do we have these popular price charts but we \
also include the added flexibility of changing the threshold reversal level.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}, {
   3.5841523050128965`*^9, 3.584152336611704*^9}, {3.5841524176203375`*^9, 
   3.584152584884905*^9}}],

Cell[CellGroupData[{

Cell["Candlestick and Trend Charts", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9, 
   3.5838068609627776`*^9}],

Cell[CellGroupData[{

Cell["Comany: General Electric", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9}],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"SameQ", "[", 
          RowBox[{"fChart", ",", "CandlestickChart"}], "]"}], ",", 
         RowBox[{"fChart", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", 
             RowBox[{"DatePlus", "[", 
              RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"fChart", ",", "\"\< of \>\"", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MatchQ", "[", 
                  RowBox[{
                   RowBox[{"FinancialData", "[", 
                    RowBox[{"\"\<GE\>\"", ",", "\"\<Name\>\""}], "]"}], ",", 
                   RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], 
                  "]"}], ",", "\"\<GE\>\"", ",", 
                 RowBox[{"FinancialData", "[", 
                  RowBox[{"\"\<GE\>\"", ",", "\"\<Name\>\""}], "]"}]}], "]"}],
                ",", " ", "\"\< for last \>\"", ",", "365", ",", 
               "\"\< days\>\""}], " ", "}"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"fChart", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<GE\>\"", ",", 
             RowBox[{"DatePlus", "[", 
              RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
           RowBox[{"Switch", "[", 
            RowBox[{
            "fChart", ",", "KagiChart", ",", "0.02", ",", "RenkoChart", ",", 
             "0.1", ",", "LineBreakChart", ",", "3", ",", "PointFigureChart", 
             ",", "0.03", ",", "CandlestickChart", ",", "0.02"}], "]"}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"fChart", ",", "\"\< of \>\"", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MatchQ", "[", 
                  RowBox[{
                   RowBox[{"FinancialData", "[", 
                    RowBox[{"\"\<GE\>\"", ",", "\"\<Name\>\""}], "]"}], ",", 
                   RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], 
                  "]"}], ",", "\"\<GE\>\"", ",", 
                 RowBox[{"FinancialData", "[", 
                  RowBox[{"\"\<GE\>\"", ",", "\"\<Name\>\""}], "]"}]}], "]"}],
                ",", " ", "\"\< for last \>\"", ",", "365", ",", 
               "\"\< days\>\""}], " ", "}"}], "]"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"fChart", ",", 
         RowBox[{"{", 
          RowBox[{
          "CandlestickChart", ",", "KagiChart", ",", "RenkoChart", ",", 
           "LineBreakChart", ",", "PointFigureChart"}], "}"}]}], "}"}]}], 
      "]"}], ",", "2", ",", "2", ",", "1", ",", 
     RowBox[{"{", "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"730", ",", "700"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5838061314880543`*^9, 3.583806196384766*^9}, 
   3.583806313122443*^9, {3.58380634593832*^9, 3.583806363509325*^9}, {
   3.5838064848982677`*^9, 3.5838064920106745`*^9}, {3.583806608773353*^9, 
   3.5838066183078985`*^9}, {3.5838066706608934`*^9, 3.5838067433320494`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comany: Microsoft", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, {
  3.583806852738307*^9, 3.583806881441949*^9}}],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"SameQ", "[", 
          RowBox[{"fChart", ",", "CandlestickChart"}], "]"}], ",", 
         RowBox[{"fChart", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", 
             RowBox[{"DatePlus", "[", 
              RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"fChart", ",", "\"\< of \>\"", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MatchQ", "[", 
                  RowBox[{
                   RowBox[{"FinancialData", "[", 
                    RowBox[{"\"\<MSFT\>\"", ",", "\"\<Name\>\""}], "]"}], ",", 
                   RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], 
                  "]"}], ",", "\"\<MSFT\>\"", ",", 
                 RowBox[{"FinancialData", "[", 
                  RowBox[{"\"\<MSFT\>\"", ",", "\"\<Name\>\""}], "]"}]}], 
                "]"}], ",", " ", "\"\< for last \>\"", ",", "365", ",", 
               "\"\< days\>\""}], " ", "}"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"fChart", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<MSFT\>\"", ",", 
             RowBox[{"DatePlus", "[", 
              RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
           RowBox[{"Switch", "[", 
            RowBox[{
            "fChart", ",", "KagiChart", ",", "0.02", ",", "RenkoChart", ",", 
             "0.1", ",", "LineBreakChart", ",", "3", ",", "PointFigureChart", 
             ",", "0.03", ",", "CandlestickChart", ",", "0.02"}], "]"}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{"fChart", ",", "\"\< of \>\"", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MatchQ", "[", 
                  RowBox[{
                   RowBox[{"FinancialData", "[", 
                    RowBox[{"\"\<MSFT\>\"", ",", "\"\<Name\>\""}], "]"}], ",", 
                   RowBox[{"Missing", "[", "\"\<NotAvailable\>\"", "]"}]}], 
                  "]"}], ",", "\"\<MSFT\>\"", ",", 
                 RowBox[{"FinancialData", "[", 
                  RowBox[{"\"\<MSFT\>\"", ",", "\"\<Name\>\""}], "]"}]}], 
                "]"}], ",", " ", "\"\< for last \>\"", ",", "365", ",", 
               "\"\< days\>\""}], " ", "}"}], "]"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"fChart", ",", 
         RowBox[{"{", 
          RowBox[{
          "CandlestickChart", ",", "KagiChart", ",", "RenkoChart", ",", 
           "LineBreakChart", ",", "PointFigureChart"}], "}"}]}], "}"}]}], 
      "]"}], ",", "2", ",", "2", ",", "1", ",", 
     RowBox[{"{", "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"730", ",", "700"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5838061314880543`*^9, 3.583806196384766*^9}, 
   3.583806313122443*^9, {3.58380634593832*^9, 3.583806363509325*^9}, {
   3.5838064848982677`*^9, 3.5838064920106745`*^9}, {3.583806608773353*^9, 
   3.5838066183078985`*^9}, {3.5838066706608934`*^9, 
   3.5838067433320494`*^9}, {3.5838069097505684`*^9, 3.583806918280056*^9}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example 5: \[Delta] - \[Gamma] Hedges for a list of securities\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}, {3.583805545995566*^9, 
  3.583805546363587*^9}, {3.5838068151691585`*^9, 3.583806822049552*^9}, {
  3.5838069601934533`*^9, 3.583806960626478*^9}, {3.58380760213317*^9, 
  3.583807631092827*^9}, {3.5838116233511705`*^9, 3.583811629062497*^9}}],

Cell["\<\
1)  Added Value: The evaluation of a range of powerful derivative products \
which can be used to replicate the behavior of an underlying stock that we \
wish to hedge against in the market.

2)  Caption: In order to minimize the risk associated with a particular stock \
it is often necessary to hedge against the variability in that stock by \
trying to statically replicate its behavior using a range of derivative \
products. The following table provides graphs and tables which show how \
successfully different options can replicate any given stock.

3)  Why we are better: We are able to combine graphs and tables with the \
computation of complex financial derivatives to show which instruments would \
best be used in an immunised portfolio to hedge against the risky behavior of \
any given stock. Very few other financial programs have such a range of \
capability for both computation and graphics.\
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}, {
   3.5841523050128965`*^9, 3.584152336611704*^9}, {3.5841524176203375`*^9, 
   3.584152584884905*^9}, {3.5841526407420993`*^9, 3.584152706260847*^9}, {
   3.5841527365015764`*^9, 3.584153095111088*^9}}],

Cell[CellGroupData[{

Cell["\<\
Various \[Delta] - \[Gamma] Hedges designed to replicate underlying securities\
\>", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9, 
   3.5838068609627776`*^9, {3.583811423989768*^9, 3.5838114473181024`*^9}, {
   3.5838116356548743`*^9, 3.5838116388550577`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Comany:  \[Delta] - \[Gamma] Hedges for General Electric\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}}],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"price", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<GE\>\"", ",", "\"\<Close\>\""}], "]"}]}], ",", "\n", 
     RowBox[{"div", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<GE\>\"", ",", "\"\<DividendYield\>\""}], "]"}]}], ",", 
     "\n", 
     RowBox[{"vol", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<GE\>\"", ",", "\"\<Volatility50Day\>\""}], "]"}]}]}], 
    "}"}], ",", 
   RowBox[{"Column", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"DeltaGammaHedge", "[", 
       RowBox[{"#", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", 
           RowBox[{"Switch", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"-", "1"}], "]"}], "]"}], ",", "\"\<Put\>\"", ",", 
             RowBox[{"1.1", "*", "price"}], ",", "\"\<Call\>\"", ",", 
             RowBox[{"0.9", "*", "price"}]}], "]"}]}], ",", " ", 
          RowBox[{"\"\<Expiration\>\"", "\[Rule]", "1"}]}], "}"}], ",", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<InterestRate\>\"", "\[Rule]", " ", "0.002"}], ",", 
          RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", " ", "price"}], ",", " ", 
          RowBox[{"\"\<Dividend\>\"", "\[Rule]", "div"}], ",", " ", 
          RowBox[{"\"\<Volatility\>\"", "\[Rule]", "vol"}]}], "}"}]}], "]"}], 
      "&"}], " ", "/@", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Call\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Put\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Put\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Put\>\""}], 
        "}"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4952132473995705`*^9, 3.4952132521652565`*^9}, {
   3.495213350994646*^9, 3.4952133583228655`*^9}, {3.495213543793989*^9, 
   3.4952136202637177`*^9}, {3.495213665498672*^9, 3.495213671217495*^9}, {
   3.4952138342352066`*^9, 3.49521388523586*^9}, {3.495214258316529*^9, 
   3.495214258785261*^9}, {3.4952142910183983`*^9, 3.4952142992055836`*^9}, {
   3.4952144392314568`*^9, 3.4952144771206264`*^9}, {3.495214566712267*^9, 
   3.495214641117564*^9}, {3.4952147925062513`*^9, 3.495214857458545*^9}, 
   3.4952157716963673`*^9, 3.495217663645976*^9, {3.495217869427843*^9, 
   3.4952178964276705`*^9}, {3.495217986192721*^9, 3.4952179896926985`*^9}, {
   3.4952180212862463`*^9, 3.495218065551588*^9}, {3.495218096770138*^9, 
   3.495218188113773*^9}, 3.495218579474202*^9, 3.4952187111469197`*^9, {
   3.495218744162756*^9, 3.4952187494596653`*^9}, {3.4952188203038683`*^9, 
   3.4952188234288883`*^9}, {3.4952188554603434`*^9, 3.495218855882221*^9}, 
   3.4952193374946785`*^9, {3.495219376463678*^9, 3.4952193790886946`*^9}, {
   3.4952200570149083`*^9, 3.4952200623743176`*^9}, {3.495284465908083*^9, 
   3.4952844775800323`*^9}, 3.4952845197053022`*^9, 3.4952845616586957`*^9, {
   3.4952849458174047`*^9, 3.495285022739772*^9}, 3.4952862327631407`*^9, {
   3.495286510280542*^9, 3.4952865144524436`*^9}, {3.4952868488452086`*^9, 
   3.4952868826422997`*^9}, {3.4952869897992353`*^9, 3.49528709048738*^9}, 
   3.495289290188958*^9, {3.5074663423934727`*^9, 3.5074663636966915`*^9}, {
   3.5074664743380194`*^9, 3.5074664747750444`*^9}, {3.507466817002334*^9, 
   3.507466827797553*^9}, {3.5074673499480743`*^9, 3.507467356656086*^9}, {
   3.5206175359046288`*^9, 3.5206175365956974`*^9}, {3.5206177430003357`*^9, 
   3.520617743762412*^9}, {3.520618657824809*^9, 3.52061867133616*^9}, {
   3.520620080156826*^9, 3.520620080416696*^9}, {3.5206205246678495`*^9, 
   3.5206205380078497`*^9}, {3.521404919171875*^9, 3.521404928890625*^9}, 
   3.5214224365625*^9, {3.583807556758575*^9, 3.5838075621658845`*^9}, {
   3.5838078753357964`*^9, 3.583807875783822*^9}, {3.583810013153073*^9, 
   3.5838100155212083`*^9}, {3.583810051865287*^9, 3.583810120946238*^9}, {
   3.583810170594078*^9, 3.5838102168347225`*^9}, {3.583810322754781*^9, 
   3.583810342531912*^9}, {3.583810413027944*^9, 3.5838104695401764`*^9}, {
   3.5838105125326357`*^9, 3.5838105444364605`*^9}, 3.5838106047409096`*^9, {
   3.583810677430067*^9, 3.583810679156166*^9}, {3.583810755253518*^9, 
   3.583810820584255*^9}, 3.583810851176005*^9, {3.58381092189705*^9, 
   3.583811064615213*^9}, {3.5838115190182033`*^9, 3.5838115191772127`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Comany:  \[Delta] - \[Gamma] Hedges for Microsoft\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.5838114878464203`*^9, 3.583811490725585*^9}, {
   3.5838115727742777`*^9, 3.583811587884142*^9}}],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"price", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<MSFT\>\"", ",", "\"\<Close\>\""}], "]"}]}], ",", "\n", 
     RowBox[{"div", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<MSFT\>\"", ",", "\"\<DividendYield\>\""}], "]"}]}], ",", 
     "\n", 
     RowBox[{"vol", "=", 
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<MSFT\>\"", ",", "\"\<Volatility50Day\>\""}], "]"}]}]}], 
    "}"}], ",", 
   RowBox[{"Column", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"DeltaGammaHedge", "[", 
       RowBox[{"#", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", 
           RowBox[{"Switch", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"-", "1"}], "]"}], "]"}], ",", "\"\<Put\>\"", ",", 
             RowBox[{"1.1", "*", "price"}], ",", "\"\<Call\>\"", ",", 
             RowBox[{"0.9", "*", "price"}]}], "]"}]}], ",", " ", 
          RowBox[{"\"\<Expiration\>\"", "\[Rule]", "1"}]}], "}"}], ",", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<InterestRate\>\"", "\[Rule]", " ", "0.002"}], ",", 
          RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", " ", "price"}], ",", " ", 
          RowBox[{"\"\<Dividend\>\"", "\[Rule]", "div"}], ",", " ", 
          RowBox[{"\"\<Volatility\>\"", "\[Rule]", "vol"}]}], "}"}]}], "]"}], 
      "&"}], " ", "/@", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Call\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<American\>\"", ",", "\"\<Put\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Future\>\"", ",", "\"\<European\>\"", ",", "\"\<Put\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Call\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Perpetual\>\"", ",", "\"\<American\>\"", ",", "\"\<Put\>\""}], 
        "}"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4952132473995705`*^9, 3.4952132521652565`*^9}, {
   3.495213350994646*^9, 3.4952133583228655`*^9}, {3.495213543793989*^9, 
   3.4952136202637177`*^9}, {3.495213665498672*^9, 3.495213671217495*^9}, {
   3.4952138342352066`*^9, 3.49521388523586*^9}, {3.495214258316529*^9, 
   3.495214258785261*^9}, {3.4952142910183983`*^9, 3.4952142992055836`*^9}, {
   3.4952144392314568`*^9, 3.4952144771206264`*^9}, {3.495214566712267*^9, 
   3.495214641117564*^9}, {3.4952147925062513`*^9, 3.495214857458545*^9}, 
   3.4952157716963673`*^9, 3.495217663645976*^9, {3.495217869427843*^9, 
   3.4952178964276705`*^9}, {3.495217986192721*^9, 3.4952179896926985`*^9}, {
   3.4952180212862463`*^9, 3.495218065551588*^9}, {3.495218096770138*^9, 
   3.495218188113773*^9}, 3.495218579474202*^9, 3.4952187111469197`*^9, {
   3.495218744162756*^9, 3.4952187494596653`*^9}, {3.4952188203038683`*^9, 
   3.4952188234288883`*^9}, {3.4952188554603434`*^9, 3.495218855882221*^9}, 
   3.4952193374946785`*^9, {3.495219376463678*^9, 3.4952193790886946`*^9}, {
   3.4952200570149083`*^9, 3.4952200623743176`*^9}, {3.495284465908083*^9, 
   3.4952844775800323`*^9}, 3.4952845197053022`*^9, 3.4952845616586957`*^9, {
   3.4952849458174047`*^9, 3.495285022739772*^9}, 3.4952862327631407`*^9, {
   3.495286510280542*^9, 3.4952865144524436`*^9}, {3.4952868488452086`*^9, 
   3.4952868826422997`*^9}, {3.4952869897992353`*^9, 3.49528709048738*^9}, 
   3.495289290188958*^9, {3.5074663423934727`*^9, 3.5074663636966915`*^9}, {
   3.5074664743380194`*^9, 3.5074664747750444`*^9}, {3.507466817002334*^9, 
   3.507466827797553*^9}, {3.5074673499480743`*^9, 3.507467356656086*^9}, {
   3.5206175359046288`*^9, 3.5206175365956974`*^9}, {3.5206177430003357`*^9, 
   3.520617743762412*^9}, {3.520618657824809*^9, 3.52061867133616*^9}, {
   3.520620080156826*^9, 3.520620080416696*^9}, {3.5206205246678495`*^9, 
   3.5206205380078497`*^9}, {3.521404919171875*^9, 3.521404928890625*^9}, 
   3.5214224365625*^9, {3.583807556758575*^9, 3.5838075621658845`*^9}, {
   3.5838078753357964`*^9, 3.583807875783822*^9}, {3.583810013153073*^9, 
   3.5838100155212083`*^9}, {3.583810051865287*^9, 3.583810120946238*^9}, {
   3.583810170594078*^9, 3.5838102168347225`*^9}, {3.583810322754781*^9, 
   3.583810342531912*^9}, {3.583810413027944*^9, 3.5838104695401764`*^9}, {
   3.5838105125326357`*^9, 3.5838105444364605`*^9}, 3.5838106047409096`*^9, {
   3.583810677430067*^9, 3.583810679156166*^9}, {3.583810755253518*^9, 
   3.583810820584255*^9}, 3.583810851176005*^9, {3.58381092189705*^9, 
   3.583811064615213*^9}, {3.5838114982660165`*^9, 3.5838115276416965`*^9}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example 6: Financial Indicators for a list of securities\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}, {3.583805545995566*^9, 
  3.583805546363587*^9}, {3.5838068151691585`*^9, 3.583806822049552*^9}, {
  3.5838069601934533`*^9, 3.583806960626478*^9}, {3.58380760213317*^9, 
  3.583807631092827*^9}, {3.5838116233511705`*^9, 3.583811629062497*^9}, {
  3.5838116638304863`*^9, 3.58381166424651*^9}, {3.583812316825835*^9, 
  3.583812321610109*^9}}],

Cell["\<\
1)  Added Value: A graphics grid of a range of popular financial indicators \
allows one to see if there is any hidden pattern in the prices of a stock \
which can become the basis of a trading strategy.

2)  Caption: Trading stocks is a matter of elucidating some hidden pattern in \
the stock prices and indicators are the tools that are used for this purpose. \
If many of the popular indicators are arranged in a grid then it becomes \
possible to spot price patterns that would not have been apparent otherwise. \
In this way we can compare at a glance a range of different indicators for \
any given stock.

3)  Why we are better: We have over 100 different financial indicators with a \
full choice of structure parameters that make it more likely than other \
programs that one can find an optimal trading strategy. \
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}, {
   3.5841523050128965`*^9, 3.584152336611704*^9}, {3.5841524176203375`*^9, 
   3.584152584884905*^9}, {3.5841526407420993`*^9, 3.584152706260847*^9}, {
   3.5841527365015764`*^9, 3.584153095111088*^9}, {3.584153167688239*^9, 
   3.5841531828071036`*^9}, {3.5841532221193523`*^9, 3.584153542408672*^9}}],

Cell[CellGroupData[{

Cell["\<\
Financial Indicators for a range of securities\
\>", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9, 
   3.5838068609627776`*^9, {3.583811423989768*^9, 3.5838114473181024`*^9}, {
   3.5838116356548743`*^9, 3.5838116388550577`*^9}, {3.5838123767312613`*^9, 
   3.5838123817065463`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Comany: Financial Indicators for General Electric\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}, {
   3.583812331977702*^9, 3.5838123364259567`*^9}}],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"indic", ",", "par1", ",", "par2", ",", "par3", ",", "par4"}], 
    "}"}], ",", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"indic", "=", 
          RowBox[{"FinancialIndicator", "[", "indicator", "]"}]}], ";", 
         RowBox[{"par1", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "1"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par2", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "2"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par3", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "3"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "4", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par4", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "4"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "5", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"Quiet", "[", 
          RowBox[{"TradingChart", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<GE\>\"", ",", 
              RowBox[{"DatePlus", "[", 
               RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"FinancialIndicator", "[", 
              RowBox[{
              "indicator", ",", "par1", ",", "par2", ",", "par3", ",", 
               "par4"}], "]"}], "}"}], ",", 
            RowBox[{"PlotLabel", "\[Rule]", 
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{
               "\"\<Last \>\"", ",", "365", ",", " ", "\"\< days of \>\"", 
                ",", "\"\<GE\>\"", ",", "\"\< with \>\"", ",", "indicator", 
                ",", "\"\<(\>\"", ",", "par1", ",", "\"\<,\>\"", ",", "par2", 
                ",", "\"\<,\>\"", ",", "par3", ",", "\"\<,\>\"", ",", "par4", 
                ",", "\"\<)\>\""}], "}"}], "]"}]}], ",", 
            RowBox[{"ImageSize", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"450", ",", "310"}], "}"}]}]}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"indicator", ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<AverageTrueRange\>\"", ",", "\"\<FastStochastic\>\"", ",", 
            " ", "\"\<FullStochastic\>\"", ",", 
            "\"\<ParabolicStopAndReversal\>\"", ",", 
            "\"\<PolarizedFractalEfficiency\>\"", ",", 
            "\"\<RelativeStrengthIndex\>\"", ",", "\"\<TRIX\>\"", ",", 
            "\"\<WilliamsPercentR\>\""}], "}"}]}], "}"}]}], "]"}], ",", "2"}],
      "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.583811787947585*^9, {3.5838119623005576`*^9, 3.583812031980543*^9}, {
   3.583812156077641*^9, 3.583812211852831*^9}, {3.5838124507184935`*^9, 
   3.58381256150383*^9}, {3.583812608815536*^9, 3.5838126437915363`*^9}, {
   3.5838126817437077`*^9, 3.583812712720479*^9}, {3.583812927170745*^9, 
   3.5838129379693623`*^9}, {3.583813333539988*^9, 3.5838133966595984`*^9}, {
   3.5838134480685387`*^9, 3.583813448403558*^9}, {3.5838137582942824`*^9, 
   3.583813769668933*^9}, {3.583813999222063*^9, 3.5838139995740833`*^9}, {
   3.5838140562623253`*^9, 3.5838140665499134`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Comany: Financial Indicators for Micrososft\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}, {
   3.583812331977702*^9, 3.5838123364259567`*^9}, {3.5838140918583612`*^9, 
   3.5838140950095415`*^9}}],

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"indic", ",", "par1", ",", "par2", ",", "par3", ",", "par4"}], 
    "}"}], ",", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"indic", "=", 
          RowBox[{"FinancialIndicator", "[", "indicator", "]"}]}], ";", 
         RowBox[{"par1", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "1"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par2", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "2"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par3", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "3"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "4", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"par4", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "indic", "]"}], ">", "4"}], ",", 
            RowBox[{"indic", "[", 
             RowBox[{"[", "5", "]"}], "]"}], ",", 
            RowBox[{"Sequence", "[", "]"}]}], "]"}]}], ";", 
         RowBox[{"Quiet", "[", 
          RowBox[{"TradingChart", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<MSFT\>\"", ",", 
              RowBox[{"DatePlus", "[", 
               RowBox[{"-", "365"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"FinancialIndicator", "[", 
              RowBox[{
              "indicator", ",", "par1", ",", "par2", ",", "par3", ",", 
               "par4"}], "]"}], "}"}], ",", 
            RowBox[{"PlotLabel", "\[Rule]", 
             RowBox[{"Row", "[", 
              RowBox[{"{", 
               RowBox[{
               "\"\<Last \>\"", ",", "365", ",", " ", "\"\< days of \>\"", 
                ",", "\"\<MSFT\>\"", ",", "\"\< with \>\"", ",", "indicator", 
                ",", "\"\<(\>\"", ",", "par1", ",", "\"\<,\>\"", ",", "par2", 
                ",", "\"\<,\>\"", ",", "par3", ",", "\"\<,\>\"", ",", "par4", 
                ",", "\"\<)\>\""}], "}"}], "]"}]}], ",", 
            RowBox[{"ImageSize", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"450", ",", "310"}], "}"}]}]}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"indicator", ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<AverageTrueRange\>\"", ",", "\"\<FastStochastic\>\"", ",", 
            " ", "\"\<FullStochastic\>\"", ",", 
            "\"\<ParabolicStopAndReversal\>\"", ",", 
            "\"\<PolarizedFractalEfficiency\>\"", ",", 
            "\"\<RelativeStrengthIndex\>\"", ",", "\"\<TRIX\>\"", ",", 
            "\"\<WilliamsPercentR\>\""}], "}"}]}], "}"}]}], "]"}], ",", "2"}],
      "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.583811787947585*^9, {3.5838119623005576`*^9, 3.583812031980543*^9}, {
   3.583812156077641*^9, 3.583812211852831*^9}, {3.5838124507184935`*^9, 
   3.58381256150383*^9}, {3.583812608815536*^9, 3.5838126437915363`*^9}, {
   3.5838126817437077`*^9, 3.583812712720479*^9}, {3.583812927170745*^9, 
   3.5838129379693623`*^9}, {3.583813333539988*^9, 3.5838133966595984`*^9}, {
   3.5838134480685387`*^9, 3.583813448403558*^9}, {3.5838137582942824`*^9, 
   3.583813769668933*^9}, {3.583813999222063*^9, 3.5838139995740833`*^9}, {
   3.5838140562623253`*^9, 3.5838140665499134`*^9}, {3.5838141056541505`*^9, 
   3.5838141123575335`*^9}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example 7: Backtesting for a list of securities\
\>", "Section",
 CellChangeTimes->{{3.583783750971962*^9, 3.583783770236064*^9}, {
  3.583804471095085*^9, 3.583804471399102*^9}, {3.5838045297194386`*^9, 
  3.5838045314475374`*^9}, {3.5838049388248377`*^9, 3.5838049392088594`*^9}, {
  3.583805225786251*^9, 3.583805237241906*^9}, {3.583805545995566*^9, 
  3.583805546363587*^9}, {3.5838068151691585`*^9, 3.583806822049552*^9}, {
  3.5838069601934533`*^9, 3.583806960626478*^9}, {3.58380760213317*^9, 
  3.583807631092827*^9}, {3.5838116233511705`*^9, 3.583811629062497*^9}, {
  3.5838116638304863`*^9, 3.58381166424651*^9}, {3.583812316825835*^9, 
  3.583812321610109*^9}, {3.583814247426259*^9, 3.583814247922288*^9}, {
  3.583814653316475*^9, 3.583814656595662*^9}}],

Cell["\<\
1)  Added Value: Backtesting methods associated with two financial indicators \
for trading assets, which allow one to investigate the profitability of \
trading based upon recognizing price patterns as revealed by indicators.

2)  Caption: Once a trader has identified a particular financial indicator as \
the one most likely to determine optimal buy/sell points then it is necessary \
to use backtesting of that strategy with prior historical data to see whether \
the strategy will be successful. Here we indicate two backtesting methods \
based upon the financial indicators Linear Regression Slope and Moving \
Average Convergence Divergence.

3)  Why we are better: We are not in fact better at this than many other \
trading programs but it is considered so essential by traders that we need to \
show that this is something we can do, otherwise no trader will buy the \
program. \
\>", "Text",
 CellChangeTimes->{{3.583847294834941*^9, 3.5838473187703104`*^9}, {
   3.58387478827353*^9, 3.583875241094164*^9}, 3.584147592703368*^9, {
   3.5841476272313433`*^9, 3.5841476552309446`*^9}, {3.5841504467156086`*^9, 
   3.584150642123785*^9}, {3.584150684956235*^9, 3.5841508287814612`*^9}, {
   3.584150864765519*^9, 3.584150876909214*^9}, {3.5841509175655394`*^9, 
   3.5841509641262026`*^9}, {3.584150996734068*^9, 3.5841510954227123`*^9}, {
   3.584151151262906*^9, 3.584151226975237*^9}, {3.5841513141752243`*^9, 
   3.58415140833561*^9}, {3.5841514588634996`*^9, 3.5841515637765007`*^9}, {
   3.5841516346565547`*^9, 3.5841516818412533`*^9}, {3.584151987202719*^9, 
   3.5841520092659807`*^9}, {3.584152061682979*^9, 3.5841521905633507`*^9}, {
   3.5841523050128965`*^9, 3.584152336611704*^9}, {3.5841524176203375`*^9, 
   3.584152584884905*^9}, {3.5841526407420993`*^9, 3.584152706260847*^9}, {
   3.5841527365015764`*^9, 3.584153095111088*^9}, {3.584153167688239*^9, 
   3.5841531828071036`*^9}, {3.5841532221193523`*^9, 
   3.5841535705692825`*^9}, {3.584153700921738*^9, 3.584153727577263*^9}, {
   3.5841537587780476`*^9, 3.5841541514035044`*^9}, {3.5841541882036095`*^9, 
   3.5841542615158024`*^9}, {3.5841547896620107`*^9, 3.5841547902060413`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Backtesting for a range of securities\
\>", "Subsection",
 CellChangeTimes->{{3.5838047519931517`*^9, 3.5838047868081427`*^9}, {
   3.5838053417868857`*^9, 3.583805349706339*^9}, 3.583805474491476*^9, 
   3.5838068609627776`*^9, {3.583811423989768*^9, 3.5838114473181024`*^9}, {
   3.5838116356548743`*^9, 3.5838116388550577`*^9}, {3.5838123767312613`*^9, 
   3.5838123817065463`*^9}, 3.583814671445512*^9}],

Cell[CellGroupData[{

Cell["\<\
Linear Regression Slope and Moving Average Convergence Divergence Backtesting \
for General Electric\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}, {
   3.583812331977702*^9, 3.5838123364259567`*^9}, 3.583814675412739*^9, {
   3.5838147288857975`*^9, 3.583814742085552*^9}, {3.5838148195889854`*^9, 
   3.5838148260533547`*^9}, {3.583815801913171*^9, 3.5838158031612425`*^9}}],

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{"Charting`BackTesting", "[", 
         RowBox[{
          RowBox[{"FinancialData", "[", 
           RowBox[{"\"\<GE\>\"", ",", "\"\<OHLCV\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"2012", ",", "1"}], "}"}], ",", 
              RowBox[{"Date", "[", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "\"\<LRS\>\"", ",", 
          RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", "21"}], ",", " ", 
          RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
          RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
          RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "10000"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{
       "\"\<Linear Regression Slope Backtesting for \>\"", "<>", 
        "\"\<GE\>\""}], ",", "Top"}], "]"}], ",", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{"Charting`BackTesting", "[", 
         RowBox[{
          RowBox[{"FinancialData", "[", 
           RowBox[{"\"\<GE\>\"", ",", "\"\<OHLCV\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"2011", ",", "1"}], "}"}], ",", 
              RowBox[{"Date", "[", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "\"\<MACD\>\"", ",", 
          RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"13", ",", "33", ",", "10"}], "}"}]}], ",", " ", 
          RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
          RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
          RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "10000"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{
       "\"\<Moving Average Convergence Divergence Backtesting for \>\"", 
        "<>", "\"\<GE\>\""}], ",", "Top"}], "]"}]}], "}"}], ",", " ", 
   "\"\<   \>\"", ",", 
   RowBox[{"Alignment", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Center", ",", "Top"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4996270095708523`*^9, 3.4996270290401287`*^9}, {
   3.49962782853901*^9, 3.4996278352799664`*^9}, {3.499627894766952*^9, 
   3.499627907869459*^9}, {3.49962875540844*^9, 3.499628769476714*^9}, {
   3.5354677790942416`*^9, 3.535467806502982*^9}, {3.5354818876640234`*^9, 
   3.535481888512108*^9}, {3.5354819243206887`*^9, 3.5354819848817444`*^9}, {
   3.535482056405896*^9, 3.5354820666619215`*^9}, {3.53548209765602*^9, 
   3.5354821010953646`*^9}, {3.5354822512783813`*^9, 3.535482271950448*^9}, {
   3.535483594918644*^9, 3.535483658123644*^9}, {3.5355539399426875`*^9, 
   3.5355539454452376`*^9}, {3.5355568164010196`*^9, 
   3.5355568222570195`*^9}, {3.5355568528310194`*^9, 3.5355568583990197`*^9}, 
   3.53555717972602*^9, {3.5838148674477224`*^9, 3.583814931511387*^9}, {
   3.583814964695285*^9, 3.5838150212075167`*^9}, {3.583815060519766*^9, 
   3.5838150832160635`*^9}, {3.5838151133687887`*^9, 3.583815144503569*^9}, {
   3.583815344937033*^9, 3.5838153920747294`*^9}, {3.583815588266951*^9, 
   3.5838155945233088`*^9}, {3.5838156973551903`*^9, 
   3.5838157145941763`*^9}, {3.583815774204586*^9, 3.5838157756296673`*^9}, {
   3.5838159183488307`*^9, 3.5838159361088467`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Linear Regression Slope and Moving Average Convergence Divergence Backtesting \
for Microsoft\
\>", "Subsubsection",
 CellChangeTimes->{{3.5838054089557276`*^9, 3.58380541143487*^9}, 
   3.583806852738307*^9, {3.583811564487804*^9, 3.5838115670789523`*^9}, {
   3.583812331977702*^9, 3.5838123364259567`*^9}, 3.583814675412739*^9, {
   3.5838147288857975`*^9, 3.583814742085552*^9}, {3.5838148195889854`*^9, 
   3.5838148260533547`*^9}, {3.583815801913171*^9, 3.5838158031612425`*^9}, {
   3.583815868489979*^9, 3.583815872201191*^9}}],

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{"Charting`BackTesting", "[", 
         RowBox[{
          RowBox[{"FinancialData", "[", 
           RowBox[{"\"\<MSFT\>\"", ",", "\"\<OHLCV\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"2012", ",", "1"}], "}"}], ",", 
              RowBox[{"Date", "[", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "\"\<LRS\>\"", ",", 
          RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", "21"}], ",", " ", 
          RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
          RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
          RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "10000"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{
       "\"\<Linear Regression Slope Backtesting for \>\"", "<>", 
        "\"\<MSFT\>\""}], ",", "Top"}], "]"}], ",", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{"Charting`BackTesting", "[", 
         RowBox[{
          RowBox[{"FinancialData", "[", 
           RowBox[{"\"\<MSFT\>\"", ",", "\"\<OHLCV\>\"", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"2010", ",", "1"}], "}"}], ",", 
              RowBox[{"Date", "[", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "\"\<MACD\>\"", ",", 
          RowBox[{"\"\<AveragePeriod\>\"", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"13", ",", "33", ",", "10"}], "}"}]}], ",", " ", 
          RowBox[{"Method", "\[Rule]", "\"\<Report\>\""}], ",", 
          RowBox[{"\"\<TransactionCost\>\"", "\[Rule]", "3.5"}], ",", " ", 
          RowBox[{"\"\<InitialInvestment\>\"", "\[Rule]", "10000"}]}], "]"}], 
        "]"}], ",", 
       RowBox[{
       "\"\<Moving Average Convergence Divergence Backtesting for \>\"", 
        "<>", "\"\<MSFT\>\""}], ",", "Top"}], "]"}]}], "}"}], ",", " ", 
   "\"\<   \>\"", ",", 
   RowBox[{"Alignment", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Center", ",", "Top"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4996270095708523`*^9, 3.4996270290401287`*^9}, {
   3.49962782853901*^9, 3.4996278352799664`*^9}, {3.499627894766952*^9, 
   3.499627907869459*^9}, {3.49962875540844*^9, 3.499628769476714*^9}, {
   3.5354677790942416`*^9, 3.535467806502982*^9}, {3.5354818876640234`*^9, 
   3.535481888512108*^9}, {3.5354819243206887`*^9, 3.5354819848817444`*^9}, {
   3.535482056405896*^9, 3.5354820666619215`*^9}, {3.53548209765602*^9, 
   3.5354821010953646`*^9}, {3.5354822512783813`*^9, 3.535482271950448*^9}, {
   3.535483594918644*^9, 3.535483658123644*^9}, {3.5355539399426875`*^9, 
   3.5355539454452376`*^9}, {3.5355568164010196`*^9, 
   3.5355568222570195`*^9}, {3.5355568528310194`*^9, 3.5355568583990197`*^9}, 
   3.53555717972602*^9, {3.5838148674477224`*^9, 3.583814931511387*^9}, {
   3.583814964695285*^9, 3.5838150212075167`*^9}, {3.583815060519766*^9, 
   3.5838150832160635`*^9}, {3.5838151133687887`*^9, 3.583815144503569*^9}, {
   3.583815344937033*^9, 3.5838153920747294`*^9}, {3.583815588266951*^9, 
   3.5838155945233088`*^9}, {3.5838156973551903`*^9, 
   3.5838157145941763`*^9}, {3.583815774204586*^9, 3.5838157756296673`*^9}, {
   3.5838158453886576`*^9, 3.583815861116557*^9}, {3.583815891885317*^9, 
   3.58381590137286*^9}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1288, 916},
WindowMargins->{{24, Automatic}, {5, Automatic}},
Magnification:>1.25 Inherited,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (May 20, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 111, 1, 113, "Title"],
Cell[CellGroupData[{
Cell[715, 27, 32, 0, 98, "Section"],
Cell[750, 29, 119, 3, 36, "Input",
 InitializationCell->True],
Cell[872, 34, 101, 2, 36, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[1010, 41, 88, 1, 60, "Section"],
Cell[1101, 44, 230, 7, 36, "Input",
 InitializationCell->True],
Cell[1334, 53, 831, 16, 106, "Input",
 InitializationCell->True],
Cell[2168, 71, 416, 9, 60, "Input",
 InitializationCell->True],
Cell[2587, 82, 244, 7, 36, "Input",
 InitializationCell->True],
Cell[2834, 91, 306, 8, 36, "Input",
 InitializationCell->True],
Cell[3143, 101, 468, 11, 60, "Input",
 InitializationCell->True],
Cell[3614, 114, 311, 8, 36, "Input",
 InitializationCell->True],
Cell[3928, 124, 110, 2, 36, "Input",
 InitializationCell->True],
Cell[4041, 128, 531, 12, 60, "Input",
 InitializationCell->True],
Cell[4575, 142, 5660, 126, 418, "Input",
 InitializationCell->True],
Cell[10238, 270, 707, 21, 60, "Input",
 InitializationCell->True],
Cell[10948, 293, 4651, 121, 244, "Input",
 InitializationCell->True],
Cell[15602, 416, 3173, 85, 244, "Input",
 InitializationCell->True],
Cell[18778, 503, 6955, 188, 451, "Input",
 InitializationCell->True],
Cell[25736, 693, 13309, 311, 888, "Input",
 InitializationCell->True],
Cell[39048, 1006, 1509, 33, 83, "Input",
 InitializationCell->True],
Cell[40560, 1041, 1337, 28, 83, "Input",
 InitializationCell->True],
Cell[41900, 1071, 1373, 28, 83, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[43310, 1104, 136, 2, 60, "Section"],
Cell[43449, 1108, 857, 17, 60, "Input",
 InitializationCell->True],
Cell[44309, 1127, 885, 16, 83, "Input",
 InitializationCell->True],
Cell[45197, 1145, 920, 17, 83, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[46154, 1167, 144, 2, 60, "Section"],
Cell[46301, 1171, 475, 8, 38, "Text"],
Cell[46779, 1181, 301, 11, 187, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47117, 1197, 124, 3, 98, "Section"],
Cell[CellGroupData[{
Cell[47266, 1204, 157, 2, 46, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[47426, 1208, 1161, 19, 106, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[48602, 1230, 838, 15, 220, "Text"],
Cell[CellGroupData[{
Cell[49465, 1249, 167, 2, 66, "Subsection"],
Cell[CellGroupData[{
Cell[49657, 1255, 101, 1, 52, "Subsubsection"],
Cell[49761, 1258, 894, 20, 112, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[50692, 1283, 101, 1, 52, "Subsubsection"],
Cell[50796, 1286, 2788, 65, 300, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[53633, 1357, 162, 2, 66, "Subsection"],
Cell[CellGroupData[{
Cell[53820, 1363, 101, 1, 52, "Subsubsection"],
Cell[53924, 1366, 975, 21, 112, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[54936, 1392, 101, 1, 52, "Subsubsection"],
Cell[55040, 1395, 2857, 66, 300, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[57958, 1468, 215, 3, 60, "Section"],
Cell[58176, 1473, 1246, 21, 253, "Text"],
Cell[CellGroupData[{
Cell[59447, 1498, 169, 3, 66, "Subsection"],
Cell[CellGroupData[{
Cell[59641, 1505, 114, 1, 52, "Subsubsection"],
Cell[59758, 1508, 678, 16, 81, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60473, 1529, 248, 5, 52, "Subsubsection"],
Cell[60724, 1536, 496, 10, 47, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[61281, 1553, 344, 6, 60, "Section"],
Cell[61628, 1561, 1532, 25, 283, "Text"],
Cell[CellGroupData[{
Cell[63185, 1590, 190, 2, 66, "Subsection"],
Cell[63378, 1594, 291, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[63694, 1603, 103, 1, 52, "Subsubsection"],
Cell[63800, 1606, 169, 3, 47, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64006, 1614, 106, 1, 52, "Subsubsection"],
Cell[64115, 1617, 523, 11, 47, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[64687, 1634, 213, 3, 66, "Subsection"],
Cell[CellGroupData[{
Cell[64925, 1641, 103, 1, 52, "Subsubsection"],
Cell[65031, 1644, 222, 4, 47, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65290, 1653, 106, 1, 52, "Subsubsection"],
Cell[65399, 1656, 574, 12, 47, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[66034, 1675, 441, 7, 60, "Section"],
Cell[66478, 1684, 1462, 24, 253, "Text"],
Cell[CellGroupData[{
Cell[67965, 1712, 222, 3, 66, "Subsection"],
Cell[CellGroupData[{
Cell[68212, 1719, 142, 2, 52, "Subsubsection"],
Cell[68357, 1723, 3375, 74, 456, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71769, 1802, 158, 2, 52, "Subsubsection"],
Cell[71930, 1806, 3445, 75, 456, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[75436, 1888, 600, 9, 60, "Section"],
Cell[76039, 1899, 1888, 29, 313, "Text"],
Cell[CellGroupData[{
Cell[77952, 1932, 382, 6, 66, "Subsection"],
Cell[CellGroupData[{
Cell[78359, 1942, 230, 4, 52, "Subsubsection"],
Cell[78592, 1948, 4945, 95, 268, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83574, 2048, 275, 5, 52, "Subsubsection"],
Cell[83852, 2055, 4951, 95, 268, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[88864, 2157, 693, 11, 60, "Section"],
Cell[89560, 2170, 1902, 29, 283, "Text"],
Cell[CellGroupData[{
Cell[91487, 2203, 404, 7, 66, "Subsection"],
Cell[CellGroupData[{
Cell[91916, 2214, 275, 5, 52, "Subsubsection"],
Cell[92194, 2221, 3928, 89, 393, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96159, 2315, 323, 6, 52, "Subsubsection"],
Cell[96485, 2323, 3986, 90, 393, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[100532, 2420, 779, 12, 60, "Section"],
Cell[101314, 2434, 2176, 33, 283, "Text"],
Cell[CellGroupData[{
Cell[103515, 2471, 417, 7, 66, "Subsection"],
Cell[CellGroupData[{
Cell[103957, 2482, 502, 8, 88, "Subsubsection"],
Cell[104462, 2492, 3383, 69, 268, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107882, 2566, 545, 9, 52, "Subsubsection"],
Cell[108430, 2577, 3438, 70, 268, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
